Class: Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionPromptInputs
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionPromptInputs
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
"Direct" prompting for Experimental Video Generation. These will be sent directly to the LDM without being rewritten.
Instance Attribute Summary collapse
-
#audio_prompt ⇒ String
Description of audio content in the video, without speech.
-
#negative_audio_prompt ⇒ String
Negative description of audio content in the video.
-
#negative_prompt ⇒ String
Single negative prompt for what not to generate.
-
#prompt_chunks ⇒ Array<String>
2s, 256 tokens per chunk, 4 total chunks.
-
#transcript ⇒ String
Spoken transcript of the video for characters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiLargeModelsVisionPromptInputs
constructor
A new instance of CloudAiLargeModelsVisionPromptInputs.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiLargeModelsVisionPromptInputs
Returns a new instance of CloudAiLargeModelsVisionPromptInputs.
620 621 622 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 620 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_prompt ⇒ String
Description of audio content in the video, without speech.
Corresponds to the JSON property audioPrompt
598 599 600 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 598 def audio_prompt @audio_prompt end |
#negative_audio_prompt ⇒ String
Negative description of audio content in the video.
Corresponds to the JSON property negativeAudioPrompt
603 604 605 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 603 def negative_audio_prompt @negative_audio_prompt end |
#negative_prompt ⇒ String
Single negative prompt for what not to generate.
Corresponds to the JSON property negativePrompt
608 609 610 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 608 def negative_prompt @negative_prompt end |
#prompt_chunks ⇒ Array<String>
2s, 256 tokens per chunk, 4 total chunks. Required.
Corresponds to the JSON property promptChunks
613 614 615 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 613 def prompt_chunks @prompt_chunks end |
#transcript ⇒ String
Spoken transcript of the video for characters.
Corresponds to the JSON property transcript
618 619 620 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 618 def transcript @transcript end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
625 626 627 628 629 630 631 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 625 def update!(**args) @audio_prompt = args[:audio_prompt] if args.key?(:audio_prompt) @negative_audio_prompt = args[:negative_audio_prompt] if args.key?(:negative_audio_prompt) @negative_prompt = args[:negative_prompt] if args.key?(:negative_prompt) @prompt_chunks = args[:prompt_chunks] if args.key?(:prompt_chunks) @transcript = args[:transcript] if args.key?(:transcript) end |