Class: Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionRaiInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Next ID: 6

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiLargeModelsVisionRaiInfo

Returns a new instance of CloudAiLargeModelsVisionRaiInfo.



608
609
610
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 608

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocked_entitiesArray<String>

List of blocked entities from the blocklist if it is detected. Corresponds to the JSON property blockedEntities

Returns:

  • (Array<String>)


583
584
585
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 583

def blocked_entities
  @blocked_entities
end

#detected_labelsArray<Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionRaiInfoDetectedLabels>

The list of detected labels for different rai categories. Corresponds to the JSON property detectedLabels



588
589
590
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 588

def detected_labels
  @detected_labels
end

#model_nameString

The model name used to indexing into the RaiFilterConfig map. Would either be one of imagegeneration@002-006, imagen-3.0-... api endpoint names, or internal names used for mapping to different filter configs (genselfie, ai_watermark) than its api endpoint. Corresponds to the JSON property modelName

Returns:

  • (String)


596
597
598
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 596

def model_name
  @model_name
end

#rai_categoriesArray<String>

List of rai categories' information to return Corresponds to the JSON property raiCategories

Returns:

  • (Array<String>)


601
602
603
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 601

def rai_categories
  @rai_categories
end

#scoresArray<Float>

List of rai scores mapping to the rai categories. Rounded to 1 decimal place. Corresponds to the JSON property scores

Returns:

  • (Array<Float>)


606
607
608
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 606

def scores
  @scores
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



613
614
615
616
617
618
619
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 613

def update!(**args)
  @blocked_entities = args[:blocked_entities] if args.key?(:blocked_entities)
  @detected_labels = args[:detected_labels] if args.key?(:detected_labels)
  @model_name = args[:model_name] if args.key?(:model_name)
  @rai_categories = args[:rai_categories] if args.key?(:rai_categories)
  @scores = args[:scores] if args.key?(:scores)
end