Class: Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionSeamless

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiLargeModelsVisionSeamless

Returns a new instance of CloudAiLargeModelsVisionSeamless.



1062
1063
1064
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#loopBoolean Also known as: loop?

If true, the generated video will be loopable (seamless time looping). Corresponds to the JSON property loop

Returns:

  • (Boolean)


1046
1047
1048
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1046

def loop
  @loop
end

#tessellate_horizontalBoolean Also known as: tessellate_horizontal?

If true, the generated video will be tessellatable as a horizontal tessellation. Corresponds to the JSON property tessellateHorizontal

Returns:

  • (Boolean)


1053
1054
1055
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1053

def tessellate_horizontal
  @tessellate_horizontal
end

#tessellate_verticalBoolean Also known as: tessellate_vertical?

If true, the generated video will be tessellatable as a vertical tessellation. Corresponds to the JSON property tessellateVertical

Returns:

  • (Boolean)


1059
1060
1061
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1059

def tessellate_vertical
  @tessellate_vertical
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1067
1068
1069
1070
1071
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1067

def update!(**args)
  @loop = args[:loop] if args.key?(:loop)
  @tessellate_horizontal = args[:tessellate_horizontal] if args.key?(:tessellate_horizontal)
  @tessellate_vertical = args[:tessellate_vertical] if args.key?(:tessellate_vertical)
end