Class: Google::Apis::AiplatformV1beta1::CloudAiPlatformCommonCreatePipelineJobApiErrorDetail
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::CloudAiPlatformCommonCreatePipelineJobApiErrorDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Create API error message for Vertex Pipeline.
Instance Attribute Summary collapse
-
#error_cause ⇒ String
The error root cause returned by CreatePipelineJob API.
-
#public_message ⇒ String
Public messages contains actionable items for the error cause.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiPlatformCommonCreatePipelineJobApiErrorDetail
constructor
A new instance of CloudAiPlatformCommonCreatePipelineJobApiErrorDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiPlatformCommonCreatePipelineJobApiErrorDetail
Returns a new instance of CloudAiPlatformCommonCreatePipelineJobApiErrorDetail.
852 853 854 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 852 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_cause ⇒ String
The error root cause returned by CreatePipelineJob API.
Corresponds to the JSON property errorCause
845 846 847 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 845 def error_cause @error_cause end |
#public_message ⇒ String
Public messages contains actionable items for the error cause.
Corresponds to the JSON property publicMessage
850 851 852 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 850 def @public_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
857 858 859 860 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 857 def update!(**args) @error_cause = args[:error_cause] if args.key?(:error_cause) @public_message = args[:public_message] if args.key?(:public_message) end |