Class: Google::Apis::AiplatformV1beta1::GenaiField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a single field in a struct.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiField

Returns a new instance of GenaiField.



880
881
882
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 880

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Corresponds to the JSON property name

Returns:

  • (String)


870
871
872
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 870

def name
  @name
end

#valueGoogle::Apis::AiplatformV1beta1::GenaiValue

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error. Corresponds to the JSON property value



878
879
880
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 878

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



885
886
887
888
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 885

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end