Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigSessionConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigSessionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The configuration of CodeMender sessions.
Instance Attribute Summary collapse
-
#max_rounds ⇒ Fixnum
The maximum number of interaction rounds the agent is allowed to perform before reaching a timeout.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1CodeMenderAgentConfigSessionConfig
constructor
A new instance of GenaiVertexV1beta1CodeMenderAgentConfigSessionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1CodeMenderAgentConfigSessionConfig
Returns a new instance of GenaiVertexV1beta1CodeMenderAgentConfigSessionConfig.
1560 1561 1562 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1560 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_rounds ⇒ Fixnum
The maximum number of interaction rounds the agent is allowed to perform
before reaching a timeout.
Corresponds to the JSON property max_rounds
1558 1559 1560 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1558 def max_rounds @max_rounds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1565 1566 1567 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1565 def update!(**args) @max_rounds = args[:max_rounds] if args.key?(:max_rounds) end |