Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ComputerUse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool that can be used by the model to interact with the computer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1ComputerUse

Returns a new instance of GenaiVertexV1beta1ComputerUse.



1812
1813
1814
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1812

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disabled_safety_policiesArray<String>

Optional. Disabled safety policies for computer use. Corresponds to the JSON property disabledSafetyPolicies

Returns:

  • (Array<String>)


1794
1795
1796
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1794

def disabled_safety_policies
  @disabled_safety_policies
end

#enable_prompt_injection_detectionBoolean Also known as: enable_prompt_injection_detection?

Whether enable the prompt injection detection check on computer-use request. Corresponds to the JSON property enablePromptInjectionDetection

Returns:

  • (Boolean)


1799
1800
1801
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1799

def enable_prompt_injection_detection
  @enable_prompt_injection_detection
end

#environmentString

The environment being operated. Corresponds to the JSON property environment

Returns:

  • (String)


1805
1806
1807
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1805

def environment
  @environment
end

#excluded_predefined_functionsArray<String>

The list of predefined functions that are excluded from the model call. Corresponds to the JSON property excludedPredefinedFunctions

Returns:

  • (Array<String>)


1810
1811
1812
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1810

def excluded_predefined_functions
  @excluded_predefined_functions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1817
1818
1819
1820
1821
1822
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1817

def update!(**args)
  @disabled_safety_policies = args[:disabled_safety_policies] if args.key?(:disabled_safety_policies)
  @enable_prompt_injection_detection = args[:enable_prompt_injection_detection] if args.key?(:enable_prompt_injection_detection)
  @environment = args[:environment] if args.key?(:environment)
  @excluded_predefined_functions = args[:excluded_predefined_functions] if args.key?(:excluded_predefined_functions)
end