Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CreateInteractionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration parameters for creating an interaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1CreateInteractionRequest

Returns a new instance of GenaiVertexV1beta1CreateInteractionRequest.



2074
2075
2076
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backgroundBoolean Also known as: background?

Input only. Whether to run the model interaction in the background. Corresponds to the JSON property background

Returns:

  • (Boolean)


2054
2055
2056
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2054

def background
  @background
end

#interactionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Interaction

Response for InteractionService.CreateInteraction. Corresponds to the JSON property interaction



2060
2061
2062
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2060

def interaction
  @interaction
end

#storeBoolean Also known as: store?

Input only. Whether to store the response and request for later retrieval. Corresponds to the JSON property store

Returns:

  • (Boolean)


2065
2066
2067
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2065

def store
  @store
end

#streamBoolean Also known as: stream?

Input only. Whether the interaction will be streamed. Corresponds to the JSON property stream

Returns:

  • (Boolean)


2071
2072
2073
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2071

def stream
  @stream
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2079
2080
2081
2082
2083
2084
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2079

def update!(**args)
  @background = args[:background] if args.key?(:background)
  @interaction = args[:interaction] if args.key?(:interaction)
  @store = args[:store] if args.key?(:store)
  @stream = args[:stream] if args.key?(:stream)
end