Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1DeepResearchAgentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for the Deep Research agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1DeepResearchAgentConfig

Returns a new instance of GenaiVertexV1beta1DeepResearchAgentConfig.



2115
2116
2117
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collaborative_planningBoolean Also known as: collaborative_planning?

Enables human-in-the-loop planning for the Deep Research agent. If set to true, the Deep Research agent will provide a research plan in its response. The agent will then proceed only if the user confirms the plan in the next turn. Corresponds to the JSON property collaborativePlanning

Returns:

  • (Boolean)


2096
2097
2098
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2096

def collaborative_planning
  @collaborative_planning
end

#enable_bigquery_toolBoolean Also known as: enable_bigquery_tool?

Enables bigquery tool for the Deep Research agent. Corresponds to the JSON property enableBigqueryTool

Returns:

  • (Boolean)


2102
2103
2104
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2102

def enable_bigquery_tool
  @enable_bigquery_tool
end

#thinking_summariesString

Whether to include thought summaries in the response. Corresponds to the JSON property thinkingSummaries

Returns:

  • (String)


2108
2109
2110
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2108

def thinking_summaries
  @thinking_summaries
end

#visualizationString

Whether to include visualizations in the response. Corresponds to the JSON property visualization

Returns:

  • (String)


2113
2114
2115
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2113

def visualization
  @visualization
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2120
2121
2122
2123
2124
2125
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2120

def update!(**args)
  @collaborative_planning = args[:collaborative_planning] if args.key?(:collaborative_planning)
  @enable_bigquery_tool = args[:enable_bigquery_tool] if args.key?(:enable_bigquery_tool)
  @thinking_summaries = args[:thinking_summaries] if args.key?(:thinking_summaries)
  @visualization = args[:visualization] if args.key?(:visualization)
end