Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1DynamicAgentConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1DynamicAgentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for dynamic agents.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1DynamicAgentConfig
constructor
A new instance of GenaiVertexV1beta1DynamicAgentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1DynamicAgentConfig
Returns a new instance of GenaiVertexV1beta1DynamicAgentConfig.
2217 2218 2219 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property config
2215 2216 2217 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2215 def config @config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2222 2223 2224 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2222 def update!(**args) @config = args[:config] if args.key?(:config) end |