Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileCitation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileCitation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A file citation annotation.
Instance Attribute Summary collapse
-
#custom_metadata ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#document_uri ⇒ String
The URI of the file.
-
#file_name ⇒ String
The name of the file.
-
#media_id ⇒ String
Media ID in-case of image citations, if applicable.
-
#page_number ⇒ Fixnum
Page number of the cited document, if applicable.
-
#source ⇒ String
Source attributed for a portion of the text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FileCitation
constructor
A new instance of GenaiVertexV1beta1FileCitation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FileCitation
Returns a new instance of GenaiVertexV1beta1FileCitation.
2034 2035 2036 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2034 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_metadata ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property customMetadata
2007 2008 2009 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2007 def @custom_metadata end |
#document_uri ⇒ String
The URI of the file.
Corresponds to the JSON property documentUri
2012 2013 2014 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2012 def document_uri @document_uri end |
#file_name ⇒ String
The name of the file.
Corresponds to the JSON property fileName
2017 2018 2019 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2017 def file_name @file_name end |
#media_id ⇒ String
Media ID in-case of image citations, if applicable.
Corresponds to the JSON property mediaId
2022 2023 2024 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2022 def media_id @media_id end |
#page_number ⇒ Fixnum
Page number of the cited document, if applicable.
Corresponds to the JSON property pageNumber
2027 2028 2029 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2027 def page_number @page_number end |
#source ⇒ String
Source attributed for a portion of the text.
Corresponds to the JSON property source
2032 2033 2034 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2032 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2039 2040 2041 2042 2043 2044 2045 2046 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2039 def update!(**args) @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata) @document_uri = args[:document_uri] if args.key?(:document_uri) @file_name = args[:file_name] if args.key?(:file_name) @media_id = args[:media_id] if args.key?(:media_id) @page_number = args[:page_number] if args.key?(:page_number) @source = args[:source] if args.key?(:source) end |