Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool that can be used by the model to search files.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1FileSearch

Returns a new instance of GenaiVertexV1beta1FileSearch.



1991
1992
1993
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1991

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_search_store_namesArray<String>

The file search store names to search. Corresponds to the JSON property fileSearchStoreNames

Returns:

  • (Array<String>)


1979
1980
1981
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1979

def file_search_store_names
  @file_search_store_names
end

#metadata_filterString

Metadata filter to apply to the semantic retrieval documents and chunks. Corresponds to the JSON property metadataFilter

Returns:

  • (String)


1984
1985
1986
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1984

def 
  @metadata_filter
end

#top_kFixnum

The number of semantic retrieval chunks to retrieve. Corresponds to the JSON property topK

Returns:

  • (Fixnum)


1989
1990
1991
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1989

def top_k
  @top_k
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1996
1997
1998
1999
2000
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1996

def update!(**args)
  @file_search_store_names = args[:file_search_store_names] if args.key?(:file_search_store_names)
  @metadata_filter = args[:metadata_filter] if args.key?(:metadata_filter)
  @top_k = args[:top_k] if args.key?(:top_k)
end