Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionCallContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionCallContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A function tool call content block.
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionCallContent
constructor
A new instance of GenaiVertexV1beta1FunctionCallContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionCallContent
Returns a new instance of GenaiVertexV1beta1FunctionCallContent.
2470 2471 2472 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property arguments
2463 2464 2465 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2463 def arguments @arguments end |
#name ⇒ String
Required. The name of the tool to call.
Corresponds to the JSON property name
2468 2469 2470 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2468 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2475 2476 2477 2478 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2475 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @name = args[:name] if args.key?(:name) end |