Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionCallDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionCallDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#name ⇒ String
Corresponds to the JSON property
name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionCallDelta
constructor
A new instance of GenaiVertexV1beta1FunctionCallDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionCallDelta
Returns a new instance of GenaiVertexV1beta1FunctionCallDelta.
2356 2357 2358 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2356 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property arguments
2349 2350 2351 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2349 def arguments @arguments end |
#name ⇒ String
Corresponds to the JSON property name
2354 2355 2356 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2354 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2361 2362 2363 2364 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2361 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @name = args[:name] if args.key?(:name) end |