Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionCallStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionCallStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A function tool call step.
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionCallStep
constructor
A new instance of GenaiVertexV1beta1FunctionCallStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionCallStep
Returns a new instance of GenaiVertexV1beta1FunctionCallStep.
2741 2742 2743 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2741 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property arguments
2734 2735 2736 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2734 def arguments @arguments end |
#name ⇒ String
Required. The name of the tool to call.
Corresponds to the JSON property name
2739 2740 2741 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2739 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2746 2747 2748 2749 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2746 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @name = args[:name] if args.key?(:name) end |