Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A function tool result content block.
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property
contentList. -
#is_error ⇒ Boolean
(also: #is_error?)
Whether the tool call resulted in an error.
-
#name ⇒ String
The name of the tool that was called.
-
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultContent
constructor
A new instance of GenaiVertexV1beta1FunctionResultContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultContent
Returns a new instance of GenaiVertexV1beta1FunctionResultContent.
2783 2784 2785 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2783 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property contentList
2759 2760 2761 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2759 def content_list @content_list end |
#is_error ⇒ Boolean Also known as: is_error?
Whether the tool call resulted in an error.
Corresponds to the JSON property isError
2764 2765 2766 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2764 def is_error @is_error end |
#name ⇒ String
The name of the tool that was called.
Corresponds to the JSON property name
2770 2771 2772 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2770 def name @name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
2775 2776 2777 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2775 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
2781 2782 2783 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2781 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2788 2789 2790 2791 2792 2793 2794 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2788 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @is_error = args[:is_error] if args.key?(:is_error) @name = args[:name] if args.key?(:name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |