Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultDelta

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultDelta

Returns a new instance of GenaiVertexV1beta1FunctionResultDelta.



2820
2821
2822
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_errorBoolean Also known as: is_error?

Corresponds to the JSON property isError

Returns:

  • (Boolean)


2804
2805
2806
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2804

def is_error
  @is_error
end

#nameString

Corresponds to the JSON property name

Returns:

  • (String)


2810
2811
2812
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2810

def name
  @name
end

#resultGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error. Corresponds to the JSON property result



2818
2819
2820
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2818

def result
  @result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2825
2826
2827
2828
2829
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2825

def update!(**args)
  @is_error = args[:is_error] if args.key?(:is_error)
  @name = args[:name] if args.key?(:name)
  @result = args[:result] if args.key?(:result)
end