Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Result of a function tool call.
Instance Attribute Summary collapse
-
#is_error ⇒ Boolean
(also: #is_error?)
Whether the tool call resulted in an error.
-
#name ⇒ String
The name of the tool that was called.
-
#result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value
Valuerepresents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultStep
constructor
A new instance of GenaiVertexV1beta1FunctionResultStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultStep
Returns a new instance of GenaiVertexV1beta1FunctionResultStep.
2855 2856 2857 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2855 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_error ⇒ Boolean Also known as: is_error?
Whether the tool call resulted in an error.
Corresponds to the JSON property isError
2839 2840 2841 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2839 def is_error @is_error end |
#name ⇒ String
The name of the tool that was called.
Corresponds to the JSON property name
2845 2846 2847 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2845 def name @name end |
#result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value
Value represents a dynamically typed value which can be either null, a
number, a string, a boolean, a recursive struct value, or a list of values. A
producer of value is expected to set one of these variants. Absence of any
variant indicates an error.
Corresponds to the JSON property result
2853 2854 2855 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2853 def result @result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2860 2861 2862 2863 2864 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2860 def update!(**args) @is_error = args[:is_error] if args.key?(:is_error) @name = args[:name] if args.key?(:name) @result = args[:result] if args.key?(:result) end |