Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GenerationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration parameters for model interactions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1GenerationConfig

Returns a new instance of GenaiVertexV1beta1GenerationConfig.



2980
2981
2982
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2980

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#image_configGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageConfig

The configuration for image interaction. Corresponds to the JSON property imageConfig



2918
2919
2920
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2918

def image_config
  @image_config
end

#max_output_tokensFixnum

The maximum number of tokens to include in the response. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


2923
2924
2925
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2923

def max_output_tokens
  @max_output_tokens
end

#seedFixnum

Seed used in decoding for reproducibility. Corresponds to the JSON property seed

Returns:

  • (Fixnum)


2928
2929
2930
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2928

def seed
  @seed
end

#speech_configArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1SpeechConfig>

Configuration for speech interaction. Corresponds to the JSON property speechConfig



2933
2934
2935
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2933

def speech_config
  @speech_config
end

#stop_sequencesArray<String>

A list of character sequences that will stop output interaction. Corresponds to the JSON property stopSequences

Returns:

  • (Array<String>)


2938
2939
2940
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2938

def stop_sequences
  @stop_sequences
end

#temperatureFloat

Controls the randomness of the output. Corresponds to the JSON property temperature

Returns:

  • (Float)


2943
2944
2945
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2943

def temperature
  @temperature
end

#thinking_levelString

The level of thought tokens that the model should generate. Corresponds to the JSON property thinkingLevel

Returns:

  • (String)


2948
2949
2950
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2948

def thinking_level
  @thinking_level
end

#thinking_summariesString

Whether to include thought summaries in the response. Corresponds to the JSON property thinkingSummaries

Returns:

  • (String)


2953
2954
2955
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2953

def thinking_summaries
  @thinking_summaries
end

#tool_choice_configGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ToolChoiceConfig

The tool choice configuration containing allowed tools. Corresponds to the JSON property toolChoiceConfig



2958
2959
2960
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2958

def tool_choice_config
  @tool_choice_config
end

#tool_choice_modeString

The mode of the tool choice. Corresponds to the JSON property toolChoiceMode

Returns:

  • (String)


2963
2964
2965
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2963

def tool_choice_mode
  @tool_choice_mode
end

#top_pFloat

The maximum cumulative probability of tokens to consider when sampling. Corresponds to the JSON property topP

Returns:

  • (Float)


2968
2969
2970
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2968

def top_p
  @top_p
end

#transcription_configGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1TranscriptionConfig

Configuration for speech recognition (transcription). Corresponds to the JSON property transcriptionConfig



2973
2974
2975
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2973

def transcription_config
  @transcription_config
end

#video_configGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1VideoConfig

Configuration options for video generation. Corresponds to the JSON property videoConfig



2978
2979
2980
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2978

def video_config
  @video_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
2998
2999
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2985

def update!(**args)
  @image_config = args[:image_config] if args.key?(:image_config)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @seed = args[:seed] if args.key?(:seed)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences)
  @temperature = args[:temperature] if args.key?(:temperature)
  @thinking_level = args[:thinking_level] if args.key?(:thinking_level)
  @thinking_summaries = args[:thinking_summaries] if args.key?(:thinking_summaries)
  @tool_choice_config = args[:tool_choice_config] if args.key?(:tool_choice_config)
  @tool_choice_mode = args[:tool_choice_mode] if args.key?(:tool_choice_mode)
  @top_p = args[:top_p] if args.key?(:top_p)
  @transcription_config = args[:transcription_config] if args.key?(:transcription_config)
  @video_config = args[:video_config] if args.key?(:video_config)
end