Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMaps

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool that can be used by the model to call Google Maps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMaps

Returns a new instance of GenaiVertexV1beta1GoogleMaps.



3023
3024
3025
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_widgetBoolean Also known as: enable_widget?

Whether to return a widget context token in the tool call result of the response. Corresponds to the JSON property enableWidget

Returns:

  • (Boolean)


3010
3011
3012
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3010

def enable_widget
  @enable_widget
end

#latitudeFloat

The latitude of the user's location. Corresponds to the JSON property latitude

Returns:

  • (Float)


3016
3017
3018
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3016

def latitude
  @latitude
end

#longitudeFloat

The longitude of the user's location. Corresponds to the JSON property longitude

Returns:

  • (Float)


3021
3022
3023
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3021

def longitude
  @longitude
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3028
3029
3030
3031
3032
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3028

def update!(**args)
  @enable_widget = args[:enable_widget] if args.key?(:enable_widget)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
end