Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Google Maps content.
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallContentGoogleMapsCallArguments
The arguments to pass to the Google Maps tool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsCallContent
constructor
A new instance of GenaiVertexV1beta1GoogleMapsCallContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsCallContent
Returns a new instance of GenaiVertexV1beta1GoogleMapsCallContent.
2343 2344 2345 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallContentGoogleMapsCallArguments
The arguments to pass to the Google Maps tool.
Corresponds to the JSON property arguments
2341 2342 2343 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2341 def arguments @arguments end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2348 2349 2350 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2348 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) end |