Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallContentGoogleMapsCallArguments
The arguments to pass to the Google Maps tool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsCallDelta
constructor
A new instance of GenaiVertexV1beta1GoogleMapsCallDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsCallDelta
Returns a new instance of GenaiVertexV1beta1GoogleMapsCallDelta.
2381 2382 2383 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2381 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallContentGoogleMapsCallArguments
The arguments to pass to the Google Maps tool.
Corresponds to the JSON property arguments
2379 2380 2381 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2379 def arguments @arguments end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2386 2387 2388 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2386 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) end |