Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Google Maps call step.
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallStepGoogleMapsCallStepArguments
The arguments to pass to the Google Maps tool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsCallStep
constructor
A new instance of GenaiVertexV1beta1GoogleMapsCallStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsCallStep
Returns a new instance of GenaiVertexV1beta1GoogleMapsCallStep.
2766 2767 2768 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2766 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallStepGoogleMapsCallStepArguments
The arguments to pass to the Google Maps tool.
Corresponds to the JSON property arguments
2764 2765 2766 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2764 def arguments @arguments end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2771 2772 2773 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2771 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) end |