Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces

Returns a new instance of GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces.



2980
2981
2982
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2980

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Title of the place. Corresponds to the JSON property name

Returns:

  • (String)


2962
2963
2964
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2962

def name
  @name
end

#place_idString

The ID of the place, in places/place_id`format. Corresponds to the JSON propertyplaceId`

Returns:

  • (String)


2967
2968
2969
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2967

def place_id
  @place_id
end

#review_snippetsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet>

Snippets of reviews that are used to generate answers about the features of a given place in Google Maps. Corresponds to the JSON property reviewSnippets



2973
2974
2975
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2973

def review_snippets
  @review_snippets
end

#urlString

URI reference of the place. Corresponds to the JSON property url

Returns:

  • (String)


2978
2979
2980
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2978

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2985
2986
2987
2988
2989
2990
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2985

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @place_id = args[:place_id] if args.key?(:place_id)
  @review_snippets = args[:review_snippets] if args.key?(:review_snippets)
  @url = args[:url] if args.key?(:url)
end