Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchResultContentGoogleSearchResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchResultContentGoogleSearchResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The result of the Google Search.
Instance Attribute Summary collapse
-
#search_suggestions ⇒ String
Web content snippet that can be embedded in a web page or an app webview.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleSearchResultContentGoogleSearchResult
constructor
A new instance of GenaiVertexV1beta1GoogleSearchResultContentGoogleSearchResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleSearchResultContentGoogleSearchResult
Returns a new instance of GenaiVertexV1beta1GoogleSearchResultContentGoogleSearchResult.
2772 2773 2774 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#search_suggestions ⇒ String
Web content snippet that can be embedded in a web page or an app webview.
Corresponds to the JSON property search_suggestions
2770 2771 2772 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2770 def search_suggestions @search_suggestions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2777 2778 2779 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2777 def update!(**args) @search_suggestions = args[:search_suggestions] if args.key?(:search_suggestions) end |