Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchResultStepGoogleSearchResultItem
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchResultStepGoogleSearchResultItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The result of the Google Search.
Instance Attribute Summary collapse
-
#search_suggestions ⇒ String
Web content snippet that can be embedded in a web page or an app webview.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleSearchResultStepGoogleSearchResultItem
constructor
A new instance of GenaiVertexV1beta1GoogleSearchResultStepGoogleSearchResultItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleSearchResultStepGoogleSearchResultItem
Returns a new instance of GenaiVertexV1beta1GoogleSearchResultStepGoogleSearchResultItem.
3079 3080 3081 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3079 def initialize(**args) update!(**args) end |
Instance Attribute Details
#search_suggestions ⇒ String
Web content snippet that can be embedded in a web page or an app webview.
Corresponds to the JSON property search_suggestions
3077 3078 3079 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3077 def search_suggestions @search_suggestions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3084 3085 3086 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3084 def update!(**args) @search_suggestions = args[:search_suggestions] if args.key?(:search_suggestions) end |