Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStreamingEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStreamingEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#content_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentDelta
The content block delta data, used for content.delta events.
-
#content_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStart
The content block start data, used for content.start events.
-
#content_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStop
The content block stop data, used for content.stop events.
-
#error_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ErrorEvent
The error event data, used for error events.
-
#event_id ⇒ String
The event_id token to be used to resume the interaction stream, from this event.
-
#interaction_complete_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompleteEvent
The interaction data, used for interaction.complete events.
-
#interaction_completed_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompletedSseEvent
The interaction data, used for interaction.completed events.
-
#interaction_created_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCreatedSseEvent
The interaction data, used for interaction.created events.
-
#interaction_start_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStartEvent
The interaction data, used for interaction.start events.
-
#interaction_status_update ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStatusUpdate
The interaction status data, used for interaction.status_update events.
-
#step_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepDelta
The step delta data, used for step.delta events.
-
#step_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStart
The step start data, used for step.start events.
-
#step_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStop
The step stop data, used for step.stop events.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1InteractionStreamingEvent
constructor
A new instance of GenaiVertexV1beta1InteractionStreamingEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1InteractionStreamingEvent
Returns a new instance of GenaiVertexV1beta1InteractionStreamingEvent.
4099 4100 4101 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4099 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentDelta
The content block delta data, used for content.delta events. Legacy content-
based streaming event, used when steps are disabled.
Corresponds to the JSON property contentDelta
4027 4028 4029 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4027 def content_delta @content_delta end |
#content_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStart
The content block start data, used for content.start events. Legacy content-
based streaming event, used when steps are disabled.
Corresponds to the JSON property contentStart
4033 4034 4035 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4033 def content_start @content_start end |
#content_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStop
The content block stop data, used for content.stop events. Legacy content-
based streaming event, used when steps are disabled.
Corresponds to the JSON property contentStop
4039 4040 4041 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4039 def content_stop @content_stop end |
#error_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ErrorEvent
The error event data, used for error events.
Corresponds to the JSON property errorEvent
4044 4045 4046 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4044 def error_event @error_event end |
#event_id ⇒ String
The event_id token to be used to resume the interaction stream, from this
event.
Corresponds to the JSON property eventId
4050 4051 4052 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4050 def event_id @event_id end |
#interaction_complete_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompleteEvent
The interaction data, used for interaction.complete events. Legacy event, used
when steps are disabled.
Corresponds to the JSON property interactionCompleteEvent
4056 4057 4058 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4056 def interaction_complete_event @interaction_complete_event end |
#interaction_completed_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompletedSseEvent
The interaction data, used for interaction.completed events. Used when steps
are enabled.
Corresponds to the JSON property interactionCompletedEvent
4062 4063 4064 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4062 def interaction_completed_event @interaction_completed_event end |
#interaction_created_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCreatedSseEvent
The interaction data, used for interaction.created events. Used when steps are
enabled.
Corresponds to the JSON property interactionCreatedEvent
4068 4069 4070 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4068 def interaction_created_event @interaction_created_event end |
#interaction_start_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStartEvent
The interaction data, used for interaction.start events. Legacy event, used
when steps are disabled.
Corresponds to the JSON property interactionStartEvent
4074 4075 4076 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4074 def interaction_start_event @interaction_start_event end |
#interaction_status_update ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStatusUpdate
The interaction status data, used for interaction.status_update events.
Corresponds to the JSON property interactionStatusUpdate
4079 4080 4081 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4079 def interaction_status_update @interaction_status_update end |
#step_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepDelta
The step delta data, used for step.delta events. Step-based streaming event,
used when steps are enabled.
Corresponds to the JSON property stepDelta
4085 4086 4087 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4085 def step_delta @step_delta end |
#step_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStart
The step start data, used for step.start events. Step-based streaming event,
used when steps are enabled.
Corresponds to the JSON property stepStart
4091 4092 4093 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4091 def step_start @step_start end |
#step_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStop
The step stop data, used for step.stop events. Step-based streaming event,
used when steps are enabled.
Corresponds to the JSON property stepStop
4097 4098 4099 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4097 def step_stop @step_stop end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4104 def update!(**args) @content_delta = args[:content_delta] if args.key?(:content_delta) @content_start = args[:content_start] if args.key?(:content_start) @content_stop = args[:content_stop] if args.key?(:content_stop) @error_event = args[:error_event] if args.key?(:error_event) @event_id = args[:event_id] if args.key?(:event_id) @interaction_complete_event = args[:interaction_complete_event] if args.key?(:interaction_complete_event) @interaction_completed_event = args[:interaction_completed_event] if args.key?(:interaction_completed_event) @interaction_created_event = args[:interaction_created_event] if args.key?(:interaction_created_event) @interaction_start_event = args[:interaction_start_event] if args.key?(:interaction_start_event) @interaction_status_update = args[:interaction_status_update] if args.key?(:interaction_status_update) @step_delta = args[:step_delta] if args.key?(:step_delta) @step_start = args[:step_start] if args.key?(:step_start) @step_stop = args[:step_stop] if args.key?(:step_stop) end |