Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#name ⇒ String
Corresponds to the JSON property
name. -
#server_name ⇒ String
Corresponds to the JSON property
serverName.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolCallDelta
constructor
A new instance of GenaiVertexV1beta1McpServerToolCallDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolCallDelta
Returns a new instance of GenaiVertexV1beta1McpServerToolCallDelta.
4155 4156 4157 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4155 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property arguments
4143 4144 4145 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4143 def arguments @arguments end |
#name ⇒ String
Corresponds to the JSON property name
4148 4149 4150 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4148 def name @name end |
#server_name ⇒ String
Corresponds to the JSON property serverName
4153 4154 4155 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4153 def server_name @server_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4160 4161 4162 4163 4164 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4160 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @name = args[:name] if args.key?(:name) @server_name = args[:server_name] if args.key?(:server_name) end |