Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

MCPServer tool result content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultContent

Returns a new instance of GenaiVertexV1beta1McpServerToolResultContent.



4450
4451
4452
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4450

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList

Corresponds to the JSON property contentList



4427
4428
4429
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4427

def content_list
  @content_list
end

#nameString

Name of the tool which is called for this specific tool call. Corresponds to the JSON property name

Returns:

  • (String)


4432
4433
4434
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4432

def name
  @name
end

#server_nameString

The name of the used MCP server. Corresponds to the JSON property serverName

Returns:

  • (String)


4437
4438
4439
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4437

def server_name
  @server_name
end

#string_resultString

Corresponds to the JSON property stringResult

Returns:

  • (String)


4442
4443
4444
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4442

def string_result
  @string_result
end

#struct_resultGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct

Struct represents a structured data value, consisting of fields which map to dynamically typed values. Corresponds to the JSON property structResult



4448
4449
4450
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4448

def struct_result
  @struct_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4455
4456
4457
4458
4459
4460
4461
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4455

def update!(**args)
  @content_list = args[:content_list] if args.key?(:content_list)
  @name = args[:name] if args.key?(:name)
  @server_name = args[:server_name] if args.key?(:server_name)
  @string_result = args[:string_result] if args.key?(:string_result)
  @struct_result = args[:struct_result] if args.key?(:struct_result)
end