Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

MCPServer tool result step.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultStep

Returns a new instance of GenaiVertexV1beta1McpServerToolResultStep.



4526
4527
4528
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4526

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the tool which is called for this specific tool call. Corresponds to the JSON property name

Returns:

  • (String)


4511
4512
4513
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4511

def name
  @name
end

#resultGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error. Corresponds to the JSON property result



4519
4520
4521
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4519

def result
  @result
end

#server_nameString

The name of the used MCP server. Corresponds to the JSON property serverName

Returns:

  • (String)


4524
4525
4526
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4524

def server_name
  @server_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4531
4532
4533
4534
4535
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4531

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @result = args[:result] if args.key?(:result)
  @server_name = args[:server_name] if args.key?(:server_name)
end