Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RagStoreConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Use to specify configuration for RAG Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1RagStoreConfig

Returns a new instance of GenaiVertexV1beta1RagStoreConfig.



4674
4675
4676
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4674

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rag_resourcesArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RagStoreConfigRagResource>

Optional. The representation of the rag source. Corresponds to the JSON property ragResources



4657
4658
4659
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4657

def rag_resources
  @rag_resources
end

#rag_retrieval_configGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1RagStoreConfigRagRetrievalConfig

Specifies the context retrieval config. Corresponds to the JSON property ragRetrievalConfig



4662
4663
4664
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4662

def rag_retrieval_config
  @rag_retrieval_config
end

#similarity_top_kFixnum

Optional. Number of top k results to return from the selected corpora. Corresponds to the JSON property similarityTopK

Returns:

  • (Fixnum)


4667
4668
4669
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4667

def similarity_top_k
  @similarity_top_k
end

#vector_distance_thresholdFloat

Optional. Only return results with vector distance smaller than the threshold. Corresponds to the JSON property vectorDistanceThreshold

Returns:

  • (Float)


4672
4673
4674
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4672

def vector_distance_threshold
  @vector_distance_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4679
4680
4681
4682
4683
4684
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4679

def update!(**args)
  @rag_resources = args[:rag_resources] if args.key?(:rag_resources)
  @rag_retrieval_config = args[:rag_retrieval_config] if args.key?(:rag_retrieval_config)
  @similarity_top_k = args[:similarity_top_k] if args.key?(:similarity_top_k)
  @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold)
end