Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1SafetySetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A safety setting that affects the safety-blocking behavior. A SafetySetting consists of a harm category and a threshold for that category.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1SafetySetting

Returns a new instance of GenaiVertexV1beta1SafetySetting.



5120
5121
5122
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5120

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#method_propString

Optional. The method for blocking content. If not specified, the default behavior is to use the probability score. Corresponds to the JSON property method

Returns:

  • (String)


5107
5108
5109
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5107

def method_prop
  @method_prop
end

#thresholdString

Required. The threshold for blocking content. If the harm probability exceeds this threshold, the content will be blocked. Corresponds to the JSON property threshold

Returns:

  • (String)


5113
5114
5115
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5113

def threshold
  @threshold
end

#typeString

Required. The type of harm category to be blocked. Corresponds to the JSON property type

Returns:

  • (String)


5118
5119
5120
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5118

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5125
5126
5127
5128
5129
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5125

def update!(**args)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @threshold = args[:threshold] if args.key?(:threshold)
  @type = args[:type] if args.key?(:type)
end