Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolCallDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolCallDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#code_execution_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionCallDelta
Corresponds to the JSON property
codeExecutionCall. -
#file_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchCallDelta
Corresponds to the JSON property
fileSearchCall. -
#google_maps_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallDelta
Corresponds to the JSON property
googleMapsCall. -
#google_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchCallDelta
Corresponds to the JSON property
googleSearchCall. -
#mcp_server_tool_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
Corresponds to the JSON property
mcpServerToolCall. -
#retrieval_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalCallDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search, etc.
-
#signature ⇒ String
A signature hash for backend validation.
-
#url_context_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextCallDelta
Corresponds to the JSON property
urlContextCall.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolCallDelta
constructor
A new instance of GenaiVertexV1beta1ServerToolCallDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolCallDelta
Returns a new instance of GenaiVertexV1beta1ServerToolCallDelta.
5172 5173 5174 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5172 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionCallDelta
Corresponds to the JSON property codeExecutionCall
5133 5134 5135 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5133 def code_execution_call @code_execution_call end |
#file_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchCallDelta
Corresponds to the JSON property fileSearchCall
5138 5139 5140 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5138 def file_search_call @file_search_call end |
#google_maps_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallDelta
Corresponds to the JSON property googleMapsCall
5143 5144 5145 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5143 def google_maps_call @google_maps_call end |
#google_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchCallDelta
Corresponds to the JSON property googleSearchCall
5148 5149 5150 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5148 def google_search_call @google_search_call end |
#mcp_server_tool_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
Corresponds to the JSON property mcpServerToolCall
5153 5154 5155 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5153 def mcp_server_tool_call @mcp_server_tool_call end |
#retrieval_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalCallDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search,
etc. RetrievalType decides which tool is used.
Corresponds to the JSON property retrievalCall
5159 5160 5161 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5159 def retrieval_call @retrieval_call end |
#signature ⇒ String
A signature hash for backend validation.
Corresponds to the JSON property signature
NOTE: Values are automatically base64 encoded/decoded in the client library.
5165 5166 5167 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5165 def signature @signature end |
#url_context_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextCallDelta
Corresponds to the JSON property urlContextCall
5170 5171 5172 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5170 def url_context_call @url_context_call end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5177 5178 5179 5180 5181 5182 5183 5184 5185 5186 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5177 def update!(**args) @code_execution_call = args[:code_execution_call] if args.key?(:code_execution_call) @file_search_call = args[:file_search_call] if args.key?(:file_search_call) @google_maps_call = args[:google_maps_call] if args.key?(:google_maps_call) @google_search_call = args[:google_search_call] if args.key?(:google_search_call) @mcp_server_tool_call = args[:mcp_server_tool_call] if args.key?(:mcp_server_tool_call) @retrieval_call = args[:retrieval_call] if args.key?(:retrieval_call) @signature = args[:signature] if args.key?(:signature) @url_context_call = args[:url_context_call] if args.key?(:url_context_call) end |