Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolResultDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolResultDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#code_execution_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionResultDelta
Corresponds to the JSON property
codeExecutionResult. -
#file_search_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchResultDelta
Corresponds to the JSON property
fileSearchResult. -
#google_maps_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultDelta
Corresponds to the JSON property
googleMapsResult. -
#google_search_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchResultDelta
Corresponds to the JSON property
googleSearchResult. -
#mcp_server_tool_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
Corresponds to the JSON property
mcpServerToolResult. -
#retrieval_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalResultDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search, etc.
-
#signature ⇒ String
A signature hash for backend validation.
-
#url_context_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextResultDelta
Corresponds to the JSON property
urlContextResult.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolResultDelta
constructor
A new instance of GenaiVertexV1beta1ServerToolResultDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolResultDelta
Returns a new instance of GenaiVertexV1beta1ServerToolResultDelta.
5235 5236 5237 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5235 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionResultDelta
Corresponds to the JSON property codeExecutionResult
5196 5197 5198 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5196 def code_execution_result @code_execution_result end |
#file_search_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchResultDelta
Corresponds to the JSON property fileSearchResult
5201 5202 5203 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5201 def file_search_result @file_search_result end |
#google_maps_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultDelta
Corresponds to the JSON property googleMapsResult
5206 5207 5208 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5206 def google_maps_result @google_maps_result end |
#google_search_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchResultDelta
Corresponds to the JSON property googleSearchResult
5211 5212 5213 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5211 def google_search_result @google_search_result end |
#mcp_server_tool_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
Corresponds to the JSON property mcpServerToolResult
5216 5217 5218 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5216 def mcp_server_tool_result @mcp_server_tool_result end |
#retrieval_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalResultDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search,
etc. ToolResultDelta.type
Corresponds to the JSON property retrievalResult
5222 5223 5224 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5222 def retrieval_result @retrieval_result end |
#signature ⇒ String
A signature hash for backend validation.
Corresponds to the JSON property signature
NOTE: Values are automatically base64 encoded/decoded in the client library.
5228 5229 5230 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5228 def signature @signature end |
#url_context_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextResultDelta
Corresponds to the JSON property urlContextResult
5233 5234 5235 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5233 def url_context_result @url_context_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5240 5241 5242 5243 5244 5245 5246 5247 5248 5249 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5240 def update!(**args) @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result) @file_search_result = args[:file_search_result] if args.key?(:file_search_result) @google_maps_result = args[:google_maps_result] if args.key?(:google_maps_result) @google_search_result = args[:google_search_result] if args.key?(:google_search_result) @mcp_server_tool_result = args[:mcp_server_tool_result] if args.key?(:mcp_server_tool_result) @retrieval_result = args[:retrieval_result] if args.key?(:retrieval_result) @signature = args[:signature] if args.key?(:signature) @url_context_result = args[:url_context_result] if args.key?(:url_context_result) end |