Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextResponseFormat
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextResponseFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for text output format.
Instance Attribute Summary collapse
-
#mime_type ⇒ String
The MIME type of the text output.
-
#schema ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1TextResponseFormat
constructor
A new instance of GenaiVertexV1beta1TextResponseFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1TextResponseFormat
Returns a new instance of GenaiVertexV1beta1TextResponseFormat.
4935 4936 4937 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4935 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mime_type ⇒ String
The MIME type of the text output.
Corresponds to the JSON property mimeType
4927 4928 4929 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4927 def mime_type @mime_type end |
#schema ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property schema
4933 4934 4935 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4933 def schema @schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4940 4941 4942 4943 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4940 def update!(**args) @mime_type = args[:mime_type] if args.key?(:mime_type) @schema = args[:schema] if args.key?(:schema) end |