Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ThoughtSummaryDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ThoughtSummaryDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#content ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ThoughtSummaryContent
A new summary item to be added to the thought.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ThoughtSummaryDelta
constructor
A new instance of GenaiVertexV1beta1ThoughtSummaryDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ThoughtSummaryDelta
Returns a new instance of GenaiVertexV1beta1ThoughtSummaryDelta.
4409 4410 4411 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ThoughtSummaryContent
A new summary item to be added to the thought.
Corresponds to the JSON property content
4407 4408 4409 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4407 def content @content end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4414 4415 4416 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4414 def update!(**args) @content = args[:content] if args.key?(:content) end |