Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1Value

Returns a new instance of GenaiVertexV1beta1Value.



6728
6729
6730
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6728

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Represents a boolean value. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


6694
6695
6696
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6694

def bool_value
  @bool_value
end

#content_valueGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content

The content of the response. Corresponds to the JSON property contentValue



6700
6701
6702
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6700

def content_value
  @content_value
end

#list_valueGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ListValue

ListValue is a wrapper around a repeated field of values. Corresponds to the JSON property listValue



6705
6706
6707
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6705

def list_value
  @list_value
end

#null_valueString

Represents a null value. Corresponds to the JSON property nullValue

Returns:

  • (String)


6710
6711
6712
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6710

def null_value
  @null_value
end

#number_valueFloat

Represents a double value. Corresponds to the JSON property numberValue

Returns:

  • (Float)


6715
6716
6717
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6715

def number_value
  @number_value
end

#string_valueString

Represents a string value. Corresponds to the JSON property stringValue

Returns:

  • (String)


6720
6721
6722
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6720

def string_value
  @string_value
end

#struct_valueGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct

Struct represents a structured data value, consisting of fields which map to dynamically typed values. Corresponds to the JSON property structValue



6726
6727
6728
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6726

def struct_value
  @struct_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6733
6734
6735
6736
6737
6738
6739
6740
6741
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6733

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @content_value = args[:content_value] if args.key?(:content_value)
  @list_value = args[:list_value] if args.key?(:list_value)
  @null_value = args[:null_value] if args.key?(:null_value)
  @number_value = args[:number_value] if args.key?(:number_value)
  @string_value = args[:string_value] if args.key?(:string_value)
  @struct_value = args[:struct_value] if args.key?(:struct_value)
end