Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1VideoConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration options for video generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1VideoConfig

Returns a new instance of GenaiVertexV1beta1VideoConfig.



6755
6756
6757
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#taskString

Optional task mode for video generation. If not specified, the model automatically determines the appropriate mode based on the provided text prompt and input media. Corresponds to the JSON property task

Returns:

  • (String)


6753
6754
6755
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6753

def task
  @task
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6760
6761
6762
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6760

def update!(**args)
  @task = args[:task] if args.key?(:task)
end