Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1VideoContentStaticMediaProcessing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1VideoContentStaticMediaProcessing

Returns a new instance of GenaiVertexV1beta1VideoContentStaticMediaProcessing.



6858
6859
6860
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_offsetString

Optional. Segment end time. Specified as a decimal number of seconds followed by an 's' suffix, e.g., "30s". Must be non-negative and greater than start_offset if start_offset is set. Corresponds to the JSON property endOffset

Returns:

  • (String)


6845
6846
6847
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6845

def end_offset
  @end_offset
end

#fpsFloat

Optional. Video frame-rate sampling density. Corresponds to the JSON property fps

Returns:

  • (Float)


6850
6851
6852
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6850

def fps
  @fps
end

#start_offsetString

Optional. Segment start time. Specified as a decimal number of seconds followed by an 's' suffix, e.g., "10.5s". Must be non-negative. Corresponds to the JSON property startOffset

Returns:

  • (String)


6856
6857
6858
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6856

def start_offset
  @start_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6863
6864
6865
6866
6867
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6863

def update!(**args)
  @end_offset = args[:end_offset] if args.key?(:end_offset)
  @fps = args[:fps] if args.key?(:fps)
  @start_offset = args[:start_offset] if args.key?(:start_offset)
end