Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aPart

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A single part of a message or artifact. A part carries exactly one kind of content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aPart

Returns a new instance of GoogleCloudAiplatformV1beta1A2aPart.



7037
7038
7039
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataHash<String,Object>

Optional. Structured data content. Corresponds to the JSON property data

Returns:

  • (Hash<String,Object>)


7003
7004
7005
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7003

def data
  @data
end

#filenameString

Optional. The name of the file, when the part represents a file. Corresponds to the JSON property filename

Returns:

  • (String)


7008
7009
7010
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7008

def filename
  @filename
end

#media_typeString

Optional. The IANA media type of the content, e.g. "text/plain" or "image/png". Corresponds to the JSON property mediaType

Returns:

  • (String)


7013
7014
7015
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7013

def media_type
  @media_type
end

#metadataHash<String,Object>

Optional. Additional context or parameters related to the part. Extensions can be used to strongly type metadata values for specific use cases. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


7019
7020
7021
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7019

def 
  @metadata
end

#rawString

Optional. Raw binary content. Corresponds to the JSON property raw NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


7025
7026
7027
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7025

def raw
  @raw
end

#textString

Optional. Textual content. Corresponds to the JSON property text

Returns:

  • (String)


7030
7031
7032
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7030

def text
  @text
end

#urlString

Optional. A URL pointing to the content. Corresponds to the JSON property url

Returns:

  • (String)


7035
7036
7037
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7035

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7042
7043
7044
7045
7046
7047
7048
7049
7050
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7042

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @filename = args[:filename] if args.key?(:filename)
  @media_type = args[:media_type] if args.key?(:media_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @raw = args[:raw] if args.key?(:raw)
  @text = args[:text] if args.key?(:text)
  @url = args[:url] if args.key?(:url)
end