Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifact
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a single artifact produced by a task.
Instance Attribute Summary collapse
-
#artifact_id ⇒ String
Required.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#extensions ⇒ Array<String>
Optional.
-
#metadata ⇒ Hash<String,Object>
Optional.
-
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aPart>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskArtifact
constructor
A new instance of GoogleCloudAiplatformV1beta1A2aTaskArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskArtifact
Returns a new instance of GoogleCloudAiplatformV1beta1A2aTaskArtifact.
7211 7212 7213 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7211 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_id ⇒ String
Required. The unique identifier of the artifact within the task.
Corresponds to the JSON property artifactId
7183 7184 7185 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7183 def artifact_id @artifact_id end |
#description ⇒ String
Optional. A human-readable description of the artifact.
Corresponds to the JSON property description
7188 7189 7190 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7188 def description @description end |
#display_name ⇒ String
Optional. The human-readable name of the artifact.
Corresponds to the JSON property displayName
7193 7194 7195 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7193 def display_name @display_name end |
#extensions ⇒ Array<String>
Optional. A2A protocol extensions associated with the artifact.
Corresponds to the JSON property extensions
7198 7199 7200 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7198 def extensions @extensions end |
#metadata ⇒ Hash<String,Object>
Optional. Additional context or parameters related to the artifact. Extensions
can be used to strongly type metadata values for specific use cases.
Corresponds to the JSON property metadata
7204 7205 7206 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7204 def @metadata end |
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aPart>
Required. The content parts that make up the artifact.
Corresponds to the JSON property parts
7209 7210 7211 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7209 def parts @parts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7216 def update!(**args) @artifact_id = args[:artifact_id] if args.key?(:artifact_id) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @extensions = args[:extensions] if args.key?(:extensions) @metadata = args[:metadata] if args.key?(:metadata) @parts = args[:parts] if args.key?(:parts) end |