Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskHistoryAppend

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An event payload that appends a new message to the task history.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskHistoryAppend

Returns a new instance of GoogleCloudAiplatformV1beta1A2aTaskHistoryAppend.



7347
7348
7349
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7347

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messageGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage

Represents a single message in a conversation, compliant with the A2A specification. Corresponds to the JSON property message



7345
7346
7347
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7345

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7352
7353
7354
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7352

def update!(**args)
  @message = args[:message] if args.key?(:message)
end