Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a single message in a conversation, compliant with the A2A specification.
Instance Attribute Summary collapse
-
#extensions ⇒ Array<String>
Optional.
-
#message_id ⇒ String
Required.
-
#metadata ⇒ Hash<String,Object>
Optional.
-
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aPart>
Required.
-
#reference_task_ids ⇒ Array<String>
Optional.
-
#role ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskMessage
constructor
A new instance of GoogleCloudAiplatformV1beta1A2aTaskMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskMessage
Returns a new instance of GoogleCloudAiplatformV1beta1A2aTaskMessage.
7439 7440 7441 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#extensions ⇒ Array<String>
Optional. A2A protocol extensions associated with the message.
Corresponds to the JSON property extensions
7411 7412 7413 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7411 def extensions @extensions end |
#message_id ⇒ String
Required. The unique identifier of the message.
Corresponds to the JSON property messageId
7416 7417 7418 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7416 def @message_id end |
#metadata ⇒ Hash<String,Object>
Optional. Additional context or parameters related to the message. Extensions
can be used to strongly type metadata values for specific use cases.
Corresponds to the JSON property metadata
7422 7423 7424 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7422 def @metadata end |
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aPart>
Required. The content parts that make up the message.
Corresponds to the JSON property parts
7427 7428 7429 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7427 def parts @parts end |
#reference_task_ids ⇒ Array<String>
Optional. The IDs of other tasks referenced by this message.
Corresponds to the JSON property referenceTaskIds
7432 7433 7434 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7432 def reference_task_ids @reference_task_ids end |
#role ⇒ String
Required. The role of the sender of the message.
Corresponds to the JSON property role
7437 7438 7439 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7437 def role @role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7444 7445 7446 7447 7448 7449 7450 7451 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7444 def update!(**args) @extensions = args[:extensions] if args.key?(:extensions) @message_id = args[:message_id] if args.key?(:message_id) @metadata = args[:metadata] if args.key?(:metadata) @parts = args[:parts] if args.key?(:parts) @reference_task_ids = args[:reference_task_ids] if args.key?(:reference_task_ids) @role = args[:role] if args.key?(:role) end |