Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskStatus
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents the status of an A2aTask.
Instance Attribute Summary collapse
-
#message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage
Represents a single message in a conversation, compliant with the A2A specification.
-
#state ⇒ String
Output only.
-
#timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskStatus
constructor
A new instance of GoogleCloudAiplatformV1beta1A2aTaskStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskStatus
Returns a new instance of GoogleCloudAiplatformV1beta1A2aTaskStatus.
7245 7246 7247 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7245 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage
Represents a single message in a conversation, compliant with the A2A
specification.
Corresponds to the JSON property message
7233 7234 7235 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7233 def @message end |
#state ⇒ String
Output only. The current state of the task.
Corresponds to the JSON property state
7238 7239 7240 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7238 def state @state end |
#timestamp ⇒ String
Output only. The time at which the state was set.
Corresponds to the JSON property timestamp
7243 7244 7245 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7243 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7250 7251 7252 7253 7254 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7250 def update!(**args) @message = args[:message] if args.key?(:message) @state = args[:state] if args.key?(:state) @timestamp = args[:timestamp] if args.key?(:timestamp) end |