Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AddContextArtifactsAndExecutionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for MetadataService.AddContextArtifactsAndExecutions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AddContextArtifactsAndExecutionsRequest

Returns a new instance of GoogleCloudAiplatformV1beta1AddContextArtifactsAndExecutionsRequest.



6685
6686
6687
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifactsArray<String>

The resource names of the Artifacts to attribute to the Context. Format: projects/project/locations/location/metadataStores/metadatastore/ artifacts/artifact` Corresponds to the JSON propertyartifacts`

Returns:

  • (Array<String>)


6676
6677
6678
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6676

def artifacts
  @artifacts
end

#executionsArray<String>

The resource names of the Executions to associate with the Context. Format: projects/project/locations/location/metadataStores/metadatastore/ executions/execution` Corresponds to the JSON propertyexecutions`

Returns:

  • (Array<String>)


6683
6684
6685
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6683

def executions
  @executions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6690
6691
6692
6693
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6690

def update!(**args)
  @artifacts = args[:artifacts] if args.key?(:artifacts)
  @executions = args[:executions] if args.key?(:executions)
end