Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Agent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A Vertex agent contains instructions and configurations for the LLM to execute a certain task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Agent

Returns a new instance of GoogleCloudAiplatformV1beta1Agent.



7578
7579
7580
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_agentString

Required. The base agent for the agent. Supported values: * antigravity- preview-05-2026 Corresponds to the JSON property base_agent

Returns:

  • (String)


7519
7520
7521
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7519

def base_agent
  @base_agent
end

#base_environmentObject

Optional. The base environment configuration for the agent. Valid types: * A string value for the environment ID, or remote for the default. * A struct value for the environment_config. Corresponds to the JSON property base_environment

Returns:

  • (Object)


7526
7527
7528
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7526

def base_environment
  @base_environment
end

#createdString

Output only. The time the agent was created. Corresponds to the JSON property created

Returns:

  • (String)


7531
7532
7533
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7531

def created
  @created
end

#descriptionString

Optional. The description of the agent. Corresponds to the JSON property description

Returns:

  • (String)


7536
7537
7538
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7536

def description
  @description
end

#idString

Immutable. The user-specified ID for the agent. This ID becomes the final component of the agent resource name. If not provided, Vertex AI will generate a value for this ID. The ID can be up to 63 characters and must match the regular expression [a-z]([a-z0-9-]0,61[a-z0-9])?. Corresponds to the JSON property id

Returns:

  • (String)


7544
7545
7546
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7544

def id
  @id
end

#metadataHash<String,String>

Optional. The metadata for the agent. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


7549
7550
7551
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7549

def 
  @metadata
end

#nameString

Identifier. The resource name of the agent. Format: projects/project/ locations/location/agents/agent`. Corresponds to the JSON propertyname`

Returns:

  • (String)


7555
7556
7557
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7555

def name
  @name
end

#objectString

Output only. The object type of the resource. For agents, the value is agent. Corresponds to the JSON property object

Returns:

  • (String)


7560
7561
7562
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7560

def object
  @object
end

#system_instructionString

Optional. The instructions for the agent to follow. These instructions are passed to the LLM as a system instruction. Corresponds to the JSON property system_instruction

Returns:

  • (String)


7566
7567
7568
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7566

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentTool>

Optional. The tools available to the agent. Corresponds to the JSON property tools



7571
7572
7573
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7571

def tools
  @tools
end

#updatedString

Output only. The time the agent was last updated. Corresponds to the JSON property updated

Returns:

  • (String)


7576
7577
7578
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7576

def updated
  @updated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7583

def update!(**args)
  @base_agent = args[:base_agent] if args.key?(:base_agent)
  @base_environment = args[:base_environment] if args.key?(:base_environment)
  @created = args[:created] if args.key?(:created)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @object = args[:object] if args.key?(:object)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
  @updated = args[:updated] if args.key?(:updated)
end