Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentTool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool provides a list of actions available to the Agent during the process of executing a task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentTool

Returns a new instance of GoogleCloudAiplatformV1beta1AgentTool.



8111
8112
8113
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headersHash<String,String>

Optional. The headers for the MCP server, such as for authentication. Only applicable when type is mcp_server. Corresponds to the JSON property headers

Returns:

  • (Hash<String,String>)


8091
8092
8093
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8091

def headers
  @headers
end

#nameString

Optional. The name of the MCP server. Only applicable when type is mcp_server. Corresponds to the JSON property name

Returns:

  • (String)


8097
8098
8099
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8097

def name
  @name
end

#typeString

Required. The type of the tool. Supported types: * code_execution * filesystem * google_search * mcp_server * url_context Corresponds to the JSON property type

Returns:

  • (String)


8103
8104
8105
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8103

def type
  @type
end

#urlString

Optional. The URL for the MCP server endpoint. Only applicable when type is mcp_server. Corresponds to the JSON property url

Returns:

  • (String)


8109
8110
8111
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8109

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8116
8117
8118
8119
8120
8121
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8116

def update!(**args)
  @headers = args[:headers] if args.key?(:headers)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
  @url = args[:url] if args.key?(:url)
end