Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Artifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Instance of a general artifact.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Artifact

Returns a new instance of GoogleCloudAiplatformV1beta1Artifact.



8824
8825
8826
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8824

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Artifact was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8750
8751
8752
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8750

def create_time
  @create_time
end

#descriptionString

Description of the Artifact Corresponds to the JSON property description

Returns:

  • (String)


8755
8756
8757
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8755

def description
  @description
end

#display_nameString

User provided display name of the Artifact. May be up to 128 Unicode characters. Corresponds to the JSON property displayName

Returns:

  • (String)


8761
8762
8763
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8761

def display_name
  @display_name
end

#etagString

An eTag used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


8767
8768
8769
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8767

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Artifacts. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Artifact (System labels are excluded). Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8776
8777
8778
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8776

def labels
  @labels
end

#metadataHash<String,Object>

Properties of the Artifact. Top level metadata keys' heading and trailing spaces will be trimmed. The size of this field should not exceed 200KB. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


8782
8783
8784
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8782

def 
  @metadata
end

#nameString

Output only. The resource name of the Artifact. Corresponds to the JSON property name

Returns:

  • (String)


8787
8788
8789
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8787

def name
  @name
end

#schema_titleString

The title of the schema describing the metadata. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store. Corresponds to the JSON property schemaTitle

Returns:

  • (String)


8795
8796
8797
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8795

def schema_title
  @schema_title
end

#schema_versionString

The version of the schema in schema_name to use. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store. Corresponds to the JSON property schemaVersion

Returns:

  • (String)


8803
8804
8805
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8803

def schema_version
  @schema_version
end

#stateString

The state of this Artifact. This is a property of the Artifact, and does not imply or capture any ongoing process. This property is managed by clients ( such as Vertex AI Pipelines), and the system does not prescribe or check the validity of state transitions. Corresponds to the JSON property state

Returns:

  • (String)


8811
8812
8813
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8811

def state
  @state
end

#update_timeString

Output only. Timestamp when this Artifact was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8816
8817
8818
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8816

def update_time
  @update_time
end

#uriString

The uniform resource identifier of the artifact file. May be empty if there is no actual artifact file. Corresponds to the JSON property uri

Returns:

  • (String)


8822
8823
8824
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8822

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8829

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @schema_title = args[:schema_title] if args.key?(:schema_title)
  @schema_version = args[:schema_version] if args.key?(:schema_version)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end