Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Attribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Attribution that explains a particular prediction output.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Attribution

Returns a new instance of GoogleCloudAiplatformV1beta1Attribution.



9296
9297
9298
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9296

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approximation_errorFloat

Output only. Error of feature_attributions caused by approximation used in the explanation method. Lower value means more precise attributions. * For Sampled Shapley attribution, increasing path_count might reduce the error. * For Integrated Gradients attribution, increasing step_count might reduce the error.

  • For XRAI attribution, increasing step_count might reduce the error. See this introduction for more information. Corresponds to the JSON property approximationError

Returns:

  • (Float)


9233
9234
9235
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9233

def approximation_error
  @approximation_error
end

#baseline_output_valueFloat

Output only. Model predicted output if the input instance is constructed from the baselines of all the features defined in ExplanationMetadata.inputs. The field name of the output is determined by the key in ExplanationMetadata. outputs. If the Model's predicted output has multiple dimensions (rank > 1), this is the value in the output located by output_index. If there are multiple baselines, their output values are averaged. Corresponds to the JSON property baselineOutputValue

Returns:

  • (Float)


9243
9244
9245
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9243

def baseline_output_value
  @baseline_output_value
end

#feature_attributionsObject

Output only. Attributions of each explained feature. Features are extracted from the prediction instances according to explanation metadata for inputs. The value is a struct, whose keys are the name of the feature. The values are how much the feature in the instance contributed to the predicted result. The format of the value is determined by the feature's input format: * If the feature is a scalar value, the attribution value is a floating number. * If the feature is an array of scalar values, the attribution value is an array. * If the feature is a struct, the attribution value is a struct. The keys in the attribution value struct are the same as the keys in the feature struct. The formats of the values in the attribution struct are determined by the formats of the values in the feature struct. The ExplanationMetadata. feature_attributions_schema_uri field, pointed to by the ExplanationSpec field of the Endpoint.deployed_models object, points to the schema file that describes the features and their attribution values (if it is populated). Corresponds to the JSON property featureAttributions

Returns:

  • (Object)


9261
9262
9263
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9261

def feature_attributions
  @feature_attributions
end

#instance_output_valueFloat

Output only. Model predicted output on the corresponding explanation instance. The field name of the output is determined by the key in ExplanationMetadata. outputs. If the Model predicted output has multiple dimensions, this is the value in the output located by output_index. Corresponds to the JSON property instanceOutputValue

Returns:

  • (Float)


9269
9270
9271
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9269

def instance_output_value
  @instance_output_value
end

#output_display_nameString

Output only. The display name of the output identified by output_index. For example, the predicted class name by a multi-classification Model. This field is only populated iff the Model predicts display names as a separate field along with the explained output. The predicted display name must has the same shape of the explained output, and can be located using output_index. Corresponds to the JSON property outputDisplayName

Returns:

  • (String)


9278
9279
9280
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9278

def output_display_name
  @output_display_name
end

#output_indexArray<Fixnum>

Output only. The index that locates the explained prediction output. If the prediction output is a scalar value, output_index is not populated. If the prediction output has multiple dimensions, the length of the output_index list is the same as the number of dimensions of the output. The i-th element in output_index is the element index of the i-th dimension of the output vector. Indices start from 0. Corresponds to the JSON property outputIndex

Returns:

  • (Array<Fixnum>)


9288
9289
9290
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9288

def output_index
  @output_index
end

#output_nameString

Output only. Name of the explain output. Specified as the key in ExplanationMetadata.outputs. Corresponds to the JSON property outputName

Returns:

  • (String)


9294
9295
9296
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9294

def output_name
  @output_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9301
9302
9303
9304
9305
9306
9307
9308
9309
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9301

def update!(**args)
  @approximation_error = args[:approximation_error] if args.key?(:approximation_error)
  @baseline_output_value = args[:baseline_output_value] if args.key?(:baseline_output_value)
  @feature_attributions = args[:feature_attributions] if args.key?(:feature_attributions)
  @instance_output_value = args[:instance_output_value] if args.key?(:instance_output_value)
  @output_display_name = args[:output_display_name] if args.key?(:output_display_name)
  @output_index = args[:output_index] if args.key?(:output_index)
  @output_name = args[:output_name] if args.key?(:output_name)
end