Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscription
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The transcription of an audio part. For multi-speaker audio, each speaker
segment is a separate Part with its own AudioTranscription carrying the
speaker_label.
Instance Attribute Summary collapse
-
#speaker_label ⇒ String
Optional.
-
#text ⇒ String
Required.
-
#words ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionWordInfo>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AudioTranscription
constructor
A new instance of GoogleCloudAiplatformV1beta1AudioTranscription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AudioTranscription
Returns a new instance of GoogleCloudAiplatformV1beta1AudioTranscription.
9373 9374 9375 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#speaker_label ⇒ String
Optional. A label identifying the speaker of this audio segment (e.g. spk_1,
spk_2). Present when diarization is set.
Corresponds to the JSON property speakerLabel
9360 9361 9362 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9360 def speaker_label @speaker_label end |
#text ⇒ String
Required. The transcription text of this audio segment.
Corresponds to the JSON property text
9365 9366 9367 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9365 def text @text end |
#words ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionWordInfo>
Optional. Detailed word-level transcriptions and timing details. Present when
word_timestamp is set.
Corresponds to the JSON property words
9371 9372 9373 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9371 def words @words end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9378 9379 9380 9381 9382 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9378 def update!(**args) @speaker_label = args[:speaker_label] if args.key?(:speaker_label) @text = args[:text] if args.key?(:text) @words = args[:words] if args.key?(:words) end |