Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for speech recognition (transcription).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AudioTranscriptionConfig

Returns a new instance of GoogleCloudAiplatformV1beta1AudioTranscriptionConfig.



9491
9492
9493
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adaptation_phrasesArray<String>

Optional. Deprecated: Use custom_vocabulary instead. A list of phrases to bias the speech recognition model towards. Corresponds to the JSON property adaptationPhrases

Returns:

  • (Array<String>)


9443
9444
9445
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9443

def adaptation_phrases
  @adaptation_phrases
end

#custom_vocabularyArray<String>

Optional. A list of custom vocabulary phrases to bias the speech recognition model toward recognizing specific terms. Corresponds to the JSON property customVocabulary

Returns:

  • (Array<String>)


9449
9450
9451
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9449

def custom_vocabulary
  @custom_vocabulary
end

#diarizationBoolean Also known as: diarization?

Optional. Configures speaker diarization. Corresponds to the JSON property diarization

Returns:

  • (Boolean)


9454
9455
9456
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9454

def diarization
  @diarization
end

#language_autoGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionConfigLanguageAuto

Deprecated: Use top-level language_codes instead. Indicates the language of the audio should be automatically detected. Corresponds to the JSON property languageAuto



9461
9462
9463
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9461

def language_auto
  @language_auto
end

#language_codesArray<String>

Optional. BCP-47 language codes providing hints about the languages present in the audio. If omitted or empty, defaults to automatic language detection. Corresponds to the JSON property languageCodes

Returns:

  • (Array<String>)


9467
9468
9469
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9467

def language_codes
  @language_codes
end

#language_hintsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionConfigLanguageHints

Deprecated: Use top-level language_codes instead. Provides hints to the model about possible languages present in the audio. Corresponds to the JSON property languageHints



9473
9474
9475
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9473

def language_hints
  @language_hints
end

#modeString

Optional. Configures transcription mode. Supported values: VERBATIM, SMART. If unspecified, defaults to VERBATIM transcription. In SMART mode, the model performs disfluency removal (eliminating filler words, repetitions, and false starts), light grammatical cleanup, automatic formatting (paragraphs, bullet points, numbered lists), and minor user edits (inline self-corrections). Timestamps and diarization are incompatible with mode SMART. Corresponds to the JSON property mode

Returns:

  • (String)


9483
9484
9485
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9483

def mode
  @mode
end

#word_timestampBoolean Also known as: word_timestamp?

Optional. Configures word-level timestamp generation. Corresponds to the JSON property wordTimestamp

Returns:

  • (Boolean)


9488
9489
9490
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9488

def word_timestamp
  @word_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9496

def update!(**args)
  @adaptation_phrases = args[:adaptation_phrases] if args.key?(:adaptation_phrases)
  @custom_vocabulary = args[:custom_vocabulary] if args.key?(:custom_vocabulary)
  @diarization = args[:diarization] if args.key?(:diarization)
  @language_auto = args[:language_auto] if args.key?(:language_auto)
  @language_codes = args[:language_codes] if args.key?(:language_codes)
  @language_hints = args[:language_hints] if args.key?(:language_hints)
  @mode = args[:mode] if args.key?(:mode)
  @word_timestamp = args[:word_timestamp] if args.key?(:word_timestamp)
end