Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionWordInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Information about a single recognized word.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AudioTranscriptionWordInfo

Returns a new instance of GoogleCloudAiplatformV1beta1AudioTranscriptionWordInfo.



9250
9251
9252
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_offsetString

Optional. End offset in time of the word relative to the start of the audio. Corresponds to the JSON property endOffset

Returns:

  • (String)


9238
9239
9240
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9238

def end_offset
  @end_offset
end

#start_offsetString

Optional. Start offset in time of the word relative to the start of the audio. Corresponds to the JSON property startOffset

Returns:

  • (String)


9243
9244
9245
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9243

def start_offset
  @start_offset
end

#wordString

Required. Transcript of the word. Corresponds to the JSON property word

Returns:

  • (String)


9248
9249
9250
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9248

def word
  @word
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9255
9256
9257
9258
9259
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9255

def update!(**args)
  @end_offset = args[:end_offset] if args.key?(:end_offset)
  @start_offset = args[:start_offset] if args.key?(:start_offset)
  @word = args[:word] if args.key?(:word)
end