Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AugmentPromptResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AugmentPromptResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for AugmentPrompt.
Instance Attribute Summary collapse
-
#augmented_prompt ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Augmented prompt, only text format is supported for now.
-
#facts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Fact>
Retrieved facts from RAG data sources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AugmentPromptResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1AugmentPromptResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AugmentPromptResponse
Returns a new instance of GoogleCloudAiplatformV1beta1AugmentPromptResponse.
8063 8064 8065 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8063 def initialize(**args) update!(**args) end |
Instance Attribute Details
#augmented_prompt ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Augmented prompt, only text format is supported for now.
Corresponds to the JSON property augmentedPrompt
8056 8057 8058 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8056 def augmented_prompt @augmented_prompt end |
#facts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Fact>
Retrieved facts from RAG data sources.
Corresponds to the JSON property facts
8061 8062 8063 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8061 def facts @facts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8068 8069 8070 8071 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8068 def update!(**args) @augmented_prompt = args[:augmented_prompt] if args.key?(:augmented_prompt) @facts = args[:facts] if args.key?(:facts) end |