Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AuthConfigGoogleServiceAccountConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Config for Google Service Account Authentication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AuthConfigGoogleServiceAccountConfig

Returns a new instance of GoogleCloudAiplatformV1beta1AuthConfigGoogleServiceAccountConfig.



7410
7411
7412
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#service_accountString

Optional. The service account that the extension execution service runs as. - If the service account is specified, the iam.serviceAccounts.getAccessToken permission should be granted to Vertex AI Extension Service Agent (https:// cloud.google.com/vertex-ai/docs/general/access-control#service-agents) on the specified service account. - If not specified, the Vertex AI Extension Service Agent will be used to execute the Extension. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


7408
7409
7410
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7408

def 
  @service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7415
7416
7417
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7415

def update!(**args)
  @service_account = args[:service_account] if args.key?(:service_account)
end