Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AutoraterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The configs for autorater. This is applicable to both EvaluateInstances and EvaluateDataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AutoraterConfig

Returns a new instance of GoogleCloudAiplatformV1beta1AutoraterConfig.



8354
8355
8356
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autorater_modelString

Optional. The fully qualified name of the publisher model or tuned autorater endpoint to use. Publisher model format: projects/project/locations/ location/publishers/*/models/* Tuned model endpoint format: projects/ project/locations/location/endpoints/endpoint` Corresponds to the JSON propertyautoraterModel`

Returns:

  • (String)


8328
8329
8330
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8328

def autorater_model
  @autorater_model
end

#flip_enabledBoolean Also known as: flip_enabled?

Optional. Default is true. Whether to flip the candidate and baseline responses. This is only applicable to the pairwise metric. If enabled, also provide PairwiseMetricSpec.candidate_response_field_name and PairwiseMetricSpec.baseline_response_field_name. When rendering PairwiseMetricSpec.metric_prompt_template, the candidate and baseline fields will be flipped for half of the samples to reduce bias. Corresponds to the JSON property flipEnabled

Returns:

  • (Boolean)


8338
8339
8340
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8338

def flip_enabled
  @flip_enabled
end

#generation_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property generationConfig



8346
8347
8348
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8346

def generation_config
  @generation_config
end

#sampling_countFixnum

Optional. Number of samples for each instance in the dataset. If not specified, the default is 4. Minimum value is 1, maximum value is 32. Corresponds to the JSON property samplingCount

Returns:

  • (Fixnum)


8352
8353
8354
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8352

def sampling_count
  @sampling_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8359
8360
8361
8362
8363
8364
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8359

def update!(**args)
  @autorater_model = args[:autorater_model] if args.key?(:autorater_model)
  @flip_enabled = args[:flip_enabled] if args.key?(:flip_enabled)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @sampling_count = args[:sampling_count] if args.key?(:sampling_count)
end