Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchDedicatedResources

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A description of resources that are used for performing batch operations, are dedicated to a Model, and need manual configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchDedicatedResources

Returns a new instance of GoogleCloudAiplatformV1beta1BatchDedicatedResources.



9957
9958
9959
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#flex_startGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FlexStart

FlexStart is used to schedule the deployment workload on DWS resource. It contains the max duration of the deployment. Corresponds to the JSON property flexStart



9930
9931
9932
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9930

def flex_start
  @flex_start
end

#machine_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



9935
9936
9937
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9935

def machine_spec
  @machine_spec
end

#max_replica_countFixnum

Immutable. The maximum number of machine replicas the batch operation may be scaled to. The default value is 10. Corresponds to the JSON property maxReplicaCount

Returns:

  • (Fixnum)


9941
9942
9943
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9941

def max_replica_count
  @max_replica_count
end

#spotBoolean Also known as: spot?

Optional. If true, schedule the deployment workload on spot VMs. Corresponds to the JSON property spot

Returns:

  • (Boolean)


9947
9948
9949
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9947

def spot
  @spot
end

#starting_replica_countFixnum

Immutable. The number of machine replicas used at the start of the batch operation. If not set, Agent Platform decides starting number, not greater than max_replica_count Corresponds to the JSON property startingReplicaCount

Returns:

  • (Fixnum)


9955
9956
9957
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9955

def starting_replica_count
  @starting_replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9962
9963
9964
9965
9966
9967
9968
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9962

def update!(**args)
  @flex_start = args[:flex_start] if args.key?(:flex_start)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @max_replica_count = args[:max_replica_count] if args.key?(:max_replica_count)
  @spot = args[:spot] if args.key?(:spot)
  @starting_replica_count = args[:starting_replica_count] if args.key?(:starting_replica_count)
end