Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchPredictionJobInputConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configures the input to BatchPredictionJob. See Model. supported_input_storage_formats for Model's supported input formats, and how instances should be expressed via any of them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchPredictionJobInputConfig

Returns a new instance of GoogleCloudAiplatformV1beta1BatchPredictionJobInputConfig.



8092
8093
8094
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigquerySource



8074
8075
8076
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8074

def bigquery_source
  @bigquery_source
end

#gcs_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



8079
8080
8081
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8079

def gcs_source
  @gcs_source
end

#instances_formatString

Required. The format in which instances are given, must be one of the Model's supported_input_storage_formats. Corresponds to the JSON property instancesFormat

Returns:

  • (String)


8085
8086
8087
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8085

def instances_format
  @instances_format
end

#vertex_multimodal_dataset_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexMultimodalDatasetSource

The Vertex Multimodal Dataset for the input content. Corresponds to the JSON property vertexMultimodalDatasetSource



8090
8091
8092
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8090

def vertex_multimodal_dataset_source
  @vertex_multimodal_dataset_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8097
8098
8099
8100
8101
8102
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8097

def update!(**args)
  @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @instances_format = args[:instances_format] if args.key?(:instances_format)
  @vertex_multimodal_dataset_source = args[:vertex_multimodal_dataset_source] if args.key?(:vertex_multimodal_dataset_source)
end