Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryRequestSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The request set for the evaluation run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BigQueryRequestSet

Returns a new instance of GoogleCloudAiplatformV1beta1BigQueryRequestSet.



11237
11238
11239
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidate_response_columnsHash<String,String>

Optional. Map of candidate name to candidate response column name. The column will be in evaluation_item.CandidateResponse format. Corresponds to the JSON property candidateResponseColumns

Returns:

  • (Hash<String,String>)


11212
11213
11214
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11212

def candidate_response_columns
  @candidate_response_columns
end

#prompt_columnString

Optional. The name of the column that contains the requests to evaluate. This will be in evaluation_item.EvalPrompt format. Corresponds to the JSON property promptColumn

Returns:

  • (String)


11218
11219
11220
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11218

def prompt_column
  @prompt_column
end

#rubrics_columnString

Optional. The name of the column that contains the rubrics. This is in evaluation_rubric.RubricGroup format. Corresponds to the JSON property rubricsColumn

Returns:

  • (String)


11224
11225
11226
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11224

def rubrics_column
  @rubrics_column
end

#sampling_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryRequestSetSamplingConfig

The sampling config. Corresponds to the JSON property samplingConfig



11229
11230
11231
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11229

def sampling_config
  @sampling_config
end

#uriString

Required. The URI of a BigQuery table. e.g. bq://projectId.bqDatasetId. bqTableId Corresponds to the JSON property uri

Returns:

  • (String)


11235
11236
11237
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11235

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11242
11243
11244
11245
11246
11247
11248
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11242

def update!(**args)
  @candidate_response_columns = args[:candidate_response_columns] if args.key?(:candidate_response_columns)
  @prompt_column = args[:prompt_column] if args.key?(:prompt_column)
  @rubrics_column = args[:rubrics_column] if args.key?(:rubrics_column)
  @sampling_config = args[:sampling_config] if args.key?(:sampling_config)
  @uri = args[:uri] if args.key?(:uri)
end