Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Candidate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A response candidate generated from the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Candidate

Returns a new instance of GoogleCloudAiplatformV1beta1Candidate.



11830
11831
11832
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11830

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#avg_logprobsFloat

Output only. The average log probability of the tokens in this candidate. This is a length-normalized score that can be used to compare the quality of candidates of different lengths. A higher average log probability suggests a more confident and coherent response. Corresponds to the JSON property avgLogprobs

Returns:

  • (Float)


11768
11769
11770
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11768

def avg_logprobs
  @avg_logprobs
end

#citation_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CitationMetadata

A collection of citations that apply to a piece of generated content. Corresponds to the JSON property citationMetadata



11773
11774
11775
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11773

def 
  @citation_metadata
end

#contentGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



11780
11781
11782
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11780

def content
  @content
end

#finish_messageString

Output only. Describes the reason the model stopped generating tokens in more detail. This field is returned only when finish_reason is set. Corresponds to the JSON property finishMessage

Returns:

  • (String)


11786
11787
11788
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11786

def finish_message
  @finish_message
end

#finish_reasonString

Output only. The reason why the model stopped generating tokens. If empty, the model has not stopped generating. Corresponds to the JSON property finishReason

Returns:

  • (String)


11792
11793
11794
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11792

def finish_reason
  @finish_reason
end

#grounding_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingMetadata

Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources. Corresponds to the JSON property groundingMetadata



11799
11800
11801
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11799

def 
  @grounding_metadata
end

#indexFixnum

Output only. The 0-based index of this candidate in the list of generated responses. This is useful for distinguishing between multiple candidates when candidate_count > 1. Corresponds to the JSON property index

Returns:

  • (Fixnum)


11806
11807
11808
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11806

def index
  @index
end

#logprobs_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LogprobsResult

The log probabilities of the tokens generated by the model. This is useful for understanding the model's confidence in its predictions and for debugging. For example, you can use log probabilities to identify when the model is making a less confident prediction or to explore alternative responses that the model considered. A low log probability can also indicate that the model is " hallucinating" or generating factually incorrect information. Corresponds to the JSON property logprobsResult



11816
11817
11818
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11816

def logprobs_result
  @logprobs_result
end

#safety_ratingsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetyRating>

Output only. A list of ratings for the safety of a response candidate. There is at most one rating per category. Corresponds to the JSON property safetyRatings



11822
11823
11824
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11822

def safety_ratings
  @safety_ratings
end

#url_context_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UrlContextMetadata

Metadata returned when the model uses the url_context tool to get information from a user-provided URL. Corresponds to the JSON property urlContextMetadata



11828
11829
11830
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11828

def 
  @url_context_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11835
11836
11837
11838
11839
11840
11841
11842
11843
11844
11845
11846
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11835

def update!(**args)
  @avg_logprobs = args[:avg_logprobs] if args.key?(:avg_logprobs)
  @citation_metadata = args[:citation_metadata] if args.key?(:citation_metadata)
  @content = args[:content] if args.key?(:content)
  @finish_message = args[:finish_message] if args.key?(:finish_message)
  @finish_reason = args[:finish_reason] if args.key?(:finish_reason)
  @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata)
  @index = args[:index] if args.key?(:index)
  @logprobs_result = args[:logprobs_result] if args.key?(:logprobs_result)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
  @url_context_metadata = args[:url_context_metadata] if args.key?(:url_context_metadata)
end