Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Result for a single candidate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CandidateResult

Returns a new instance of GoogleCloudAiplatformV1beta1CandidateResult.



12010
12011
12012
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_resultsObject

Optional. Additional results for the metric. Corresponds to the JSON property additionalResults

Returns:

  • (Object)


11972
11973
11974
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11972

def additional_results
  @additional_results
end

#candidateString

Required. The candidate that is being evaluated. The value is the same as the candidate name in the EvaluationRequest. Corresponds to the JSON property candidate

Returns:

  • (String)


11978
11979
11980
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11978

def candidate
  @candidate
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



11988
11989
11990
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11988

def error
  @error
end

#explanationString

Optional. The explanation for the metric. Corresponds to the JSON property explanation

Returns:

  • (String)


11993
11994
11995
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11993

def explanation
  @explanation
end

#metricString

Required. The metric that was evaluated. Corresponds to the JSON property metric

Returns:

  • (String)


11998
11999
12000
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11998

def metric
  @metric
end

#rubric_verdictsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricVerdict>

Optional. The rubric verdicts for the metric. Corresponds to the JSON property rubricVerdicts



12003
12004
12005
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12003

def rubric_verdicts
  @rubric_verdicts
end

#scoreFloat

Optional. The score for the metric. Corresponds to the JSON property score

Returns:

  • (Float)


12008
12009
12010
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12008

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12015
12016
12017
12018
12019
12020
12021
12022
12023
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12015

def update!(**args)
  @additional_results = args[:additional_results] if args.key?(:additional_results)
  @candidate = args[:candidate] if args.key?(:candidate)
  @error = args[:error] if args.key?(:error)
  @explanation = args[:explanation] if args.key?(:explanation)
  @metric = args[:metric] if args.key?(:metric)
  @rubric_verdicts = args[:rubric_verdicts] if args.key?(:rubric_verdicts)
  @score = args[:score] if args.key?(:score)
end