Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
This message will be placed in the metadata field of a google.longrunning. Operation associated with a CheckTrialEarlyStoppingState request.
Instance Attribute Summary collapse
-
#generic_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenericOperationMetadata
Generic Metadata shared by all operations.
-
#study ⇒ String
The name of the Study that the Trial belongs to.
-
#trial ⇒ String
The Trial name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata
constructor
A new instance of GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata
Returns a new instance of GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata.
12025 12026 12027 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generic_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenericOperationMetadata
Generic Metadata shared by all operations.
Corresponds to the JSON property genericMetadata
12013 12014 12015 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12013 def @generic_metadata end |
#study ⇒ String
The name of the Study that the Trial belongs to.
Corresponds to the JSON property study
12018 12019 12020 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12018 def study @study end |
#trial ⇒ String
The Trial name.
Corresponds to the JSON property trial
12023 12024 12025 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12023 def trial @trial end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12030 12031 12032 12033 12034 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12030 def update!(**args) @generic_metadata = args[:generic_metadata] if args.key?(:generic_metadata) @study = args[:study] if args.key?(:study) @trial = args[:trial] if args.key?(:trial) end |