Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CloudLoggingConfigTracingContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Tracing context for Observability correlation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CloudLoggingConfigTracingContext

Returns a new instance of GoogleCloudAiplatformV1beta1CloudLoggingConfigTracingContext.



11173
11174
11175
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_idString

Optional. Unique identifier for a conversation (session thread), used to store and correlate messages within a conversation. The value corresponds to the gen_ai.conversation.id field in the the OpenTelemetry GenAI attributes. Corresponds to the JSON property conversationId

Returns:

  • (String)


11157
11158
11159
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11157

def conversation_id
  @conversation_id
end

#span_idString

Optional. ID of the Cloud Trace span associated with the current operation in which the log is being written. e.g., 7a2190356c3fc94b. If a span is being evaluated, this field should be populated. Corresponds to the JSON property spanId

Returns:

  • (String)


11164
11165
11166
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11164

def span_id
  @span_id
end

#trace_idString

Optional. Trace ID being written to Cloud Trace in association with this log entry. e.g., 12345, the numeric ID from the resource name. If a trace or span is being evaluated, this field should be populated. Corresponds to the JSON property traceId

Returns:

  • (String)


11171
11172
11173
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11171

def trace_id
  @trace_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11178
11179
11180
11181
11182
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11178

def update!(**args)
  @conversation_id = args[:conversation_id] if args.key?(:conversation_id)
  @span_id = args[:span_id] if args.key?(:span_id)
  @trace_id = args[:trace_id] if args.key?(:trace_id)
end