Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContentsExampleExpectedContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A single step of the expected output.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ContentsExampleExpectedContent

Returns a new instance of GoogleCloudAiplatformV1beta1ContentsExampleExpectedContent.



5326
5327
5328
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



5324
5325
5326
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5324

def content
  @content
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5331
5332
5333
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5331

def update!(**args)
  @content = args[:content] if args.key?(:content)
end