Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateDeploymentResourcePoolRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for CreateDeploymentResourcePool method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateDeploymentResourcePoolRequest

Returns a new instance of GoogleCloudAiplatformV1beta1CreateDeploymentResourcePoolRequest.



10650
10651
10652
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployment_resource_poolGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeploymentResourcePool

A description of resources that can be shared by multiple DeployedModels, whose underlying specification consists of a DedicatedResources. Corresponds to the JSON property deploymentResourcePool



10640
10641
10642
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10640

def deployment_resource_pool
  @deployment_resource_pool
end

#deployment_resource_pool_idString

Required. The ID to use for the DeploymentResourcePool, which will become the final component of the DeploymentResourcePool's resource name. The maximum length is 63 characters, and valid characters are /^[a-z]([a-z0-9-]0,61[a- z0-9])?$/. Corresponds to the JSON property deploymentResourcePoolId

Returns:

  • (String)


10648
10649
10650
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10648

def deployment_resource_pool_id
  @deployment_resource_pool_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10655
10656
10657
10658
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10655

def update!(**args)
  @deployment_resource_pool = args[:deployment_resource_pool] if args.key?(:deployment_resource_pool)
  @deployment_resource_pool_id = args[:deployment_resource_pool_id] if args.key?(:deployment_resource_pool_id)
end