Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateTensorboardRunRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for TensorboardService.CreateTensorboardRun.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateTensorboardRunRequest

Returns a new instance of GoogleCloudAiplatformV1beta1CreateTensorboardRunRequest.



12545
12546
12547
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The resource name of the TensorboardExperiment to create the TensorboardRun in. Format: projects/project/locations/location/ tensorboards/tensorboard/experiments/experiment` Corresponds to the JSON propertyparent`

Returns:

  • (String)


12530
12531
12532
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12530

def parent
  @parent
end

#tensorboard_runGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardRun

TensorboardRun maps to a specific execution of a training job with a given set of hyperparameter values, model definition, dataset, etc Corresponds to the JSON property tensorboardRun



12536
12537
12538
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12536

def tensorboard_run
  @tensorboard_run
end

#tensorboard_run_idString

Required. The ID to use for the Tensorboard run, which becomes the final component of the Tensorboard run's resource name. This value should be 1-128 characters, and valid characters are /a-z-/. Corresponds to the JSON property tensorboardRunId

Returns:

  • (String)


12543
12544
12545
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12543

def tensorboard_run_id
  @tensorboard_run_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12550
12551
12552
12553
12554
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12550

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @tensorboard_run = args[:tensorboard_run] if args.key?(:tensorboard_run)
  @tensorboard_run_id = args[:tensorboard_run_id] if args.key?(:tensorboard_run_id)
end