Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Dataset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A collection of DataItems and Annotations on them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Dataset

Returns a new instance of GoogleCloudAiplatformV1beta1Dataset.



15164
15165
15166
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15164

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Dataset was created. Corresponds to the JSON property createTime

Returns:

  • (String)


15059
15060
15061
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15059

def create_time
  @create_time
end

#data_item_countFixnum

Output only. The number of DataItems in this Dataset. Only apply for non- structured Dataset. Corresponds to the JSON property dataItemCount

Returns:

  • (Fixnum)


15065
15066
15067
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15065

def data_item_count
  @data_item_count
end

#descriptionString

The description of the Dataset. Corresponds to the JSON property description

Returns:

  • (String)


15070
15071
15072
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15070

def description
  @description
end

#display_nameString

Required. The user-defined name of the Dataset. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


15076
15077
15078
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15076

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



15082
15083
15084
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15082

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


15088
15089
15090
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15088

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Datasets. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Dataset (System labels are excluded). See https://goo.gl/ xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for each Dataset: * "aiplatform.googleapis.com/ dataset_metadata_schema": output only, its value is the metadata_schema's title. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


15102
15103
15104
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15102

def labels
  @labels
end

#metadataObject

Required. Additional information about the Dataset. Corresponds to the JSON property metadata

Returns:

  • (Object)


15107
15108
15109
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15107

def 
  @metadata
end

#metadata_artifactString

Output only. The resource name of the Artifact that was created in MetadataStore when creating the Dataset. The Artifact resource name pattern is projects/project/locations/location/metadataStores/metadata_store/ artifacts/artifact`. Corresponds to the JSON propertymetadataArtifact`

Returns:

  • (String)


15115
15116
15117
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15115

def 
  @metadata_artifact
end

#metadata_schema_uriString

Required. Points to a YAML file stored on Google Cloud Storage describing additional information about the Dataset. The schema is defined as an OpenAPI 3.0.2 Schema Object. The schema files that can be used here are found in gs:// google-cloud-aiplatform/schema/dataset/metadata/. Corresponds to the JSON property metadataSchemaUri

Returns:

  • (String)


15123
15124
15125
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15123

def 
  @metadata_schema_uri
end

#model_referenceString

Optional. Reference to the public base model last used by the dataset. Only set for prompt datasets. Corresponds to the JSON property modelReference

Returns:

  • (String)


15129
15130
15131
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15129

def model_reference
  @model_reference
end

#nameString

Output only. Identifier. The resource name of the Dataset. Format: projects/ project/locations/location/datasets/dataset` Corresponds to the JSON propertyname`

Returns:

  • (String)


15135
15136
15137
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15135

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


15140
15141
15142
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15140

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


15146
15147
15148
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15146

def satisfies_pzs
  @satisfies_pzs
end

#saved_queriesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SavedQuery>

All SavedQueries belong to the Dataset will be returned in List/Get Dataset response. The annotation_specs field will not be populated except for UI cases which will only use annotation_spec_count. In CreateDataset request, a SavedQuery is created together if this field is set, up to one SavedQuery can be set in CreateDatasetRequest. The SavedQuery should not contain any AnnotationSpec. Corresponds to the JSON property savedQueries



15157
15158
15159
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15157

def saved_queries
  @saved_queries
end

#update_timeString

Output only. Timestamp when this Dataset was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


15162
15163
15164
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15162

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15169
15170
15171
15172
15173
15174
15175
15176
15177
15178
15179
15180
15181
15182
15183
15184
15185
15186
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15169

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_item_count = args[:data_item_count] if args.key?(:data_item_count)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metadata_artifact = args[:metadata_artifact] if args.key?(:metadata_artifact)
  @metadata_schema_uri = args[:metadata_schema_uri] if args.key?(:metadata_schema_uri)
  @model_reference = args[:model_reference] if args.key?(:model_reference)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @saved_queries = args[:saved_queries] if args.key?(:saved_queries)
  @update_time = args[:update_time] if args.key?(:update_time)
end