Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetStats
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Statistics computed over a tuning dataset.
Instance Attribute Summary collapse
-
#contents_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#dropped_example_indices ⇒ Array<Fixnum>
Output only.
-
#dropped_example_reasons ⇒ Array<String>
Output only.
-
#reinforcement_tuning_user_dataset_examples ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningUserDatasetExamples
Sample reinforcement tuning user data in the training dataset.
-
#total_billable_character_count ⇒ Fixnum
Output only.
-
#total_billable_token_count ⇒ Fixnum
Output only.
-
#total_tuning_character_count ⇒ Fixnum
Output only.
-
#tuning_dataset_example_count ⇒ Fixnum
Output only.
-
#tuning_step_count ⇒ Fixnum
Output only.
-
#user_dataset_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Output only.
-
#user_input_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#user_message_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#user_output_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DatasetStats
constructor
A new instance of GoogleCloudAiplatformV1beta1DatasetStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DatasetStats
Returns a new instance of GoogleCloudAiplatformV1beta1DatasetStats.
15394 15395 15396 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15394 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property contentsPerExampleDistribution
15329 15330 15331 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15329 def contents_per_example_distribution @contents_per_example_distribution end |
#dropped_example_indices ⇒ Array<Fixnum>
Output only. A partial sample of the indices (starting from 1) of the dropped
examples.
Corresponds to the JSON property droppedExampleIndices
15335 15336 15337 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15335 def dropped_example_indices @dropped_example_indices end |
#dropped_example_reasons ⇒ Array<String>
Output only. For each index in dropped_example_indices, the user-facing
reason why the example was dropped.
Corresponds to the JSON property droppedExampleReasons
15341 15342 15343 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15341 def dropped_example_reasons @dropped_example_reasons end |
#reinforcement_tuning_user_dataset_examples ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningUserDatasetExamples
Sample reinforcement tuning user data in the training dataset. The contents
are truncated for better UI showing.
Corresponds to the JSON property reinforcementTuningUserDatasetExamples
15347 15348 15349 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15347 def reinforcement_tuning_user_dataset_examples @reinforcement_tuning_user_dataset_examples end |
#total_billable_character_count ⇒ Fixnum
Output only. Number of billable characters in the tuning dataset.
Corresponds to the JSON property totalBillableCharacterCount
15352 15353 15354 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15352 def total_billable_character_count @total_billable_character_count end |
#total_billable_token_count ⇒ Fixnum
Output only. Number of billable tokens in the tuning dataset.
Corresponds to the JSON property totalBillableTokenCount
15357 15358 15359 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15357 def total_billable_token_count @total_billable_token_count end |
#total_tuning_character_count ⇒ Fixnum
Output only. Number of tuning characters in the tuning dataset.
Corresponds to the JSON property totalTuningCharacterCount
15362 15363 15364 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15362 def total_tuning_character_count @total_tuning_character_count end |
#tuning_dataset_example_count ⇒ Fixnum
Output only. Number of examples in the tuning dataset.
Corresponds to the JSON property tuningDatasetExampleCount
15367 15368 15369 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15367 def tuning_dataset_example_count @tuning_dataset_example_count end |
#tuning_step_count ⇒ Fixnum
Output only. Number of tuning steps for this Tuning Job.
Corresponds to the JSON property tuningStepCount
15372 15373 15374 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15372 def tuning_step_count @tuning_step_count end |
#user_dataset_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Output only. Sample user messages in the training dataset uri.
Corresponds to the JSON property userDatasetExamples
15377 15378 15379 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15377 def user_dataset_examples @user_dataset_examples end |
#user_input_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userInputTokenDistribution
15382 15383 15384 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15382 def user_input_token_distribution @user_input_token_distribution end |
#user_message_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userMessagePerExampleDistribution
15387 15388 15389 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15387 def @user_message_per_example_distribution end |
#user_output_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userOutputTokenDistribution
15392 15393 15394 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15392 def user_output_token_distribution @user_output_token_distribution end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15399 15400 15401 15402 15403 15404 15405 15406 15407 15408 15409 15410 15411 15412 15413 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15399 def update!(**args) @contents_per_example_distribution = args[:contents_per_example_distribution] if args.key?(:contents_per_example_distribution) @dropped_example_indices = args[:dropped_example_indices] if args.key?(:dropped_example_indices) @dropped_example_reasons = args[:dropped_example_reasons] if args.key?(:dropped_example_reasons) @reinforcement_tuning_user_dataset_examples = args[:reinforcement_tuning_user_dataset_examples] if args.key?(:reinforcement_tuning_user_dataset_examples) @total_billable_character_count = args[:total_billable_character_count] if args.key?(:total_billable_character_count) @total_billable_token_count = args[:total_billable_token_count] if args.key?(:total_billable_token_count) @total_tuning_character_count = args[:total_tuning_character_count] if args.key?(:total_tuning_character_count) @tuning_dataset_example_count = args[:tuning_dataset_example_count] if args.key?(:tuning_dataset_example_count) @tuning_step_count = args[:tuning_step_count] if args.key?(:tuning_step_count) @user_dataset_examples = args[:user_dataset_examples] if args.key?(:user_dataset_examples) @user_input_token_distribution = args[:user_input_token_distribution] if args.key?(:user_input_token_distribution) @user_message_per_example_distribution = args[:user_message_per_example_distribution] if args.key?(:user_message_per_example_distribution) @user_output_token_distribution = args[:user_output_token_distribution] if args.key?(:user_output_token_distribution) end |