Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeleteFeatureValuesResponseSelectTimeRangeAndFeature
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeleteFeatureValuesResponseSelectTimeRangeAndFeature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message if the request uses the SelectTimeRangeAndFeature option.
Instance Attribute Summary collapse
-
#impacted_feature_count ⇒ Fixnum
The count of the features or columns impacted.
-
#offline_storage_modified_entity_row_count ⇒ Fixnum
The count of modified entity rows in the offline storage.
-
#online_storage_modified_entity_count ⇒ Fixnum
The count of modified entities in the online storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeleteFeatureValuesResponseSelectTimeRangeAndFeature
constructor
A new instance of GoogleCloudAiplatformV1beta1DeleteFeatureValuesResponseSelectTimeRangeAndFeature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeleteFeatureValuesResponseSelectTimeRangeAndFeature
Returns a new instance of GoogleCloudAiplatformV1beta1DeleteFeatureValuesResponseSelectTimeRangeAndFeature.
15758 15759 15760 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15758 def initialize(**args) update!(**args) end |
Instance Attribute Details
#impacted_feature_count ⇒ Fixnum
The count of the features or columns impacted. This is the same as the feature
count in the request.
Corresponds to the JSON property impactedFeatureCount
15741 15742 15743 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15741 def impacted_feature_count @impacted_feature_count end |
#offline_storage_modified_entity_row_count ⇒ Fixnum
The count of modified entity rows in the offline storage. Each row corresponds
to the combination of an entity ID and a timestamp. One entity ID can have
multiple rows in the offline storage. Within each row, only the features
specified in the request are deleted.
Corresponds to the JSON property offlineStorageModifiedEntityRowCount
15749 15750 15751 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15749 def offline_storage_modified_entity_row_count @offline_storage_modified_entity_row_count end |
#online_storage_modified_entity_count ⇒ Fixnum
The count of modified entities in the online storage. Each entity ID
corresponds to one entity. Within each entity, only the features specified in
the request are deleted.
Corresponds to the JSON property onlineStorageModifiedEntityCount
15756 15757 15758 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15756 def online_storage_modified_entity_count @online_storage_modified_entity_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15763 15764 15765 15766 15767 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15763 def update!(**args) @impacted_feature_count = args[:impacted_feature_count] if args.key?(:impacted_feature_count) @offline_storage_modified_entity_row_count = args[:offline_storage_modified_entity_row_count] if args.key?(:offline_storage_modified_entity_row_count) @online_storage_modified_entity_count = args[:online_storage_modified_entity_count] if args.key?(:online_storage_modified_entity_count) end |