Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestModelConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The model config to use for the deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployRequestModelConfig

Returns a new instance of GoogleCloudAiplatformV1beta1DeployRequestModelConfig.



8456
8457
8458
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8456

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accept_eulaBoolean Also known as: accept_eula?

Optional. Whether the user accepts the End User License Agreement (EULA) for the model. Corresponds to the JSON property acceptEula

Returns:

  • (Boolean)


8416
8417
8418
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8416

def accept_eula
  @accept_eula
end

#container_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelContainerSpec

Specification of a container for serving predictions. Some fields in this message correspond to fields in the Kubernetes Container v1 core specification. Corresponds to the JSON property containerSpec



8425
8426
8427
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8425

def container_spec
  @container_spec
end

#hugging_face_access_tokenString

Optional. The Hugging Face read access token used to access the model artifacts of gated models. Corresponds to the JSON property huggingFaceAccessToken

Returns:

  • (String)


8431
8432
8433
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8431

def hugging_face_access_token
  @hugging_face_access_token
end

#hugging_face_cache_enabledBoolean Also known as: hugging_face_cache_enabled?

Optional. If true, the model will deploy with a cached version instead of directly downloading the model artifacts from Hugging Face. This is suitable for VPC-SC users with limited internet access. Corresponds to the JSON property huggingFaceCacheEnabled

Returns:

  • (Boolean)


8438
8439
8440
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8438

def hugging_face_cache_enabled
  @hugging_face_cache_enabled
end

#model_display_nameString

Optional. The user-specified display name of the uploaded model. If not set, a default name will be used. Corresponds to the JSON property modelDisplayName

Returns:

  • (String)


8445
8446
8447
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8445

def model_display_name
  @model_display_name
end

#model_user_idString

Optional. The ID to use for the uploaded Model, which will become the final component of the model resource name. When not provided, Vertex AI will generate a value for this ID. When Model Registry model is provided, this field will be ignored. This value may be up to 63 characters, and valid characters are [a-z0-9_-]. The first character cannot be a number or hyphen. Corresponds to the JSON property modelUserId

Returns:

  • (String)


8454
8455
8456
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8454

def model_user_id
  @model_user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8461

def update!(**args)
  @accept_eula = args[:accept_eula] if args.key?(:accept_eula)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @hugging_face_access_token = args[:hugging_face_access_token] if args.key?(:hugging_face_access_token)
  @hugging_face_cache_enabled = args[:hugging_face_cache_enabled] if args.key?(:hugging_face_cache_enabled)
  @model_display_name = args[:model_display_name] if args.key?(:model_display_name)
  @model_user_id = args[:model_user_id] if args.key?(:model_user_id)
end