Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModelStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Runtime status of the deployed model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployedModelStatus

Returns a new instance of GoogleCloudAiplatformV1beta1DeployedModelStatus.



15511
15512
15513
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15511

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_replica_countFixnum

Output only. The number of available replicas of the deployed model. Corresponds to the JSON property availableReplicaCount

Returns:

  • (Fixnum)


15499
15500
15501
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15499

def available_replica_count
  @available_replica_count
end

#last_update_timeString

Output only. The time at which the status was last updated. Corresponds to the JSON property lastUpdateTime

Returns:

  • (String)


15504
15505
15506
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15504

def last_update_time
  @last_update_time
end

#messageString

Output only. The latest deployed model's status message (if any). Corresponds to the JSON property message

Returns:

  • (String)


15509
15510
15511
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15509

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15516
15517
15518
15519
15520
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15516

def update!(**args)
  @available_replica_count = args[:available_replica_count] if args.key?(:available_replica_count)
  @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
  @message = args[:message] if args.key?(:message)
end