Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DynamicRetrievalConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Describes the options to customize dynamic retrieval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DynamicRetrievalConfig

Returns a new instance of GoogleCloudAiplatformV1beta1DynamicRetrievalConfig.



17320
17321
17322
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dynamic_thresholdFloat

Optional. The threshold to be used in dynamic retrieval. If not set, a system default value is used. Corresponds to the JSON property dynamicThreshold

Returns:

  • (Float)


17313
17314
17315
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17313

def dynamic_threshold
  @dynamic_threshold
end

#modeString

The mode of the predictor to be used in dynamic retrieval. Corresponds to the JSON property mode

Returns:

  • (String)


17318
17319
17320
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17318

def mode
  @mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17325
17326
17327
17328
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17325

def update!(**args)
  @dynamic_threshold = args[:dynamic_threshold] if args.key?(:dynamic_threshold)
  @mode = args[:mode] if args.key?(:mode)
end