Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for PredictionService.EmbedContent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EmbedContentRequest

Returns a new instance of GoogleCloudAiplatformV1beta1EmbedContentRequest.



17374
17375
17376
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_truncateBoolean Also known as: auto_truncate?

Optional. Deprecated: Please use EmbedContentConfig.auto_truncate instead. Whether to silently truncate the input content if it's longer than the maximum sequence length. Corresponds to the JSON property autoTruncate

Returns:

  • (Boolean)


17340
17341
17342
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17340

def auto_truncate
  @auto_truncate
end

#contentGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



17348
17349
17350
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17348

def content
  @content
end

#embed_content_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentRequestEmbedContentConfig

Configurations for the EmbedContent API. Corresponds to the JSON property embedContentConfig



17353
17354
17355
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17353

def embed_content_config
  @embed_content_config
end

#output_dimensionalityFixnum

Optional. Deprecated: Please use EmbedContentConfig.output_dimensionality instead. Reduced dimension for the output embedding. If set, excessive values in the output embedding are truncated from the end. Corresponds to the JSON property outputDimensionality

Returns:

  • (Fixnum)


17360
17361
17362
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17360

def output_dimensionality
  @output_dimensionality
end

#task_typeString

Optional. Deprecated: Please use EmbedContentConfig.task_type instead. The task type of the embedding. Corresponds to the JSON property taskType

Returns:

  • (String)


17366
17367
17368
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17366

def task_type
  @task_type
end

#titleString

Optional. Deprecated: Please use EmbedContentConfig.title instead. The title for the text. Corresponds to the JSON property title

Returns:

  • (String)


17372
17373
17374
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17372

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17379
17380
17381
17382
17383
17384
17385
17386
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17379

def update!(**args)
  @auto_truncate = args[:auto_truncate] if args.key?(:auto_truncate)
  @content = args[:content] if args.key?(:content)
  @embed_content_config = args[:embed_content_config] if args.key?(:embed_content_config)
  @output_dimensionality = args[:output_dimensionality] if args.key?(:output_dimensionality)
  @task_type = args[:task_type] if args.key?(:task_type)
  @title = args[:title] if args.key?(:title)
end