Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentRequestEmbedContentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configurations for the EmbedContent API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EmbedContentRequestEmbedContentConfig

Returns a new instance of GoogleCloudAiplatformV1beta1EmbedContentRequestEmbedContentConfig.



9607
9608
9609
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_track_extractionBoolean Also known as: audio_track_extraction?

Optional. Whether to extract audio from video content. Corresponds to the JSON property audioTrackExtraction

Returns:

  • (Boolean)


9573
9574
9575
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9573

def audio_track_extraction
  @audio_track_extraction
end

#auto_truncateBoolean Also known as: auto_truncate?

Optional. Whether to silently truncate the input content if it's longer than the maximum sequence length. Only applicable to text-only embedding models. Corresponds to the JSON property autoTruncate

Returns:

  • (Boolean)


9580
9581
9582
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9580

def auto_truncate
  @auto_truncate
end

#document_ocrBoolean Also known as: document_ocr?

Optional. Whether to enable OCR for document content. Corresponds to the JSON property documentOcr

Returns:

  • (Boolean)


9586
9587
9588
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9586

def document_ocr
  @document_ocr
end

#output_dimensionalityFixnum

Optional. Reduced dimension for the output embedding. If set, excessive values in the output embedding are truncated from the end. Corresponds to the JSON property outputDimensionality

Returns:

  • (Fixnum)


9593
9594
9595
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9593

def output_dimensionality
  @output_dimensionality
end

#task_typeString

Optional. The task type of the embedding. Only applicable to text-only embedding models. Corresponds to the JSON property taskType

Returns:

  • (String)


9599
9600
9601
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9599

def task_type
  @task_type
end

#titleString

Optional. The title for the text. Only applicable to text-only embedding models. Corresponds to the JSON property title

Returns:

  • (String)


9605
9606
9607
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9605

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9612
9613
9614
9615
9616
9617
9618
9619
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9612

def update!(**args)
  @audio_track_extraction = args[:audio_track_extraction] if args.key?(:audio_track_extraction)
  @auto_truncate = args[:auto_truncate] if args.key?(:auto_truncate)
  @document_ocr = args[:document_ocr] if args.key?(:document_ocr)
  @output_dimensionality = args[:output_dimensionality] if args.key?(:output_dimensionality)
  @task_type = args[:task_type] if args.key?(:task_type)
  @title = args[:title] if args.key?(:title)
end