Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for PredictionService.EmbedContent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EmbedContentResponse

Returns a new instance of GoogleCloudAiplatformV1beta1EmbedContentResponse.



17527
17528
17529
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17527

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#embeddingGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentResponseEmbedding

A list of floats representing an embedding. Corresponds to the JSON property embedding



17513
17514
17515
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17513

def embedding
  @embedding
end

#truncatedBoolean Also known as: truncated?

Whether the input content was truncated before generating the embedding. Corresponds to the JSON property truncated

Returns:

  • (Boolean)


17518
17519
17520
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17518

def truncated
  @truncated
end

#usage_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UsageMetadata

Usage metadata about the content generation request and response. This message provides a detailed breakdown of token usage and other relevant metrics. Corresponds to the JSON property usageMetadata



17525
17526
17527
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17525

def 
  @usage_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17532
17533
17534
17535
17536
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17532

def update!(**args)
  @embedding = args[:embedding] if args.key?(:embedding)
  @truncated = args[:truncated] if args.key?(:truncated)
  @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata)
end