Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Model error analysis for each annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation

Returns a new instance of GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation.



16194
16195
16196
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16194

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributed_itemsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotationAttributedItem>

Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type. Corresponds to the JSON property attributedItems



16176
16177
16178
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16176

def attributed_items
  @attributed_items
end

#outlier_scoreFloat

The outlier score of this annotated item. Usually defined as the min of all distances from attributed items. Corresponds to the JSON property outlierScore

Returns:

  • (Float)


16182
16183
16184
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16182

def outlier_score
  @outlier_score
end

#outlier_thresholdFloat

The threshold used to determine if this annotation is an outlier or not. Corresponds to the JSON property outlierThreshold

Returns:

  • (Float)


16187
16188
16189
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16187

def outlier_threshold
  @outlier_threshold
end

#query_typeString

The query type used for finding the attributed items. Corresponds to the JSON property queryType

Returns:

  • (String)


16192
16193
16194
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16192

def query_type
  @query_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16199
16200
16201
16202
16203
16204
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16199

def update!(**args)
  @attributed_items = args[:attributed_items] if args.key?(:attributed_items)
  @outlier_score = args[:outlier_score] if args.key?(:outlier_score)
  @outlier_threshold = args[:outlier_threshold] if args.key?(:outlier_threshold)
  @query_type = args[:query_type] if args.key?(:query_type)
end