Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationDataset
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationDataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The dataset used for evaluation.
Instance Attribute Summary collapse
-
#bigquery_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQuerySource
The BigQuery location for the input content.
-
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource
The Google Cloud Storage location for the input content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationDataset
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationDataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationDataset
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationDataset.
18777 18778 18779 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQuerySource
The BigQuery location for the input content.
Corresponds to the JSON property bigquerySource
18770 18771 18772 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18770 def bigquery_source @bigquery_source end |
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
18775 18776 18777 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18775 def gcs_source @gcs_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18782 18783 18784 18785 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18782 def update!(**args) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) end |