Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstance

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationInstance.



18898
18899
18900
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData

Deprecated: Use agent_eval_data instead. Contains data specific to agent evaluations. Corresponds to the JSON property agentData



18859
18860
18861
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18859

def agent_data
  @agent_data
end

#agent_eval_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData

Represents data specific to multi-turn agent evaluations. Corresponds to the JSON property agentEvalData



18864
18865
18866
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18864

def agent_eval_data
  @agent_eval_data
end

#interactions_data_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInteractionsDataSource

Source for populating AgentData from an Interactions API interaction. Corresponds to the JSON property interactionsDataSource



18869
18870
18871
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18869

def interactions_data_source
  @interactions_data_source
end

#other_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceMapInstance

Instance data specified as a map. Corresponds to the JSON property otherData



18874
18875
18876
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18874

def other_data
  @other_data
end

#promptGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property prompt



18879
18880
18881
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18879

def prompt
  @prompt
end

#referenceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property reference



18884
18885
18886
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18884

def reference
  @reference
end

#responseGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property response



18889
18890
18891
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18889

def response
  @response
end

#rubric_groupsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGroup>

Optional. Named groups of rubrics associated with the prompt. This is used for rubric-based evaluations where rubrics can be referenced by a key. The key could represent versions, associated metrics, etc. Corresponds to the JSON property rubricGroups



18896
18897
18898
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18896

def rubric_groups
  @rubric_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18903
18904
18905
18906
18907
18908
18909
18910
18911
18912
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18903

def update!(**args)
  @agent_data = args[:agent_data] if args.key?(:agent_data)
  @agent_eval_data = args[:agent_eval_data] if args.key?(:agent_eval_data)
  @interactions_data_source = args[:interactions_data_source] if args.key?(:interactions_data_source)
  @other_data = args[:other_data] if args.key?(:other_data)
  @prompt = args[:prompt] if args.key?(:prompt)
  @reference = args[:reference] if args.key?(:reference)
  @response = args[:response] if args.key?(:response)
  @rubric_groups = args[:rubric_groups] if args.key?(:rubric_groups)
end