Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

EvaluationMetric is a resource that represents a reusable metric configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationMetric

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationMetric.



19405
19406
19407
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19405

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the EvaluationMetric was created. Corresponds to the JSON property createTime

Returns:

  • (String)


19361
19362
19363
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19361

def create_time
  @create_time
end

#descriptionString

Optional. A description of the EvaluationMetric. Corresponds to the JSON property description

Returns:

  • (String)


19366
19367
19368
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19366

def description
  @description
end

#display_nameString

Required. The user-friendly display name for the EvaluationMetric. Corresponds to the JSON property displayName

Returns:

  • (String)


19371
19372
19373
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19371

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



19377
19378
19379
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19377

def encryption_spec
  @encryption_spec
end

#gcs_uriString

Optional. The Google Cloud Storage URI that stores the metric specification.. Corresponds to the JSON property gcsUri

Returns:

  • (String)


19382
19383
19384
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19382

def gcs_uri
  @gcs_uri
end

#labelsHash<String,String>

Optional. Labels for the evaluation metric. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


19387
19388
19389
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19387

def labels
  @labels
end

#metricGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Metric

The metric used for running evaluations. Corresponds to the JSON property metric



19392
19393
19394
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19392

def metric
  @metric
end

#nameString

Identifier. The resource name of the EvaluationMetric. Format: projects/ project/locations/location/evaluationMetrics/evaluation_metric` Corresponds to the JSON propertyname`

Returns:

  • (String)


19398
19399
19400
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19398

def name
  @name
end

#update_timeString

Output only. The time when the EvaluationMetric was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


19403
19404
19405
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19403

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19410
19411
19412
19413
19414
19415
19416
19417
19418
19419
19420
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19410

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @labels = args[:labels] if args.key?(:labels)
  @metric = args[:metric] if args.key?(:metric)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end