Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPrompt
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPrompt
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Prompt to be evaluated. This can represent a single-turn prompt or a multi- turn conversation for agent evaluations.
Instance Attribute Summary collapse
-
#agent_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData
Represents data specific to multi-turn agent evaluations.
-
#prompt_template_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPromptPromptTemplateData
Message to hold a prompt template and the values to populate the template.
-
#text ⇒ String
Text prompt.
-
#user_scenario ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPromptUserScenario
User scenario to help simulate multi-turn agent running results.
-
#value ⇒ Object
Fields and values that can be used to populate the prompt template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationPrompt
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationPrompt.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationPrompt
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationPrompt.
17778 17779 17780 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData
Represents data specific to multi-turn agent evaluations.
Corresponds to the JSON property agentData
17756 17757 17758 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17756 def agent_data @agent_data end |
#prompt_template_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPromptPromptTemplateData
Message to hold a prompt template and the values to populate the template.
Corresponds to the JSON property promptTemplateData
17761 17762 17763 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17761 def prompt_template_data @prompt_template_data end |
#text ⇒ String
Text prompt.
Corresponds to the JSON property text
17766 17767 17768 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17766 def text @text end |
#user_scenario ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPromptUserScenario
User scenario to help simulate multi-turn agent running results.
Corresponds to the JSON property userScenario
17771 17772 17773 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17771 def user_scenario @user_scenario end |
#value ⇒ Object
Fields and values that can be used to populate the prompt template.
Corresponds to the JSON property value
17776 17777 17778 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17776 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17783 17784 17785 17786 17787 17788 17789 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17783 def update!(**args) @agent_data = args[:agent_data] if args.key?(:agent_data) @prompt_template_data = args[:prompt_template_data] if args.key?(:prompt_template_data) @text = args[:text] if args.key?(:text) @user_scenario = args[:user_scenario] if args.key?(:user_scenario) @value = args[:value] if args.key?(:value) end |