Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPromptUserScenario

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

User scenario to help simulate multi-turn agent running results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationPromptUserScenario

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationPromptUserScenario.



17827
17828
17829
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_planString

Required. The plan for the conversation, used to drive the multi-turn agent run and generate the simulated agent evaluation dataset. Corresponds to the JSON property conversationPlan

Returns:

  • (String)


17819
17820
17821
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17819

def conversation_plan
  @conversation_plan
end

#starting_promptString

Required. The prompt that starts the conversation between the simulated user and the agent under test. Corresponds to the JSON property startingPrompt

Returns:

  • (String)


17825
17826
17827
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17825

def starting_prompt
  @starting_prompt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17832
17833
17834
17835
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17832

def update!(**args)
  @conversation_plan = args[:conversation_plan] if args.key?(:conversation_plan)
  @starting_prompt = args[:starting_prompt] if args.key?(:starting_prompt)
end