Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A single evaluation request supporting input for both single-turn model
generation and multi-turn agent execution traces. Valid input modes: 1.
Inference Mode: prompt is set (containing text or AgentData context). 2.
Offline Eval Mode: prompt is unset, and candidate_responses contains
agent_data (the completed execution trace). Validation Rule: Either prompt
must be set, OR at least one of the candidate_responses must contain
agent_data.
Instance Attribute Summary collapse
-
#candidate_responses ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse>
Optional.
-
#golden_response ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse
Responses from model or agent.
-
#prompt ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPrompt
Prompt to be evaluated.
-
#rubrics ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGroup>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRequest
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRequest.
16414 16415 16416 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16414 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate_responses ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse>
Optional. Responses from model under test and other baseline models for
comparison.
Corresponds to the JSON property candidateResponses
16395 16396 16397 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16395 def candidate_responses @candidate_responses end |
#golden_response ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse
Responses from model or agent.
Corresponds to the JSON property goldenResponse
16400 16401 16402 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16400 def golden_response @golden_response end |
#prompt ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPrompt
Prompt to be evaluated. This can represent a single-turn prompt or a multi-
turn conversation for agent evaluations.
Corresponds to the JSON property prompt
16406 16407 16408 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16406 def prompt @prompt end |
#rubrics ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGroup>
Optional. Named groups of rubrics associated with this prompt. The key is a
user-defined name for the rubric group.
Corresponds to the JSON property rubrics
16412 16413 16414 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16412 def rubrics @rubrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16419 16420 16421 16422 16423 16424 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16419 def update!(**args) @candidate_responses = args[:candidate_responses] if args.key?(:candidate_responses) @golden_response = args[:golden_response] if args.key?(:golden_response) @prompt = args[:prompt] if args.key?(:prompt) @rubrics = args[:rubrics] if args.key?(:rubrics) end |