Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration that describes an agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig.



16990
16991
16992
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16990

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#developer_instructionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property developerInstruction



16983
16984
16985
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16983

def developer_instruction
  @developer_instruction
end

#toolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>

Optional. The tools available to the agent. Corresponds to the JSON property tools



16988
16989
16990
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16988

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16995
16996
16997
16998
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16995

def update!(**args)
  @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction)
  @tools = args[:tools] if args.key?(:tools)
end