Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricGenerationSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Specification for how rubrics should be generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricGenerationSpec

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricGenerationSpec.



17783
17784
17785
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17783

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metric_resource_nameString

Optional. Resource name of the metric definition. Corresponds to the JSON property metricResourceName

Returns:

  • (String)


17758
17759
17760
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17758

def metric_resource_name
  @metric_resource_name
end

#model_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigAutoraterConfig

The autorater config used for the evaluation run. Corresponds to the JSON property modelConfig



17763
17764
17765
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17763

def model_config
  @model_config
end

#prompt_templateString

Optional. Template for the prompt used to generate rubrics. The details should be updated based on the most-recent recipe requirements. Corresponds to the JSON property promptTemplate

Returns:

  • (String)


17769
17770
17771
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17769

def prompt_template
  @prompt_template
end

#rubric_content_typeString

Optional. The type of rubric content to be generated. Corresponds to the JSON property rubricContentType

Returns:

  • (String)


17774
17775
17776
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17774

def rubric_content_type
  @rubric_content_type
end

#rubric_type_ontologyArray<String>

Optional. An optional, pre-defined list of allowed types for generated rubrics. If this field is provided, it implies include_rubric_type should be true, and the generated rubric types should be chosen from this ontology. Corresponds to the JSON property rubricTypeOntology

Returns:

  • (Array<String>)


17781
17782
17783
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17781

def rubric_type_ontology
  @rubric_type_ontology
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17788
17789
17790
17791
17792
17793
17794
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17788

def update!(**args)
  @metric_resource_name = args[:metric_resource_name] if args.key?(:metric_resource_name)
  @model_config = args[:model_config] if args.key?(:model_config)
  @prompt_template = args[:prompt_template] if args.key?(:prompt_template)
  @rubric_content_type = args[:rubric_content_type] if args.key?(:rubric_content_type)
  @rubric_type_ontology = args[:rubric_type_ontology] if args.key?(:rubric_type_ontology)
end