Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

EvaluationSet is a collection of related EvaluationItems that are evaluated together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationSet

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationSet.



20575
20576
20577
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_configsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig>

Optional. Static configurations for each agent associated with the items in this set. Key: agent_id (matches the author field in events). Value: The static configuration of the agent. Corresponds to the JSON property agentConfigs



20536
20537
20538
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20536

def agent_configs
  @agent_configs
end

#create_timeString

Output only. Timestamp when this item was created. Corresponds to the JSON property createTime

Returns:

  • (String)


20541
20542
20543
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20541

def create_time
  @create_time
end

#display_nameString

Required. The display name of the EvaluationSet. Corresponds to the JSON property displayName

Returns:

  • (String)


20546
20547
20548
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20546

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



20552
20553
20554
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20552

def encryption_spec
  @encryption_spec
end

#evaluation_itemsArray<String>

Required. The EvaluationItems that are part of this dataset. Corresponds to the JSON property evaluationItems

Returns:

  • (Array<String>)


20557
20558
20559
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20557

def evaluation_items
  @evaluation_items
end

#metadataObject

Optional. Metadata for the EvaluationSet. Corresponds to the JSON property metadata

Returns:

  • (Object)


20562
20563
20564
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20562

def 
  @metadata
end

#nameString

Identifier. The resource name of the EvaluationSet. Format: projects/project /locations/location/evaluationSets/evaluation_set` Corresponds to the JSON propertyname`

Returns:

  • (String)


20568
20569
20570
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20568

def name
  @name
end

#update_timeString

Output only. Timestamp when this item was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


20573
20574
20575
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20573

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20580
20581
20582
20583
20584
20585
20586
20587
20588
20589
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20580

def update!(**args)
  @agent_configs = args[:agent_configs] if args.key?(:agent_configs)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @evaluation_items = args[:evaluation_items] if args.key?(:evaluation_items)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end