Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesExampleGcsSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The Cloud Storage input instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExamplesExampleGcsSource

Returns a new instance of GoogleCloudAiplatformV1beta1ExamplesExampleGcsSource.



19624
19625
19626
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19624

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_formatString

The format in which instances are given, if not specified, assume it's JSONL format. Currently only JSONL format is supported. Corresponds to the JSON property dataFormat

Returns:

  • (String)


19617
19618
19619
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19617

def data_format
  @data_format
end

#gcs_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



19622
19623
19624
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19622

def gcs_source
  @gcs_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19629
19630
19631
19632
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19629

def update!(**args)
  @data_format = args[:data_format] if args.key?(:data_format)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
end