Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExecutableCode
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExecutableCode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Code generated by the model that is meant to be executed, and the result
returned to the model. Generated when using the CodeExecution tool, in which
the code will be automatically executed, and a corresponding
CodeExecutionResult will also be generated.
Instance Attribute Summary collapse
-
#code ⇒ String
Required.
-
#id ⇒ String
Optional.
-
#language ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecutableCode
constructor
A new instance of GoogleCloudAiplatformV1beta1ExecutableCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecutableCode
Returns a new instance of GoogleCloudAiplatformV1beta1ExecutableCode.
21187 21188 21189 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21187 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Required. The code to be executed.
Corresponds to the JSON property code
21174 21175 21176 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21174 def code @code end |
#id ⇒ String
Optional. Unique identifier of the ExecutableCode part. The server returns
the CodeExecutionResult with the matching id.
Corresponds to the JSON property id
21180 21181 21182 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21180 def id @id end |
#language ⇒ String
Required. Programming language of the code.
Corresponds to the JSON property language
21185 21186 21187 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21185 def language @language end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21192 21193 21194 21195 21196 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21192 def update!(**args) @code = args[:code] if args.key?(:code) @id = args[:id] if args.key?(:id) @language = args[:language] if args.key?(:language) end |