Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExecuteExtensionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ExtensionExecutionService.ExecuteExtension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecuteExtensionRequest

Returns a new instance of GoogleCloudAiplatformV1beta1ExecuteExtensionRequest.



19799
19800
19801
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19799

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operation_idString

Required. The desired ID of the operation to be executed in this extension as defined in ExtensionOperation.operation_id. Corresponds to the JSON property operationId

Returns:

  • (String)


19784
19785
19786
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19784

def operation_id
  @operation_id
end

#operation_paramsHash<String,Object>

Optional. Request parameters that will be used for executing this operation. The struct should be in a form of map with param name as the key and actual param value as the value. E.g. If this operation requires a param "name" to be set to "abc". you can set this to something like "name": "abc". Corresponds to the JSON property operationParams

Returns:

  • (Hash<String,Object>)


19792
19793
19794
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19792

def operation_params
  @operation_params
end

#runtime_auth_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AuthConfig

Auth configuration to run the extension. Corresponds to the JSON property runtimeAuthConfig



19797
19798
19799
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19797

def runtime_auth_config
  @runtime_auth_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19804
19805
19806
19807
19808
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19804

def update!(**args)
  @operation_id = args[:operation_id] if args.key?(:operation_id)
  @operation_params = args[:operation_params] if args.key?(:operation_params)
  @runtime_auth_config = args[:runtime_auth_config] if args.key?(:runtime_auth_config)
end