Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Explanation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Explanation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Explanation of a prediction (provided in PredictResponse.predictions) produced by the Model on a given instance.
Instance Attribute Summary collapse
-
#attributions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Attribution>
Output only.
-
#neighbors ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Neighbor>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Explanation
constructor
A new instance of GoogleCloudAiplatformV1beta1Explanation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Explanation
Returns a new instance of GoogleCloudAiplatformV1beta1Explanation.
13487 13488 13489 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13487 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Attribution>
Output only. Feature attributions grouped by predicted outputs. For Models
that predict only one output, such as regression Models that predict only one
score, there is only one attibution that explains the predicted output. For
Models that predict multiple outputs, such as multiclass Models that predict
multiple classes, each element explains one specific item. Attribution.
output_index can be used to identify which output this attribution is
explaining. By default, we provide Shapley values for the predicted class.
However, you can configure the explanation request to generate Shapley values
for any other classes too. For example, if a model predicts a probability of
0.4 for approving a loan application, the model's decision is to reject the
application since p(reject) = 0.6 > p(approve) = 0.4, and the default
Shapley values would be computed for rejection decision and not approval, even
though the latter might be the positive class. If users set
ExplanationParameters.top_k, the attributions are sorted by
instance_output_value in descending order. If ExplanationParameters.
output_indices is specified, the attributions are stored by Attribution.
output_index in the same order as they appear in the output_indices.
Corresponds to the JSON property attributions
13478 13479 13480 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13478 def attributions @attributions end |
#neighbors ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Neighbor>
Output only. List of the nearest neighbors for example-based explanations. For
models deployed with the examples explanations feature enabled, the
attributions field is empty and instead the neighbors field is populated.
Corresponds to the JSON property neighbors
13485 13486 13487 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13485 def neighbors @neighbors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13492 13493 13494 13495 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13492 def update!(**args) @attributions = args[:attributions] if args.key?(:attributions) @neighbors = args[:neighbors] if args.key?(:neighbors) end |