Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpecOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The ExplanationSpec entries that can be overridden at online explanation time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplanationSpecOverride

Returns a new instance of GoogleCloudAiplatformV1beta1ExplanationSpecOverride.



22061
22062
22063
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22061

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#examples_overrideGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesOverride

Overrides for example-based explanations. Corresponds to the JSON property examplesOverride



22048
22049
22050
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22048

def examples_override
  @examples_override
end

#metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataOverride

The ExplanationMetadata entries that can be overridden at online explanation time. Corresponds to the JSON property metadata



22054
22055
22056
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22054

def 
  @metadata
end

#parametersGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationParameters

Parameters to configure explaining for Model's predictions. Corresponds to the JSON property parameters



22059
22060
22061
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22059

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22066
22067
22068
22069
22070
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22066

def update!(**args)
  @examples_override = args[:examples_override] if args.key?(:examples_override)
  @metadata = args[:metadata] if args.key?(:metadata)
  @parameters = args[:parameters] if args.key?(:parameters)
end