Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for FeaturestoreService.ExportFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest.



22168
22169
22170
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22168

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureValueDestination

A destination location for Feature values and format. Corresponds to the JSON property destination



22144
22145
22146
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22144

def destination
  @destination
end

#feature_selectorGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelector

Selector for Features of an EntityType. Corresponds to the JSON property featureSelector



22149
22150
22151
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22149

def feature_selector
  @feature_selector
end

#full_exportGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestFullExport

Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time]. Corresponds to the JSON property fullExport



22155
22156
22157
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22155

def full_export
  @full_export
end

#settingsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DestinationFeatureSetting>

Per-Feature export settings. Corresponds to the JSON property settings



22160
22161
22162
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22160

def settings
  @settings
end

#snapshot_exportGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestSnapshotExport

Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time]. Corresponds to the JSON property snapshotExport



22166
22167
22168
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22166

def snapshot_export
  @snapshot_export
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22173
22174
22175
22176
22177
22178
22179
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22173

def update!(**args)
  @destination = args[:destination] if args.key?(:destination)
  @feature_selector = args[:feature_selector] if args.key?(:feature_selector)
  @full_export = args[:full_export] if args.key?(:full_export)
  @settings = args[:settings] if args.key?(:settings)
  @snapshot_export = args[:snapshot_export] if args.key?(:snapshot_export)
end