Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportModelOperationMetadataOutputInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Further describes the output of the ExportModel. Supplements ExportModelRequest.OutputConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportModelOperationMetadataOutputInfo

Returns a new instance of GoogleCloudAiplatformV1beta1ExportModelOperationMetadataOutputInfo.



22394
22395
22396
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22394

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_output_uriString

Output only. If the Model artifact is being exported to Google Cloud Storage this is the full path of the directory created, into which the Model files are being written to. Corresponds to the JSON property artifactOutputUri

Returns:

  • (String)


22386
22387
22388
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22386

def artifact_output_uri
  @artifact_output_uri
end

#image_output_uriString

Output only. If the Model image is being exported to Google Container Registry or Artifact Registry this is the full path of the image created. Corresponds to the JSON property imageOutputUri

Returns:

  • (String)


22392
22393
22394
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22392

def image_output_uri
  @image_output_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22399
22400
22401
22402
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22399

def update!(**args)
  @artifact_output_uri = args[:artifact_output_uri] if args.key?(:artifact_output_uri)
  @image_output_uri = args[:image_output_uri] if args.key?(:image_output_uri)
end