Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportPublisherModelRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportPublisherModelRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ModelGardenService.ExportPublisherModel.
Instance Attribute Summary collapse
-
#destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportPublisherModelRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1ExportPublisherModelRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportPublisherModelRequest
Returns a new instance of GoogleCloudAiplatformV1beta1ExportPublisherModelRequest.
19264 19265 19266 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19264 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property destination
19262 19263 19264 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19262 def destination @destination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19269 19270 19271 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19269 def update!(**args) @destination = args[:destination] if args.key?(:destination) end |