Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Fact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The fact used in grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Fact

Returns a new instance of GoogleCloudAiplatformV1beta1Fact.



23014
23015
23016
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunkGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk

A RagChunk includes the content of a chunk of a RagFile, and associated metadata. Corresponds to the JSON property chunk



22976
22977
22978
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22976

def chunk
  @chunk
end

#queryString

Query that is used to retrieve this fact. Corresponds to the JSON property query

Returns:

  • (String)


22981
22982
22983
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22981

def query
  @query
end

#scoreFloat

If present, according to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the fact and its range depends on the metric type. For example, if the metric type is COSINE_DISTANCE, it represents the distance between the query and the fact. The larger the distance, the less relevant the fact is to the query. The range is [0, 2], while 0 means the most relevant and 2 means the least relevant. Corresponds to the JSON property score

Returns:

  • (Float)


22992
22993
22994
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22992

def score
  @score
end

#summaryString

If present, the summary/snippet of the fact. Corresponds to the JSON property summary

Returns:

  • (String)


22997
22998
22999
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22997

def summary
  @summary
end

#titleString

If present, it refers to the title of this fact. Corresponds to the JSON property title

Returns:

  • (String)


23002
23003
23004
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23002

def title
  @title
end

#uriString

If present, this uri links to the source of the fact. Corresponds to the JSON property uri

Returns:

  • (String)


23007
23008
23009
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23007

def uri
  @uri
end

#vector_distanceFloat

If present, the distance between the query vector and this fact vector. Corresponds to the JSON property vectorDistance

Returns:

  • (Float)


23012
23013
23014
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23012

def vector_distance
  @vector_distance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23019
23020
23021
23022
23023
23024
23025
23026
23027
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23019

def update!(**args)
  @chunk = args[:chunk] if args.key?(:chunk)
  @query = args[:query] if args.key?(:query)
  @score = args[:score] if args.key?(:score)
  @summary = args[:summary] if args.key?(:summary)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
  @vector_distance = args[:vector_distance] if args.key?(:vector_distance)
end