Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FasterDeploymentConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FasterDeploymentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for faster model deployment.
Instance Attribute Summary collapse
-
#fast_tryout_enabled ⇒ Boolean
(also: #fast_tryout_enabled?)
If true, enable fast tryout feature for this deployed model.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FasterDeploymentConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1FasterDeploymentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FasterDeploymentConfig
Returns a new instance of GoogleCloudAiplatformV1beta1FasterDeploymentConfig.
21291 21292 21293 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21291 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fast_tryout_enabled ⇒ Boolean Also known as: fast_tryout_enabled?
If true, enable fast tryout feature for this deployed model.
Corresponds to the JSON property fastTryoutEnabled
21288 21289 21290 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21288 def fast_tryout_enabled @fast_tryout_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21296 21297 21298 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21296 def update!(**args) @fast_tryout_enabled = args[:fast_tryout_enabled] if args.key?(:fast_tryout_enabled) end |