Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Feature

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Feature Metadata information. For example, color is a feature that describes an apple.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Feature

Returns a new instance of GoogleCloudAiplatformV1beta1Feature.



23181
23182
23183
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23181

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Only applicable for Vertex AI Feature Store (Legacy). Timestamp when this EntityType was created. Corresponds to the JSON property createTime

Returns:

  • (String)


23087
23088
23089
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23087

def create_time
  @create_time
end

#descriptionString

Description of the Feature. Corresponds to the JSON property description

Returns:

  • (String)


23092
23093
23094
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23092

def description
  @description
end

#disable_monitoringBoolean Also known as: disable_monitoring?

Optional. Only applicable for Vertex AI Feature Store (Legacy). If not set, use the monitoring_config defined for the EntityType this Feature belongs to. Only Features with type (Feature.ValueType) BOOL, STRING, DOUBLE or INT64 can enable monitoring. If set to true, all types of data monitoring are disabled despite the config on EntityType. Corresponds to the JSON property disableMonitoring

Returns:

  • (Boolean)


23101
23102
23103
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23101

def disable_monitoring
  @disable_monitoring
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


23108
23109
23110
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23108

def etag
  @etag
end

#feature_stats_and_anomalyArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly>

Output only. Only applicable for Vertex AI Feature Store. The list of historical stats and anomalies. Corresponds to the JSON property featureStatsAndAnomaly



23114
23115
23116
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23114

def feature_stats_and_anomaly
  @feature_stats_and_anomaly
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your Features. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one Feature (System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


23125
23126
23127
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23125

def labels
  @labels
end

#monitoring_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfig

Configuration of how features in Featurestore are monitored. Corresponds to the JSON property monitoringConfig



23130
23131
23132
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23130

def monitoring_config
  @monitoring_config
end

#monitoring_statsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAnomaly>

Output only. Only applicable for Vertex AI Feature Store (Legacy). A list of historical SnapshotAnalysis stats requested by user, sorted by FeatureStatsAnomaly.start_time descending. Corresponds to the JSON property monitoringStats



23137
23138
23139
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23137

def monitoring_stats
  @monitoring_stats
end

#monitoring_stats_anomaliesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitoringStatsAnomaly>

Output only. Only applicable for Vertex AI Feature Store (Legacy). The list of historical stats and anomalies with specified objectives. Corresponds to the JSON property monitoringStatsAnomalies



23143
23144
23145
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23143

def monitoring_stats_anomalies
  @monitoring_stats_anomalies
end

#nameString

Immutable. Name of the Feature. Format: projects/project/locations/ location/featurestores/featurestore/entityTypes/entity_type/features/ feature`projects/`project`/locations/`location`/featureGroups/` feature_group`/features/`feature The last part feature is assigned by the client. The feature can be up to 64 characters long and can consist only of ASCII Latin letters A-Z and a-z, underscore(_), and ASCII digits 0-9 starting with a letter. The value will be unique given an entity type. Corresponds to the JSON property name

Returns:

  • (String)


23154
23155
23156
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23154

def name
  @name
end

#point_of_contactString

Entity responsible for maintaining this feature. Can be comma separated list of email addresses or URIs. Corresponds to the JSON property pointOfContact

Returns:

  • (String)


23160
23161
23162
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23160

def point_of_contact
  @point_of_contact
end

#update_timeString

Output only. Only applicable for Vertex AI Feature Store (Legacy). Timestamp when this EntityType was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


23166
23167
23168
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23166

def update_time
  @update_time
end

#value_typeString

Immutable. Only applicable for Vertex AI Feature Store (Legacy). Type of Feature value. Corresponds to the JSON property valueType

Returns:

  • (String)


23172
23173
23174
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23172

def value_type
  @value_type
end

#version_column_nameString

Only applicable for Vertex AI Feature Store. The name of the BigQuery Table/ View column hosting data for this version. If no value is provided, will use feature_id. Corresponds to the JSON property versionColumnName

Returns:

  • (String)


23179
23180
23181
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23179

def version_column_name
  @version_column_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23186
23187
23188
23189
23190
23191
23192
23193
23194
23195
23196
23197
23198
23199
23200
23201
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23186

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disable_monitoring = args[:disable_monitoring] if args.key?(:disable_monitoring)
  @etag = args[:etag] if args.key?(:etag)
  @feature_stats_and_anomaly = args[:feature_stats_and_anomaly] if args.key?(:feature_stats_and_anomaly)
  @labels = args[:labels] if args.key?(:labels)
  @monitoring_config = args[:monitoring_config] if args.key?(:monitoring_config)
  @monitoring_stats = args[:monitoring_stats] if args.key?(:monitoring_stats)
  @monitoring_stats_anomalies = args[:monitoring_stats_anomalies] if args.key?(:monitoring_stats_anomalies)
  @name = args[:name] if args.key?(:name)
  @point_of_contact = args[:point_of_contact] if args.key?(:point_of_contact)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
  @version_column_name = args[:version_column_name] if args.key?(:version_column_name)
end