Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureNoiseSigma
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureNoiseSigma
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Noise sigma by features. Noise sigma represents the standard deviation of the gaussian kernel that will be used to add noise to interpolated inputs prior to computing gradients.
Instance Attribute Summary collapse
-
#noise_sigma ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureNoiseSigmaNoiseSigmaForFeature>
Noise sigma per feature.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureNoiseSigma
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureNoiseSigma.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureNoiseSigma
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureNoiseSigma.
23530 23531 23532 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#noise_sigma ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureNoiseSigmaNoiseSigmaForFeature>
Noise sigma per feature. No noise is added to features that are not set.
Corresponds to the JSON property noiseSigma
23528 23529 23530 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23528 def noise_sigma @noise_sigma end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23535 23536 23537 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23535 def update!(**args) @noise_sigma = args[:noise_sigma] if args.key?(:noise_sigma) end |