Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureNoiseSigmaNoiseSigmaForFeature
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureNoiseSigmaNoiseSigmaForFeature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Noise sigma for a single feature.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the input feature for which noise sigma is provided.
-
#sigma ⇒ Float
This represents the standard deviation of the Gaussian kernel that will be used to add noise to the feature prior to computing gradients.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureNoiseSigmaNoiseSigmaForFeature
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureNoiseSigmaNoiseSigmaForFeature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureNoiseSigmaNoiseSigmaForFeature
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureNoiseSigmaNoiseSigmaForFeature.
21664 21665 21666 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21664 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name of the input feature for which noise sigma is provided. The features
are defined in explanation metadata inputs.
Corresponds to the JSON property name
21654 21655 21656 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21654 def name @name end |
#sigma ⇒ Float
This represents the standard deviation of the Gaussian kernel that will be
used to add noise to the feature prior to computing gradients. Similar to
noise_sigma but represents the noise added to the current feature. Defaults to
0.1.
Corresponds to the JSON property sigma
21662 21663 21664 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21662 def sigma @sigma end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21669 21670 21671 21672 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21669 def update!(**args) @name = args[:name] if args.key?(:name) @sigma = args[:sigma] if args.key?(:sigma) end |