Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Vertex AI Feature Online Store provides a centralized repository for serving ML features and embedding indexes at low latency. The Feature Online Store is a top-level container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStore

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStore.



23718
23719
23720
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigtableGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable

Contains settings for the Cloud Bigtable instance that will be created to serve featureValues for all FeatureViews under this FeatureOnlineStore. Corresponds to the JSON property bigtable



23640
23641
23642
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23640

def bigtable
  @bigtable
end

#create_timeString

Output only. Timestamp when this FeatureOnlineStore was created. Corresponds to the JSON property createTime

Returns:

  • (String)


23645
23646
23647
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23645

def create_time
  @create_time
end

#dedicated_serving_endpointGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint

The dedicated serving endpoint for this FeatureOnlineStore. Only need to set when you choose Optimized storage type. Public endpoint is provisioned by default. Corresponds to the JSON property dedicatedServingEndpoint



23652
23653
23654
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23652

def dedicated_serving_endpoint
  @dedicated_serving_endpoint
end

#embedding_managementGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreEmbeddingManagement

Deprecated: This sub message is no longer needed anymore and embedding management is automatically enabled when specifying Optimized storage type. Contains settings for embedding management. Corresponds to the JSON property embeddingManagement



23659
23660
23661
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23659

def embedding_management
  @embedding_management
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



23665
23666
23667
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23665

def encryption_spec
  @encryption_spec
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


23671
23672
23673
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23671

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your FeatureOnlineStore. Label keys and values can be no longer than 64 characters ( Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo. gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one FeatureOnlineStore(System labels are excluded)." System reserved label keys are prefixed with "aiplatform. googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


23683
23684
23685
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23683

def labels
  @labels
end

#nameString

Identifier. Name of the FeatureOnlineStore. Format: projects/project/ locations/location/featureOnlineStores/featureOnlineStore` Corresponds to the JSON propertyname`

Returns:

  • (String)


23689
23690
23691
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23689

def name
  @name
end

#optimizedGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreOptimized

Optimized storage type Corresponds to the JSON property optimized



23694
23695
23696
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23694

def optimized
  @optimized
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


23699
23700
23701
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23699

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


23705
23706
23707
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23705

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. State of the featureOnlineStore. Corresponds to the JSON property state

Returns:

  • (String)


23711
23712
23713
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23711

def state
  @state
end

#update_timeString

Output only. Timestamp when this FeatureOnlineStore was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


23716
23717
23718
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23716

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23723
23724
23725
23726
23727
23728
23729
23730
23731
23732
23733
23734
23735
23736
23737
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23723

def update!(**args)
  @bigtable = args[:bigtable] if args.key?(:bigtable)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_serving_endpoint = args[:dedicated_serving_endpoint] if args.key?(:dedicated_serving_endpoint)
  @embedding_management = args[:embedding_management] if args.key?(:embedding_management)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @optimized = args[:optimized] if args.key?(:optimized)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end