Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The dedicated serving endpoint for this FeatureOnlineStore. Only need to set when you choose Optimized storage type. Public endpoint is provisioned by default.
Instance Attribute Summary collapse
-
#private_service_connect_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig
Represents configuration for private service connect.
-
#public_endpoint_domain_name ⇒ String
Output only.
-
#service_attachment ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint.
23874 23875 23876 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23874 def initialize(**args) update!(**args) end |
Instance Attribute Details
#private_service_connect_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig
Represents configuration for private service connect.
Corresponds to the JSON property privateServiceConnectConfig
23860 23861 23862 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23860 def private_service_connect_config @private_service_connect_config end |
#public_endpoint_domain_name ⇒ String
Output only. This field will be populated with the domain name to use for this
FeatureOnlineStore
Corresponds to the JSON property publicEndpointDomainName
23866 23867 23868 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23866 def public_endpoint_domain_name @public_endpoint_domain_name end |
#service_attachment ⇒ String
Output only. The name of the service attachment resource. Populated if private
service connect is enabled and after FeatureViewSync is created.
Corresponds to the JSON property serviceAttachment
23872 23873 23874 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23872 def @service_attachment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23879 23880 23881 23882 23883 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23879 def update!(**args) @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config) @public_endpoint_domain_name = args[:public_endpoint_domain_name] if args.key?(:public_endpoint_domain_name) @service_attachment = args[:service_attachment] if args.key?(:service_attachment) end |