Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreEmbeddingManagement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Deprecated: This sub message is no longer needed anymore and embedding management is automatically enabled when specifying Optimized storage type. Contains settings for embedding management.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStoreEmbeddingManagement

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStoreEmbeddingManagement.



23900
23901
23902
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Optional. Immutable. Whether to enable embedding management in this FeatureOnlineStore. It's immutable after creation to ensure the FeatureOnlineStore availability. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


23897
23898
23899
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23897

def enabled
  @enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23905
23906
23907
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23905

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
end