Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A Feature Registry source for features that need to be synced to Online Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySource

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySource.



24634
24635
24636
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24634

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feature_groupsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySourceFeatureGroup>

Required. List of features that need to be synced to Online Store. Corresponds to the JSON property featureGroups



24627
24628
24629
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24627

def feature_groups
  @feature_groups
end

#project_numberFixnum

Optional. The project number of the parent project of the Feature Groups. Corresponds to the JSON property projectNumber

Returns:

  • (Fixnum)


24632
24633
24634
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24632

def project_number
  @project_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24639
24640
24641
24642
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24639

def update!(**args)
  @feature_groups = args[:feature_groups] if args.key?(:feature_groups)
  @project_number = args[:project_number] if args.key?(:project_number)
end