Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for FeatureViews created in Optimized FeatureOnlineStore.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig.



24776
24777
24778
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24776

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automatic_resourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AutomaticResources

A description of resources that to large degree are decided by Agent Platform, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines. Corresponds to the JSON property automaticResources



24774
24775
24776
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24774

def automatic_resources
  @automatic_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24781
24782
24783
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24781

def update!(**args)
  @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources)
end