Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Deprecated. Use IndexConfig instead.
Instance Attribute Summary collapse
-
#brute_force_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfigBruteForceConfig
Optional.
-
#crowding_column ⇒ String
Optional.
-
#distance_measure_type ⇒ String
Optional.
-
#embedding_column ⇒ String
Optional.
-
#embedding_dimension ⇒ Fixnum
Optional.
-
#filter_columns ⇒ Array<String>
Optional.
-
#tree_ah_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfigTreeAhConfig
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfig
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfig.
25032 25033 25034 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25032 def initialize(**args) update!(**args) end |
Instance Attribute Details
#brute_force_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfigBruteForceConfig
Optional. Configuration options for using brute force search, which simply
implements the standard linear search in the database for each query. It is
primarily meant for benchmarking and to generate the ground truth for
approximate search.
Corresponds to the JSON property bruteForceConfig
24992 24993 24994 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24992 def brute_force_config @brute_force_config end |
#crowding_column ⇒ String
Optional. Column of crowding. This column contains crowding attribute which is
a constraint on a neighbor list produced by FeatureOnlineStoreService.
SearchNearestEntities to diversify search results. If NearestNeighborQuery.
per_crowding_attribute_neighbor_count is set to K in
SearchNearestEntitiesRequest, it's guaranteed that no more than K entities of
the same crowding attribute are returned in the response.
Corresponds to the JSON property crowdingColumn
25002 25003 25004 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25002 def crowding_column @crowding_column end |
#distance_measure_type ⇒ String
Optional. The distance measure used in nearest neighbor search.
Corresponds to the JSON property distanceMeasureType
25007 25008 25009 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25007 def distance_measure_type @distance_measure_type end |
#embedding_column ⇒ String
Optional. Column of embedding. This column contains the source data to create
index for vector search. embedding_column must be set when using vector search.
Corresponds to the JSON property embeddingColumn
25013 25014 25015 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25013 def @embedding_column end |
#embedding_dimension ⇒ Fixnum
Optional. The number of dimensions of the input embedding.
Corresponds to the JSON property embeddingDimension
25018 25019 25020 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25018 def @embedding_dimension end |
#filter_columns ⇒ Array<String>
Optional. Columns of features that're used to filter vector search results.
Corresponds to the JSON property filterColumns
25023 25024 25025 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25023 def filter_columns @filter_columns end |
#tree_ah_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfigTreeAhConfig
Optional. Configuration options for the tree-AH algorithm (Shallow tree +
Asymmetric Hashing). Please refer to this paper for more details: https://
arxiv.org/abs/1908.10396
Corresponds to the JSON property treeAhConfig
25030 25031 25032 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25030 def tree_ah_config @tree_ah_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25037 25038 25039 25040 25041 25042 25043 25044 25045 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25037 def update!(**args) @brute_force_config = args[:brute_force_config] if args.key?(:brute_force_config) @crowding_column = args[:crowding_column] if args.key?(:crowding_column) @distance_measure_type = args[:distance_measure_type] if args.key?(:distance_measure_type) @embedding_column = args[:embedding_column] if args.key?(:embedding_column) @embedding_dimension = args[:embedding_dimension] if args.key?(:embedding_dimension) @filter_columns = args[:filter_columns] if args.key?(:filter_columns) @tree_ah_config = args[:tree_ah_config] if args.key?(:tree_ah_config) end |