Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVertexRagSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A Vertex Rag source for features that need to be synced to Online Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewVertexRagSource

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureViewVertexRagSource.



21860
21861
21862
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21860

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rag_corpus_idFixnum

Optional. The RAG corpus id corresponding to this FeatureView. Corresponds to the JSON property ragCorpusId

Returns:

  • (Fixnum)


21848
21849
21850
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21848

def rag_corpus_id
  @rag_corpus_id
end

#uriString

Required. The BigQuery view/table URI that will be materialized on each manual sync trigger. The table/view is expected to have the following columns and types at least: - corpus_id (STRING, NULLABLE/REQUIRED) - file_id (STRING, NULLABLE/REQUIRED) - chunk_id (STRING, NULLABLE/REQUIRED) - chunk_data_type (STRING, NULLABLE/REQUIRED) - chunk_data (STRING, NULLABLE/REQUIRED) - embeddings (FLOAT, REPEATED) - file_original_uri (STRING, NULLABLE/REQUIRED) Corresponds to the JSON property uri

Returns:

  • (String)


21858
21859
21860
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21858

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21865
21866
21867
21868
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21865

def update!(**args)
  @rag_corpus_id = args[:rag_corpus_id] if args.key?(:rag_corpus_id)
  @uri = args[:uri] if args.key?(:uri)
end