Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigImportFeaturesAnalysis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration of the Featurestore's ImportFeature Analysis Based Monitoring. This type of analysis generates statistics for values of each Feature imported by every ImportFeatureValues operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigImportFeaturesAnalysis

Returns a new instance of GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigImportFeaturesAnalysis.



25268
25269
25270
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#anomaly_detection_baselineString

The baseline used to do anomaly detection for the statistics generated by import features analysis. Corresponds to the JSON property anomalyDetectionBaseline

Returns:

  • (String)


25260
25261
25262
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25260

def anomaly_detection_baseline
  @anomaly_detection_baseline
end

#stateString

Whether to enable / disable / inherite default hebavior for import features analysis. Corresponds to the JSON property state

Returns:

  • (String)


25266
25267
25268
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25266

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25273
25274
25275
25276
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25273

def update!(**args)
  @anomaly_detection_baseline = args[:anomaly_detection_baseline] if args.key?(:anomaly_detection_baseline)
  @state = args[:state] if args.key?(:state)
end