Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigSnapshotAnalysis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration of the Featurestore's Snapshot Analysis Based Monitoring. This type of analysis generates statistics for each Feature based on a snapshot of the latest feature value of each entities every monitoring_interval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigSnapshotAnalysis

Returns a new instance of GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigSnapshotAnalysis.



25319
25320
25321
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disabledBoolean Also known as: disabled?

The monitoring schedule for snapshot analysis. For EntityType-level config: unset / disabled = true indicates disabled by default for Features under it; otherwise by default enable snapshot analysis monitoring with monitoring_interval for Features under it. Feature-level config: disabled = true indicates disabled regardless of the EntityType-level config; unset monitoring_interval indicates going with EntityType-level config; otherwise run snapshot analysis monitoring with monitoring_interval regardless of the EntityType-level config. Explicitly Disable the snapshot analysis based monitoring. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


25296
25297
25298
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25296

def disabled
  @disabled
end

#monitoring_intervalString

Configuration of the snapshot analysis based monitoring pipeline running interval. The value is rolled up to full day. If both monitoring_interval_days and the deprecated monitoring_interval field are set when creating/updating EntityTypes/Features, monitoring_interval_days will be used. Corresponds to the JSON property monitoringInterval

Returns:

  • (String)


25305
25306
25307
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25305

def monitoring_interval
  @monitoring_interval
end

#monitoring_interval_daysFixnum

Configuration of the snapshot analysis based monitoring pipeline running interval. The value indicates number of days. Corresponds to the JSON property monitoringIntervalDays

Returns:

  • (Fixnum)


25311
25312
25313
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25311

def monitoring_interval_days
  @monitoring_interval_days
end

#staleness_daysFixnum

Customized export features time window for snapshot analysis. Unit is one day. Default value is 3 weeks. Minimum value is 1 day. Maximum value is 4000 days. Corresponds to the JSON property stalenessDays

Returns:

  • (Fixnum)


25317
25318
25319
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25317

def staleness_days
  @staleness_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25324
25325
25326
25327
25328
25329
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25324

def update!(**args)
  @disabled = args[:disabled] if args.key?(:disabled)
  @monitoring_interval = args[:monitoring_interval] if args.key?(:monitoring_interval)
  @monitoring_interval_days = args[:monitoring_interval_days] if args.key?(:monitoring_interval_days)
  @staleness_days = args[:staleness_days] if args.key?(:staleness_days)
end