Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeedbackContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Feedback context is a resource that represents additional information about the conversation where the feedback was given, such as the conversation history, system instructions, etc. If provided, feedback context allows to correlate the feedback with the conversation, even if the original session is deleted or not available.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeedbackContext

Returns a new instance of GoogleCloudAiplatformV1beta1FeedbackContext.



25446
25447
25448
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25446

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#context_eventsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SessionEvent>

Optional. The session events from the originating session. Corresponds to the JSON property contextEvents



25437
25438
25439
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25437

def context_events
  @context_events
end

#nameString

Identifier. The resource name. Assigned by the server on create. Format: projects/project/locations/location/reasoningEngines/reasoning_engine/ feedbackEntries/feedback_entry/feedbackContext Corresponds to the JSON property name

Returns:

  • (String)


25444
25445
25446
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25444

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25451
25452
25453
25454
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25451

def update!(**args)
  @context_events = args[:context_events] if args.key?(:context_events)
  @name = args[:name] if args.key?(:name)
end