Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeedbackEntry
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeedbackEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
FeedbackEntry is a resource that represents a user's feedback on a conversation with an agent.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_metadata ⇒ Hash<String,String>
Optional.
-
#event_id ⇒ String
Required.
-
#feedback_labels ⇒ Array<String>
Corresponds to the JSON property
feedbackLabels. -
#feedback_text ⇒ String
Optional.
-
#feedback_type ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#session_id ⇒ String
Required.
-
#source ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#user_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeedbackEntry
constructor
A new instance of GoogleCloudAiplatformV1beta1FeedbackEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeedbackEntry
Returns a new instance of GoogleCloudAiplatformV1beta1FeedbackEntry.
25523 25524 25525 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25523 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the entry was created.
Corresponds to the JSON property createTime
25465 25466 25467 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25465 def create_time @create_time end |
#custom_metadata ⇒ Hash<String,String>
Optional. Additional key-value metadata associated with the feedback.
Corresponds to the JSON property customMetadata
25470 25471 25472 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25470 def @custom_metadata end |
#event_id ⇒ String
Required. The ID of the event within the session that the feedback relates to.
Corresponds to the JSON property eventId
25475 25476 25477 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25475 def event_id @event_id end |
#feedback_labels ⇒ Array<String>
Corresponds to the JSON property feedbackLabels
25480 25481 25482 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25480 def feedback_labels @feedback_labels end |
#feedback_text ⇒ String
Optional. Qualitative free-form comments provided by the user.
Corresponds to the JSON property feedbackText
25485 25486 25487 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25485 def feedback_text @feedback_text end |
#feedback_type ⇒ String
Required. The coarse-grained type of feedback provided by the user. Must be
set to a value other than FEEDBACK_TYPE_UNSPECIFIED.
Corresponds to the JSON property feedbackType
25491 25492 25493 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25491 def feedback_type @feedback_type end |
#name ⇒ String
Identifier. The resource name. Assigned by the server on create. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
feedbackEntries/feedback_entry`
Corresponds to the JSON propertyname`
25498 25499 25500 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25498 def name @name end |
#session_id ⇒ String
Required. The ID of the session that the feedback relates to.
Corresponds to the JSON property sessionId
25503 25504 25505 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25503 def session_id @session_id end |
#source ⇒ String
Optional. The surface that the feedback originated from.
Corresponds to the JSON property source
25508 25509 25510 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25508 def source @source end |
#update_time ⇒ String
Output only. The time at which the entry was most recently updated.
Corresponds to the JSON property updateTime
25513 25514 25515 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25513 def update_time @update_time end |
#user_id ⇒ String
Optional. A caller-supplied identifier for the user who provided the feedback.
The semantics of this field (for example whether it is an opaque token, a
hashed value, or a user-visible identifier) are determined by the calling
application.
Corresponds to the JSON property userId
25521 25522 25523 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25521 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25528 25529 25530 25531 25532 25533 25534 25535 25536 25537 25538 25539 25540 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25528 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata) @event_id = args[:event_id] if args.key?(:event_id) @feedback_labels = args[:feedback_labels] if args.key?(:feedback_labels) @feedback_text = args[:feedback_text] if args.key?(:feedback_text) @feedback_type = args[:feedback_type] if args.key?(:feedback_type) @name = args[:name] if args.key?(:name) @session_id = args[:session_id] if args.key?(:session_id) @source = args[:source] if args.key?(:source) @update_time = args[:update_time] if args.key?(:update_time) @user_id = args[:user_id] if args.key?(:user_id) end |