Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FetchFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for FeatureOnlineStoreService.FetchFeatureValues. All the features under the requested feature view will be returned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FetchFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1FetchFeatureValuesRequest.



25639
25640
25641
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_formatString

Optional. Response data format. If not set, FeatureViewDataFormat.KEY_VALUE will be used. Corresponds to the JSON property dataFormat

Returns:

  • (String)


25620
25621
25622
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25620

def data_format
  @data_format
end

#data_keyGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewDataKey

Lookup key for a feature view. Corresponds to the JSON property dataKey



25625
25626
25627
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25625

def data_key
  @data_key
end

#formatString

Specify response data format. If not set, KeyValue format will be used. Deprecated. Use FetchFeatureValuesRequest.data_format. Corresponds to the JSON property format

Returns:

  • (String)


25631
25632
25633
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25631

def format
  @format
end

#idString

Simple ID. The whole string will be used as is to identify Entity to fetch feature values for. Corresponds to the JSON property id

Returns:

  • (String)


25637
25638
25639
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25637

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25644
25645
25646
25647
25648
25649
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25644

def update!(**args)
  @data_format = args[:data_format] if args.key?(:data_format)
  @data_key = args[:data_key] if args.key?(:data_key)
  @format = args[:format] if args.key?(:format)
  @id = args[:id] if args.key?(:id)
end