Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The result output from a FunctionCall that contains a string representing the
FunctionDeclaration.name and a structured JSON object containing any output
from the function is used as context to the model. This should contain the
result of a FunctionCall made based on model prediction.
Instance Attribute Summary collapse
-
#id ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionResponsePart>
Optional.
-
#response ⇒ Hash<String,Object>
Required.
-
#scheduling ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1FunctionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionResponse
Returns a new instance of GoogleCloudAiplatformV1beta1FunctionResponse.
26510 26511 26512 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26510 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Optional. The id of the function call this response is for. Populated by the
client to match the corresponding function call id.
Corresponds to the JSON property id
26481 26482 26483 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26481 def id @id end |
#name ⇒ String
Required. The name of the function to call. Matches FunctionDeclaration.name
and FunctionCall.name.
Corresponds to the JSON property name
26487 26488 26489 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26487 def name @name end |
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionResponsePart>
Optional. Ordered Parts that constitute a function response. Parts may have
different IANA MIME types.
Corresponds to the JSON property parts
26493 26494 26495 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26493 def parts @parts end |
#response ⇒ Hash<String,Object>
Required. The function response in JSON object format. Use "output" key to
specify function output and "error" key to specify error details (if any). If "
output" and "error" keys are not specified, then whole "response" is treated
as function output.
Corresponds to the JSON property response
26501 26502 26503 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26501 def response @response end |
#scheduling ⇒ String
Optional. Specifies how the response should be scheduled in the conversation.
Only applicable to NON_BLOCKING function calls, is ignored otherwise. Defaults
to WHEN_IDLE.
Corresponds to the JSON property scheduling
26508 26509 26510 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26508 def scheduling @scheduling end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26515 26516 26517 26518 26519 26520 26521 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26515 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @parts = args[:parts] if args.key?(:parts) @response = args[:response] if args.key?(:response) @scheduling = args[:scheduling] if args.key?(:scheduling) end |