Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionResponsePart

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A datatype containing media that is part of a FunctionResponse message. A FunctionResponsePart consists of data which has an associated datatype. A FunctionResponsePart can only contain one of the accepted types in FunctionResponsePart.data. A FunctionResponsePart must have a fixed IANA MIME type identifying the type and subtype of the media if the inline_data field is filled with raw bytes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionResponsePart

Returns a new instance of GoogleCloudAiplatformV1beta1FunctionResponsePart.



24782
24783
24784
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionResponseFileData

URI based data for function response. Corresponds to the JSON property fileData



24774
24775
24776
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24774

def file_data
  @file_data
end

#inline_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionResponseBlob

Raw media bytes for function response. Text should not be sent as raw bytes, use the 'text' field. Corresponds to the JSON property inlineData



24780
24781
24782
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24780

def inline_data
  @inline_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24787
24788
24789
24790
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24787

def update!(**args)
  @file_data = args[:file_data] if args.key?(:file_data)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
end