Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GatewayConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for a single gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GatewayConfig

Returns a new instance of GoogleCloudAiplatformV1beta1GatewayConfig.



26749
26750
26751
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_projectsArray<String>

Optional. Additional consumer projects permitted to attach their own PSC endpoint to this gateway's ServiceAttachment. This is the "decoupled" mode, where the customer creates the PSC endpoint in a project other than this gateway's network project. Each listed project is VPC-SC enforced: it must be within the caller's service perimeter. The owning SemanticGovernancePolicyEngine's own project is always permitted implicitly and need not be listed. Format: projects/project`(ID or number). Corresponds to the JSON propertyallowedProjects`

Returns:

  • (Array<String>)


26700
26701
26702
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26700

def allowed_projects
  @allowed_projects
end

#dns_recordString

Output only. The fully qualified record name of the created A-record in Cloud DNS. Corresponds to the JSON property dnsRecord

Returns:

  • (String)


26706
26707
26708
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26706

def dns_record
  @dns_record
end

#dns_zone_nameString

Optional. Name of the private Cloud DNS managed zone in which to create the gateway's A-record. This is the managed zone's own name, not its DNS name: for a zone serving example.internal., this field takes the zone name, such as my-private-zone. The zone's DNS name is combined with a generated per-gateway label to form the record's fully qualified name, which must stay within the 255-octet DNS limit. If the full name is too long, gateway provisioning fails when it attempts to create the DNS record. Corresponds to the JSON property dnsZoneName

Returns:

  • (String)


26717
26718
26719
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26717

def dns_zone_name
  @dns_zone_name
end

#ip_addressString

Output only. The private IP address of the PSC endpoint. Corresponds to the JSON property ipAddress

Returns:

  • (String)


26722
26723
26724
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26722

def ip_address
  @ip_address
end

#networkString

Optional. The URI of the network resource where PSC-E will be provisioned. if not provided default network will be used. Format: projects/project/global/ networks/network Corresponds to the JSON property network

Returns:

  • (String)


26729
26730
26731
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26729

def network
  @network
end

#psc_endpointString

Output only. The self-link or name of the Private Service Connect endpoint forwarding rule. Corresponds to the JSON property pscEndpoint

Returns:

  • (String)


26735
26736
26737
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26735

def psc_endpoint
  @psc_endpoint
end

#stateString

Output only. The state of the Gateway configuration. Corresponds to the JSON property state

Returns:

  • (String)


26740
26741
26742
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26740

def state
  @state
end

#subnetworkString

Optional. The URI of the subnetwork resource where PSC-E will be provisioned. if not provided default subnet will be used from the same location Format: projects/project/regions/region/subnetworks/subnetwork Corresponds to the JSON property subnetwork

Returns:

  • (String)


26747
26748
26749
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26747

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26754
26755
26756
26757
26758
26759
26760
26761
26762
26763
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26754

def update!(**args)
  @allowed_projects = args[:allowed_projects] if args.key?(:allowed_projects)
  @dns_record = args[:dns_record] if args.key?(:dns_record)
  @dns_zone_name = args[:dns_zone_name] if args.key?(:dns_zone_name)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @network = args[:network] if args.key?(:network)
  @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint)
  @state = args[:state] if args.key?(:state)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end