Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GeminiPreferenceExampleCompletion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Completion and its preference score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GeminiPreferenceExampleCompletion

Returns a new instance of GoogleCloudAiplatformV1beta1GeminiPreferenceExampleCompletion.



25487
25488
25489
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property completion



25480
25481
25482
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25480

def completion
  @completion
end

#scoreFloat

The score for the given completion. Corresponds to the JSON property score

Returns:

  • (Float)


25485
25486
25487
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25485

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25492
25493
25494
25495
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25492

def update!(**args)
  @completion = args[:completion] if args.key?(:completion)
  @score = args[:score] if args.key?(:score)
end