Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateContentResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateContentResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for [PredictionService.GenerateContent].
Instance Attribute Summary collapse
-
#candidates ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Candidate>
Output only.
-
#create_time ⇒ String
Output only.
-
#model_version ⇒ String
Output only.
-
#prompt_feedback ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateContentResponsePromptFeedback
Content filter results for a prompt sent in the request.
-
#response_id ⇒ String
Output only.
-
#usage_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateContentResponseUsageMetadata
Usage metadata about the content generation request and response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateContentResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateContentResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateContentResponse
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateContentResponse.
25343 25344 25345 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidates ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Candidate>
Output only. Generated candidates.
Corresponds to the JSON property candidates
25312 25313 25314 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25312 def candidates @candidates end |
#create_time ⇒ String
Output only. Timestamp when the request is made to the server.
Corresponds to the JSON property createTime
25317 25318 25319 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25317 def create_time @create_time end |
#model_version ⇒ String
Output only. The model version used to generate the response.
Corresponds to the JSON property modelVersion
25322 25323 25324 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25322 def model_version @model_version end |
#prompt_feedback ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateContentResponsePromptFeedback
Content filter results for a prompt sent in the request. Note: This is sent
only in the first stream chunk and only if no candidates were generated due to
content violations.
Corresponds to the JSON property promptFeedback
25329 25330 25331 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25329 def prompt_feedback @prompt_feedback end |
#response_id ⇒ String
Output only. response_id is used to identify each response. It is the encoding
of the event_id.
Corresponds to the JSON property responseId
25335 25336 25337 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25335 def response_id @response_id end |
#usage_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateContentResponseUsageMetadata
Usage metadata about the content generation request and response. This message
provides a detailed breakdown of token usage and other relevant metrics.
Corresponds to the JSON property usageMetadata
25341 25342 25343 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25341 def @usage_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25348 25349 25350 25351 25352 25353 25354 25355 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25348 def update!(**args) @candidates = args[:candidates] if args.key?(:candidates) @create_time = args[:create_time] if args.key?(:create_time) @model_version = args[:model_version] if args.key?(:model_version) @prompt_feedback = args[:prompt_feedback] if args.key?(:prompt_feedback) @response_id = args[:response_id] if args.key?(:response_id) @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata) end |