Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateInstanceRubricsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateInstanceRubricsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for EvaluationService.GenerateInstanceRubrics.
Instance Attribute Summary collapse
-
#agent_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig
Deprecated: Use
google.cloud.aiplatform.master.AgentConfiginagent_eval_datainstead. -
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Required.
-
#location ⇒ String
Required.
-
#metric_resource_name ⇒ String
Optional.
-
#predefined_rubric_generation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredefinedMetricSpec
The spec for a pre-defined metric.
-
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGenerationSpec
Specification for how rubrics should be generated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateInstanceRubricsRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateInstanceRubricsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateInstanceRubricsRequest
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateInstanceRubricsRequest.
24039 24040 24041 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24039 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig
Deprecated: Use google.cloud.aiplatform.master.AgentConfig in
agent_eval_data instead. Configuration for an Agent.
Corresponds to the JSON property agentConfig
24005 24006 24007 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24005 def agent_config @agent_config end |
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Required. The prompt to generate rubrics from. For single-turn queries, this
is a single instance. For multi-turn queries, this is a repeated field that
contains conversation history + latest request.
Corresponds to the JSON property contents
24012 24013 24014 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24012 def contents @contents end |
#location ⇒ String
Required. The resource name of the Location to generate rubrics from. Format:
projects/project/locations/location`
Corresponds to the JSON propertylocation`
24018 24019 24020 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24018 def location @location end |
#metric_resource_name ⇒ String
Optional. The resource name of a registered metric. Rubric generation using
predefined metric spec or LLMBasedMetricSpec is supported. If this field is
set, the configuration provided in this field is used for rubric generation.
The predefined_rubric_generation_spec and rubric_generation_spec fields
will be ignored.
Corresponds to the JSON property metricResourceName
24027 24028 24029 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24027 def metric_resource_name @metric_resource_name end |
#predefined_rubric_generation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredefinedMetricSpec
The spec for a pre-defined metric.
Corresponds to the JSON property predefinedRubricGenerationSpec
24032 24033 24034 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24032 def predefined_rubric_generation_spec @predefined_rubric_generation_spec end |
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGenerationSpec
Specification for how rubrics should be generated.
Corresponds to the JSON property rubricGenerationSpec
24037 24038 24039 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24037 def rubric_generation_spec @rubric_generation_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24044 24045 24046 24047 24048 24049 24050 24051 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24044 def update!(**args) @agent_config = args[:agent_config] if args.key?(:agent_config) @contents = args[:contents] if args.key?(:contents) @location = args[:location] if args.key?(:location) @metric_resource_name = args[:metric_resource_name] if args.key?(:metric_resource_name) @predefined_rubric_generation_spec = args[:predefined_rubric_generation_spec] if args.key?(:predefined_rubric_generation_spec) @rubric_generation_spec = args[:rubric_generation_spec] if args.key?(:rubric_generation_spec) end |