Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectContentsSourceEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectContentsSourceEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A single piece of conversation from which to generate memories.
Instance Attribute Summary collapse
-
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectContentsSourceEvent
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectContentsSourceEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectContentsSourceEvent
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectContentsSourceEvent.
19439 19440 19441 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
19437 19438 19439 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19437 def content @content end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19444 19445 19446 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19444 def update!(**args) @content = args[:content] if args.key?(:content) end |