Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateVideoResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateVideoResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Generate video response.
Instance Attribute Summary collapse
-
#generated_samples ⇒ Array<String>
The cloud storage uris of the generated videos.
-
#rai_media_filtered_count ⇒ Fixnum
Returns if any videos were filtered due to RAI policies.
-
#rai_media_filtered_reasons ⇒ Array<String>
Returns rai failure reasons if any.
-
#videos ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateVideoResponseVideo>
List of video bytes or Cloud Storage URIs of the generated videos.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateVideoResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateVideoResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateVideoResponse
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateVideoResponse.
24546 24547 24548 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24546 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generated_samples ⇒ Array<String>
The cloud storage uris of the generated videos.
Corresponds to the JSON property generatedSamples
24529 24530 24531 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24529 def generated_samples @generated_samples end |
#rai_media_filtered_count ⇒ Fixnum
Returns if any videos were filtered due to RAI policies.
Corresponds to the JSON property raiMediaFilteredCount
24534 24535 24536 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24534 def rai_media_filtered_count @rai_media_filtered_count end |
#rai_media_filtered_reasons ⇒ Array<String>
Returns rai failure reasons if any.
Corresponds to the JSON property raiMediaFilteredReasons
24539 24540 24541 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24539 def rai_media_filtered_reasons @rai_media_filtered_reasons end |
#videos ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateVideoResponseVideo>
List of video bytes or Cloud Storage URIs of the generated videos.
Corresponds to the JSON property videos
24544 24545 24546 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24544 def videos @videos end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24551 24552 24553 24554 24555 24556 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24551 def update!(**args) @generated_samples = args[:generated_samples] if args.key?(:generated_samples) @rai_media_filtered_count = args[:rai_media_filtered_count] if args.key?(:rai_media_filtered_count) @rai_media_filtered_reasons = args[:rai_media_filtered_reasons] if args.key?(:rai_media_filtered_reasons) @videos = args[:videos] if args.key?(:videos) end |