Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMaps

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A Maps chunk is a piece of evidence that comes from Google Maps, containing information about places or routes. This is used to provide the user with rich, location-based information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMaps

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMaps.



28850
28851
28852
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#place_answer_sourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources

The sources that were used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as URIs to flag content. Corresponds to the JSON property placeAnswerSources



28822
28823
28824
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28822

def place_answer_sources
  @place_answer_sources
end

#place_idString

This Place's resource name, in places/place_id`format. This can be used to look up the place in the Google Maps API. Corresponds to the JSON propertyplaceId`

Returns:

  • (String)


28828
28829
28830
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28828

def place_id
  @place_id
end

#routeGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsRoute

Route information from Google Maps. Corresponds to the JSON property route



28833
28834
28835
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28833

def route
  @route
end

#textString

The text of the place answer. Corresponds to the JSON property text

Returns:

  • (String)


28838
28839
28840
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28838

def text
  @text
end

#titleString

The title of the place. Corresponds to the JSON property title

Returns:

  • (String)


28843
28844
28845
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28843

def title
  @title
end

#uriString

The URI of the place. Corresponds to the JSON property uri

Returns:

  • (String)


28848
28849
28850
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28848

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28855
28856
28857
28858
28859
28860
28861
28862
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28855

def update!(**args)
  @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources)
  @place_id = args[:place_id] if args.key?(:place_id)
  @route = args[:route] if args.key?(:route)
  @text = args[:text] if args.key?(:text)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end