Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingMetadataSourceFlaggingUri

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A URI that can be used to flag a place or review for inappropriate content. This is populated only when the grounding source is Google Maps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingMetadataSourceFlaggingUri

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingMetadataSourceFlaggingUri.



20791
20792
20793
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20791

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#flag_content_uriString

The URI that can be used to flag the content. Corresponds to the JSON property flagContentUri

Returns:

  • (String)


20784
20785
20786
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20784

def flag_content_uri
  @flag_content_uri
end

#source_idString

The ID of the place or review. Corresponds to the JSON property sourceId

Returns:

  • (String)


20789
20790
20791
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20789

def source_id
  @source_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20796
20797
20798
20799
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20796

def update!(**args)
  @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri)
  @source_id = args[:source_id] if args.key?(:source_id)
end