Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingSupport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A collection of supporting references for a segment or part of the model's response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingSupport

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingSupport.



25632
25633
25634
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_scoresArray<Float>

The confidence scores for the support references. This list is parallel to the grounding_chunk_indices list. A score is a value between 0.0 and 1.0, with a higher score indicating a higher confidence that the reference supports the claim. For Gemini 2.0 and before, this list has the same size as grounding_chunk_indices. For Gemini 2.5 and later, this list is empty and should be ignored. Corresponds to the JSON property confidenceScores

Returns:

  • (Array<Float>)


25609
25610
25611
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25609

def confidence_scores
  @confidence_scores
end

#grounding_chunk_indicesArray<Fixnum>

A list of indices into the grounding_chunks field of the GroundingMetadata message. These indices specify which grounding chunks support the claim made in the content segment. For example, if this field has the values [1, 3], it means that grounding_chunks[1] and grounding_chunks[3] are the sources for the claim in the content segment. Corresponds to the JSON property groundingChunkIndices

Returns:

  • (Array<Fixnum>)


25618
25619
25620
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25618

def grounding_chunk_indices
  @grounding_chunk_indices
end

#rendered_partsArray<Fixnum>

Indices into the rendered_parts field of the GroundingMetadata message. These indices specify which rendered parts are associated with this support message. Corresponds to the JSON property renderedParts

Returns:

  • (Array<Fixnum>)


25625
25626
25627
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25625

def rendered_parts
  @rendered_parts
end

#segmentGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Segment

A segment of the content. Corresponds to the JSON property segment



25630
25631
25632
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25630

def segment
  @segment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25637
25638
25639
25640
25641
25642
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25637

def update!(**args)
  @confidence_scores = args[:confidence_scores] if args.key?(:confidence_scores)
  @grounding_chunk_indices = args[:grounding_chunk_indices] if args.key?(:grounding_chunk_indices)
  @rendered_parts = args[:rendered_parts] if args.key?(:rendered_parts)
  @segment = args[:segment] if args.key?(:segment)
end