Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for EvaluationManagementService.ImportEvaluationSet.
Instance Attribute Summary collapse
-
#agent_engine_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestAgentEngineSource
Source for loading Agent Engine sessions.
-
#bigquery_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryRequestSet
The request set for the evaluation run.
-
#cloud_trace_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestCloudTraceSource
Source for loading traces directly from Cloud Trace.
-
#evaluation_set ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationSet
EvaluationSet is a collection of related EvaluationItems that are evaluated together.
-
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestGcsSource
Source for loading data from Cloud Storage.
-
#inline_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestInlineSource
Wrapper for inline data.
-
#interactions_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestInteractionsSource
Source for importing interactions from the Interactions API into an EvaluationSet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest
Returns a new instance of GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest.
29624 29625 29626 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29624 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_engine_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestAgentEngineSource
Source for loading Agent Engine sessions.
Corresponds to the JSON property agentEngineSource
29584 29585 29586 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29584 def agent_engine_source @agent_engine_source end |
#bigquery_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryRequestSet
The request set for the evaluation run.
Corresponds to the JSON property bigquerySource
29589 29590 29591 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29589 def bigquery_source @bigquery_source end |
#cloud_trace_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestCloudTraceSource
Source for loading traces directly from Cloud Trace.
Corresponds to the JSON property cloudTraceSource
29594 29595 29596 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29594 def cloud_trace_source @cloud_trace_source end |
#evaluation_set ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationSet
EvaluationSet is a collection of related EvaluationItems that are evaluated
together.
Corresponds to the JSON property evaluationSet
29600 29601 29602 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29600 def evaluation_set @evaluation_set end |
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcsDestination
29605 29606 29607 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29605 def gcs_destination @gcs_destination end |
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestGcsSource
Source for loading data from Cloud Storage.
Corresponds to the JSON property gcsSource
29610 29611 29612 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29610 def gcs_source @gcs_source end |
#inline_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestInlineSource
Wrapper for inline data.
Corresponds to the JSON property inlineSource
29615 29616 29617 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29615 def inline_source @inline_source end |
#interactions_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestInteractionsSource
Source for importing interactions from the Interactions API into an
EvaluationSet. The agent identity is specified once, with a list of
interaction IDs to import.
Corresponds to the JSON property interactionsSource
29622 29623 29624 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29622 def interactions_source @interactions_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29629 29630 29631 29632 29633 29634 29635 29636 29637 29638 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29629 def update!(**args) @agent_engine_source = args[:agent_engine_source] if args.key?(:agent_engine_source) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @cloud_trace_source = args[:cloud_trace_source] if args.key?(:cloud_trace_source) @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @inline_source = args[:inline_source] if args.key?(:inline_source) @interactions_source = args[:interactions_source] if args.key?(:interactions_source) end |