Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportIndexRequestConnectorConfigBigQuerySourceConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportIndexRequestConnectorConfigBigQuerySourceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for importing data from a BigQuery table.
Instance Attribute Summary collapse
-
#datapoint_field_mapping ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportIndexRequestConnectorConfigDatapointFieldMapping
Mapping of datapoint fields to column names for columnar data sources.
-
#table_path ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImportIndexRequestConnectorConfigBigQuerySourceConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1ImportIndexRequestConnectorConfigBigQuerySourceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImportIndexRequestConnectorConfigBigQuerySourceConfig
Returns a new instance of GoogleCloudAiplatformV1beta1ImportIndexRequestConnectorConfigBigQuerySourceConfig.
21489 21490 21491 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21489 def initialize(**args) update!(**args) end |
Instance Attribute Details
#datapoint_field_mapping ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportIndexRequestConnectorConfigDatapointFieldMapping
Mapping of datapoint fields to column names for columnar data sources.
Corresponds to the JSON property datapointFieldMapping
21481 21482 21483 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21481 def datapoint_field_mapping @datapoint_field_mapping end |
#table_path ⇒ String
Required. The path to the BigQuery table containing the index data, in the
format of bq://...
Corresponds to the JSON property tablePath
21487 21488 21489 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21487 def table_path @table_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21494 21495 21496 21497 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21494 def update!(**args) @datapoint_field_mapping = args[:datapoint_field_mapping] if args.key?(:datapoint_field_mapping) @table_path = args[:table_path] if args.key?(:table_path) end |