Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A datapoint of Index.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IndexDatapoint

Returns a new instance of GoogleCloudAiplatformV1beta1IndexDatapoint.



30562
30563
30564
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#crowding_tagGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapointCrowdingTag

Crowding tag is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than some value k' of the k neighbors returned have the same value of crowding_attribute. Corresponds to the JSON property crowdingTag



30523
30524
30525
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30523

def crowding_tag
  @crowding_tag
end

#datapoint_idString

Required. Unique identifier of the datapoint. Corresponds to the JSON property datapointId

Returns:

  • (String)


30528
30529
30530
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30528

def datapoint_id
  @datapoint_id
end

#embedding_metadataHash<String,Object>

Optional. The key-value map of additional metadata for the datapoint. Corresponds to the JSON property embeddingMetadata

Returns:

  • (Hash<String,Object>)


30533
30534
30535
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30533

def 
  @embedding_metadata
end

#feature_vectorArray<Float>

Required. Feature embedding vector for dense index. An array of numbers with the length of [NearestNeighborSearchConfig.dimensions]. Corresponds to the JSON property featureVector

Returns:

  • (Array<Float>)


30539
30540
30541
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30539

def feature_vector
  @feature_vector
end

#numeric_restrictsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapointNumericRestriction>

Optional. List of Restrict of the datapoint, used to perform "restricted searches" where boolean rule are used to filter the subset of the database eligible for matching. This uses numeric comparisons. Corresponds to the JSON property numericRestricts



30546
30547
30548
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30546

def numeric_restricts
  @numeric_restricts
end

#restrictsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapointRestriction>

Optional. List of Restrict of the datapoint, used to perform "restricted searches" where boolean rule are used to filter the subset of the database eligible for matching. This uses categorical tokens. See: https://cloud.google. com/vertex-ai/docs/matching-engine/filtering Corresponds to the JSON property restricts



30554
30555
30556
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30554

def restricts
  @restricts
end

#sparse_embeddingGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapointSparseEmbedding

Feature embedding vector for sparse index. An array of numbers whose values are located in the specified dimensions. Corresponds to the JSON property sparseEmbedding



30560
30561
30562
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30560

def sparse_embedding
  @sparse_embedding
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30567
30568
30569
30570
30571
30572
30573
30574
30575
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30567

def update!(**args)
  @crowding_tag = args[:crowding_tag] if args.key?(:crowding_tag)
  @datapoint_id = args[:datapoint_id] if args.key?(:datapoint_id)
  @embedding_metadata = args[:embedding_metadata] if args.key?(:embedding_metadata)
  @feature_vector = args[:feature_vector] if args.key?(:feature_vector)
  @numeric_restricts = args[:numeric_restricts] if args.key?(:numeric_restricts)
  @restricts = args[:restricts] if args.key?(:restricts)
  @sparse_embedding = args[:sparse_embedding] if args.key?(:sparse_embedding)
end