Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapointSparseEmbedding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Feature embedding vector for sparse index. An array of numbers whose values are located in the specified dimensions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IndexDatapointSparseEmbedding

Returns a new instance of GoogleCloudAiplatformV1beta1IndexDatapointSparseEmbedding.



29083
29084
29085
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsArray<Fixnum>

Required. The list of indexes for the embedding values of the sparse vector. Corresponds to the JSON property dimensions

Returns:

  • (Array<Fixnum>)


29076
29077
29078
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29076

def dimensions
  @dimensions
end

#valuesArray<Float>

Required. The list of embedding values of the sparse vector. Corresponds to the JSON property values

Returns:

  • (Array<Float>)


29081
29082
29083
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29081

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29088
29089
29090
29091
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29088

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @values = args[:values] if args.key?(:values)
end