Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IngestionDirectContentsSourceEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A single event to ingest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IngestionDirectContentsSourceEvent

Returns a new instance of GoogleCloudAiplatformV1beta1IngestionDirectContentsSourceEvent.



27173
27174
27175
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



27158
27159
27160
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27158

def content
  @content
end

#event_idString

Optional. A unique identifier for the event. If an event with the same event_id is ingested multiple times, it will be de-duplicated. Corresponds to the JSON property eventId

Returns:

  • (String)


27164
27165
27166
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27164

def event_id
  @event_id
end

#event_timeString

Optional. The time at which the event occurred. If provided, this timestamp will be used for ordering events within a stream. If not provided, the server- side ingestion time will be used. Corresponds to the JSON property eventTime

Returns:

  • (String)


27171
27172
27173
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27171

def event_time
  @event_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27178
27179
27180
27181
27182
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27178

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @event_id = args[:event_id] if args.key?(:event_id)
  @event_time = args[:event_time] if args.key?(:event_time)
end