Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LineageSubgraph
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LineageSubgraph
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A subgraph of the overall lineage graph. Event edges connect Artifact and Execution nodes.
Instance Attribute Summary collapse
-
#artifacts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Artifact>
The Artifact nodes in the subgraph.
-
#events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Event>
The Event edges between Artifacts and Executions in the subgraph.
-
#executions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Execution>
The Execution nodes in the subgraph.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LineageSubgraph
constructor
A new instance of GoogleCloudAiplatformV1beta1LineageSubgraph.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LineageSubgraph
Returns a new instance of GoogleCloudAiplatformV1beta1LineageSubgraph.
31526 31527 31528 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifacts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Artifact>
The Artifact nodes in the subgraph.
Corresponds to the JSON property artifacts
31514 31515 31516 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31514 def artifacts @artifacts end |
#events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Event>
The Event edges between Artifacts and Executions in the subgraph.
Corresponds to the JSON property events
31519 31520 31521 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31519 def events @events end |
#executions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Execution>
The Execution nodes in the subgraph.
Corresponds to the JSON property executions
31524 31525 31526 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31524 def executions @executions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31531 31532 31533 31534 31535 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31531 def update!(**args) @artifacts = args[:artifacts] if args.key?(:artifacts) @events = args[:events] if args.key?(:events) @executions = args[:executions] if args.key?(:executions) end |