Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListMemoriesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListMemoriesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for MemoryBankService.ListMemories.
Instance Attribute Summary collapse
-
#memories ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Memory>
List of Memories in the requested page.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListMemoriesResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ListMemoriesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListMemoriesResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ListMemoriesResponse.
23819 23820 23821 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23819 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memories ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Memory>
List of Memories in the requested page.
Corresponds to the JSON property memories
23811 23812 23813 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23811 def memories @memories end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListMemoriesRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
23817 23818 23819 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23817 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23824 23825 23826 23827 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23824 def update!(**args) @memories = args[:memories] if args.key?(:memories) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |