Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListMemoryRevisionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for MemoryBankService.ListMemoryRevisions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListMemoryRevisionsResponse

Returns a new instance of GoogleCloudAiplatformV1beta1ListMemoryRevisionsResponse.



29224
29225
29226
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#memory_revisionsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryRevision>

The list of Memory Revisions in the request page. Corresponds to the JSON property memoryRevisions



29216
29217
29218
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29216

def memory_revisions
  @memory_revisions
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


29222
29223
29224
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29222

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29229
29230
29231
29232
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29229

def update!(**args)
  @memory_revisions = args[:memory_revisions] if args.key?(:memory_revisions)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end