Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListModelVersionCheckpointsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListModelVersionCheckpointsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for ModelService.ListModelVersionCheckpoints
Instance Attribute Summary collapse
-
#checkpoints ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelVersionCheckpoint>
List of Model Version checkpoints.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListModelVersionCheckpointsResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ListModelVersionCheckpointsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListModelVersionCheckpointsResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ListModelVersionCheckpointsResponse.
24053 24054 24055 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoints ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelVersionCheckpoint>
List of Model Version checkpoints.
Corresponds to the JSON property checkpoints
24045 24046 24047 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24045 def checkpoints @checkpoints end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to
ListModelVersionCheckpointsRequest.page_token to obtain that page.
Corresponds to the JSON property nextPageToken
24051 24052 24053 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24051 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24058 24059 24060 24061 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24058 def update!(**args) @checkpoints = args[:checkpoints] if args.key?(:checkpoints) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |