Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListModelVersionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListModelVersionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for ModelService.ListModelVersions
Instance Attribute Summary collapse
-
#models ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Model>
List of Model versions in the requested page.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListModelVersionsResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ListModelVersionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListModelVersionsResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ListModelVersionsResponse.
32953 32954 32955 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32953 def initialize(**args) update!(**args) end |
Instance Attribute Details
#models ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Model>
List of Model versions in the requested page. In the returned Model name field,
version ID instead of regvision tag will be included.
Corresponds to the JSON property models
32945 32946 32947 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32945 def models @models end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListModelVersionsRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
32951 32952 32953 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32951 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32958 32959 32960 32961 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32958 def update!(**args) @models = args[:models] if args.key?(:models) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |