Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListMonitoredAgentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for AgentAnomalyDetectionService.ListMonitoredAgents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListMonitoredAgentsResponse

Returns a new instance of GoogleCloudAiplatformV1beta1ListMonitoredAgentsResponse.



31392
31393
31394
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31392

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#monitored_agentsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MonitoredAgent>

A list of MonitoredAgents that matches the specified filter in the request. Corresponds to the JSON property monitoredAgents



31378
31379
31380
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31378

def monitored_agents
  @monitored_agents
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31384
31385
31386
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31384

def next_page_token
  @next_page_token
end

#total_sizeFixnum

The total number of MonitoredAgents matching the request, after any filter is applied. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


31390
31391
31392
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31390

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31397
31398
31399
31400
31401
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31397

def update!(**args)
  @monitored_agents = args[:monitored_agents] if args.key?(:monitored_agents)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @total_size = args[:total_size] if args.key?(:total_size)
end