Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListRagDataSchemasResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListRagDataSchemasResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for VertexRagDataService.ListRagDataSchemas.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#rag_data_schemas ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagDataSchema>
List of RagDataSchemas in the requested page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListRagDataSchemasResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ListRagDataSchemasResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListRagDataSchemasResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ListRagDataSchemasResponse.
31196 31197 31198 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31196 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to
ListRagDataSchemasRequest.page_token to obtain that page.
Corresponds to the JSON property nextPageToken
31189 31190 31191 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31189 def next_page_token @next_page_token end |
#rag_data_schemas ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagDataSchema>
List of RagDataSchemas in the requested page.
Corresponds to the JSON property ragDataSchemas
31194 31195 31196 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31194 def rag_data_schemas @rag_data_schemas end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31201 31202 31203 31204 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31201 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rag_data_schemas = args[:rag_data_schemas] if args.key?(:rag_data_schemas) end |