Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListRagMetadataResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListRagMetadataResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for VertexRagDataService.ListRagMetadata.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#rag_metadata ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadata>
List of RagMetadata in the requested page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListRagMetadataResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ListRagMetadataResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListRagMetadataResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ListRagMetadataResponse.
24413 24414 24415 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24413 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListRagMetadataRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
24406 24407 24408 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24406 def next_page_token @next_page_token end |
#rag_metadata ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadata>
List of RagMetadata in the requested page.
Corresponds to the JSON property ragMetadata
24411 24412 24413 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24411 def @rag_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24418 24419 24420 24421 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24418 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rag_metadata = args[:rag_metadata] if args.key?(:rag_metadata) end |