Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListSkillRevisionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for SkillRegistryService.ListSkillRevisions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListSkillRevisionsResponse

Returns a new instance of GoogleCloudAiplatformV1beta1ListSkillRevisionsResponse.



31512
31513
31514
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31512

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31505
31506
31507
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31505

def next_page_token
  @next_page_token
end

#skill_revisionsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SkillRevision>

The list of Skill Revisions in the request page. Corresponds to the JSON property skillRevisions



31510
31511
31512
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31510

def skill_revisions
  @skill_revisions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31517
31518
31519
31520
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31517

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @skill_revisions = args[:skill_revisions] if args.key?(:skill_revisions)
end