Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListTrainingPipelinesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListTrainingPipelinesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for PipelineService.ListTrainingPipelines
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#training_pipelines ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrainingPipeline>
List of TrainingPipelines in the requested page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListTrainingPipelinesResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ListTrainingPipelinesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListTrainingPipelinesResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ListTrainingPipelinesResponse.
30332 30333 30334 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30332 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to
ListTrainingPipelinesRequest.page_token to obtain that page.
Corresponds to the JSON property nextPageToken
30325 30326 30327 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30325 def next_page_token @next_page_token end |
#training_pipelines ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrainingPipeline>
List of TrainingPipelines in the requested page.
Corresponds to the JSON property trainingPipelines
30330 30331 30332 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30330 def training_pipelines @training_pipelines end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30337 30338 30339 30340 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30337 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @training_pipelines = args[:training_pipelines] if args.key?(:training_pipelines) end |