Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListTrialsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListTrialsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for VizierService.ListTrials.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Pass this token as the
page_tokenfield of the request for a subsequent call. -
#trials ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Trial>
The Trials associated with the Study.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListTrialsResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ListTrialsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListTrialsResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ListTrialsResponse.
33305 33306 33307 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Pass this token as the page_token field of the request for a subsequent call.
If this field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
33298 33299 33300 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33298 def next_page_token @next_page_token end |
#trials ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Trial>
The Trials associated with the Study.
Corresponds to the JSON property trials
33303 33304 33305 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33303 def trials @trials end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33310 33311 33312 33313 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33310 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @trials = args[:trials] if args.key?(:trials) end |