Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListTuningJobsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListTuningJobsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for GenAiTuningService.ListTuningJobs
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#tuning_jobs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningJob>
The tuning jobs that match the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListTuningJobsResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ListTuningJobsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListTuningJobsResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ListTuningJobsResponse.
24860 24861 24862 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24860 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this token in a subsequent [
GenAiTuningService.ListTuningJobs] call to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
24853 24854 24855 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24853 def next_page_token @next_page_token end |
#tuning_jobs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningJob>
The tuning jobs that match the request.
Corresponds to the JSON property tuningJobs
24858 24859 24860 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24858 def tuning_jobs @tuning_jobs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24865 24866 24867 24868 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24865 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @tuning_jobs = args[:tuning_jobs] if args.key?(:tuning_jobs) end |