Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a semantic grouping of failures (e.g., "Hallucination of Action").

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LossCluster

Returns a new instance of GoogleCloudAiplatformV1beta1LossCluster.



34074
34075
34076
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Unique identifier for the loss cluster within the scope of the analysis result. Corresponds to the JSON property clusterId

Returns:

  • (String)


34056
34057
34058
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34056

def cluster_id
  @cluster_id
end

#examplesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossExample>

A list of examples that belong to this cluster. This links the cluster back to the specific EvaluationItems and Rubrics. Corresponds to the JSON property examples



34062
34063
34064
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34062

def examples
  @examples
end

#item_countFixnum

The total number of EvaluationItems falling into this cluster. Corresponds to the JSON property itemCount

Returns:

  • (Fixnum)


34067
34068
34069
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34067

def item_count
  @item_count
end

#taxonomy_entryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossTaxonomyEntry

Defines a specific entry in the loss pattern taxonomy. Corresponds to the JSON property taxonomyEntry



34072
34073
34074
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34072

def taxonomy_entry
  @taxonomy_entry
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34079
34080
34081
34082
34083
34084
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34079

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @examples = args[:examples] if args.key?(:examples)
  @item_count = args[:item_count] if args.key?(:item_count)
  @taxonomy_entry = args[:taxonomy_entry] if args.key?(:taxonomy_entry)
end