Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Measurement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A message representing a Measurement of a Trial. A Measurement contains the Metrics got by executing a Trial using suggested hyperparameter values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Measurement

Returns a new instance of GoogleCloudAiplatformV1beta1Measurement.



32063
32064
32065
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#elapsed_durationString

Output only. Time that the Trial has been running at the point of this Measurement. Corresponds to the JSON property elapsedDuration

Returns:

  • (String)


32049
32050
32051
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32049

def elapsed_duration
  @elapsed_duration
end

#metricsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MeasurementMetric>

Output only. A list of metrics got by evaluating the objective functions using suggested Parameter values. Corresponds to the JSON property metrics



32055
32056
32057
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32055

def metrics
  @metrics
end

#step_countFixnum

Output only. The number of steps the machine learning model has been trained for. Must be non-negative. Corresponds to the JSON property stepCount

Returns:

  • (Fixnum)


32061
32062
32063
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32061

def step_count
  @step_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32068
32069
32070
32071
32072
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32068

def update!(**args)
  @elapsed_duration = args[:elapsed_duration] if args.key?(:elapsed_duration)
  @metrics = args[:metrics] if args.key?(:metrics)
  @step_count = args[:step_count] if args.key?(:step_count)
end