Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents configuration for triggering generation.
Instance Attribute Summary collapse
-
#generation_rule ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule
Represents the active rule that determines when to flush the buffer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfig
Returns a new instance of GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfig.
25816 25817 25818 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generation_rule ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule
Represents the active rule that determines when to flush the buffer.
Corresponds to the JSON property generationRule
25814 25815 25816 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25814 def generation_rule @generation_rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25821 25822 25823 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25821 def update!(**args) @generation_rule = args[:generation_rule] if args.key?(:generation_rule) end |