Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents the active rule that determines when to flush the buffer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule

Returns a new instance of GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule.



34865
34866
34867
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_countFixnum

Optional. Specifies to trigger generation when the event count reaches this limit. Corresponds to the JSON property eventCount

Returns:

  • (Fixnum)


34845
34846
34847
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34845

def event_count
  @event_count
end

#fixed_intervalString

Optional. Specifies to trigger generation at a fixed interval. The duration must have a minute-level granularity. Corresponds to the JSON property fixedInterval

Returns:

  • (String)


34851
34852
34853
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34851

def fixed_interval
  @fixed_interval
end

#idle_durationString

Optional. Specifies to trigger generation if the stream is inactive for the specified duration after the most recent event. The duration must have a minute-level granularity. Corresponds to the JSON property idleDuration

Returns:

  • (String)


34858
34859
34860
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34858

def idle_duration
  @idle_duration
end

#overlap_event_countFixnum

Optional. Re-include the last N already-processed events in the next window. Corresponds to the JSON property overlapEventCount

Returns:

  • (Fixnum)


34863
34864
34865
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34863

def overlap_event_count
  @overlap_event_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34870
34871
34872
34873
34874
34875
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34870

def update!(**args)
  @event_count = args[:event_count] if args.key?(:event_count)
  @fixed_interval = args[:fixed_interval] if args.key?(:fixed_interval)
  @idle_duration = args[:idle_duration] if args.key?(:idle_duration)
  @overlap_event_count = args[:overlap_event_count] if args.key?(:overlap_event_count)
end