Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Instance of a general MetadataSchema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetadataSchema

Returns a new instance of GoogleCloudAiplatformV1beta1MetadataSchema.



35165
35166
35167
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35165

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this MetadataSchema was created. Corresponds to the JSON property createTime

Returns:

  • (String)


35131
35132
35133
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35131

def create_time
  @create_time
end

#descriptionString

Description of the Metadata Schema Corresponds to the JSON property description

Returns:

  • (String)


35136
35137
35138
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35136

def description
  @description
end

#nameString

Output only. The resource name of the MetadataSchema. Corresponds to the JSON property name

Returns:

  • (String)


35141
35142
35143
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35141

def name
  @name
end

#schemaString

Required. The raw YAML string representation of the MetadataSchema. The combination of [MetadataSchema.version] and the schema name given by title in [MetadataSchema.schema] must be unique within a MetadataStore. The schema is defined as an OpenAPI 3.0.2 MetadataSchema Object Corresponds to the JSON property schema

Returns:

  • (String)


35150
35151
35152
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35150

def schema
  @schema
end

#schema_typeString

The type of the MetadataSchema. This is a property that identifies which metadata types will use the MetadataSchema. Corresponds to the JSON property schemaType

Returns:

  • (String)


35156
35157
35158
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35156

def schema_type
  @schema_type
end

#schema_versionString

The version of the MetadataSchema. The version's format must match the following regular expression: ^[0-9]+.+.+$, which would allow to order/ compare different versions. Example: 1.0.0, 1.0.1, etc. Corresponds to the JSON property schemaVersion

Returns:

  • (String)


35163
35164
35165
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35163

def schema_version
  @schema_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35170
35171
35172
35173
35174
35175
35176
35177
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35170

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @schema = args[:schema] if args.key?(:schema)
  @schema_type = args[:schema_type] if args.key?(:schema_type)
  @schema_version = args[:schema_version] if args.key?(:schema_version)
end