Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Instance of a metadata store. Contains a set of metadata that can be queried.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetadataStore

Returns a new instance of GoogleCloudAiplatformV1beta1MetadataStore.



35286
35287
35288
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this MetadataStore was created. Corresponds to the JSON property createTime

Returns:

  • (String)


35253
35254
35255
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35253

def create_time
  @create_time
end

#dataplex_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStoreDataplexConfig

Represents Dataplex integration settings. Corresponds to the JSON property dataplexConfig



35258
35259
35260
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35258

def dataplex_config
  @dataplex_config
end

#descriptionString

Description of the MetadataStore. Corresponds to the JSON property description

Returns:

  • (String)


35263
35264
35265
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35263

def description
  @description
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



35269
35270
35271
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35269

def encryption_spec
  @encryption_spec
end

#nameString

Output only. The resource name of the MetadataStore instance. Corresponds to the JSON property name

Returns:

  • (String)


35274
35275
35276
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35274

def name
  @name
end

#stateGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStoreMetadataStoreState

Represents state information for a MetadataStore. Corresponds to the JSON property state



35279
35280
35281
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35279

def state
  @state
end

#update_timeString

Output only. Timestamp when this MetadataStore was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


35284
35285
35286
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35284

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35291
35292
35293
35294
35295
35296
35297
35298
35299
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35291

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config)
  @description = args[:description] if args.key?(:description)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end