Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Metadata about the metric, used for visualization and organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetricMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1MetricMetadata.



34889
34890
34891
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#other_metadataHash<String,Object>

Optional. Flexible metadata for user-defined attributes. Corresponds to the JSON property otherMetadata

Returns:

  • (Hash<String,Object>)


34876
34877
34878
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34876

def 
  @other_metadata
end

#score_rangeGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadataScoreRange

The range of possible scores for this metric, used for plotting. Corresponds to the JSON property scoreRange



34881
34882
34883
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34881

def score_range
  @score_range
end

#titleString

Optional. The user-friendly name for the metric. If not set for a registered metric, it will default to the metric's display name. Corresponds to the JSON property title

Returns:

  • (String)


34887
34888
34889
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34887

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34894
34895
34896
34897
34898
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34894

def update!(**args)
  @other_metadata = args[:other_metadata] if args.key?(:other_metadata)
  @score_range = args[:score_range] if args.key?(:score_range)
  @title = args[:title] if args.key?(:title)
end