Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadataScoreRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The range of possible scores for this metric, used for plotting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetricMetadataScoreRange

Returns a new instance of GoogleCloudAiplatformV1beta1MetricMetadataScoreRange.



35465
35466
35467
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The description of the score explaining the directionality etc. Corresponds to the JSON property description

Returns:

  • (String)


35447
35448
35449
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35447

def description
  @description
end

#maxFloat

Required. The maximum value of the score range (inclusive). Corresponds to the JSON property max

Returns:

  • (Float)


35452
35453
35454
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35452

def max
  @max
end

#minFloat

Required. The minimum value of the score range (inclusive). Corresponds to the JSON property min

Returns:

  • (Float)


35457
35458
35459
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35457

def min
  @min
end

#stepFloat

Optional. The distance between discrete steps in the range. If unset, the range is assumed to be continuous. Corresponds to the JSON property step

Returns:

  • (Float)


35463
35464
35465
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35463

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35470
35471
35472
35473
35474
35475
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35470

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @max = args[:max] if args.key?(:max)
  @min = args[:min] if args.key?(:min)
  @step = args[:step] if args.key?(:step)
end