Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelArmorConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelArmorConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for Model Armor. Model Armor is a Google Cloud service that provides safety and security filtering for prompts and responses. It helps protect your AI applications from risks such as harmful content, sensitive data leakage, and prompt injection attacks.
Instance Attribute Summary collapse
-
#prompt_template_name ⇒ String
Optional.
-
#response_template_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelArmorConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelArmorConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelArmorConfig
Returns a new instance of GoogleCloudAiplatformV1beta1ModelArmorConfig.
32327 32328 32329 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32327 def initialize(**args) update!(**args) end |
Instance Attribute Details
#prompt_template_name ⇒ String
Optional. The resource name of the Model Armor template to use for prompt
screening. A Model Armor template is a set of customized filters and
thresholds that define how Model Armor screens content. If specified, Model
Armor will use this template to check the user's prompt for safety and
security risks before it is sent to the model. The name must be in the format
projects/project/locations/location/templates/template`.
Corresponds to the JSON propertypromptTemplateName`
32315 32316 32317 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32315 def prompt_template_name @prompt_template_name end |
#response_template_name ⇒ String
Optional. The resource name of the Model Armor template to use for response
screening. A Model Armor template is a set of customized filters and
thresholds that define how Model Armor screens content. If specified, Model
Armor will use this template to check the model's response for safety and
security risks before it is returned to the user. The name must be in the
format projects/project/locations/location/templates/template`.
Corresponds to the JSON propertyresponseTemplateName`
32325 32326 32327 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32325 def response_template_name @response_template_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32332 32333 32334 32335 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32332 def update!(**args) @prompt_template_name = args[:prompt_template_name] if args.key?(:prompt_template_name) @response_template_name = args[:response_template_name] if args.key?(:response_template_name) end |