Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Monitoring alert triggered condition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition.



37660
37661
37662
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37660

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#thresholdFloat

A condition that compares a stats value against a threshold. Alert will be triggered if value above the threshold. Corresponds to the JSON property threshold

Returns:

  • (Float)


37658
37659
37660
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37658

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37665
37666
37667
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37665

def update!(**args)
  @threshold = args[:threshold] if args.key?(:threshold)
end