Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a model monitoring job that analyze dataset using different monitoring algorithm.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The display name of the ModelMonitoringJob.
-
#job_execution_detail ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetail
Represent the execution details of the job.
-
#model_monitoring_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSpec
Monitoring monitoring job spec.
-
#name ⇒ String
Output only.
-
#schedule ⇒ String
Output only.
-
#schedule_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringJob
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitoringJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringJob
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringJob.
38176 38177 38178 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38176 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this ModelMonitoringJob was created.
Corresponds to the JSON property createTime
38124 38125 38126 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38124 def create_time @create_time end |
#display_name ⇒ String
The display name of the ModelMonitoringJob. The name can be up to 128
characters long and can consist of any UTF-8.
Corresponds to the JSON property displayName
38130 38131 38132 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38130 def display_name @display_name end |
#job_execution_detail ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetail
Represent the execution details of the job.
Corresponds to the JSON property jobExecutionDetail
38135 38136 38137 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38135 def job_execution_detail @job_execution_detail end |
#model_monitoring_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSpec
Monitoring monitoring job spec. It outlines the specifications for monitoring
objectives, notifications, and result exports.
Corresponds to the JSON property modelMonitoringSpec
38141 38142 38143 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38141 def model_monitoring_spec @model_monitoring_spec end |
#name ⇒ String
Output only. Resource name of a ModelMonitoringJob. Format: projects/
project_id/locations/location_id/modelMonitors/model_monitor_id/
modelMonitoringJobs/model_monitoring_job_id`
Corresponds to the JSON propertyname`
38148 38149 38150 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38148 def name @name end |
#schedule ⇒ String
Output only. Schedule resource name. It will only appear when this job is
triggered by a schedule.
Corresponds to the JSON property schedule
38154 38155 38156 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38154 def schedule @schedule end |
#schedule_time ⇒ String
Output only. Timestamp when this ModelMonitoringJob was scheduled. It will
only appear when this job is triggered by a schedule.
Corresponds to the JSON property scheduleTime
38160 38161 38162 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38160 def schedule_time @schedule_time end |
#state ⇒ String
Output only. The state of the monitoring job. * When the job is still creating,
the state will be 'JOB_STATE_PENDING'. * Once the job is successfully created,
the state will be 'JOB_STATE_RUNNING'. * Once the job is finished, the state
will be one of 'JOB_STATE_FAILED', 'JOB_STATE_SUCCEEDED', '
JOB_STATE_PARTIALLY_SUCCEEDED'.
Corresponds to the JSON property state
38169 38170 38171 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38169 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this ModelMonitoringJob was updated most recently.
Corresponds to the JSON property updateTime
38174 38175 38176 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38174 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38181 38182 38183 38184 38185 38186 38187 38188 38189 38190 38191 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38181 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @job_execution_detail = args[:job_execution_detail] if args.key?(:job_execution_detail) @model_monitoring_spec = args[:model_monitoring_spec] if args.key?(:model_monitoring_spec) @name = args[:name] if args.key?(:name) @schedule = args[:schedule] if args.key?(:schedule) @schedule_time = args[:schedule_time] if args.key?(:schedule_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |