Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Processed dataset information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset.



38253
38254
38255
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38253

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

Actual data location of the processed dataset. Corresponds to the JSON property location

Returns:

  • (String)


38243
38244
38245
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38243

def location
  @location
end

#time_rangeGoogle::Apis::AiplatformV1beta1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property timeRange



38251
38252
38253
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38251

def time_range
  @time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38258
38259
38260
38261
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38258

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @time_range = args[:time_range] if args.key?(:time_range)
end