Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Output from BatchPredictionJob for Model Monitoring baseline dataset, which can be used to generate baseline attribution scores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline.



34871
34872
34873
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34871

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigqueryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property bigquery



34859
34860
34861
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34859

def bigquery
  @bigquery
end

#gcsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcs



34864
34865
34866
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34864

def gcs
  @gcs
end

#prediction_formatString

The storage format of the predictions generated BatchPrediction job. Corresponds to the JSON property predictionFormat

Returns:

  • (String)


34869
34870
34871
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34869

def prediction_format
  @prediction_format
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34876
34877
34878
34879
34880
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34876

def update!(**args)
  @bigquery = args[:bigquery] if args.key?(:bigquery)
  @gcs = args[:gcs] if args.key?(:gcs)
  @prediction_format = args[:prediction_format] if args.key?(:prediction_format)
end