Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Data drift monitoring spec. Data drift measures the distribution distance between the current dataset and a baseline dataset. A typical use case is to detect data drift between the recent production serving dataset and the training dataset, or to compare the recent production dataset with a dataset from a previous period.
Instance Attribute Summary collapse
-
#categorical_metric_type ⇒ String
Supported metrics type: * l_infinity * jensen_shannon_divergence Corresponds to the JSON property
categoricalMetricType. -
#default_categorical_alert_condition ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
Monitoring alert triggered condition.
-
#default_numeric_alert_condition ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
Monitoring alert triggered condition.
-
#feature_alert_conditions ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>
Per feature alert condition will override default alert condition.
-
#features ⇒ Array<String>
Feature names / Prediction output names interested in monitoring.
-
#numeric_metric_type ⇒ String
Supported metrics type: * jensen_shannon_divergence Corresponds to the JSON property
numericMetricType.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec.
38577 38578 38579 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38577 def initialize(**args) update!(**args) end |
Instance Attribute Details
#categorical_metric_type ⇒ String
Supported metrics type: * l_infinity * jensen_shannon_divergence
Corresponds to the JSON property categoricalMetricType
38547 38548 38549 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38547 def categorical_metric_type @categorical_metric_type end |
#default_categorical_alert_condition ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
Monitoring alert triggered condition.
Corresponds to the JSON property defaultCategoricalAlertCondition
38552 38553 38554 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38552 def default_categorical_alert_condition @default_categorical_alert_condition end |
#default_numeric_alert_condition ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
Monitoring alert triggered condition.
Corresponds to the JSON property defaultNumericAlertCondition
38557 38558 38559 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38557 def default_numeric_alert_condition @default_numeric_alert_condition end |
#feature_alert_conditions ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>
Per feature alert condition will override default alert condition.
Corresponds to the JSON property featureAlertConditions
38562 38563 38564 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38562 def feature_alert_conditions @feature_alert_conditions end |
#features ⇒ Array<String>
Feature names / Prediction output names interested in monitoring. These should
be a subset of the input feature names or prediction output names specified in
the monitoring schema. If the field is not specified all features / prediction
outputs outlied in the monitoring schema will be used.
Corresponds to the JSON property features
38570 38571 38572 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38570 def features @features end |
#numeric_metric_type ⇒ String
Supported metrics type: * jensen_shannon_divergence
Corresponds to the JSON property numericMetricType
38575 38576 38577 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38575 def numeric_metric_type @numeric_metric_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38582 38583 38584 38585 38586 38587 38588 38589 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38582 def update!(**args) @categorical_metric_type = args[:categorical_metric_type] if args.key?(:categorical_metric_type) @default_categorical_alert_condition = args[:default_categorical_alert_condition] if args.key?(:default_categorical_alert_condition) @default_numeric_alert_condition = args[:default_numeric_alert_condition] if args.key?(:default_numeric_alert_condition) @feature_alert_conditions = args[:feature_alert_conditions] if args.key?(:feature_alert_conditions) @features = args[:features] if args.key?(:features) @numeric_metric_type = args[:numeric_metric_type] if args.key?(:numeric_metric_type) end |