Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringOutputSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Specification for the export destination of monitoring results, including metrics, logs, etc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringOutputSpec

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringOutputSpec.



38681
38682
38683
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_base_directoryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcsBaseDirectory



38679
38680
38681
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38679

def gcs_base_directory
  @gcs_base_directory
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38686
38687
38688
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38686

def update!(**args)
  @gcs_base_directory = args[:gcs_base_directory] if args.key?(:gcs_base_directory)
end