Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Schema field definition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema.



38763
38764
38765
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38763

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_typeString

Supported data types are: float integer boolean string categorical Corresponds to the JSON property dataType

Returns:

  • (String)


38750
38751
38752
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38750

def data_type
  @data_type
end

#nameString

Field name. Corresponds to the JSON property name

Returns:

  • (String)


38755
38756
38757
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38755

def name
  @name
end

#repeatedBoolean Also known as: repeated?

Describes if the schema field is an array of given data type. Corresponds to the JSON property repeated

Returns:

  • (Boolean)


38760
38761
38762
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38760

def repeated
  @repeated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38768
38769
38770
38771
38772
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38768

def update!(**args)
  @data_type = args[:data_type] if args.key?(:data_type)
  @name = args[:name] if args.key?(:name)
  @repeated = args[:repeated] if args.key?(:repeated)
end