Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringStatsAnomalies

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Statistics and anomalies generated by Model Monitoring.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringStatsAnomalies

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringStatsAnomalies.



36573
36574
36575
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#anomaly_countFixnum

Number of anomalies within all stats. Corresponds to the JSON property anomalyCount

Returns:

  • (Fixnum)


36556
36557
36558
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36556

def anomaly_count
  @anomaly_count
end

#deployed_model_idString

Deployed Model ID. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


36561
36562
36563
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36561

def deployed_model_id
  @deployed_model_id
end

#feature_statsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies>

A list of historical Stats and Anomalies generated for all Features. Corresponds to the JSON property featureStats



36566
36567
36568
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36566

def feature_stats
  @feature_stats
end

#objectiveString

Model Monitoring Objective those stats and anomalies belonging to. Corresponds to the JSON property objective

Returns:

  • (String)


36571
36572
36573
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36571

def objective
  @objective
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36578
36579
36580
36581
36582
36583
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36578

def update!(**args)
  @anomaly_count = args[:anomaly_count] if args.key?(:anomaly_count)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @feature_stats = args[:feature_stats] if args.key?(:feature_stats)
  @objective = args[:objective] if args.key?(:objective)
end