Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborQuery
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A query to find a number of similar entities.
Instance Attribute Summary collapse
-
#embedding ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborQueryEmbedding
The embedding vector.
-
#entity_id ⇒ String
Optional.
-
#neighbor_count ⇒ Fixnum
Optional.
-
#numeric_filters ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborQueryNumericFilter>
Optional.
-
#parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborQueryParameters
Parameters that can be overrided in each query to tune query latency and recall.
-
#per_crowding_attribute_neighbor_count ⇒ Fixnum
Optional.
-
#string_filters ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborQueryStringFilter>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NearestNeighborQuery
constructor
A new instance of GoogleCloudAiplatformV1beta1NearestNeighborQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NearestNeighborQuery
Returns a new instance of GoogleCloudAiplatformV1beta1NearestNeighborQuery.
39785 39786 39787 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39785 def initialize(**args) update!(**args) end |
Instance Attribute Details
#embedding ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborQueryEmbedding
The embedding vector.
Corresponds to the JSON property embedding
39747 39748 39749 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39747 def @embedding end |
#entity_id ⇒ String
Optional. The entity id whose similar entities should be searched for. If
embedding is set, search will use embedding instead of entity_id.
Corresponds to the JSON property entityId
39753 39754 39755 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39753 def entity_id @entity_id end |
#neighbor_count ⇒ Fixnum
Optional. The number of similar entities to be retrieved from feature view for
each query.
Corresponds to the JSON property neighborCount
39759 39760 39761 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39759 def neighbor_count @neighbor_count end |
#numeric_filters ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborQueryNumericFilter>
Optional. The list of numeric filters.
Corresponds to the JSON property numericFilters
39764 39765 39766 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39764 def numeric_filters @numeric_filters end |
#parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborQueryParameters
Parameters that can be overrided in each query to tune query latency and
recall.
Corresponds to the JSON property parameters
39770 39771 39772 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39770 def parameters @parameters end |
#per_crowding_attribute_neighbor_count ⇒ Fixnum
Optional. Crowding is a constraint on a neighbor list produced by nearest
neighbor search requiring that no more than
sper_crowding_attribute_neighbor_count of the k neighbors returned have the
same value of crowding_attribute. It's used for improving result diversity.
Corresponds to the JSON property perCrowdingAttributeNeighborCount
39778 39779 39780 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39778 def per_crowding_attribute_neighbor_count @per_crowding_attribute_neighbor_count end |
#string_filters ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborQueryStringFilter>
Optional. The list of string filters.
Corresponds to the JSON property stringFilters
39783 39784 39785 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39783 def string_filters @string_filters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39790 39791 39792 39793 39794 39795 39796 39797 39798 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39790 def update!(**args) @embedding = args[:embedding] if args.key?(:embedding) @entity_id = args[:entity_id] if args.key?(:entity_id) @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count) @numeric_filters = args[:numeric_filters] if args.key?(:numeric_filters) @parameters = args[:parameters] if args.key?(:parameters) @per_crowding_attribute_neighbor_count = args[:per_crowding_attribute_neighbor_count] if args.key?(:per_crowding_attribute_neighbor_count) @string_filters = args[:string_filters] if args.key?(:string_filters) end |