Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborsNeighbor
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborsNeighbor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A neighbor of the query vector.
Instance Attribute Summary collapse
-
#distance ⇒ Float
The distance between the neighbor and the query vector.
-
#entity_id ⇒ String
The id of the similar entity.
-
#entity_key_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FetchFeatureValuesResponse
Response message for FeatureOnlineStoreService.FetchFeatureValues Corresponds to the JSON property
entityKeyValues.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NearestNeighborsNeighbor
constructor
A new instance of GoogleCloudAiplatformV1beta1NearestNeighborsNeighbor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NearestNeighborsNeighbor
Returns a new instance of GoogleCloudAiplatformV1beta1NearestNeighborsNeighbor.
35964 35965 35966 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35964 def initialize(**args) update!(**args) end |
Instance Attribute Details
#distance ⇒ Float
The distance between the neighbor and the query vector.
Corresponds to the JSON property distance
35952 35953 35954 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35952 def distance @distance end |
#entity_id ⇒ String
The id of the similar entity.
Corresponds to the JSON property entityId
35957 35958 35959 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35957 def entity_id @entity_id end |
#entity_key_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FetchFeatureValuesResponse
Response message for FeatureOnlineStoreService.FetchFeatureValues
Corresponds to the JSON property entityKeyValues
35962 35963 35964 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35962 def entity_key_values @entity_key_values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35969 35970 35971 35972 35973 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35969 def update!(**args) @distance = args[:distance] if args.key?(:distance) @entity_id = args[:entity_id] if args.key?(:entity_id) @entity_key_values = args[:entity_key_values] if args.key?(:entity_key_values) end |