Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NfsMount
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NfsMount
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a mount configuration for Network File System (NFS) to mount.
Instance Attribute Summary collapse
-
#mount_point ⇒ String
Required.
-
#path ⇒ String
Required.
-
#server ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NfsMount
constructor
A new instance of GoogleCloudAiplatformV1beta1NfsMount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NfsMount
Returns a new instance of GoogleCloudAiplatformV1beta1NfsMount.
31185 31186 31187 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mount_point ⇒ String
Required. Destination mount path. The NFS will be mounted for the user under /
mnt/nfs/
Corresponds to the JSON property mountPoint
31171 31172 31173 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31171 def mount_point @mount_point end |
#path ⇒ String
Required. Source path exported from NFS server. Has to start with '/', and
combined with the ip address, it indicates the source mount path in the form
of server:path
Corresponds to the JSON property path
31178 31179 31180 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31178 def path @path end |
#server ⇒ String
Required. IP address of the NFS server.
Corresponds to the JSON property server
31183 31184 31185 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31183 def server @server end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31190 31191 31192 31193 31194 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31190 def update!(**args) @mount_point = args[:mount_point] if args.key?(:mount_point) @path = args[:path] if args.key?(:path) @server = args[:server] if args.key?(:server) end |