Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookReservationAffinity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Notebook Reservation Affinity for consuming Zonal reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NotebookReservationAffinity

Returns a new instance of GoogleCloudAiplatformV1beta1NotebookReservationAffinity.



40744
40745
40746
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consume_reservation_typeString

Required. Specifies the type of reservation from which this instance can consume resources: RESERVATION_ANY (default), RESERVATION_SPECIFIC, or RESERVATION_NONE. See Consuming reserved instances for examples. Corresponds to the JSON property consumeReservationType

Returns:

  • (String)


40729
40730
40731
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40729

def consume_reservation_type
  @consume_reservation_type
end

#keyString

Optional. Corresponds to the label key of a reservation resource. To target a RESERVATION_SPECIFIC by name, use compute.googleapis.com/reservation-name as the key and specify the name of your reservation as its value. Corresponds to the JSON property key

Returns:

  • (String)


40736
40737
40738
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40736

def key
  @key
end

#valuesArray<String>

Optional. Corresponds to the label values of a reservation resource. This must be the full path name of Reservation. Corresponds to the JSON property values

Returns:

  • (Array<String>)


40742
40743
40744
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40742

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40749
40750
40751
40752
40753
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40749

def update!(**args)
  @consume_reservation_type = args[:consume_reservation_type] if args.key?(:consume_reservation_type)
  @key = args[:key] if args.key?(:key)
  @values = args[:values] if args.key?(:values)
end