Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluator

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An OnlineEvaluator contains the configuration for an Online Evaluation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluator

Returns a new instance of GoogleCloudAiplatformV1beta1OnlineEvaluator.



41251
41252
41253
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41251

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_resourceString

Required. Immutable. The name of the agent that the OnlineEvaluator evaluates periodically. This value is used to filter the traces with a matching cloud. resource_id and link the evaluation results with relevant dashboards/UIs. This field is immutable. Once set, it cannot be changed. Corresponds to the JSON property agentResource

Returns:

  • (String)


41192
41193
41194
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41192

def agent_resource
  @agent_resource
end

#cloud_observabilityGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability

Data source for the OnlineEvaluator, based on Google Cloud Observability stack (Cloud Trace & Cloud Logging). Corresponds to the JSON property cloudObservability



41198
41199
41200
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41198

def cloud_observability
  @cloud_observability
end

#configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorConfig

Configuration for sampling behavior of the OnlineEvaluator. The OnlineEvaluator runs at a fixed interval of 10 minutes. Corresponds to the JSON property config



41204
41205
41206
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41204

def config
  @config
end

#create_timeString

Output only. Timestamp when the OnlineEvaluator was created. Corresponds to the JSON property createTime

Returns:

  • (String)


41209
41210
41211
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41209

def create_time
  @create_time
end

#display_nameString

Optional. Human-readable name for the OnlineEvaluator. The name doesn't have to be unique. The name can consist of any UTF-8 characters. The maximum length is 63 characters. If the display name exceeds max characters, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property displayName

Returns:

  • (String)


41217
41218
41219
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41217

def display_name
  @display_name
end

#metric_sourcesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricSource>

Required. A list of metric sources to be used for evaluating samples. At least one MetricSource must be provided. Right now, only predefined metrics and registered metrics are supported. Every registered metric must have display_name (or title) and score_range defined. Otherwise, the evaluations will fail. The maximum number of metric_sources is 25. Corresponds to the JSON property metricSources



41226
41227
41228
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41226

def metric_sources
  @metric_sources
end

#nameString

Identifier. The resource name of the OnlineEvaluator. Format: projects/ project/locations/location/onlineEvaluators/id. Corresponds to the JSON property name

Returns:

  • (String)


41232
41233
41234
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41232

def name
  @name
end

#stateString

Output only. The state of the OnlineEvaluator. Corresponds to the JSON property state

Returns:

  • (String)


41237
41238
41239
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41237

def state
  @state
end

#state_detailsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorStateDetails>

Output only. Contains additional information about the state of the OnlineEvaluator. This is used to provide more details in the event of a failure. Corresponds to the JSON property stateDetails



41244
41245
41246
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41244

def state_details
  @state_details
end

#update_timeString

Output only. Timestamp when the OnlineEvaluator was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


41249
41250
41251
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41249

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41256
41257
41258
41259
41260
41261
41262
41263
41264
41265
41266
41267
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41256

def update!(**args)
  @agent_resource = args[:agent_resource] if args.key?(:agent_resource)
  @cloud_observability = args[:cloud_observability] if args.key?(:cloud_observability)
  @config = args[:config] if args.key?(:config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @metric_sources = args[:metric_sources] if args.key?(:metric_sources)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
  @update_time = args[:update_time] if args.key?(:update_time)
end