Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Data source for the OnlineEvaluator, based on Google Cloud Observability stack (Cloud Trace & Cloud Logging).
Instance Attribute Summary collapse
-
#log_view ⇒ String
Optional.
-
#open_telemetry ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityOpenTelemetry
Configuration for data source following OpenTelemetry.
-
#session_scope ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilitySessionScope
If chosen, the online evaluator will evaluate sessions matching specified
filter. -
#trace_scope ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScope
If chosen, the online evaluator will evaluate single traces matching specified
filter. -
#trace_view ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability
constructor
A new instance of GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability
Returns a new instance of GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability.
41305 41306 41307 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#log_view ⇒ String
Optional. Optional log view that will be used to query logs. If empty, the
_Default view will be used.
Corresponds to the JSON property logView
41279 41280 41281 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41279 def log_view @log_view end |
#open_telemetry ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityOpenTelemetry
Configuration for data source following OpenTelemetry.
Corresponds to the JSON property openTelemetry
41284 41285 41286 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41284 def open_telemetry @open_telemetry end |
#session_scope ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilitySessionScope
If chosen, the online evaluator will evaluate sessions matching specified
filter. A session is a group of traces with a common gen_ai.conversation.id.
Corresponds to the JSON property sessionScope
41290 41291 41292 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41290 def session_scope @session_scope end |
#trace_scope ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScope
If chosen, the online evaluator will evaluate single traces matching specified
filter.
Corresponds to the JSON property traceScope
41296 41297 41298 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41296 def trace_scope @trace_scope end |
#trace_view ⇒ String
Optional. Optional trace view that will be used to query traces. If empty, the
_Default view will be used. NOTE: This field is not supported yet and will
be ignored if set.
Corresponds to the JSON property traceView
41303 41304 41305 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41303 def trace_view @trace_view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41310 41311 41312 41313 41314 41315 41316 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41310 def update!(**args) @log_view = args[:log_view] if args.key?(:log_view) @open_telemetry = args[:open_telemetry] if args.key?(:open_telemetry) @session_scope = args[:session_scope] if args.key?(:session_scope) @trace_scope = args[:trace_scope] if args.key?(:trace_scope) @trace_view = args[:trace_view] if args.key?(:trace_view) end |