Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilitySessionScopeInactivityTrigger

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for inactivity based session completion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilitySessionScopeInactivityTrigger

Returns a new instance of GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilitySessionScopeInactivityTrigger.



41403
41404
41405
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41403

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#thresholdString

Required. The amount of time that must pass with no new traces before a session is considered ready for evaluation. This is a required field if InactivityTrigger is used. The value must be a positive duration no greater than 7 days (604800 seconds). Corresponds to the JSON property threshold

Returns:

  • (String)


41401
41402
41403
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41401

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41408
41409
41410
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41408

def update!(**args)
  @threshold = args[:threshold] if args.key?(:threshold)
end