Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilitySessionScopePredicate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Defines a single filter predicate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilitySessionScopePredicate

Returns a new instance of GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilitySessionScopePredicate.



41452
41453
41454
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41452

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate

Defines a predicate for filtering based on a numeric value. Corresponds to the JSON property duration



41420
41421
41422
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41420

def duration
  @duration
end

#model_call_errorsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate

Defines a predicate for filtering based on a numeric value. Corresponds to the JSON property modelCallErrors



41425
41426
41427
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41425

def model_call_errors
  @model_call_errors
end

#model_callsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate

Defines a predicate for filtering based on a numeric value. Corresponds to the JSON property modelCalls



41430
41431
41432
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41430

def model_calls
  @model_calls
end

#tool_call_errorsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate

Defines a predicate for filtering based on a numeric value. Corresponds to the JSON property toolCallErrors



41435
41436
41437
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41435

def tool_call_errors
  @tool_call_errors
end

#tool_callsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate

Defines a predicate for filtering based on a numeric value. Corresponds to the JSON property toolCalls



41440
41441
41442
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41440

def tool_calls
  @tool_calls
end

#total_token_usageGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate

Defines a predicate for filtering based on a numeric value. Corresponds to the JSON property totalTokenUsage



41445
41446
41447
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41445

def total_token_usage
  @total_token_usage
end

#user_turnsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate

Defines a predicate for filtering based on a numeric value. Corresponds to the JSON property userTurns



41450
41451
41452
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41450

def user_turns
  @user_turns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41457
41458
41459
41460
41461
41462
41463
41464
41465
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41457

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @model_call_errors = args[:model_call_errors] if args.key?(:model_call_errors)
  @model_calls = args[:model_calls] if args.key?(:model_calls)
  @tool_call_errors = args[:tool_call_errors] if args.key?(:tool_call_errors)
  @tool_calls = args[:tool_calls] if args.key?(:tool_calls)
  @total_token_usage = args[:total_token_usage] if args.key?(:total_token_usage)
  @user_turns = args[:user_turns] if args.key?(:user_turns)
end