Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScopePredicate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScopePredicate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Defines a single filter predicate.
Instance Attribute Summary collapse
-
#duration ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
-
#total_token_usage ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScopePredicate
constructor
A new instance of GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScopePredicate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScopePredicate
Returns a new instance of GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScopePredicate.
39121 39122 39123 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
Corresponds to the JSON property duration
39114 39115 39116 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39114 def duration @duration end |
#total_token_usage ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
Corresponds to the JSON property totalTokenUsage
39119 39120 39121 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39119 def total_token_usage @total_token_usage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39126 39127 39128 39129 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39126 def update!(**args) @duration = args[:duration] if args.key?(:duration) @total_token_usage = args[:total_token_usage] if args.key?(:total_token_usage) end |