Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OutputFieldSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Specifies the properties of a single field that are included in each generated synthetic example. This helps the model understand what kind of data to generate for each field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OutputFieldSpec

Returns a new instance of GoogleCloudAiplatformV1beta1OutputFieldSpec.



41674
41675
41676
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41674

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_nameString

Required. The name of this field in the generated synthetic data, such as " email_subject" or "customer_review". Corresponds to the JSON property fieldName

Returns:

  • (String)


41658
41659
41660
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41658

def field_name
  @field_name
end

#field_typeString

Optional. The data type of the field. Defaults to CONTENT if not set. Corresponds to the JSON property fieldType

Returns:

  • (String)


41663
41664
41665
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41663

def field_type
  @field_type
end

#guidanceString

Optional. Specific instructions for the large language model on how to generate content for this particular field. While the LLM can sometimes infer content from the field name, providing explicit guidance is preferred. For example, for a field named "review", the guidance could be "A positive review about a coffee maker." Corresponds to the JSON property guidance

Returns:

  • (String)


41672
41673
41674
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41672

def guidance
  @guidance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41679
41680
41681
41682
41683
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41679

def update!(**args)
  @field_name = args[:field_name] if args.key?(:field_name)
  @field_type = args[:field_type] if args.key?(:field_type)
  @guidance = args[:guidance] if args.key?(:guidance)
end