Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseMetricInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Pairwise metric instance. Usually one instance corresponds to one row in an evaluation dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PairwiseMetricInstance

Returns a new instance of GoogleCloudAiplatformV1beta1PairwiseMetricInstance.



39927
39928
39929
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39927

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_map_instanceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContentMap

Map of placeholder in metric prompt template to contents of model input. Corresponds to the JSON property contentMapInstance



39919
39920
39921
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39919

def content_map_instance
  @content_map_instance
end

#json_instanceString

Instance specified as a json string. String key-value pairs are expected in the json_instance to render PairwiseMetricSpec.instance_prompt_template. Corresponds to the JSON property jsonInstance

Returns:

  • (String)


39925
39926
39927
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39925

def json_instance
  @json_instance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39932
39933
39934
39935
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39932

def update!(**args)
  @content_map_instance = args[:content_map_instance] if args.key?(:content_map_instance)
  @json_instance = args[:json_instance] if args.key?(:json_instance)
end