Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJobRuntimeConfigPersistentResourceRuntimeDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Persistent resource based runtime detail. For more information about persistent resource, refer to https://cloud.google.com/vertex-ai/docs/training/ persistent-resource-overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PipelineJobRuntimeConfigPersistentResourceRuntimeDetail

Returns a new instance of GoogleCloudAiplatformV1beta1PipelineJobRuntimeConfigPersistentResourceRuntimeDetail.



42954
42955
42956
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#persistent_resource_nameString

Persistent resource name. Format: projects/project/locations/location/ persistentResources/persistent_resource` Corresponds to the JSON propertypersistentResourceName`

Returns:

  • (String)


42940
42941
42942
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42940

def persistent_resource_name
  @persistent_resource_name
end

#task_resource_unavailable_timeout_behaviorString

Specifies the behavior to take if the timeout is reached. Corresponds to the JSON property taskResourceUnavailableTimeoutBehavior

Returns:

  • (String)


42945
42946
42947
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42945

def task_resource_unavailable_timeout_behavior
  @task_resource_unavailable_timeout_behavior
end

#task_resource_unavailable_wait_time_msFixnum

The max time a pipeline task waits for the required CPU, memory, or accelerator resource to become available from the specified persistent resource. Default wait time is 0. Corresponds to the JSON property taskResourceUnavailableWaitTimeMs

Returns:

  • (Fixnum)


42952
42953
42954
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42952

def task_resource_unavailable_wait_time_ms
  @task_resource_unavailable_wait_time_ms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42959
42960
42961
42962
42963
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42959

def update!(**args)
  @persistent_resource_name = args[:persistent_resource_name] if args.key?(:persistent_resource_name)
  @task_resource_unavailable_timeout_behavior = args[:task_resource_unavailable_timeout_behavior] if args.key?(:task_resource_unavailable_timeout_behavior)
  @task_resource_unavailable_wait_time_ms = args[:task_resource_unavailable_wait_time_ms] if args.key?(:task_resource_unavailable_wait_time_ms)
end