Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PointwiseMetricInstance
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PointwiseMetricInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Pointwise metric instance. Usually one instance corresponds to one row in an evaluation dataset.
Instance Attribute Summary collapse
-
#content_map_instance ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContentMap
Map of placeholder in metric prompt template to contents of model input.
-
#json_instance ⇒ String
Instance specified as a json string.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PointwiseMetricInstance
constructor
A new instance of GoogleCloudAiplatformV1beta1PointwiseMetricInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PointwiseMetricInstance
Returns a new instance of GoogleCloudAiplatformV1beta1PointwiseMetricInstance.
38920 38921 38922 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38920 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_map_instance ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContentMap
Map of placeholder in metric prompt template to contents of model input.
Corresponds to the JSON property contentMapInstance
38912 38913 38914 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38912 def content_map_instance @content_map_instance end |
#json_instance ⇒ String
Instance specified as a json string. String key-value pairs are expected in
the json_instance to render PointwiseMetricSpec.instance_prompt_template.
Corresponds to the JSON property jsonInstance
38918 38919 38920 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38918 def json_instance @json_instance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38925 38926 38927 38928 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38925 def update!(**args) @content_map_instance = args[:content_map_instance] if args.key?(:content_map_instance) @json_instance = args[:json_instance] if args.key?(:json_instance) end |