Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreTunedModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A pre-tuned model for continuous tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PreTunedModel

Returns a new instance of GoogleCloudAiplatformV1beta1PreTunedModel.



41133
41134
41135
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_modelString

Output only. The name of the base model this PreTunedModel was tuned from. Corresponds to the JSON property baseModel

Returns:

  • (String)


41116
41117
41118
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41116

def base_model
  @base_model
end

#checkpoint_idString

Optional. The source checkpoint id. If not specified, the default checkpoint will be used. Corresponds to the JSON property checkpointId

Returns:

  • (String)


41122
41123
41124
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41122

def checkpoint_id
  @checkpoint_id
end

#tuned_model_nameString

The resource name of the Model. E.g., a model resource name with a specified version id or alias: projects/project/locations/location/models/model@ version_id`projects/`project`/locations/`location`/models/`model`@`alias Or, omit the version id to use the default version: projects/project/ locations/location/models/model` Corresponds to the JSON propertytunedModelName`

Returns:

  • (String)


41131
41132
41133
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41131

def tuned_model_name
  @tuned_model_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41138
41139
41140
41141
41142
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41138

def update!(**args)
  @base_model = args[:base_model] if args.key?(:base_model)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @tuned_model_name = args[:tuned_model_name] if args.key?(:tuned_model_name)
end