Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for PredictionService.Predict.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PredictResponse

Returns a new instance of GoogleCloudAiplatformV1beta1PredictResponse.



43822
43823
43824
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43822

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_model_idString

ID of the Endpoint's DeployedModel that served this prediction. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


43789
43790
43791
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43789

def deployed_model_id
  @deployed_model_id
end

#metadataObject

Output only. Request-level metadata returned by the model. The metadata type will be dependent upon the model implementation. Corresponds to the JSON property metadata

Returns:

  • (Object)


43795
43796
43797
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43795

def 
  @metadata
end

#modelString

Output only. The resource name of the Model which is deployed as the DeployedModel that this prediction hits. Corresponds to the JSON property model

Returns:

  • (String)


43801
43802
43803
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43801

def model
  @model
end

#model_display_nameString

Output only. The display name of the Model which is deployed as the DeployedModel that this prediction hits. Corresponds to the JSON property modelDisplayName

Returns:

  • (String)


43807
43808
43809
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43807

def model_display_name
  @model_display_name
end

#model_version_idString

Output only. The version ID of the Model which is deployed as the DeployedModel that this prediction hits. Corresponds to the JSON property modelVersionId

Returns:

  • (String)


43813
43814
43815
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43813

def model_version_id
  @model_version_id
end

#predictionsArray<Object>

The predictions that are the output of the predictions call. The schema of any single prediction may be specified via Endpoint's DeployedModels' Model's PredictSchemata's prediction_schema_uri. Corresponds to the JSON property predictions

Returns:

  • (Array<Object>)


43820
43821
43822
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43820

def predictions
  @predictions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43827
43828
43829
43830
43831
43832
43833
43834
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43827

def update!(**args)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @model = args[:model] if args.key?(:model)
  @model_display_name = args[:model_display_name] if args.key?(:model_display_name)
  @model_version_id = args[:model_version_id] if args.key?(:model_version_id)
  @predictions = args[:predictions] if args.key?(:predictions)
end