Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateEndpoints

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

PrivateEndpoints proto is used to provide paths for users to send requests privately. To send request via private service access, use predict_http_uri, explain_http_uri or health_http_uri. To send request via private service connect, use service_attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PrivateEndpoints

Returns a new instance of GoogleCloudAiplatformV1beta1PrivateEndpoints.



34771
34772
34773
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explain_http_uriString

Output only. Http(s) path to send explain requests. Corresponds to the JSON property explainHttpUri

Returns:

  • (String)


34753
34754
34755
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34753

def explain_http_uri
  @explain_http_uri
end

#health_http_uriString

Output only. Http(s) path to send health check requests. Corresponds to the JSON property healthHttpUri

Returns:

  • (String)


34758
34759
34760
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34758

def health_http_uri
  @health_http_uri
end

#predict_http_uriString

Output only. Http(s) path to send prediction requests. Corresponds to the JSON property predictHttpUri

Returns:

  • (String)


34763
34764
34765
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34763

def predict_http_uri
  @predict_http_uri
end

#service_attachmentString

Output only. The name of the service attachment resource. Populated if private service connect is enabled. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


34769
34770
34771
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34769

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34776
34777
34778
34779
34780
34781
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34776

def update!(**args)
  @explain_http_uri = args[:explain_http_uri] if args.key?(:explain_http_uri)
  @health_http_uri = args[:health_http_uri] if args.key?(:health_http_uri)
  @predict_http_uri = args[:predict_http_uri] if args.key?(:predict_http_uri)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end