Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpHeader

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

HttpHeader describes a custom header to be used in HTTP probes

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeHttpHeader

Returns a new instance of GoogleCloudAiplatformV1beta1ProbeHttpHeader.



44358
44359
44360
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The header field name. This will be canonicalized upon output, so case-variant names will be understood as the same header. Corresponds to the JSON property name

Returns:

  • (String)


44351
44352
44353
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44351

def name
  @name
end

#valueString

The header field value Corresponds to the JSON property value

Returns:

  • (String)


44356
44357
44358
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44356

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44363
44364
44365
44366
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44363

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end