Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeTcpSocketAction
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeTcpSocketAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
TcpSocketAction probes the health of a container by opening a TCP socket connection.
Instance Attribute Summary collapse
-
#host ⇒ String
Optional: Host name to connect to, defaults to the model serving container's IP.
-
#port ⇒ Fixnum
Number of the port to access on the container.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeTcpSocketAction
constructor
A new instance of GoogleCloudAiplatformV1beta1ProbeTcpSocketAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeTcpSocketAction
Returns a new instance of GoogleCloudAiplatformV1beta1ProbeTcpSocketAction.
34985 34986 34987 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
Optional: Host name to connect to, defaults to the model serving container's
IP.
Corresponds to the JSON property host
34977 34978 34979 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34977 def host @host end |
#port ⇒ Fixnum
Number of the port to access on the container. Number must be in the range 1
to 65535.
Corresponds to the JSON property port
34983 34984 34985 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34983 def port @port end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34990 34991 34992 34993 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34990 def update!(**args) @host = args[:host] if args.key?(:host) @port = args[:port] if args.key?(:port) end |