Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscAutomationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

PSC config that is used to automatically create PSC endpoints in the user projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PscAutomationConfig

Returns a new instance of GoogleCloudAiplatformV1beta1PscAutomationConfig.



39870
39871
39872
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39870

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_messageString

Output only. Error message if the PSC service automation failed. Corresponds to the JSON property errorMessage

Returns:

  • (String)


39840
39841
39842
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39840

def error_message
  @error_message
end

#forwarding_ruleString

Output only. Forwarding rule created by the PSC service automation. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


39845
39846
39847
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39845

def forwarding_rule
  @forwarding_rule
end

#ip_addressString

Output only. IP address rule created by the PSC service automation. Corresponds to the JSON property ipAddress

Returns:

  • (String)


39850
39851
39852
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39850

def ip_address
  @ip_address
end

#networkString

Required. The full name of the Google Compute Engine network. Format: projects/ project/global/networks/network`. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


39858
39859
39860
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39858

def network
  @network
end

#project_idString

Required. Project id used to create forwarding rule. Corresponds to the JSON property projectId

Returns:

  • (String)


39863
39864
39865
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39863

def project_id
  @project_id
end

#stateString

Output only. The state of the PSC service automation. Corresponds to the JSON property state

Returns:

  • (String)


39868
39869
39870
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39868

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39875
39876
39877
39878
39879
39880
39881
39882
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39875

def update!(**args)
  @error_message = args[:error_message] if args.key?(:error_message)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @network = args[:network] if args.key?(:network)
  @project_id = args[:project_id] if args.key?(:project_id)
  @state = args[:state] if args.key?(:state)
end