Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
This message contains configs of a publisher model.
Instance Attribute Summary collapse
-
#data_sharing_enabled_provider ⇒ String
Optional.
-
#logging_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictRequestResponseLoggingConfig
Configuration for logging request-response to a BigQuery table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PublisherModelConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1PublisherModelConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PublisherModelConfig
Returns a new instance of GoogleCloudAiplatformV1beta1PublisherModelConfig.
42589 42590 42591 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42589 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_sharing_enabled_provider ⇒ String
Optional. The model provider (publisher) for which the customer has enabled
data sharing. For publisher models that are configured to require data sharing,
a prediction request is only allowed when the model's publisher matches this
provider. Otherwise, the request is rejected.
Corresponds to the JSON property dataSharingEnabledProvider
42582 42583 42584 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42582 def data_sharing_enabled_provider @data_sharing_enabled_provider end |
#logging_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictRequestResponseLoggingConfig
Configuration for logging request-response to a BigQuery table.
Corresponds to the JSON property loggingConfig
42587 42588 42589 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42587 def logging_config @logging_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42594 42595 42596 42597 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42594 def update!(**args) @data_sharing_enabled_provider = args[:data_sharing_enabled_provider] if args.key?(:data_sharing_enabled_provider) @logging_config = args[:logging_config] if args.key?(:logging_config) end |