Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PurgeArtifactsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for MetadataService.PurgeArtifacts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PurgeArtifactsRequest

Returns a new instance of GoogleCloudAiplatformV1beta1PurgeArtifactsRequest.



44496
44497
44498
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Required. A required filter matching the Artifacts to be purged. E.g., update_time <= 2020-11-19T11:30:00-04:00. Corresponds to the JSON property filter

Returns:

  • (String)


44487
44488
44489
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44487

def filter
  @filter
end

#forceBoolean Also known as: force?

Optional. Flag to indicate to actually perform the purge. If force is set to false, the method will return a sample of Artifact names that would be deleted. Corresponds to the JSON property force

Returns:

  • (Boolean)


44493
44494
44495
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44493

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44501
44502
44503
44504
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44501

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
end