Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigSparseEmbeddingConfigBm25

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Message for BM25 parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigSparseEmbeddingConfigBm25

Returns a new instance of GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigSparseEmbeddingConfigBm25.



44673
44674
44675
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44673

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bFloat

Optional. The parameter to control document length normalization. It determines how much the document length affects the final score. b is in the range of [0, 1]. The default value is 0.75. Corresponds to the JSON property b

Returns:

  • (Float)


44658
44659
44660
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44658

def b
  @b
end

#k1Float

Optional. The parameter to control term frequency saturation. It determines the scaling between the matching term frequency and final score. k1 is in the range of [1.2, 3]. The default value is 1.2. Corresponds to the JSON property k1

Returns:

  • (Float)


44665
44666
44667
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44665

def k1
  @k1
end

#multilingualBoolean Also known as: multilingual?

Optional. Use multilingual tokenizer if set to true. Corresponds to the JSON property multilingual

Returns:

  • (Boolean)


44670
44671
44672
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44670

def multilingual
  @multilingual
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44678
44679
44680
44681
44682
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44678

def update!(**args)
  @b = args[:b] if args.key?(:b)
  @k1 = args[:k1] if args.key?(:k1)
  @multilingual = args[:multilingual] if args.key?(:multilingual)
end