Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigVertexPredictionEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Config representing a model hosted on Vertex Prediction Endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigVertexPredictionEndpoint

Returns a new instance of GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigVertexPredictionEndpoint.



46414
46415
46416
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpointString

Required. The endpoint resource name. Format: projects/project/locations/ location/publishers/publisher/models/modelor `projects/`project`/ locations/`location`/endpoints/`endpoint Corresponds to the JSON property endpoint

Returns:

  • (String)


46399
46400
46401
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46399

def endpoint
  @endpoint
end

#modelString

Output only. The resource name of the model that is deployed on the endpoint. Present only when the endpoint is not a publisher model. Pattern: projects/ project/locations/location/models/model` Corresponds to the JSON propertymodel`

Returns:

  • (String)


46406
46407
46408
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46406

def model
  @model
end

#model_version_idString

Output only. Version ID of the model that is deployed on the endpoint. Present only when the endpoint is not a publisher model. Corresponds to the JSON property modelVersionId

Returns:

  • (String)


46412
46413
46414
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46412

def model_version_id
  @model_version_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46419
46420
46421
46422
46423
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46419

def update!(**args)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @model = args[:model] if args.key?(:model)
  @model_version_id = args[:model_version_id] if args.key?(:model_version_id)
end