Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagFileParsingConfigLayoutParser

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Document AI Layout Parser config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagFileParsingConfigLayoutParser

Returns a new instance of GoogleCloudAiplatformV1beta1RagFileParsingConfigLayoutParser.



37411
37412
37413
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37411

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#global_max_parsing_requests_per_minFixnum

The maximum number of requests the job is allowed to make to the Document AI processor per minute in this project. Consult https://cloud.google.com/ document-ai/quotas and the Quota page for your project to set an appropriate value here. If this value is not specified, max_parsing_requests_per_min will be used by indexing pipeline as the global limit. Corresponds to the JSON property globalMaxParsingRequestsPerMin

Returns:

  • (Fixnum)


37391
37392
37393
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37391

def global_max_parsing_requests_per_min
  @global_max_parsing_requests_per_min
end

#max_parsing_requests_per_minFixnum

The maximum number of requests the job is allowed to make to the Document AI processor per minute. Consult https://cloud.google.com/document-ai/quotas and the Quota page for your project to set an appropriate value here. If unspecified, a default value of 120 QPM would be used. Corresponds to the JSON property maxParsingRequestsPerMin

Returns:

  • (Fixnum)


37399
37400
37401
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37399

def max_parsing_requests_per_min
  @max_parsing_requests_per_min
end

#processor_nameString

The full resource name of a Document AI processor or processor version. The processor must have type LAYOUT_PARSER_PROCESSOR. If specified, the additional_config.parse_as_scanned_pdf field must be false. Format: * projects/project_id/locations/location/processors/processor_id* ` projects/`project_id`/locations/`location`/processors/`processor_id`/ processorVersions/`processor_version_id Corresponds to the JSON property processorName

Returns:

  • (String)


37409
37410
37411
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37409

def processor_name
  @processor_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37416
37417
37418
37419
37420
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37416

def update!(**args)
  @global_max_parsing_requests_per_min = args[:global_max_parsing_requests_per_min] if args.key?(:global_max_parsing_requests_per_min)
  @max_parsing_requests_per_min = args[:max_parsing_requests_per_min] if args.key?(:max_parsing_requests_per_min)
  @processor_name = args[:processor_name] if args.key?(:processor_name)
end