Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsListConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Config for List data type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsListConfig

Returns a new instance of GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsListConfig.



37802
37803
37804
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37802

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#value_schemaGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails

Data schema details indicates the data type and the data struct corresponding to the key of user specified metadata. Corresponds to the JSON property valueSchema



37800
37801
37802
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37800

def value_schema
  @value_schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37807
37808
37809
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37807

def update!(**args)
  @value_schema = args[:value_schema] if args.key?(:value_schema)
end