Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The search strategy for the metadata value of the key.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy

Returns a new instance of GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy.



43342
43343
43344
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43342

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#search_strategy_typeString

The search strategy type to be applied on the metadata key. Corresponds to the JSON property searchStrategyType

Returns:

  • (String)


43340
43341
43342
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43340

def search_strategy_type
  @search_strategy_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43347
43348
43349
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43347

def update!(**args)
  @search_strategy_type = args[:search_strategy_type] if args.key?(:search_strategy_type)
end