Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Config for the Vector DB to use for RAG.
Instance Attribute Summary collapse
-
#api_auth ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ApiAuth
The generic reusable api auth config.
-
#pinecone ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigPinecone
The config for the Pinecone.
-
#rag_embedding_model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfig
Config for the embedding model to use for RAG.
-
#rag_managed_db ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigRagManagedDb
The config for the default RAG-managed Vector DB.
-
#rag_managed_vertex_vector_search ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigRagManagedVertexVectorSearch
The config for the RAG-managed Vertex Vector Search 2.0.
-
#vertex_feature_store ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigVertexFeatureStore
The config for the Vertex Feature Store.
-
#vertex_vector_search ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigVertexVectorSearch
The config for the Vertex Vector Search.
-
#weaviate ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigWeaviate
The config for the Weaviate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagVectorDbConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1RagVectorDbConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagVectorDbConfig
Returns a new instance of GoogleCloudAiplatformV1beta1RagVectorDbConfig.
47551 47552 47553 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47551 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_auth ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ApiAuth
The generic reusable api auth config. Deprecated. Please use AuthConfig (
google/cloud/aiplatform/master/auth.proto) instead.
Corresponds to the JSON property apiAuth
47514 47515 47516 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47514 def api_auth @api_auth end |
#pinecone ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigPinecone
The config for the Pinecone.
Corresponds to the JSON property pinecone
47519 47520 47521 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47519 def pinecone @pinecone end |
#rag_embedding_model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfig
Config for the embedding model to use for RAG.
Corresponds to the JSON property ragEmbeddingModelConfig
47524 47525 47526 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47524 def @rag_embedding_model_config end |
#rag_managed_db ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigRagManagedDb
The config for the default RAG-managed Vector DB.
Corresponds to the JSON property ragManagedDb
47529 47530 47531 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47529 def rag_managed_db @rag_managed_db end |
#rag_managed_vertex_vector_search ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigRagManagedVertexVectorSearch
The config for the RAG-managed Vertex Vector Search 2.0.
Corresponds to the JSON property ragManagedVertexVectorSearch
47534 47535 47536 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47534 def rag_managed_vertex_vector_search @rag_managed_vertex_vector_search end |
#vertex_feature_store ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigVertexFeatureStore
The config for the Vertex Feature Store.
Corresponds to the JSON property vertexFeatureStore
47539 47540 47541 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47539 def vertex_feature_store @vertex_feature_store end |
#vertex_vector_search ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigVertexVectorSearch
The config for the Vertex Vector Search.
Corresponds to the JSON property vertexVectorSearch
47544 47545 47546 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47544 def vertex_vector_search @vertex_vector_search end |
#weaviate ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigWeaviate
The config for the Weaviate.
Corresponds to the JSON property weaviate
47549 47550 47551 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47549 def weaviate @weaviate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47556 47557 47558 47559 47560 47561 47562 47563 47564 47565 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47556 def update!(**args) @api_auth = args[:api_auth] if args.key?(:api_auth) @pinecone = args[:pinecone] if args.key?(:pinecone) @rag_embedding_model_config = args[:rag_embedding_model_config] if args.key?(:rag_embedding_model_config) @rag_managed_db = args[:rag_managed_db] if args.key?(:rag_managed_db) @rag_managed_vertex_vector_search = args[:rag_managed_vertex_vector_search] if args.key?(:rag_managed_vertex_vector_search) @vertex_feature_store = args[:vertex_feature_store] if args.key?(:vertex_feature_store) @vertex_vector_search = args[:vertex_vector_search] if args.key?(:vertex_vector_search) @weaviate = args[:weaviate] if args.key?(:weaviate) end |