Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReadTensorboardUsageResponsePerUserUsageData
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReadTensorboardUsageResponsePerUserUsageData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Per user usage data.
Instance Attribute Summary collapse
-
#username ⇒ String
User's username Corresponds to the JSON property
username. -
#view_count ⇒ Fixnum
Number of times the user has read data within the Tensorboard.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReadTensorboardUsageResponsePerUserUsageData
constructor
A new instance of GoogleCloudAiplatformV1beta1ReadTensorboardUsageResponsePerUserUsageData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReadTensorboardUsageResponsePerUserUsageData
Returns a new instance of GoogleCloudAiplatformV1beta1ReadTensorboardUsageResponsePerUserUsageData.
38763 38764 38765 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38763 def initialize(**args) update!(**args) end |
Instance Attribute Details
#username ⇒ String
User's username
Corresponds to the JSON property username
38756 38757 38758 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38756 def username @username end |
#view_count ⇒ Fixnum
Number of times the user has read data within the Tensorboard.
Corresponds to the JSON property viewCount
38761 38762 38763 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38761 def view_count @view_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38768 38769 38770 38771 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38768 def update!(**args) @username = args[:username] if args.key?(:username) @view_count = args[:view_count] if args.key?(:view_count) end |