Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngine

Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngine.



48339
48340
48341
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48339

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#context_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpec

Configuration for how Agent Engine sub-resources should manage context. Corresponds to the JSON property contextSpec



48284
48285
48286
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48284

def context_spec
  @context_spec
end

#create_timeString

Output only. Timestamp when this ReasoningEngine was created. Corresponds to the JSON property createTime

Returns:

  • (String)


48289
48290
48291
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48289

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ReasoningEngine. Corresponds to the JSON property description

Returns:

  • (String)


48294
48295
48296
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48294

def description
  @description
end

#display_nameString

Required. The display name of the ReasoningEngine. Corresponds to the JSON property displayName

Returns:

  • (String)


48299
48300
48301
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48299

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



48305
48306
48307
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48305

def encryption_spec
  @encryption_spec
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


48311
48312
48313
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48311

def etag
  @etag
end

#labelsHash<String,String>

Labels for the ReasoningEngine. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


48316
48317
48318
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48316

def labels
  @labels
end

#nameString

Identifier. The resource name of the ReasoningEngine. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine` Corresponds to the JSON propertyname`

Returns:

  • (String)


48322
48323
48324
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48322

def name
  @name
end

#specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec

ReasoningEngine configurations Corresponds to the JSON property spec



48327
48328
48329
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48327

def spec
  @spec
end

#traffic_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineTrafficConfig

Traffic distribution configuration. Corresponds to the JSON property trafficConfig



48332
48333
48334
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48332

def traffic_config
  @traffic_config
end

#update_timeString

Output only. Timestamp when this ReasoningEngine was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


48337
48338
48339
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48337

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48344
48345
48346
48347
48348
48349
48350
48351
48352
48353
48354
48355
48356
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48344

def update!(**args)
  @context_spec = args[:context_spec] if args.key?(:context_spec)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @spec = args[:spec] if args.key?(:spec)
  @traffic_config = args[:traffic_config] if args.key?(:traffic_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end