Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
ReasoningEngine configurations
Instance Attribute Summary collapse
-
#agent_card ⇒ Hash<String,Object>
Optional.
-
#agent_framework ⇒ String
Optional.
-
#build_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecBuildSpec
Specification for building container image.
-
#class_methods ⇒ Array<Hash<String,Object>>
Optional.
-
#container_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecContainerSpec
Specification for deploying from a container image.
-
#deployment_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
-
#effective_identity ⇒ String
Output only.
-
#identity_type ⇒ String
Optional.
-
#package_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecPackageSpec
User-provided package specification, containing pickled object and package requirements.
-
#service_account ⇒ String
Optional.
-
#source_code_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec
Specification for deploying from source code.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpec
Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpec.
48667 48668 48669 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_card ⇒ Hash<String,Object>
Optional. The A2A Agent Card for the agent (if available). It follows the
specification at https://a2a-protocol.org/latest/specification/#5-agent-
discovery-the-agent-card.
Corresponds to the JSON property agentCard
48600 48601 48602 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48600 def agent_card @agent_card end |
#agent_framework ⇒ String
Optional. The OSS agent framework used to develop the agent. Currently
supported values: "google-adk", "langchain", "langgraph", "ag2", "llama-index",
"custom".
Corresponds to the JSON property agentFramework
48607 48608 48609 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48607 def agent_framework @agent_framework end |
#build_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecBuildSpec
Specification for building container image.
Corresponds to the JSON property buildSpec
48612 48613 48614 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48612 def build_spec @build_spec end |
#class_methods ⇒ Array<Hash<String,Object>>
Optional. Declarations for object class methods in OpenAPI specification
format.
Corresponds to the JSON property classMethods
48618 48619 48620 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48618 def class_methods @class_methods end |
#container_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecContainerSpec
Specification for deploying from a container image.
Corresponds to the JSON property containerSpec
48623 48624 48625 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48623 def container_spec @container_spec end |
#deployment_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
Corresponds to the JSON property deploymentSpec
48628 48629 48630 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48628 def deployment_spec @deployment_spec end |
#effective_identity ⇒ String
Output only. The identity to use for the Reasoning Engine. It can contain one
of the following values: * service-project@gcp-sa-aiplatform-re.googleapis.
com (for SERVICE_AGENT identity type) * name@project.gserviceaccount.com (
for SERVICE_ACCOUNT identity type) * agents.global.org.system.id.goog/
resources/aiplatform/projects/project/locations/location/reasoningEngines/
reasoning_engine (for AGENT_IDENTITY identity type)
Corresponds to the JSON property effectiveIdentity
48638 48639 48640 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48638 def effective_identity @effective_identity end |
#identity_type ⇒ String
Optional. The identity type to use for the Reasoning Engine. If not specified,
the service_account field will be used if set, otherwise the default Vertex
AI Reasoning Engine Service Agent in the project will be used.
Corresponds to the JSON property identityType
48645 48646 48647 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48645 def identity_type @identity_type end |
#package_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecPackageSpec
User-provided package specification, containing pickled object and package
requirements.
Corresponds to the JSON property packageSpec
48651 48652 48653 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48651 def package_spec @package_spec end |
#service_account ⇒ String
Optional. The service account that the Reasoning Engine artifact runs as. It
should have "roles/storage.objectViewer" for reading the user project's Cloud
Storage and "roles/aiplatform.user" for using Vertex extensions. If not
specified, the Vertex AI Reasoning Engine Service Agent in the project will be
used.
Corresponds to the JSON property serviceAccount
48660 48661 48662 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48660 def service_account @service_account end |
#source_code_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec
Specification for deploying from source code.
Corresponds to the JSON property sourceCodeSpec
48665 48666 48667 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48665 def source_code_spec @source_code_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48672 48673 48674 48675 48676 48677 48678 48679 48680 48681 48682 48683 48684 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48672 def update!(**args) @agent_card = args[:agent_card] if args.key?(:agent_card) @agent_framework = args[:agent_framework] if args.key?(:agent_framework) @build_spec = args[:build_spec] if args.key?(:build_spec) @class_methods = args[:class_methods] if args.key?(:class_methods) @container_spec = args[:container_spec] if args.key?(:container_spec) @deployment_spec = args[:deployment_spec] if args.key?(:deployment_spec) @effective_identity = args[:effective_identity] if args.key?(:effective_identity) @identity_type = args[:identity_type] if args.key?(:identity_type) @package_spec = args[:package_spec] if args.key?(:package_spec) @service_account = args[:service_account] if args.key?(:service_account) @source_code_spec = args[:source_code_spec] if args.key?(:source_code_spec) end |