Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecDeploymentSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The specification of a Reasoning Engine deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpecDeploymentSpec

Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpecDeploymentSpec.



46265
46266
46267
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_gateway_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecDeploymentSpecAgentGatewayConfig

Agent Gateway configuration for a Reasoning Engine deployment. Corresponds to the JSON property agentGatewayConfig



46202
46203
46204
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46202

def agent_gateway_config
  @agent_gateway_config
end

#agent_server_modeString

The agent server mode. Corresponds to the JSON property agentServerMode

Returns:

  • (String)


46207
46208
46209
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46207

def agent_server_mode
  @agent_server_mode
end

#container_concurrencyFixnum

Optional. Concurrency for each container and agent server. Recommended value: 2 * cpu + 1. Defaults to 9. Corresponds to the JSON property containerConcurrency

Returns:

  • (Fixnum)


46213
46214
46215
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46213

def container_concurrency
  @container_concurrency
end

#envArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EnvVar>

Optional. Environment variables to be set with the Reasoning Engine deployment. The environment variables can be updated through the UpdateReasoningEngine API. Corresponds to the JSON property env



46220
46221
46222
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46220

def env
  @env
end

#keep_alive_probeGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1KeepAliveProbe

Represents the configuration for keep-alive probe. Contains configuration on a specified endpoint that a deployment host should use to keep the container alive based on the probe settings. Corresponds to the JSON property keepAliveProbe



46227
46228
46229
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46227

def keep_alive_probe
  @keep_alive_probe
end

#max_instancesFixnum

Optional. The maximum number of application instances that can be launched to handle increased traffic. Defaults to 100. Range: [1, 1000]. If VPC-SC or PSC- I is enabled, the acceptable range is [1, 100]. Corresponds to the JSON property maxInstances

Returns:

  • (Fixnum)


46234
46235
46236
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46234

def max_instances
  @max_instances
end

#min_instancesFixnum

Optional. The minimum number of application instances that will be kept running at all times. Defaults to 1. Range: [0, 75]. Corresponds to the JSON property minInstances

Returns:

  • (Fixnum)


46240
46241
46242
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46240

def min_instances
  @min_instances
end

#psc_interface_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscInterfaceConfig

Configuration for PSC-I. Corresponds to the JSON property pscInterfaceConfig



46245
46246
46247
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46245

def psc_interface_config
  @psc_interface_config
end

#resource_limitsHash<String,String>

Optional. Resource limits for each container. Only 'cpu' and 'memory' keys are supported. Defaults to "cpu": "4", "memory": "4Gi". * The only supported values for CPU are '1', '2', '4', '6' and '8'. For more information, go to https://cloud.google.com/run/docs/configuring/cpu. * The only supported values for memory are '1Gi', '2Gi', ... '32 Gi'. * For required cpu on different memory values, go to https://cloud.google.com/run/docs/configuring/memory- limits Corresponds to the JSON property resourceLimits

Returns:

  • (Hash<String,String>)


46256
46257
46258
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46256

def resource_limits
  @resource_limits
end

#secret_envArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SecretEnvVar>

Optional. Environment variables where the value is a secret in Cloud Secret Manager. To use this feature, add 'Secret Manager Secret Accessor' role (roles/ secretmanager.secretAccessor) to AI Platform Reasoning Engine Service Agent. Corresponds to the JSON property secretEnv



46263
46264
46265
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46263

def secret_env
  @secret_env
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46270
46271
46272
46273
46274
46275
46276
46277
46278
46279
46280
46281
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46270

def update!(**args)
  @agent_gateway_config = args[:agent_gateway_config] if args.key?(:agent_gateway_config)
  @agent_server_mode = args[:agent_server_mode] if args.key?(:agent_server_mode)
  @container_concurrency = args[:container_concurrency] if args.key?(:container_concurrency)
  @env = args[:env] if args.key?(:env)
  @keep_alive_probe = args[:keep_alive_probe] if args.key?(:keep_alive_probe)
  @max_instances = args[:max_instances] if args.key?(:max_instances)
  @min_instances = args[:min_instances] if args.key?(:min_instances)
  @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config)
  @resource_limits = args[:resource_limits] if args.key?(:resource_limits)
  @secret_env = args[:secret_env] if args.key?(:secret_env)
end