Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Specifies the configuration for fetching source code from a Git repository that is managed by Developer Connect. This includes the repository, revision, and directory to use.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectConfig

Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectConfig.



49055
49056
49057
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dirString

Required. Directory, relative to the source root, in which to run the build. Corresponds to the JSON property dir

Returns:

  • (String)


49041
49042
49043
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49041

def dir
  @dir
end

Required. The Developer Connect Git repository link, formatted as projects/*/ locations/*/connections/*/gitRepositoryLink/*. Corresponds to the JSON property gitRepositoryLink

Returns:

  • (String)


49047
49048
49049
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49047

def git_repository_link
  @git_repository_link
end

#revisionString

Required. The revision to fetch from the Git repository such as a branch, a tag, a commit SHA, or any Git ref. Corresponds to the JSON property revision

Returns:

  • (String)


49053
49054
49055
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49053

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49060
49061
49062
49063
49064
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49060

def update!(**args)
  @dir = args[:dir] if args.key?(:dir)
  @git_repository_link = args[:git_repository_link] if args.key?(:git_repository_link)
  @revision = args[:revision] if args.key?(:revision)
end