Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Specifies source code to be fetched from a Git repository managed through the Developer Connect service.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectConfig
Specifies the configuration for fetching source code from a Git repository that is managed by Developer Connect.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
constructor
A new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource.
39466 39467 39468 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39466 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectConfig
Specifies the configuration for fetching source code from a Git repository
that is managed by Developer Connect. This includes the repository, revision,
and directory to use.
Corresponds to the JSON property config
39464 39465 39466 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39464 def config @config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39471 39472 39473 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39471 def update!(**args) @config = args[:config] if args.key?(:config) end |