Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineTrafficConfigTrafficSplitManualTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A single target for the traffic split, specifying a Runtime Revision and the percentage of traffic to send to it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineTrafficConfigTrafficSplitManualTarget

Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineTrafficConfigTrafficSplitManualTarget.



39641
39642
39643
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39641

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#percentFixnum

Required. Specifies percent of the traffic to this Runtime Revision. Corresponds to the JSON property percent

Returns:

  • (Fixnum)


39633
39634
39635
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39633

def percent
  @percent
end

#runtime_revision_nameString

Required. The Runtime Revision name to which to send this portion of traffic, if traffic allocation is by Runtime Revision. Corresponds to the JSON property runtimeRevisionName

Returns:

  • (String)


39639
39640
39641
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39639

def runtime_revision_name
  @runtime_revision_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39646
39647
39648
39649
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39646

def update!(**args)
  @percent = args[:percent] if args.key?(:percent)
  @runtime_revision_name = args[:runtime_revision_name] if args.key?(:runtime_revision_name)
end