Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for ModelService.RecommendSpec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RecommendSpecResponse

Returns a new instance of GoogleCloudAiplatformV1beta1RecommendSpecResponse.



49172
49173
49174
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_modelString

Output only. The base model used to finetune the custom model. Corresponds to the JSON property baseModel

Returns:

  • (String)


49159
49160
49161
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49159

def base_model
  @base_model
end

#recommendationsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation>

Output only. Recommendations of deployment options for the given custom weights model. Corresponds to the JSON property recommendations



49165
49166
49167
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49165

def recommendations
  @recommendations
end

#specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseMachineAndModelContainerSpec>

Output only. The machine and model container specs. Corresponds to the JSON property specs



49170
49171
49172
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49170

def specs
  @specs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49177
49178
49179
49180
49181
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49177

def update!(**args)
  @base_model = args[:base_model] if args.key?(:base_model)
  @recommendations = args[:recommendations] if args.key?(:recommendations)
  @specs = args[:specs] if args.key?(:specs)
end