Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Recommendation of one deployment option for the given custom weights model in one region. Contains the machine and container spec, and user accelerator quota state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation

Returns a new instance of GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation.



49462
49463
49464
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#regionString

The region for the deployment spec (machine). Corresponds to the JSON property region

Returns:

  • (String)


49450
49451
49452
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49450

def region
  @region
end

#specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseMachineAndModelContainerSpec

A machine and model container spec. Corresponds to the JSON property spec



49455
49456
49457
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49455

def spec
  @spec
end

#user_quota_stateString

Output only. The user accelerator quota state. Corresponds to the JSON property userQuotaState

Returns:

  • (String)


49460
49461
49462
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49460

def user_quota_state
  @user_quota_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49467
49468
49469
49470
49471
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49467

def update!(**args)
  @region = args[:region] if args.key?(:region)
  @spec = args[:spec] if args.key?(:spec)
  @user_quota_state = args[:user_quota_state] if args.key?(:user_quota_state)
end