Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The reward info for a reward function.
Instance Attribute Summary collapse
-
#error_status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#reward ⇒ Float
Output only.
-
#user_requested_aux_info ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo
constructor
A new instance of GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo
Returns a new instance of GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo.
49882 49883 49884 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49882 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property errorStatus
49867 49868 49869 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49867 def error_status @error_status end |
#reward ⇒ Float
Output only. The calculated reward for the reward function.
Corresponds to the JSON property reward
49872 49873 49874 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49872 def reward @reward end |
#user_requested_aux_info ⇒ String
Output only. The user-requested auxiliary info for the reward function. This
field is set only if the Cloud Run reward function configured by user returns
a "user_requested_aux_info". Refer to ReinforcementTuningCloudRunRewardScorer
for more details.
Corresponds to the JSON property userRequestedAuxInfo
49880 49881 49882 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49880 def user_requested_aux_info @user_requested_aux_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49887 49888 49889 49890 49891 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49887 def update!(**args) @error_status = args[:error_status] if args.key?(:error_status) @reward = args[:reward] if args.key?(:reward) @user_requested_aux_info = args[:user_requested_aux_info] if args.key?(:user_requested_aux_info) end |