Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReportExecutionEventRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReportExecutionEventRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for NotebookInternalService.ReportExecutionEvent.
Instance Attribute Summary collapse
-
#event_type ⇒ String
Required.
-
#status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#vm_token ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReportExecutionEventRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1ReportExecutionEventRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReportExecutionEventRequest
Returns a new instance of GoogleCloudAiplatformV1beta1ReportExecutionEventRequest.
50245 50246 50247 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50245 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_type ⇒ String
Required. The type of the event.
Corresponds to the JSON property eventType
50227 50228 50229 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50227 def event_type @event_type end |
#status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
50237 50238 50239 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50237 def status @status end |
#vm_token ⇒ String
Required. The VM identity token (a JWT) for authenticating the VM. https://
cloud.google.com/compute/docs/instances/verifying-instance-identity
Corresponds to the JSON property vmToken
50243 50244 50245 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50243 def vm_token @vm_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50250 50251 50252 50253 50254 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50250 def update!(**args) @event_type = args[:event_type] if args.key?(:event_type) @status = args[:status] if args.key?(:status) @vm_token = args[:vm_token] if args.key?(:vm_token) end |