Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Retrieval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Defines a retrieval tool that model can call to access external knowledge.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Retrieval

Returns a new instance of GoogleCloudAiplatformV1beta1Retrieval.



49883
49884
49885
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49883

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_attributionBoolean Also known as: disable_attribution?

Optional. Deprecated. This option is no longer supported. Corresponds to the JSON property disableAttribution

Returns:

  • (Boolean)


49862
49863
49864
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49862

def disable_attribution
  @disable_attribution
end

#external_apiGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExternalApi

Retrieve from data source powered by external API for grounding. The external API is not owned by Google, but need to follow the pre-defined API spec. Corresponds to the JSON property externalApi



49869
49870
49871
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49869

def external_api
  @external_api
end

#vertex_ai_searchGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexAiSearch

Retrieve from Vertex AI Search datastore or engine for grounding. datastore and engine are mutually exclusive. See https://cloud.google.com/products/agent- builder Corresponds to the JSON property vertexAiSearch



49876
49877
49878
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49876

def vertex_ai_search
  @vertex_ai_search
end

#vertex_rag_storeGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexRagStore

Retrieve from Vertex RAG Store for grounding. Corresponds to the JSON property vertexRagStore



49881
49882
49883
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49881

def vertex_rag_store
  @vertex_rag_store
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49888
49889
49890
49891
49892
49893
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49888

def update!(**args)
  @disable_attribution = args[:disable_attribution] if args.key?(:disable_attribution)
  @external_api = args[:external_api] if args.key?(:external_api)
  @vertex_ai_search = args[:vertex_ai_search] if args.key?(:vertex_ai_search)
  @vertex_rag_store = args[:vertex_rag_store] if args.key?(:vertex_rag_store)
end