Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrievalConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Retrieval config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrievalConfig

Returns a new instance of GoogleCloudAiplatformV1beta1RetrievalConfig.



50699
50700
50701
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#language_codeString

The language code of the user. Corresponds to the JSON property languageCode

Returns:

  • (String)


50689
50690
50691
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50689

def language_code
  @language_code
end

#lat_lngGoogle::Apis::AiplatformV1beta1::GoogleTypeLatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property latLng



50697
50698
50699
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50697

def lat_lng
  @lat_lng
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50704
50705
50706
50707
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50704

def update!(**args)
  @language_code = args[:language_code] if args.key?(:language_code)
  @lat_lng = args[:lat_lng] if args.key?(:lat_lng)
end