Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrievalMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Metadata related to the retrieval grounding source. This is part of the GroundingMetadata returned when grounding is enabled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrievalMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1RetrievalMetadata.



40455
40456
40457
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40455

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_search_dynamic_retrieval_scoreFloat

Optional. A score indicating how likely it is that a Google Search query could help answer the prompt. The score is in the range of [0, 1]. A score of 1 means the model is confident that a search will be helpful, and 0 means it is not. This score is populated only when Google Search grounding and dynamic retrieval are enabled. The score is used to determine whether to trigger a search. Corresponds to the JSON property googleSearchDynamicRetrievalScore

Returns:

  • (Float)


40453
40454
40455
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40453

def google_search_dynamic_retrieval_score
  @google_search_dynamic_retrieval_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40460
40461
40462
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40460

def update!(**args)
  @google_search_dynamic_retrieval_score = args[:google_search_dynamic_retrieval_score] if args.key?(:google_search_dynamic_retrieval_score)
end