Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Rubric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Message representing a single testable criterion for evaluation. One input prompt could have multiple rubrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Rubric

Returns a new instance of GoogleCloudAiplatformV1beta1Rubric.



41096
41097
41098
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricContent

Content of the rubric, defining the testable criteria. Corresponds to the JSON property content



41075
41076
41077
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41075

def content
  @content
end

#importanceString

Optional. The relative importance of this rubric. Corresponds to the JSON property importance

Returns:

  • (String)


41080
41081
41082
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41080

def importance
  @importance
end

#rubric_idString

Unique identifier for the rubric. This ID is used to refer to this rubric, e.g. , in RubricVerdict. Corresponds to the JSON property rubricId

Returns:

  • (String)


41086
41087
41088
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41086

def rubric_id
  @rubric_id
end

#typeString

Optional. A type designator for the rubric, which can inform how it's evaluated or interpreted by systems or users. It's recommended to use consistent, well-defined, upper snake_case strings. Examples: " SUMMARIZATION_QUALITY", "SAFETY_HARMFUL_CONTENT", "INSTRUCTION_ADHERENCE". Corresponds to the JSON property type

Returns:

  • (String)


41094
41095
41096
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41094

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41101
41102
41103
41104
41105
41106
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41101

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @importance = args[:importance] if args.key?(:importance)
  @rubric_id = args[:rubric_id] if args.key?(:rubric_id)
  @type = args[:type] if args.key?(:type)
end