Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A group of rubrics, used for grouping rubrics based on a metric or a version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RubricGroup

Returns a new instance of GoogleCloudAiplatformV1beta1RubricGroup.



48819
48820
48821
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Human-readable name for the group. This should be unique within a given context if used for display or selection. Example: "Instruction Following V1", "Content Quality - Summarization Task". Corresponds to the JSON property displayName

Returns:

  • (String)


48807
48808
48809
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48807

def display_name
  @display_name
end

#group_idString

Unique identifier for the group. Corresponds to the JSON property groupId

Returns:

  • (String)


48812
48813
48814
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48812

def group_id
  @group_id
end

#rubricsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Rubric>

Rubrics that are part of this group. Corresponds to the JSON property rubrics



48817
48818
48819
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48817

def rubrics
  @rubrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48824
48825
48826
48827
48828
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48824

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @group_id = args[:group_id] if args.key?(:group_id)
  @rubrics = args[:rubrics] if args.key?(:rubrics)
end