Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RuntimeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Runtime configuration to run the extension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RuntimeConfig

Returns a new instance of GoogleCloudAiplatformV1beta1RuntimeConfig.



48942
48943
48944
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_interpreter_runtime_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig

Code execution runtime configurations for code interpreter extension. Corresponds to the JSON property codeInterpreterRuntimeConfig



48925
48926
48927
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48925

def code_interpreter_runtime_config
  @code_interpreter_runtime_config
end

#default_paramsHash<String,Object>

Optional. Default parameters that will be set for all the execution of this extension. If specified, the parameter values can be overridden by values in [[ ExecuteExtensionRequest.operation_params]] at request time. The struct should be in a form of map with param name as the key and actual param value as the value. E.g. If this operation requires a param "name" to be set to "abc". you can set this to something like "name": "abc". Corresponds to the JSON property defaultParams

Returns:

  • (Hash<String,Object>)


48935
48936
48937
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48935

def default_params
  @default_params
end

#vertex_ai_search_runtime_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RuntimeConfigVertexAiSearchRuntimeConfig

Runtime configuration for Vertex AI Search extension. Corresponds to the JSON property vertexAiSearchRuntimeConfig



48940
48941
48942
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48940

def vertex_ai_search_runtime_config
  @vertex_ai_search_runtime_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48947
48948
48949
48950
48951
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48947

def update!(**args)
  @code_interpreter_runtime_config = args[:code_interpreter_runtime_config] if args.key?(:code_interpreter_runtime_config)
  @default_params = args[:default_params] if args.key?(:default_params)
  @vertex_ai_search_runtime_config = args[:vertex_ai_search_runtime_config] if args.key?(:vertex_ai_search_runtime_config)
end