Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig

Returns a new instance of GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig.



51500
51501
51502
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51500

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_input_gcs_bucketString

Optional. The Cloud Storage bucket for file input of this Extension. If specified, support input from the Cloud Storage bucket. Vertex Extension Custom Code Service Agent should be granted file reader to this bucket. If not specified, the extension will only accept file contents from request body and reject Cloud Storage file inputs. Corresponds to the JSON property fileInputGcsBucket

Returns:

  • (String)


51490
51491
51492
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51490

def file_input_gcs_bucket
  @file_input_gcs_bucket
end

#file_output_gcs_bucketString

Optional. The Cloud Storage bucket for file output of this Extension. If specified, write all output files to the Cloud Storage bucket. Vertex Extension Custom Code Service Agent should be granted file writer to this bucket. If not specified, the file content will be output in response body. Corresponds to the JSON property fileOutputGcsBucket

Returns:

  • (String)


51498
51499
51500
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51498

def file_output_gcs_bucket
  @file_output_gcs_bucket
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51505
51506
51507
51508
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51505

def update!(**args)
  @file_input_gcs_bucket = args[:file_input_gcs_bucket] if args.key?(:file_input_gcs_bucket)
  @file_output_gcs_bucket = args[:file_output_gcs_bucket] if args.key?(:file_output_gcs_bucket)
end