Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetySetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A safety setting that affects the safety-blocking behavior. A SafetySetting consists of a harm category and a threshold for that category.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SafetySetting

Returns a new instance of GoogleCloudAiplatformV1beta1SafetySetting.



47771
47772
47773
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Required. The harm category to be blocked. Corresponds to the JSON property category

Returns:

  • (String)


47757
47758
47759
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47757

def category
  @category
end

#method_propString

Optional. The method for blocking content. If not specified, the default behavior is to use the probability score. Corresponds to the JSON property method

Returns:

  • (String)


47763
47764
47765
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47763

def method_prop
  @method_prop
end

#thresholdString

Required. The threshold for blocking content. If the harm probability exceeds this threshold, the content will be blocked. Corresponds to the JSON property threshold

Returns:

  • (String)


47769
47770
47771
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47769

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47776
47777
47778
47779
47780
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47776

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @threshold = args[:threshold] if args.key?(:threshold)
end