Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SampledShapleyAttribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SampledShapleyAttribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An attribution method that approximates Shapley values for features that contribute to the label being predicted. A sampling strategy is used to approximate the value rather than considering all subsets of features.
Instance Attribute Summary collapse
-
#path_count ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SampledShapleyAttribution
constructor
A new instance of GoogleCloudAiplatformV1beta1SampledShapleyAttribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SampledShapleyAttribution
Returns a new instance of GoogleCloudAiplatformV1beta1SampledShapleyAttribution.
51774 51775 51776 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51774 def initialize(**args) update!(**args) end |
Instance Attribute Details
#path_count ⇒ Fixnum
Required. The number of feature permutations to consider when approximating
the Shapley values. Valid range of its value is [1, 50], inclusively.
Corresponds to the JSON property pathCount
51772 51773 51774 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51772 def path_count @path_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51779 51780 51781 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51779 def update!(**args) @path_count = args[:path_count] if args.key?(:path_count) end |