Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentConnectionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The connection information of the SandboxEnvironment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironmentConnectionInfo

Returns a new instance of GoogleCloudAiplatformV1beta1SandboxEnvironmentConnectionInfo.



52186
52187
52188
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52186

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#load_balancer_hostnameString

Output only. The hostname of the load balancer. Corresponds to the JSON property loadBalancerHostname

Returns:

  • (String)


52161
52162
52163
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52161

def load_balancer_hostname
  @load_balancer_hostname
end

#load_balancer_ipString

Output only. The IP address of the load balancer. Corresponds to the JSON property loadBalancerIp

Returns:

  • (String)


52166
52167
52168
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52166

def load_balancer_ip
  @load_balancer_ip
end

#routing_tokenString

Output only. The routing token for the SandboxEnvironment. Corresponds to the JSON property routingToken

Returns:

  • (String)


52171
52172
52173
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52171

def routing_token
  @routing_token
end

#sandbox_internal_ipString

Output only. The internal IP address of the SandboxEnvironment. Corresponds to the JSON property sandboxInternalIp

Returns:

  • (String)


52176
52177
52178
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52176

def sandbox_internal_ip
  @sandbox_internal_ip
end

#service_attachmentString

Output only. The name of the PSC-E service attachment created for private ingress to this SandboxEnvironment. Only populated when the template enables private ingress (see SandboxEnvironmentTemplate.ingress_control_config). VPC- SC customers use this to create a PSC endpoint in their VPC. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


52184
52185
52186
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52184

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52191
52192
52193
52194
52195
52196
52197
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52191

def update!(**args)
  @load_balancer_hostname = args[:load_balancer_hostname] if args.key?(:load_balancer_hostname)
  @load_balancer_ip = args[:load_balancer_ip] if args.key?(:load_balancer_ip)
  @routing_token = args[:routing_token] if args.key?(:routing_token)
  @sandbox_internal_ip = args[:sandbox_internal_ip] if args.key?(:sandbox_internal_ip)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end