Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The specification of a SandboxEnvironmentTemplate. A SandboxEnvironmentTemplate defines a template for creating SandboxEnvironments.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_container_environment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateCustomContainerEnvironment
The customized sandbox runtime environment for BYOC.
-
#default_container_environment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateDefaultContainerEnvironment
The default sandbox runtime environment for default container workloads.
-
#display_name ⇒ String
Required.
-
#egress_control_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateEgressControlConfig
Configuration for egress control of sandbox instances.
-
#ingress_control_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig
Represents configuration for private service connect.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate
constructor
A new instance of GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate
Returns a new instance of GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate.
52179 52180 52181 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52179 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when this SandboxEnvironmentTemplate was created.
Corresponds to the JSON property createTime
52134 52135 52136 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52134 def create_time @create_time end |
#custom_container_environment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateCustomContainerEnvironment
The customized sandbox runtime environment for BYOC.
Corresponds to the JSON property customContainerEnvironment
52139 52140 52141 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52139 def custom_container_environment @custom_container_environment end |
#default_container_environment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateDefaultContainerEnvironment
The default sandbox runtime environment for default container workloads.
Corresponds to the JSON property defaultContainerEnvironment
52144 52145 52146 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52144 def default_container_environment @default_container_environment end |
#display_name ⇒ String
Required. The display name of the SandboxEnvironmentTemplate.
Corresponds to the JSON property displayName
52149 52150 52151 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52149 def display_name @display_name end |
#egress_control_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateEgressControlConfig
Configuration for egress control of sandbox instances.
Corresponds to the JSON property egressControlConfig
52154 52155 52156 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52154 def egress_control_config @egress_control_config end |
#ingress_control_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig
Represents configuration for private service connect.
Corresponds to the JSON property ingressControlConfig
52159 52160 52161 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52159 def ingress_control_config @ingress_control_config end |
#name ⇒ String
Identifier. The resource name of the SandboxEnvironmentTemplate. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
sandboxEnvironmentTemplates/sandbox_environment_template`
Corresponds to the JSON propertyname`
52166 52167 52168 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52166 def name @name end |
#state ⇒ String
Output only. The state of the sandbox environment template.
Corresponds to the JSON property state
52171 52172 52173 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52171 def state @state end |
#update_time ⇒ String
Output only. The timestamp when this SandboxEnvironmentTemplate was most
recently updated.
Corresponds to the JSON property updateTime
52177 52178 52179 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52177 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52184 52185 52186 52187 52188 52189 52190 52191 52192 52193 52194 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52184 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_container_environment = args[:custom_container_environment] if args.key?(:custom_container_environment) @default_container_environment = args[:default_container_environment] if args.key?(:default_container_environment) @display_name = args[:display_name] if args.key?(:display_name) @egress_control_config = args[:egress_control_config] if args.key?(:egress_control_config) @ingress_control_config = args[:ingress_control_config] if args.key?(:ingress_control_config) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |