Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Scheduling
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Scheduling
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
All parameters related to queuing and scheduling of custom jobs.
Instance Attribute Summary collapse
-
#disable_retries ⇒ Boolean
(also: #disable_retries?)
Optional.
-
#max_wait_duration ⇒ String
Optional.
-
#restart_job_on_worker_restart ⇒ Boolean
(also: #restart_job_on_worker_restart?)
Optional.
-
#strategy ⇒ String
Optional.
-
#timeout ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Scheduling
constructor
A new instance of GoogleCloudAiplatformV1beta1Scheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Scheduling
Returns a new instance of GoogleCloudAiplatformV1beta1Scheduling.
53009 53010 53011 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53009 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_retries ⇒ Boolean Also known as: disable_retries?
Optional. Indicates if the job should retry for internal errors after the job
starts running. If true, overrides Scheduling.restart_job_on_worker_restart
to false.
Corresponds to the JSON property disableRetries
52980 52981 52982 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52980 def disable_retries @disable_retries end |
#max_wait_duration ⇒ String
Optional. This is the maximum duration that a job will wait for the requested
resources to be provisioned if the scheduling strategy is set to [Strategy.
DWS_FLEX_START]. If set to 0, the job will wait indefinitely. The default is
24 hours.
Corresponds to the JSON property maxWaitDuration
52989 52990 52991 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52989 def max_wait_duration @max_wait_duration end |
#restart_job_on_worker_restart ⇒ Boolean Also known as: restart_job_on_worker_restart?
Optional. Restarts the entire CustomJob if a worker gets restarted. This
feature can be used by distributed training jobs that are not resilient to
workers leaving and joining a job.
Corresponds to the JSON property restartJobOnWorkerRestart
52996 52997 52998 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52996 def restart_job_on_worker_restart @restart_job_on_worker_restart end |
#strategy ⇒ String
Optional. This determines which type of scheduling strategy to use.
Corresponds to the JSON property strategy
53002 53003 53004 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53002 def strategy @strategy end |
#timeout ⇒ String
Optional. The maximum job running time. The default is 7 days.
Corresponds to the JSON property timeout
53007 53008 53009 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53007 def timeout @timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53014 53015 53016 53017 53018 53019 53020 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53014 def update!(**args) @disable_retries = args[:disable_retries] if args.key?(:disable_retries) @max_wait_duration = args[:max_wait_duration] if args.key?(:max_wait_duration) @restart_job_on_worker_restart = args[:restart_job_on_worker_restart] if args.key?(:restart_job_on_worker_restart) @strategy = args[:strategy] if args.key?(:strategy) @timeout = args[:timeout] if args.key?(:timeout) end |