Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Schema

Returns a new instance of GoogleCloudAiplatformV1beta1Schema.



53190
53191
53192
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_propertiesObject

Optional. If type is OBJECT, specifies how to handle properties not defined in properties. If it is a boolean false, no additional properties are allowed. If it is a schema, additional properties are allowed if they conform to the schema. Corresponds to the JSON property additionalProperties

Returns:

  • (Object)


53034
53035
53036
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53034

def additional_properties
  @additional_properties
end

#any_ofArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema>

Optional. The instance must be valid against any (one or more) of the subschemas listed in any_of. Corresponds to the JSON property anyOf



53040
53041
53042
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53040

def any_of
  @any_of
end

#defaultObject

Optional. Default value to use if the field is not specified. Corresponds to the JSON property default

Returns:

  • (Object)


53045
53046
53047
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53045

def default
  @default
end

#defsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema>

Optional. defs provides a map of schema definitions that can be reused by ref elsewhere in the schema. Only allowed at root level of the schema. Corresponds to the JSON property defs



53051
53052
53053
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53051

def defs
  @defs
end

#descriptionString

Optional. Describes the data. The model uses this field to understand the purpose of the schema and how to use it. It is a best practice to provide a clear and descriptive explanation for the schema and its properties here, rather than in the prompt. Corresponds to the JSON property description

Returns:

  • (String)


53059
53060
53061
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53059

def description
  @description
end

#enumArray<String>

Optional. Possible values of the field. This field can be used to restrict a value to a fixed set of values. To mark a field as an enum, set format to enum and provide the list of possible values in enum. For example: 1. To define directions: type:STRING, format:enum, enum:["EAST", "NORTH", "SOUTH", "WEST"] 2. To define apartment numbers: type:INTEGER, format:enum, enum:[" 101", "201", "301"] Corresponds to the JSON property enum

Returns:

  • (Array<String>)


53069
53070
53071
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53069

def enum
  @enum
end

#exampleObject

Optional. Example of an instance of this schema. Corresponds to the JSON property example

Returns:

  • (Object)


53074
53075
53076
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53074

def example
  @example
end

#formatString

Optional. The format of the data. For NUMBER type, format can be float or double. For INTEGER type, format can be int32 or int64. For STRING type, format can be email, byte, date, date-time, password, and other formats to further refine the data type. Corresponds to the JSON property format

Returns:

  • (String)


53082
53083
53084
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53082

def format
  @format
end

#itemsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema

Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object. Corresponds to the JSON property items



53088
53089
53090
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53088

def items
  @items
end

#max_itemsFixnum

Optional. If type is ARRAY, max_items specifies the maximum number of items in an array. Corresponds to the JSON property maxItems

Returns:

  • (Fixnum)


53094
53095
53096
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53094

def max_items
  @max_items
end

#max_lengthFixnum

Optional. If type is STRING, max_length specifies the maximum length of the string. Corresponds to the JSON property maxLength

Returns:

  • (Fixnum)


53100
53101
53102
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53100

def max_length
  @max_length
end

#max_propertiesFixnum

Optional. If type is OBJECT, max_properties specifies the maximum number of properties that can be provided. Corresponds to the JSON property maxProperties

Returns:

  • (Fixnum)


53106
53107
53108
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53106

def max_properties
  @max_properties
end

#maximumFloat

Optional. If type is INTEGER or NUMBER, maximum specifies the maximum allowed value. Corresponds to the JSON property maximum

Returns:

  • (Float)


53112
53113
53114
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53112

def maximum
  @maximum
end

#min_itemsFixnum

Optional. If type is ARRAY, min_items specifies the minimum number of items in an array. Corresponds to the JSON property minItems

Returns:

  • (Fixnum)


53118
53119
53120
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53118

def min_items
  @min_items
end

#min_lengthFixnum

Optional. If type is STRING, min_length specifies the minimum length of the string. Corresponds to the JSON property minLength

Returns:

  • (Fixnum)


53124
53125
53126
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53124

def min_length
  @min_length
end

#min_propertiesFixnum

Optional. If type is OBJECT, min_properties specifies the minimum number of properties that can be provided. Corresponds to the JSON property minProperties

Returns:

  • (Fixnum)


53130
53131
53132
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53130

def min_properties
  @min_properties
end

#minimumFloat

Optional. If type is INTEGER or NUMBER, minimum specifies the minimum allowed value. Corresponds to the JSON property minimum

Returns:

  • (Float)


53136
53137
53138
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53136

def minimum
  @minimum
end

#nullableBoolean Also known as: nullable?

Optional. Indicates if the value of this field can be null. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


53141
53142
53143
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53141

def nullable
  @nullable
end

#patternString

Optional. If type is STRING, pattern specifies a regular expression that the string must match. Corresponds to the JSON property pattern

Returns:

  • (String)


53148
53149
53150
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53148

def pattern
  @pattern
end

#propertiesHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema>

Optional. If type is OBJECT, properties is a map of property names to schema definitions for each property of the object. Corresponds to the JSON property properties



53154
53155
53156
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53154

def properties
  @properties
end

#property_orderingArray<String>

Optional. Order of properties displayed or used where order matters. This is not a standard field in OpenAPI specification, but can be used to control the order of properties. Corresponds to the JSON property propertyOrdering

Returns:

  • (Array<String>)


53161
53162
53163
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53161

def property_ordering
  @property_ordering
end

#refString

Optional. Allows referencing another schema definition to use in place of this schema. The value must be a valid reference to a schema in defs. For example, the following schema defines a reference to a schema node named "Pet": type: object properties: pet: ref: #/defs/Pet defs: Pet: type: object properties: name: type: string The value of the "pet" property is a reference to the schema node named "Pet". See details in https://json-schema.org/understanding- json-schema/structuring Corresponds to the JSON property ref

Returns:

  • (String)


53172
53173
53174
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53172

def ref
  @ref
end

#requiredArray<String>

Optional. If type is OBJECT, required lists the names of properties that must be present. Corresponds to the JSON property required

Returns:

  • (Array<String>)


53178
53179
53180
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53178

def required
  @required
end

#titleString

Optional. Title for the schema. Corresponds to the JSON property title

Returns:

  • (String)


53183
53184
53185
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53183

def title
  @title
end

#typeString

Optional. Data type of the schema field. Corresponds to the JSON property type

Returns:

  • (String)


53188
53189
53190
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53188

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53195
53196
53197
53198
53199
53200
53201
53202
53203
53204
53205
53206
53207
53208
53209
53210
53211
53212
53213
53214
53215
53216
53217
53218
53219
53220
53221
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53195

def update!(**args)
  @additional_properties = args[:additional_properties] if args.key?(:additional_properties)
  @any_of = args[:any_of] if args.key?(:any_of)
  @default = args[:default] if args.key?(:default)
  @defs = args[:defs] if args.key?(:defs)
  @description = args[:description] if args.key?(:description)
  @enum = args[:enum] if args.key?(:enum)
  @example = args[:example] if args.key?(:example)
  @format = args[:format] if args.key?(:format)
  @items = args[:items] if args.key?(:items)
  @max_items = args[:max_items] if args.key?(:max_items)
  @max_length = args[:max_length] if args.key?(:max_length)
  @max_properties = args[:max_properties] if args.key?(:max_properties)
  @maximum = args[:maximum] if args.key?(:maximum)
  @min_items = args[:min_items] if args.key?(:min_items)
  @min_length = args[:min_length] if args.key?(:min_length)
  @min_properties = args[:min_properties] if args.key?(:min_properties)
  @minimum = args[:minimum] if args.key?(:minimum)
  @nullable = args[:nullable] if args.key?(:nullable)
  @pattern = args[:pattern] if args.key?(:pattern)
  @properties = args[:properties] if args.key?(:properties)
  @property_ordering = args[:property_ordering] if args.key?(:property_ordering)
  @ref = args[:ref] if args.key?(:ref)
  @required = args[:required] if args.key?(:required)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end