Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaImageDatasetMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The metadata of Datasets that contain Image DataItems.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaImageDatasetMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaImageDatasetMetadata.



52598
52599
52600
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52598

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_item_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing payload of the Image DataItems that belong to this Dataset. Corresponds to the JSON property dataItemSchemaUri

Returns:

  • (String)


52591
52592
52593
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52591

def data_item_schema_uri
  @data_item_schema_uri
end

#gcs_bucketString

Google Cloud Storage Bucket name that contains the blob data of this Dataset. Corresponds to the JSON property gcsBucket

Returns:

  • (String)


52596
52597
52598
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52596

def gcs_bucket
  @gcs_bucket
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52603
52604
52605
52606
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52603

def update!(**args)
  @data_item_schema_uri = args[:data_item_schema_uri] if args.key?(:data_item_schema_uri)
  @gcs_bucket = args[:gcs_bucket] if args.key?(:gcs_bucket)
end