Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaImageSegmentationAnnotationPolylineAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a polyline in image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaImageSegmentationAnnotationPolylineAnnotation

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaImageSegmentationAnnotationPolylineAnnotation.



51482
51483
51484
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_idString

The resource Id of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property annotationSpecId

Returns:

  • (String)


51469
51470
51471
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51469

def annotation_spec_id
  @annotation_spec_id
end

#display_nameString

The display name of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property displayName

Returns:

  • (String)


51474
51475
51476
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51474

def display_name
  @display_name
end

#vertexesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaVertex>

The vertexes are connected one by one and the last vertex in not connected to the first one. Corresponds to the JSON property vertexes



51480
51481
51482
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51480

def vertexes
  @vertexes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51487
51488
51489
51490
51491
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51487

def update!(**args)
  @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @vertexes = args[:vertexes] if args.key?(:vertexes)
end