Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Metrics for a single confidence threshold.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The confidence threshold value used to compute the metrics.
-
#f1_score ⇒ Float
The harmonic mean of recall and precision.
-
#precision ⇒ Float
Precision under the given confidence threshold.
-
#recall ⇒ Float
Recall under the given confidence threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics.
43272 43273 43274 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The confidence threshold value used to compute the metrics.
Corresponds to the JSON property confidenceThreshold
43255 43256 43257 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43255 def confidence_threshold @confidence_threshold end |
#f1_score ⇒ Float
The harmonic mean of recall and precision.
Corresponds to the JSON property f1Score
43260 43261 43262 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43260 def f1_score @f1_score end |
#precision ⇒ Float
Precision under the given confidence threshold.
Corresponds to the JSON property precision
43265 43266 43267 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43265 def precision @precision end |
#recall ⇒ Float
Recall under the given confidence threshold.
Corresponds to the JSON property recall
43270 43271 43272 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43270 def recall @recall end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43277 43278 43279 43280 43281 43282 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43277 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @f1_score = args[:f1_score] if args.key?(:f1_score) @precision = args[:precision] if args.key?(:precision) @recall = args[:recall] if args.key?(:recall) end |