Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry.



53258
53259
53260
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53258

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

Metrics are computed with an assumption that the model never returns predictions with score lower than this value. Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


53230
53231
53232
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53230

def confidence_threshold
  @confidence_threshold
end

#confusion_matrixGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsConfusionMatrix

Confusion matrix for the given confidence threshold. Corresponds to the JSON property confusionMatrix



53235
53236
53237
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53235

def confusion_matrix
  @confusion_matrix
end

#dice_score_coefficientFloat

DSC or the F1 score, The harmonic mean of recall and precision. Corresponds to the JSON property diceScoreCoefficient

Returns:

  • (Float)


53240
53241
53242
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53240

def dice_score_coefficient
  @dice_score_coefficient
end

#iou_scoreFloat

The intersection-over-union score. The measure of overlap of the annotation's category mask with ground truth category mask on the DataItem. Corresponds to the JSON property iouScore

Returns:

  • (Float)


53246
53247
53248
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53246

def iou_score
  @iou_score
end

#precisionFloat

Precision for the given confidence threshold. Corresponds to the JSON property precision

Returns:

  • (Float)


53251
53252
53253
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53251

def precision
  @precision
end

#recallFloat

Recall (True Positive Rate) for the given confidence threshold. Corresponds to the JSON property recall

Returns:

  • (Float)


53256
53257
53258
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53256

def recall
  @recall
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53263
53264
53265
53266
53267
53268
53269
53270
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53263

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @confusion_matrix = args[:confusion_matrix] if args.key?(:confusion_matrix)
  @dice_score_coefficient = args[:dice_score_coefficient] if args.key?(:dice_score_coefficient)
  @iou_score = args[:iou_score] if args.key?(:iou_score)
  @precision = args[:precision] if args.key?(:precision)
  @recall = args[:recall] if args.key?(:recall)
end