Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

UNIMPLEMENTED. Track matching model metrics for a single track match threshold and multiple label match confidence thresholds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetrics

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetrics.



49014
49015
49016
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_metricsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics>

Metrics for each label-match confidenceThreshold from 0.05,0.10,...,0.95,0. 96,0.97,0.98,0.99. Precision-recall curve is derived from them. Corresponds to the JSON property confidenceMetrics



48991
48992
48993
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48991

def confidence_metrics
  @confidence_metrics
end

#iou_thresholdFloat

The intersection-over-union threshold value between bounding boxes across frames used to compute this metric entry. Corresponds to the JSON property iouThreshold

Returns:

  • (Float)


48997
48998
48999
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48997

def iou_threshold
  @iou_threshold
end

#mean_bounding_box_iouFloat

The mean bounding box iou over all confidence thresholds. Corresponds to the JSON property meanBoundingBoxIou

Returns:

  • (Float)


49002
49003
49004
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49002

def mean_bounding_box_iou
  @mean_bounding_box_iou
end

#mean_mismatch_rateFloat

The mean mismatch rate over all confidence thresholds. Corresponds to the JSON property meanMismatchRate

Returns:

  • (Float)


49007
49008
49009
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49007

def mean_mismatch_rate
  @mean_mismatch_rate
end

#mean_tracking_average_precisionFloat

The mean average precision over all confidence thresholds. Corresponds to the JSON property meanTrackingAveragePrecision

Returns:

  • (Float)


49012
49013
49014
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49012

def mean_tracking_average_precision
  @mean_tracking_average_precision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49019
49020
49021
49022
49023
49024
49025
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49019

def update!(**args)
  @confidence_metrics = args[:confidence_metrics] if args.key?(:confidence_metrics)
  @iou_threshold = args[:iou_threshold] if args.key?(:iou_threshold)
  @mean_bounding_box_iou = args[:mean_bounding_box_iou] if args.key?(:mean_bounding_box_iou)
  @mean_mismatch_rate = args[:mean_mismatch_rate] if args.key?(:mean_mismatch_rate)
  @mean_tracking_average_precision = args[:mean_tracking_average_precision] if args.key?(:mean_tracking_average_precision)
end