Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Metrics for a single confidence threshold.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics.



54240
54241
54242
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_box_iouFloat

Bounding box intersection-over-union precision. Measures how well the bounding boxes overlap between each other (e.g. complete overlap or just barely above iou_threshold). Corresponds to the JSON property boundingBoxIou

Returns:

  • (Float)


54217
54218
54219
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54217

def bounding_box_iou
  @bounding_box_iou
end

#confidence_thresholdFloat

The confidence threshold value used to compute the metrics. Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


54222
54223
54224
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54222

def confidence_threshold
  @confidence_threshold
end

#mismatch_rateFloat

Mismatch rate, which measures the tracking consistency, i.e. correctness of instance ID continuity. Corresponds to the JSON property mismatchRate

Returns:

  • (Float)


54228
54229
54230
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54228

def mismatch_rate
  @mismatch_rate
end

#tracking_precisionFloat

Tracking precision. Corresponds to the JSON property trackingPrecision

Returns:

  • (Float)


54233
54234
54235
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54233

def tracking_precision
  @tracking_precision
end

#tracking_recallFloat

Tracking recall. Corresponds to the JSON property trackingRecall

Returns:

  • (Float)


54238
54239
54240
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54238

def tracking_recall
  @tracking_recall
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54245
54246
54247
54248
54249
54250
54251
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54245

def update!(**args)
  @bounding_box_iou = args[:bounding_box_iou] if args.key?(:bounding_box_iou)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @mismatch_rate = args[:mismatch_rate] if args.key?(:mismatch_rate)
  @tracking_precision = args[:tracking_precision] if args.key?(:tracking_precision)
  @tracking_recall = args[:tracking_recall] if args.key?(:tracking_recall)
end