Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictParamsGroundingConfigSourceEntry
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictParamsGroundingConfigSourceEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Single source entry for the grounding checking.
Instance Attribute Summary collapse
-
#enterprise_datastore ⇒ String
The uri of the Vertex AI Search data source.
-
#inline_context ⇒ String
The grounding text passed inline with the Predict API.
-
#type ⇒ String
The type of the grounding checking source.
-
#vertex_ai_search_datastore ⇒ String
The uri of the Vertex AI Search data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictParamsGroundingConfigSourceEntry
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaPredictParamsGroundingConfigSourceEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictParamsGroundingConfigSourceEntry
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictParamsGroundingConfigSourceEntry.
50861 50862 50863 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50861 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enterprise_datastore ⇒ String
The uri of the Vertex AI Search data source. Deprecated. Use
vertex_ai_search_datastore instead.
Corresponds to the JSON property enterpriseDatastore
50843 50844 50845 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50843 def enterprise_datastore @enterprise_datastore end |
#inline_context ⇒ String
The grounding text passed inline with the Predict API. It can support up to 1
million bytes.
Corresponds to the JSON property inlineContext
50849 50850 50851 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50849 def inline_context @inline_context end |
#type ⇒ String
The type of the grounding checking source.
Corresponds to the JSON property type
50854 50855 50856 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50854 def type @type end |
#vertex_ai_search_datastore ⇒ String
The uri of the Vertex AI Search data source.
Corresponds to the JSON property vertexAiSearchDatastore
50859 50860 50861 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50859 def vertex_ai_search_datastore @vertex_ai_search_datastore end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50866 50867 50868 50869 50870 50871 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50866 def update!(**args) @enterprise_datastore = args[:enterprise_datastore] if args.key?(:enterprise_datastore) @inline_context = args[:inline_context] if args.key?(:inline_context) @type = args[:type] if args.key?(:type) @vertex_ai_search_datastore = args[:vertex_ai_search_datastore] if args.key?(:vertex_ai_search_datastore) end |