Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictPredictionTextExtractionPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Prediction output format for Text Extraction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictPredictionTextExtractionPredictionResult

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictPredictionTextExtractionPredictionResult.



54718
54719
54720
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidencesArray<Float>

The Model's confidences in correctness of the predicted IDs, higher value means higher confidence. Order matches the Ids. Corresponds to the JSON property confidences

Returns:

  • (Array<Float>)


54690
54691
54692
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54690

def confidences
  @confidences
end

#display_namesArray<String>

The display names of the AnnotationSpecs that had been identified, order matches the IDs. Corresponds to the JSON property displayNames

Returns:

  • (Array<String>)


54696
54697
54698
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54696

def display_names
  @display_names
end

#idsArray<Fixnum>

The resource IDs of the AnnotationSpecs that had been identified, ordered by the confidence score descendingly. Corresponds to the JSON property ids

Returns:

  • (Array<Fixnum>)


54702
54703
54704
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54702

def ids
  @ids
end

#text_segment_end_offsetsArray<Fixnum>

The end offsets, inclusive, of the text segment in which the AnnotationSpec has been identified. Expressed as a zero-based number of characters as measured from the start of the text snippet. Corresponds to the JSON property textSegmentEndOffsets

Returns:

  • (Array<Fixnum>)


54709
54710
54711
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54709

def text_segment_end_offsets
  @text_segment_end_offsets
end

#text_segment_start_offsetsArray<Fixnum>

The start offsets, inclusive, of the text segment in which the AnnotationSpec has been identified. Expressed as a zero-based number of characters as measured from the start of the text snippet. Corresponds to the JSON property textSegmentStartOffsets

Returns:

  • (Array<Fixnum>)


54716
54717
54718
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54716

def text_segment_start_offsets
  @text_segment_start_offsets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54723
54724
54725
54726
54727
54728
54729
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54723

def update!(**args)
  @confidences = args[:confidences] if args.key?(:confidences)
  @display_names = args[:display_names] if args.key?(:display_names)
  @ids = args[:ids] if args.key?(:ids)
  @text_segment_end_offsets = args[:text_segment_end_offsets] if args.key?(:text_segment_end_offsets)
  @text_segment_start_offsets = args[:text_segment_start_offsets] if args.key?(:text_segment_start_offsets)
end