Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoClassificationPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Prediction output format for Video Classification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoClassificationPredictionResult

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoClassificationPredictionResult.



50332
50333
50334
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50332

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The Model's confidence in correction of this prediction, higher value means higher confidence. Corresponds to the JSON property confidence

Returns:

  • (Float)


50292
50293
50294
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50292

def confidence
  @confidence
end

#display_nameString

The display name of the AnnotationSpec that had been identified. Corresponds to the JSON property displayName

Returns:

  • (String)


50297
50298
50299
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50297

def display_name
  @display_name
end

#idString

The resource ID of the AnnotationSpec that had been identified. Corresponds to the JSON property id

Returns:

  • (String)


50302
50303
50304
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50302

def id
  @id
end

#time_segment_endString

The end, exclusive, of the video's time segment in which the AnnotationSpec has been identified. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Note that for 'segment-classification' prediction type, this equals the original 'timeSegmentEnd' from the input instance, for other types it is the end of a shot or a 1 second interval respectively. Corresponds to the JSON property timeSegmentEnd

Returns:

  • (String)


50312
50313
50314
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50312

def time_segment_end
  @time_segment_end
end

#time_segment_startString

The beginning, inclusive, of the video's time segment in which the AnnotationSpec has been identified. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Note that for 'segment- classification' prediction type, this equals the original 'timeSegmentStart' from the input instance, for other types it is the start of a shot or a 1 second interval respectively. Corresponds to the JSON property timeSegmentStart

Returns:

  • (String)


50323
50324
50325
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50323

def time_segment_start
  @time_segment_start
end

#typeString

The type of the prediction. The requested types can be configured via parameters. This will be one of - segment-classification - shot-classification

  • one-sec-interval-classification Corresponds to the JSON property type

Returns:

  • (String)


50330
50331
50332
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50330

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50337
50338
50339
50340
50341
50342
50343
50344
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50337

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end)
  @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start)
  @type = args[:type] if args.key?(:type)
end