Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptApiSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The A2 schema of a prompt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptApiSchema

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPromptApiSchema.



55974
55975
55976
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_schema_versionString

The Schema version that represents changes to the API behavior. Corresponds to the JSON property apiSchemaVersion

Returns:

  • (String)


55952
55953
55954
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55952

def api_schema_version
  @api_schema_version
end

#executionsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptInstancePromptExecution>

A list of execution instances for constructing a ready-to-use prompt. Corresponds to the JSON property executions



55957
55958
55959
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55957

def executions
  @executions
end

#multimodal_promptGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecMultimodalPrompt

Prompt variation that embeds preambles to prompt string. Corresponds to the JSON property multimodalPrompt



55962
55963
55964
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55962

def multimodal_prompt
  @multimodal_prompt
end

#structured_promptGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecStructuredPrompt

Prompt variation that stores preambles in separate fields. Corresponds to the JSON property structuredPrompt



55967
55968
55969
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55967

def structured_prompt
  @structured_prompt
end

#translation_promptGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecTranslationPrompt

Prompt variation for Translation use case. Corresponds to the JSON property translationPrompt



55972
55973
55974
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55972

def translation_prompt
  @translation_prompt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55979
55980
55981
55982
55983
55984
55985
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55979

def update!(**args)
  @api_schema_version = args[:api_schema_version] if args.key?(:api_schema_version)
  @executions = args[:executions] if args.key?(:executions)
  @multimodal_prompt = args[:multimodal_prompt] if args.key?(:multimodal_prompt)
  @structured_prompt = args[:structured_prompt] if args.key?(:structured_prompt)
  @translation_prompt = args[:translation_prompt] if args.key?(:translation_prompt)
end