Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Defines data for an application builder.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderData

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderData.



56055
56056
56057
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_repository_stateString

Serialized state of the code repository. This string will typically contain a JSON representation of the UI's CodeRepositoryService state (files, folders, content, and any metadata). The UI is responsible for serialization and deserialization. Corresponds to the JSON property codeRepositoryState

Returns:

  • (String)


56036
56037
56038
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56036

def code_repository_state
  @code_repository_state
end

#deployed_regionsArray<String>

Optional. The Cloud Run regions in which the application is currently deployed. Used to rediscover and redeploy the app in the regions it already runs in, which may differ from the prompt's location. Corresponds to the JSON property deployedRegions

Returns:

  • (Array<String>)


56043
56044
56045
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56043

def deployed_regions
  @deployed_regions
end

#frameworkString

Optional. Framework used to build the application. Corresponds to the JSON property framework

Returns:

  • (String)


56048
56049
56050
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56048

def framework
  @framework
end

#linked_resourcesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderDataLinkedResource>

Linked resources attached to the application by the user. Corresponds to the JSON property linkedResources



56053
56054
56055
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56053

def linked_resources
  @linked_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56060
56061
56062
56063
56064
56065
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56060

def update!(**args)
  @code_repository_state = args[:code_repository_state] if args.key?(:code_repository_state)
  @deployed_regions = args[:deployed_regions] if args.key?(:deployed_regions)
  @framework = args[:framework] if args.key?(:framework)
  @linked_resources = args[:linked_resources] if args.key?(:linked_resources)
end