Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderDataLinkedResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A linked resource attached to the application by the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderDataLinkedResource

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderDataLinkedResource.



53241
53242
53243
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53241

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

A user-friendly name for the data source shown in the UI. Corresponds to the JSON property displayName

Returns:

  • (String)


53223
53224
53225
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53223

def display_name
  @display_name
end

#nameString

The unique resource name of the data source. The format is determined by the ' type' field. For type "SAVED_PROMPT": projects/project/locations/location/ datasets/dataset For type "AI_AGENT": projects/project/locations/location /agents/agent Corresponds to the JSON property name

Returns:

  • (String)


53231
53232
53233
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53231

def name
  @name
end

#typeString

The type of the linked resource. e.g., "SAVED_PROMPT", "AI_AGENT" This string corresponds to the name of the LinkedResourceType enum member. See: google3/ cloud/console/web/ai/platform/llm/prompts/build/services/ specs_repository_service/linked_resources/linked_resource.ts Corresponds to the JSON property type

Returns:

  • (String)


53239
53240
53241
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53239

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53246
53247
53248
53249
53250
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53246

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end