Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecMultimodalPrompt
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecMultimodalPrompt
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Prompt variation that embeds preambles to prompt string.
Instance Attribute Summary collapse
-
#prompt_message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecMultimodalPrompt
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecMultimodalPrompt.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecMultimodalPrompt
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecMultimodalPrompt.
45659 45660 45661 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#prompt_message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
aiplatform.master.GenerateContentRequest.
Corresponds to the JSON property promptMessage
45657 45658 45659 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45657 def @prompt_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45664 45665 45666 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45664 def update!(**args) @prompt_message = args[:prompt_message] if args.key?(:prompt_message) end |