Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPartList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A list of elements and information that make up a portion of prompt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecPartList

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecPartList.



55327
55328
55329
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>

A list of elements that can be part of a prompt. Corresponds to the JSON property parts



55325
55326
55327
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55325

def parts
  @parts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55332
55333
55334
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55332

def update!(**args)
  @parts = args[:parts] if args.key?(:parts)
end