Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecTranslationPrompt
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecTranslationPrompt
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Prompt variation for Translation use case.
Instance Attribute Summary collapse
-
#example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecTranslationExample
The translation example that contains reference sentences from various sources.
-
#option ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecTranslationOption
Optional settings for translation prompt.
-
#prompt_message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
-
#source_language_code ⇒ String
The source language code.
-
#target_language_code ⇒ String
The target language code.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecTranslationPrompt
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecTranslationPrompt.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecTranslationPrompt
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecTranslationPrompt.
56476 56477 56478 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56476 def initialize(**args) update!(**args) end |
Instance Attribute Details
#example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecTranslationExample
The translation example that contains reference sentences from various sources.
Corresponds to the JSON property example
56453 56454 56455 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56453 def example @example end |
#option ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecTranslationOption
Optional settings for translation prompt.
Corresponds to the JSON property option
56458 56459 56460 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56458 def option @option end |
#prompt_message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
aiplatform.master.GenerateContentRequest.
Corresponds to the JSON property promptMessage
56464 56465 56466 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56464 def @prompt_message end |
#source_language_code ⇒ String
The source language code.
Corresponds to the JSON property sourceLanguageCode
56469 56470 56471 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56469 def source_language_code @source_language_code end |
#target_language_code ⇒ String
The target language code.
Corresponds to the JSON property targetLanguageCode
56474 56475 56476 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56474 def target_language_code @target_language_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56481 56482 56483 56484 56485 56486 56487 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56481 def update!(**args) @example = args[:example] if args.key?(:example) @option = args[:option] if args.key?(:option) @prompt_message = args[:prompt_message] if args.key?(:prompt_message) @source_language_code = args[:source_language_code] if args.key?(:source_language_code) @target_language_code = args[:target_language_code] if args.key?(:target_language_code) end |