Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTextDatasetMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The metadata of Datasets that contain Text DataItems.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTextDatasetMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaTextDatasetMetadata.



53989
53990
53991
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_item_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing payload of the Text DataItems that belong to this Dataset. Corresponds to the JSON property dataItemSchemaUri

Returns:

  • (String)


53982
53983
53984
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53982

def data_item_schema_uri
  @data_item_schema_uri
end

#gcs_bucketString

Google Cloud Storage Bucket name that contains the blob data of this Dataset. Corresponds to the JSON property gcsBucket

Returns:

  • (String)


53987
53988
53989
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53987

def gcs_bucket
  @gcs_bucket
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53994
53995
53996
53997
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53994

def update!(**args)
  @data_item_schema_uri = args[:data_item_schema_uri] if args.key?(:data_item_schema_uri)
  @gcs_bucket = args[:gcs_bucket] if args.key?(:gcs_bucket)
end