Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The metadata of Datasets that contain Text Prompt data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata.



56810
56811
56812
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidate_countFixnum

Number of candidates. Corresponds to the JSON property candidateCount

Returns:

  • (Fixnum)


56712
56713
56714
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56712

def candidate_count
  @candidate_count
end

#gcs_uriString

The Google Cloud Storage URI that stores the prompt data. Corresponds to the JSON property gcsUri

Returns:

  • (String)


56717
56718
56719
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56717

def gcs_uri
  @gcs_uri
end

#grounding_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictParamsGroundingConfig

The configuration for grounding checking. Corresponds to the JSON property groundingConfig



56722
56723
56724
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56722

def grounding_config
  @grounding_config
end

#has_prompt_variableBoolean Also known as: has_prompt_variable?

Whether the prompt dataset has prompt variable. Corresponds to the JSON property hasPromptVariable

Returns:

  • (Boolean)


56727
56728
56729
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56727

def has_prompt_variable
  @has_prompt_variable
end

#logprobsBoolean Also known as: logprobs?

Whether or not the user has enabled logit probabilities in the model parameters. Corresponds to the JSON property logprobs

Returns:

  • (Boolean)


56734
56735
56736
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56734

def logprobs
  @logprobs
end

#max_output_tokensFixnum

Value of the maximum number of tokens generated set when the dataset was saved. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


56740
56741
56742
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56740

def max_output_tokens
  @max_output_tokens
end

#noteString

User-created prompt note. Note size limit is 2KB. Corresponds to the JSON property note

Returns:

  • (String)


56745
56746
56747
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56745

def note
  @note
end

#prompt_api_schemaGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptApiSchema

The A2 schema of a prompt. Corresponds to the JSON property promptApiSchema



56750
56751
56752
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56750

def prompt_api_schema
  @prompt_api_schema
end

#prompt_typeString

Type of the prompt dataset. Corresponds to the JSON property promptType

Returns:

  • (String)


56755
56756
56757
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56755

def prompt_type
  @prompt_type
end

#seed_enabledBoolean Also known as: seed_enabled?

Seeding enables model to return a deterministic response on a best effort basis. Determinism isn't guaranteed. This field determines whether or not seeding is enabled. Corresponds to the JSON property seedEnabled

Returns:

  • (Boolean)


56762
56763
56764
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56762

def seed_enabled
  @seed_enabled
end

#seed_valueFixnum

The actual value of the seed. Corresponds to the JSON property seedValue

Returns:

  • (Fixnum)


56768
56769
56770
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56768

def seed_value
  @seed_value
end

#stop_sequencesArray<String>

Customized stop sequences. Corresponds to the JSON property stopSequences

Returns:

  • (Array<String>)


56773
56774
56775
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56773

def stop_sequences
  @stop_sequences
end

#system_instructionString

The content of the prompt dataset system instruction. Corresponds to the JSON property systemInstruction

Returns:

  • (String)


56778
56779
56780
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56778

def system_instruction
  @system_instruction
end

#system_instruction_gcs_uriString

The Google Cloud Storage URI that stores the system instruction, starting with gs://. Corresponds to the JSON property systemInstructionGcsUri

Returns:

  • (String)


56784
56785
56786
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56784

def system_instruction_gcs_uri
  @system_instruction_gcs_uri
end

#temperatureFloat

Temperature value used for sampling set when the dataset was saved. This value is used to tune the degree of randomness. Corresponds to the JSON property temperature

Returns:

  • (Float)


56790
56791
56792
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56790

def temperature
  @temperature
end

#textString

The content of the prompt dataset. Corresponds to the JSON property text

Returns:

  • (String)


56795
56796
56797
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56795

def text
  @text
end

#top_kFixnum

Top K value set when the dataset was saved. This value determines how many candidates with highest probability from the vocab would be selected for each decoding step. Corresponds to the JSON property topK

Returns:

  • (Fixnum)


56802
56803
56804
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56802

def top_k
  @top_k
end

#top_pFloat

Top P value set when the dataset was saved. Given topK tokens for decoding, top candidates will be selected until the sum of their probabilities is topP. Corresponds to the JSON property topP

Returns:

  • (Float)


56808
56809
56810
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56808

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56815
56816
56817
56818
56819
56820
56821
56822
56823
56824
56825
56826
56827
56828
56829
56830
56831
56832
56833
56834
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56815

def update!(**args)
  @candidate_count = args[:candidate_count] if args.key?(:candidate_count)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @grounding_config = args[:grounding_config] if args.key?(:grounding_config)
  @has_prompt_variable = args[:has_prompt_variable] if args.key?(:has_prompt_variable)
  @logprobs = args[:logprobs] if args.key?(:logprobs)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @note = args[:note] if args.key?(:note)
  @prompt_api_schema = args[:prompt_api_schema] if args.key?(:prompt_api_schema)
  @prompt_type = args[:prompt_type] if args.key?(:prompt_type)
  @seed_enabled = args[:seed_enabled] if args.key?(:seed_enabled)
  @seed_value = args[:seed_value] if args.key?(:seed_value)
  @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @system_instruction_gcs_uri = args[:system_instruction_gcs_uri] if args.key?(:system_instruction_gcs_uri)
  @temperature = args[:temperature] if args.key?(:temperature)
  @text = args[:text] if args.key?(:text)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end