Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTextSentimentSavedQueryMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTextSentimentSavedQueryMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The metadata of SavedQuery contains TextSentiment Annotations.
Instance Attribute Summary collapse
-
#sentiment_max ⇒ Fixnum
The maximum sentiment of sentiment Anntoation in this SavedQuery.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTextSentimentSavedQueryMetadata
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaTextSentimentSavedQueryMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTextSentimentSavedQueryMetadata
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaTextSentimentSavedQueryMetadata.
54243 54244 54245 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sentiment_max ⇒ Fixnum
The maximum sentiment of sentiment Anntoation in this SavedQuery.
Corresponds to the JSON property sentimentMax
54241 54242 54243 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54241 def sentiment_max @sentiment_max end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54248 54249 54250 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54248 def update!(**args) @sentiment_max = args[:sentiment_max] if args.key?(:sentiment_max) end |