Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs.



54765
54766
54767
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54765

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_model_idString

The ID of the base model. If it is specified, the new model will be trained based on the base model. Otherwise, the new model will be trained from scratch. The base model must be in the same Project and Location as the new Model to train, and have the same modelType. Corresponds to the JSON property baseModelId

Returns:

  • (String)


54709
54710
54711
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54709

def base_model_id
  @base_model_id
end

#budget_milli_node_hoursFixnum

The training budget of creating this model, expressed in milli node hours i.e. 1,000 value in this field means 1 node hour. The actual metadata. costMilliNodeHours will be equal or less than this value. If further model training ceases to provide any improvements, it will stop without using the full budget and the metadata.successfulStopReason will be model-converged. Note, node_hour = actual_hour * number_of_nodes_involved. For modelType cloud (default), the budget must be between 8,000 and 800,000 milli node hours, inclusive. The default value is 192,000 which represents one day in wall time, considering 8 nodes are used. For model types mobile-tf-low-latency-1, mobile-tf-versatile-1, mobile-tf-high-accuracy-1, the training budget must be between 1,000 and 100,000 milli node hours, inclusive. The default value is 24,000 which represents one day in wall time on a single node that is used. Corresponds to the JSON property budgetMilliNodeHours

Returns:

  • (Fixnum)


54725
54726
54727
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54725

def budget_milli_node_hours
  @budget_milli_node_hours
end

#disable_early_stoppingBoolean Also known as: disable_early_stopping?

Use the entire training budget. This disables the early stopping feature. When false the early stopping feature is enabled, which means that AutoML Image Classification might stop training before the entire training budget has been used. Corresponds to the JSON property disableEarlyStopping

Returns:

  • (Boolean)


54733
54734
54735
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54733

def disable_early_stopping
  @disable_early_stopping
end

#model_typeString

Corresponds to the JSON property modelType

Returns:

  • (String)


54739
54740
54741
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54739

def model_type
  @model_type
end

#multi_labelBoolean Also known as: multi_label?

If false, a single-label (multi-class) Model will be trained (i.e. assuming that for each image just up to one annotation may be applicable). If true, a multi-label Model will be trained (i.e. assuming that for each image multiple annotations may be applicable). Corresponds to the JSON property multiLabel

Returns:

  • (Boolean)


54747
54748
54749
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54747

def multi_label
  @multi_label
end

#tunable_parameterGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter

A wrapper class which contains the tunable parameters in an AutoML Image training job. Corresponds to the JSON property tunableParameter



54754
54755
54756
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54754

def tunable_parameter
  @tunable_parameter
end

#uptrain_base_model_idString

The ID of base model for upTraining. If it is specified, the new model will be upTrained based on the base model for upTraining. Otherwise, the new model will be trained from scratch. The base model for upTraining must be in the same Project and Location as the new Model to train, and have the same modelType. Corresponds to the JSON property uptrainBaseModelId

Returns:

  • (String)


54763
54764
54765
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54763

def uptrain_base_model_id
  @uptrain_base_model_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54770
54771
54772
54773
54774
54775
54776
54777
54778
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54770

def update!(**args)
  @base_model_id = args[:base_model_id] if args.key?(:base_model_id)
  @budget_milli_node_hours = args[:budget_milli_node_hours] if args.key?(:budget_milli_node_hours)
  @disable_early_stopping = args[:disable_early_stopping] if args.key?(:disable_early_stopping)
  @model_type = args[:model_type] if args.key?(:model_type)
  @multi_label = args[:multi_label] if args.key?(:multi_label)
  @tunable_parameter = args[:tunable_parameter] if args.key?(:tunable_parameter)
  @uptrain_base_model_id = args[:uptrain_base_model_id] if args.key?(:uptrain_base_model_id)
end