Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputs

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputs

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputs.



54780
54781
54782
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54780

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_experimentsArray<String>

Additional experiment flags for the time series forcasting training. Corresponds to the JSON property additionalExperiments

Returns:

  • (Array<String>)


54629
54630
54631
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54629

def additional_experiments
  @additional_experiments
end

#available_at_forecast_columnsArray<String>

Names of columns that are available and provided when a forecast is requested. These columns contain information for the given entity (identified by the time_series_identifier_column column) that is known at forecast. For example, predicted weather for a specific day. Corresponds to the JSON property availableAtForecastColumns

Returns:

  • (Array<String>)


54637
54638
54639
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54637

def available_at_forecast_columns
  @available_at_forecast_columns
end

#context_windowFixnum

The amount of time into the past training and prediction data is used for model training and prediction respectively. Expressed in number of units defined by the data_granularity field. Corresponds to the JSON property contextWindow

Returns:

  • (Fixnum)


54644
54645
54646
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54644

def context_window
  @context_window
end

#data_granularityGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsGranularity

A duration of time expressed in time granularity units. Corresponds to the JSON property dataGranularity



54649
54650
54651
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54649

def data_granularity
  @data_granularity
end

#export_evaluated_data_items_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig

Configuration for exporting test set predictions to a BigQuery table. Corresponds to the JSON property exportEvaluatedDataItemsConfig



54654
54655
54656
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54654

def export_evaluated_data_items_config
  @export_evaluated_data_items_config
end

#forecast_horizonFixnum

The amount of time into the future for which forecasted values for the target are returned. Expressed in number of units defined by the data_granularity field. Corresponds to the JSON property forecastHorizon

Returns:

  • (Fixnum)


54661
54662
54663
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54661

def forecast_horizon
  @forecast_horizon
end

#hierarchy_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionHierarchyConfig

Configuration that defines the hierarchical relationship of time series and parameters for hierarchical forecasting strategies. Corresponds to the JSON property hierarchyConfig



54667
54668
54669
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54667

def hierarchy_config
  @hierarchy_config
end

#holiday_regionsArray<String>

The geographical region based on which the holiday effect is applied in modeling by adding holiday categorical array feature that include all holidays matching the date. This option only allowed when data_granularity is day. By default, holiday effect modeling is disabled. To turn it on, specify the holiday region using this option. Corresponds to the JSON property holidayRegions

Returns:

  • (Array<String>)


54676
54677
54678
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54676

def holiday_regions
  @holiday_regions
end

#optimization_objectiveString

Objective function the model is optimizing towards. The training process creates a model that optimizes the value of the objective function over the validation set. The supported optimization objectives: * "minimize-rmse" ( default) - Minimize root-mean-squared error (RMSE). * "minimize-mae" - Minimize mean-absolute error (MAE). * "minimize-rmsle" - Minimize root-mean- squared log error (RMSLE). * "minimize-rmspe" - Minimize root-mean-squared percentage error (RMSPE). * "minimize-wape-mae" - Minimize the combination of weighted absolute percentage error (WAPE) and mean-absolute-error (MAE). * " minimize-quantile-loss" - Minimize the quantile loss at the quantiles defined in quantiles. * "minimize-mape" - Minimize the mean absolute percentage error. Corresponds to the JSON property optimizationObjective

Returns:

  • (String)


54691
54692
54693
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54691

def optimization_objective
  @optimization_objective
end

#quantilesArray<Float>

Quantiles to use for minimize-quantile-loss optimization_objective. Up to 5 quantiles are allowed of values between 0 and 1, exclusive. Required if the value of optimization_objective is minimize-quantile-loss. Represents the percent quantiles to use for that objective. Quantiles must be unique. Corresponds to the JSON property quantiles

Returns:

  • (Array<Float>)


54699
54700
54701
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54699

def quantiles
  @quantiles
end

#target_columnString

The name of the column that the Model is to predict values for. This column must be unavailable at forecast. Corresponds to the JSON property targetColumn

Returns:

  • (String)


54705
54706
54707
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54705

def target_column
  @target_column
end

#time_columnString

The name of the column that identifies time order in the time series. This column must be available at forecast. Corresponds to the JSON property timeColumn

Returns:

  • (String)


54711
54712
54713
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54711

def time_column
  @time_column
end

#time_series_attribute_columnsArray<String>

Column names that should be used as attribute columns. The value of these columns does not vary as a function of time. For example, store ID or item color. Corresponds to the JSON property timeSeriesAttributeColumns

Returns:

  • (Array<String>)


54718
54719
54720
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54718

def time_series_attribute_columns
  @time_series_attribute_columns
end

#time_series_identifier_columnString

The name of the column that identifies the time series. Corresponds to the JSON property timeSeriesIdentifierColumn

Returns:

  • (String)


54723
54724
54725
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54723

def time_series_identifier_column
  @time_series_identifier_column
end

#train_budget_milli_node_hoursFixnum

Required. The train budget of creating this model, expressed in milli node hours i.e. 1,000 value in this field means 1 node hour. The training cost of the model will not exceed this budget. The final cost will be attempted to be close to the budget, though may end up being (even) noticeably smaller - at the backend's discretion. This especially may happen when further model training ceases to provide any improvements. If the budget is set to a value known to be insufficient to train a model for the given dataset, the training won't be attempted and will error. The train budget must be between 1,000 and 72,000 milli node hours, inclusive. Corresponds to the JSON property trainBudgetMilliNodeHours

Returns:

  • (Fixnum)


54736
54737
54738
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54736

def train_budget_milli_node_hours
  @train_budget_milli_node_hours
end

#transformationsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation>

Each transformation will apply transform function to given input column. And the result will be used for training. When creating transformation for BigQuery Struct column, the column should be flattened using "." as the delimiter. Corresponds to the JSON property transformations



54744
54745
54746
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54744

def transformations
  @transformations
end

#unavailable_at_forecast_columnsArray<String>

Names of columns that are unavailable when a forecast is requested. This column contains information for the given entity (identified by the time_series_identifier_column) that is unknown before the forecast For example, actual weather on a given day. Corresponds to the JSON property unavailableAtForecastColumns

Returns:

  • (Array<String>)


54752
54753
54754
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54752

def unavailable_at_forecast_columns
  @unavailable_at_forecast_columns
end

#validation_optionsString

Validation options for the data validation component. The available options are: * "fail-pipeline" - default, will validate against the validation and fail the pipeline if it fails. * "ignore-validation" - ignore the results of the validation and continue Corresponds to the JSON property validationOptions

Returns:

  • (String)


54760
54761
54762
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54760

def validation_options
  @validation_options
end

#weight_columnString

Column name that should be used as the weight column. Higher values in this column give more importance to the row during model training. The column must have numeric values between 0 and 10000 inclusively; 0 means the row is ignored for training. If weight column field is not set, then all rows are assumed to have equal weight of 1. This column must be available at forecast. Corresponds to the JSON property weightColumn

Returns:

  • (String)


54769
54770
54771
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54769

def weight_column
  @weight_column
end

#window_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionWindowConfig

Config that contains the strategy used to generate sliding windows in time series training. A window is a series of rows that comprise the context up to the time of prediction, and the horizon following. The corresponding row for each window marks the start of the forecast horizon. Each window is used as an input example for training/evaluation. Corresponds to the JSON property windowConfig



54778
54779
54780
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54778

def window_config
  @window_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54785
54786
54787
54788
54789
54790
54791
54792
54793
54794
54795
54796
54797
54798
54799
54800
54801
54802
54803
54804
54805
54806
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54785

def update!(**args)
  @additional_experiments = args[:additional_experiments] if args.key?(:additional_experiments)
  @available_at_forecast_columns = args[:available_at_forecast_columns] if args.key?(:available_at_forecast_columns)
  @context_window = args[:context_window] if args.key?(:context_window)
  @data_granularity = args[:data_granularity] if args.key?(:data_granularity)
  @export_evaluated_data_items_config = args[:export_evaluated_data_items_config] if args.key?(:export_evaluated_data_items_config)
  @forecast_horizon = args[:forecast_horizon] if args.key?(:forecast_horizon)
  @hierarchy_config = args[:hierarchy_config] if args.key?(:hierarchy_config)
  @holiday_regions = args[:holiday_regions] if args.key?(:holiday_regions)
  @optimization_objective = args[:optimization_objective] if args.key?(:optimization_objective)
  @quantiles = args[:quantiles] if args.key?(:quantiles)
  @target_column = args[:target_column] if args.key?(:target_column)
  @time_column = args[:time_column] if args.key?(:time_column)
  @time_series_attribute_columns = args[:time_series_attribute_columns] if args.key?(:time_series_attribute_columns)
  @time_series_identifier_column = args[:time_series_identifier_column] if args.key?(:time_series_identifier_column)
  @train_budget_milli_node_hours = args[:train_budget_milli_node_hours] if args.key?(:train_budget_milli_node_hours)
  @transformations = args[:transformations] if args.key?(:transformations)
  @unavailable_at_forecast_columns = args[:unavailable_at_forecast_columns] if args.key?(:unavailable_at_forecast_columns)
  @validation_options = args[:validation_options] if args.key?(:validation_options)
  @weight_column = args[:weight_column] if args.key?(:weight_column)
  @window_config = args[:window_config] if args.key?(:window_config)
end