Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Annotation details specific to video object tracking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation.



59989
59990
59991
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_idString

The resource Id of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property annotationSpecId

Returns:

  • (String)


59950
59951
59952
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59950

def annotation_spec_id
  @annotation_spec_id
end

#display_nameString

The display name of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property displayName

Returns:

  • (String)


59955
59956
59957
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59955

def display_name
  @display_name
end

#instance_idFixnum

The instance of the object, expressed as a positive integer. Used to track the same object across different frames. Corresponds to the JSON property instanceId

Returns:

  • (Fixnum)


59961
59962
59963
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59961

def instance_id
  @instance_id
end

#time_offsetString

A time (frame) of a video to which this annotation pertains. Represented as the duration since the video's start. Corresponds to the JSON property timeOffset

Returns:

  • (String)


59967
59968
59969
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59967

def time_offset
  @time_offset
end

#x_maxFloat

The rightmost coordinate of the bounding box. Corresponds to the JSON property xMax

Returns:

  • (Float)


59972
59973
59974
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59972

def x_max
  @x_max
end

#x_minFloat

The leftmost coordinate of the bounding box. Corresponds to the JSON property xMin

Returns:

  • (Float)


59977
59978
59979
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59977

def x_min
  @x_min
end

#y_maxFloat

The bottommost coordinate of the bounding box. Corresponds to the JSON property yMax

Returns:

  • (Float)


59982
59983
59984
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59982

def y_max
  @y_max
end

#y_minFloat

The topmost coordinate of the bounding box. Corresponds to the JSON property yMin

Returns:

  • (Float)


59987
59988
59989
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59987

def y_min
  @y_min
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59994
59995
59996
59997
59998
59999
60000
60001
60002
60003
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59994

def update!(**args)
  @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
  @x_max = args[:x_max] if args.key?(:x_max)
  @x_min = args[:x_min] if args.key?(:x_min)
  @y_max = args[:y_max] if args.key?(:y_max)
  @y_min = args[:y_min] if args.key?(:y_min)
end