Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchEntryPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An entry point for displaying Google Search results. A SearchEntryPoint is populated when the grounding source for a model's response is Google Search. It provides information that you can use to display the search results in your application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchEntryPoint

Returns a new instance of GoogleCloudAiplatformV1beta1SearchEntryPoint.



49610
49611
49612
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rendered_contentString

Optional. An HTML snippet that can be embedded in a web page or an application' s webview. This snippet displays a search result, including the title, URL, and a brief description of the search result. Corresponds to the JSON property renderedContent

Returns:

  • (String)


49600
49601
49602
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49600

def rendered_content
  @rendered_content
end

#sdk_blobString

Optional. A base64-encoded JSON object that contains a list of search queries and their corresponding search URLs. This information can be used to build a custom search UI. Corresponds to the JSON property sdkBlob NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


49608
49609
49610
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49608

def sdk_blob
  @sdk_blob
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49615
49616
49617
49618
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49615

def update!(**args)
  @rendered_content = args[:rendered_content] if args.key?(:rendered_content)
  @sdk_blob = args[:sdk_blob] if args.key?(:sdk_blob)
end