Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The result of the similar example.
Instance Attribute Summary collapse
-
#example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example
The example that is similar to the searched query.
-
#similarity_score ⇒ Float
The similarity score of this example.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample
constructor
A new instance of GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample
Returns a new instance of GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample.
57483 57484 57485 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57483 def initialize(**args) update!(**args) end |
Instance Attribute Details
#example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example
The example that is similar to the searched query.
Corresponds to the JSON property example
57476 57477 57478 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57476 def example @example end |
#similarity_score ⇒ Float
The similarity score of this example.
Corresponds to the JSON property similarityScore
57481 57482 57483 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57481 def similarity_score @similarity_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57488 57489 57490 57491 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57488 def update!(**args) @example = args[:example] if args.key?(:example) @similarity_score = args[:similarity_score] if args.key?(:similarity_score) end |