Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelDeploymentMonitoringStatsAnomaliesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for JobService.SearchModelDeploymentMonitoringStatsAnomalies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchModelDeploymentMonitoringStatsAnomaliesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1SearchModelDeploymentMonitoringStatsAnomaliesRequest.



56052
56053
56054
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56052

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_model_idString

Required. The DeployedModel ID of the [ ModelDeploymentMonitoringObjectiveConfig.deployed_model_id]. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


56014
56015
56016
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56014

def deployed_model_id
  @deployed_model_id
end

#end_timeString

The latest timestamp of stats being generated. If not set, indicates feching stats till the latest possible one. Corresponds to the JSON property endTime

Returns:

  • (String)


56020
56021
56022
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56020

def end_time
  @end_time
end

#feature_display_nameString

The feature display name. If specified, only return the stats belonging to this feature. Format: ModelMonitoringStatsAnomalies. FeatureHistoricStatsAnomalies.feature_display_name, example: "user_destination" . Corresponds to the JSON property featureDisplayName

Returns:

  • (String)


56028
56029
56030
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56028

def feature_display_name
  @feature_display_name
end

#objectivesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelDeploymentMonitoringStatsAnomaliesRequestStatsAnomaliesObjective>

Required. Objectives of the stats to retrieve. Corresponds to the JSON property objectives



56033
56034
56035
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56033

def objectives
  @objectives
end

#page_sizeFixnum

The standard list page size. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


56038
56039
56040
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56038

def page_size
  @page_size
end

#page_tokenString

A page token received from a previous JobService. SearchModelDeploymentMonitoringStatsAnomalies call. Corresponds to the JSON property pageToken

Returns:

  • (String)


56044
56045
56046
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56044

def page_token
  @page_token
end

#start_timeString

The earliest timestamp of stats being generated. If not set, indicates fetching stats till the earliest possible one. Corresponds to the JSON property startTime

Returns:

  • (String)


56050
56051
56052
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56050

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56057
56058
56059
56060
56061
56062
56063
56064
56065
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56057

def update!(**args)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @end_time = args[:end_time] if args.key?(:end_time)
  @feature_display_name = args[:feature_display_name] if args.key?(:feature_display_name)
  @objectives = args[:objectives] if args.key?(:objectives)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @start_time = args[:start_time] if args.key?(:start_time)
end