Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ModelMonitoringService.SearchModelMonitoringAlerts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest

Returns a new instance of GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest.



60418
60419
60420
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alert_time_intervalGoogle::Apis::AiplatformV1beta1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property alertTimeInterval



60389
60390
60391
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60389

def alert_time_interval
  @alert_time_interval
end

#model_monitoring_jobString

If non-empty, returns the alerts of this model monitoring job. Corresponds to the JSON property modelMonitoringJob

Returns:

  • (String)


60394
60395
60396
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60394

def model_monitoring_job
  @model_monitoring_job
end

#objective_typeString

If non-empty, returns the alerts of this objective type. Supported monitoring objectives: raw-feature-drift prediction-output-drift feature-attribution Corresponds to the JSON property objectiveType

Returns:

  • (String)


60400
60401
60402
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60400

def objective_type
  @objective_type
end

#page_sizeFixnum

The standard list page size. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


60405
60406
60407
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60405

def page_size
  @page_size
end

#page_tokenString

A page token received from a previous ModelMonitoringService. SearchModelMonitoringAlerts call. Corresponds to the JSON property pageToken

Returns:

  • (String)


60411
60412
60413
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60411

def page_token
  @page_token
end

#stats_nameString

If non-empty, returns the alerts of this stats_name. Corresponds to the JSON property statsName

Returns:

  • (String)


60416
60417
60418
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60416

def stats_name
  @stats_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60423
60424
60425
60426
60427
60428
60429
60430
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60423

def update!(**args)
  @alert_time_interval = args[:alert_time_interval] if args.key?(:alert_time_interval)
  @model_monitoring_job = args[:model_monitoring_job] if args.key?(:model_monitoring_job)
  @objective_type = args[:objective_type] if args.key?(:objective_type)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @stats_name = args[:stats_name] if args.key?(:stats_name)
end