Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for ModelMonitoringService.SearchModelMonitoringAlerts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsResponse

Returns a new instance of GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsResponse.



59626
59627
59628
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59626

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#model_monitoring_alertsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlert>

Alerts retrieved for the requested objectives. Sorted by alert time descendingly. Corresponds to the JSON property modelMonitoringAlerts



59613
59614
59615
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59613

def model_monitoring_alerts
  @model_monitoring_alerts
end

#next_page_tokenString

The page token that can be used by the next ModelMonitoringService. SearchModelMonitoringAlerts call. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59619
59620
59621
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59619

def next_page_token
  @next_page_token
end

#total_number_alertsFixnum

The total number of alerts retrieved by the requested objectives. Corresponds to the JSON property totalNumberAlerts

Returns:

  • (Fixnum)


59624
59625
59626
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59624

def total_number_alerts
  @total_number_alerts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59631
59632
59633
59634
59635
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59631

def update!(**args)
  @model_monitoring_alerts = args[:model_monitoring_alerts] if args.key?(:model_monitoring_alerts)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @total_number_alerts = args[:total_number_alerts] if args.key?(:total_number_alerts)
end