Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SecretRef

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Reference to a secret stored in the Cloud Secret Manager that will provide the value for this environment variable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SecretRef

Returns a new instance of GoogleCloudAiplatformV1beta1SecretRef.



60689
60690
60691
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60689

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#secretString

Required. The name of the secret in Cloud Secret Manager. Format: secret_name . Corresponds to the JSON property secret

Returns:

  • (String)


60681
60682
60683
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60681

def secret
  @secret
end

#versionString

The Cloud Secret Manager secret version. Can be 'latest' for the latest version, an integer for a specific version, or a version alias. Corresponds to the JSON property version

Returns:

  • (String)


60687
60688
60689
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60687

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60694
60695
60696
60697
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60694

def update!(**args)
  @secret = args[:secret] if args.key?(:secret)
  @version = args[:version] if args.key?(:version)
end