Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Session

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A session contains a set of actions between users and Vertex agents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Session

Returns a new instance of GoogleCloudAiplatformV1beta1Session.



61087
61088
61089
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the session was created. Corresponds to the JSON property createTime

Returns:

  • (String)


61038
61039
61040
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61038

def create_time
  @create_time
end

#display_nameString

Optional. The display name of the session. Corresponds to the JSON property displayName

Returns:

  • (String)


61043
61044
61045
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61043

def display_name
  @display_name
end

#expire_timeString

Optional. Timestamp of when this session is considered expired. This is * always* provided on output, regardless of what was sent on input. The minimum value is 24 hours from the time of creation. Corresponds to the JSON property expireTime

Returns:

  • (String)


61050
61051
61052
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61050

def expire_time
  @expire_time
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Sessions. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


61059
61060
61061
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61059

def labels
  @labels
end

#nameString

Identifier. The resource name of the session. Format: 'projects/project/ locations/location/reasoningEngines/reasoning_engine/sessions/session'. Corresponds to the JSON property name

Returns:

  • (String)


61065
61066
61067
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61065

def name
  @name
end

#session_stateHash<String,Object>

Optional. Session specific memory which stores key conversation points. Corresponds to the JSON property sessionState

Returns:

  • (Hash<String,Object>)


61070
61071
61072
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61070

def session_state
  @session_state
end

#ttlString

Optional. Input only. The TTL for this session. The minimum value is 24 hours. Corresponds to the JSON property ttl

Returns:

  • (String)


61075
61076
61077
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61075

def ttl
  @ttl
end

#update_timeString

Output only. Timestamp when the session was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


61080
61081
61082
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61080

def update_time
  @update_time
end

#user_idString

Required. Immutable. String id provided by the user Corresponds to the JSON property userId

Returns:

  • (String)


61085
61086
61087
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61085

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61092

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @session_state = args[:session_state] if args.key?(:session_state)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_id = args[:user_id] if args.key?(:user_id)
end