Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The metadata filters that will be used to search StoredContentsExamples. If a field is unspecified, then no filtering for that field will be applied

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StoredContentsExampleParameters

Returns a new instance of GoogleCloudAiplatformV1beta1StoredContentsExampleParameters.



59921
59922
59923
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_search_keyGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey

The chat history to use to generate the search key for retrieval. Corresponds to the JSON property contentSearchKey



59908
59909
59910
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59908

def content_search_key
  @content_search_key
end

#function_namesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesArrayFilter

Filters for examples' array metadata fields. An array field is example metadata where multiple values are attributed to a single example. Corresponds to the JSON property functionNames



59914
59915
59916
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59914

def function_names
  @function_names
end

#search_keyString

The exact search key to use for retrieval. Corresponds to the JSON property searchKey

Returns:

  • (String)


59919
59920
59921
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59919

def search_key
  @search_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59926
59927
59928
59929
59930
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59926

def update!(**args)
  @content_search_key = args[:content_search_key] if args.key?(:content_search_key)
  @function_names = args[:function_names] if args.key?(:function_names)
  @search_key = args[:search_key] if args.key?(:search_key)
end