Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Options for generating the search key from the conversation history.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod

Returns a new instance of GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod.



61283
61284
61285
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61283

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_entryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethodLastEntry

Configuration for using only the last entry of the conversation history as the search key. Corresponds to the JSON property lastEntry



61281
61282
61283
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61281

def last_entry
  @last_entry
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61288
61289
61290
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61288

def update!(**args)
  @last_entry = args[:last_entry] if args.key?(:last_entry)
end