Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StreamQueryReasoningEngineRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StreamQueryReasoningEngineRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ReasoningEngineExecutionService.StreamQuery.
Instance Attribute Summary collapse
-
#class_method ⇒ String
Optional.
-
#input ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StreamQueryReasoningEngineRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1StreamQueryReasoningEngineRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StreamQueryReasoningEngineRequest
Returns a new instance of GoogleCloudAiplatformV1beta1StreamQueryReasoningEngineRequest.
61372 61373 61374 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61372 def initialize(**args) update!(**args) end |
Instance Attribute Details
#class_method ⇒ String
Optional. Class method to be used for the stream query. It is optional and
defaults to "stream_query" if unspecified.
Corresponds to the JSON property classMethod
61364 61365 61366 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61364 def class_method @class_method end |
#input ⇒ Hash<String,Object>
Optional. Input content provided by users in JSON object format. Examples
include text query, function calling parameters, media bytes, etc.
Corresponds to the JSON property input
61370 61371 61372 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61370 def input @input end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61377 61378 61379 61380 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61377 def update!(**args) @class_method = args[:class_method] if args.key?(:class_method) @input = args[:input] if args.key?(:input) end |