Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StreamingFetchFeatureValuesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for FeatureOnlineStoreService.StreamingFetchFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StreamingFetchFeatureValuesResponse

Returns a new instance of GoogleCloudAiplatformV1beta1StreamingFetchFeatureValuesResponse.



62296
62297
62298
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62296

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FetchFeatureValuesResponse>

Corresponds to the JSON property data



62279
62280
62281
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62279

def data
  @data
end

#data_keys_with_errorArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewDataKey>

Corresponds to the JSON property dataKeysWithError



62284
62285
62286
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62284

def data_keys_with_error
  @data_keys_with_error
end

#statusGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



62294
62295
62296
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62294

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62301
62302
62303
62304
62305
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62301

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @data_keys_with_error = args[:data_keys_with_error] if args.key?(:data_keys_with_error)
  @status = args[:status] if args.key?(:status)
end