Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Schema configuration for structured memories.
Instance Attribute Summary collapse
-
#id ⇒ String
Required.
-
#json_schema ⇒ Object
Optional.
-
#memory_type ⇒ String
Optional.
-
#schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema
Defines the schema of input and output data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig
Returns a new instance of GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig.
62508 62509 62510 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62508 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Required. Represents the ID of the schema. Must be 1-63 characters, start with
a lowercase letter, and consist of lowercase letters, numbers, and hyphens.
Corresponds to the JSON property id
62489 62490 62491 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62489 def id @id end |
#json_schema ⇒ Object
Optional. Represents the JSON Schema of the structured memories.
Corresponds to the JSON property jsonSchema
62494 62495 62496 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62494 def json_schema @json_schema end |
#memory_type ⇒ String
Optional. Represents the type of the structured memories associated with the
schema. If not set, then STRUCTURED_PROFILE will be used.
Corresponds to the JSON property memoryType
62500 62501 62502 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62500 def memory_type @memory_type end |
#schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema
Defines the schema of input and output data. This is a subset of the OpenAPI
3.0 Schema Object.
Corresponds to the JSON property schema
62506 62507 62508 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62506 def schema @schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62513 62514 62515 62516 62517 62518 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62513 def update!(**args) @id = args[:id] if args.key?(:id) @json_schema = args[:json_schema] if args.key?(:json_schema) @memory_type = args[:memory_type] if args.key?(:memory_type) @schema = args[:schema] if args.key?(:schema) end |