Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Study

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A message representing a Study.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Study

Returns a new instance of GoogleCloudAiplatformV1beta1Study.



59802
59803
59804
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59802

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time at which the study was created. Corresponds to the JSON property createTime

Returns:

  • (String)


59773
59774
59775
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59773

def create_time
  @create_time
end

#display_nameString

Required. Describes the Study, default value is empty string. Corresponds to the JSON property displayName

Returns:

  • (String)


59778
59779
59780
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59778

def display_name
  @display_name
end

#inactive_reasonString

Output only. A human readable reason why the Study is inactive. This should be empty if a study is ACTIVE or COMPLETED. Corresponds to the JSON property inactiveReason

Returns:

  • (String)


59784
59785
59786
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59784

def inactive_reason
  @inactive_reason
end

#nameString

Output only. The name of a study. The study's globally unique identifier. Format: projects/project/locations/location/studies/study` Corresponds to the JSON propertyname`

Returns:

  • (String)


59790
59791
59792
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59790

def name
  @name
end

#stateString

Output only. The detailed state of a Study. Corresponds to the JSON property state

Returns:

  • (String)


59795
59796
59797
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59795

def state
  @state
end

#study_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



59800
59801
59802
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59800

def study_spec
  @study_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59807
59808
59809
59810
59811
59812
59813
59814
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59807

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @inactive_reason = args[:inactive_reason] if args.key?(:inactive_reason)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
end