Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents specification of a Study.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpec

Returns a new instance of GoogleCloudAiplatformV1beta1StudySpec.



62652
62653
62654
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#algorithmString

The search algorithm specified for the Study. Corresponds to the JSON property algorithm

Returns:

  • (String)


62579
62580
62581
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62579

def algorithm
  @algorithm
end

#convex_automated_stopping_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecConvexAutomatedStoppingSpec

Configuration for ConvexAutomatedStoppingSpec. When there are enough completed trials (configured by min_measurement_count), for pending trials with enough measurements and steps, the policy first computes an overestimate of the objective value at max_num_steps according to the slope of the incomplete objective value curve. No prediction can be made if the curve is completely flat. If the overestimation is worse than the best objective value of the completed trials, this pending trial will be early-stopped, but a last measurement will be added to the pending trial with max_num_steps and predicted objective value from the autoregression model. Corresponds to the JSON property convexAutomatedStoppingSpec



62592
62593
62594
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62592

def convex_automated_stopping_spec
  @convex_automated_stopping_spec
end

#convex_stop_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecConvexStopConfig

Configuration for ConvexStopPolicy. Corresponds to the JSON property convexStopConfig



62597
62598
62599
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62597

def convex_stop_config
  @convex_stop_config
end

#decay_curve_stopping_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecDecayCurveAutomatedStoppingSpec

The decay curve automated stopping rule builds a Gaussian Process Regressor to predict the final objective value of a Trial based on the already completed Trials and the intermediate measurements of the current Trial. Early stopping is requested for the current Trial if there is very low probability to exceed the optimal value found so far. Corresponds to the JSON property decayCurveStoppingSpec



62606
62607
62608
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62606

def decay_curve_stopping_spec
  @decay_curve_stopping_spec
end

#measurement_selection_typeString

Describe which measurement selection type will be used Corresponds to the JSON property measurementSelectionType

Returns:

  • (String)


62611
62612
62613
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62611

def measurement_selection_type
  @measurement_selection_type
end

#median_automated_stopping_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecMedianAutomatedStoppingSpec

The median automated stopping rule stops a pending Trial if the Trial's best objective_value is strictly below the median 'performance' of all completed Trials reported up to the Trial's last measurement. Currently, 'performance' refers to the running average of the objective values reported by the Trial in each measurement. Corresponds to the JSON property medianAutomatedStoppingSpec



62620
62621
62622
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62620

def median_automated_stopping_spec
  @median_automated_stopping_spec
end

#metricsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecMetricSpec>

Required. Metric specs for the Study. Corresponds to the JSON property metrics



62625
62626
62627
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62625

def metrics
  @metrics
end

#observation_noiseString

The observation noise level of the study. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline. Corresponds to the JSON property observationNoise

Returns:

  • (String)


62632
62633
62634
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62632

def observation_noise
  @observation_noise
end

#parametersArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpec>

Required. The set of parameters to tune. Corresponds to the JSON property parameters



62637
62638
62639
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62637

def parameters
  @parameters
end

#study_stopping_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecStudyStoppingConfig

The configuration (stopping conditions) for automated stopping of a Study. Conditions include trial budgets, time budgets, and convergence detection. Corresponds to the JSON property studyStoppingConfig



62643
62644
62645
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62643

def study_stopping_config
  @study_stopping_config
end

#transfer_learning_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecTransferLearningConfig

This contains flag for manually disabling transfer learning for a study. The names of prior studies being used for transfer learning (if any) are also listed here. Corresponds to the JSON property transferLearningConfig



62650
62651
62652
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62650

def transfer_learning_config
  @transfer_learning_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62657
62658
62659
62660
62661
62662
62663
62664
62665
62666
62667
62668
62669
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62657

def update!(**args)
  @algorithm = args[:algorithm] if args.key?(:algorithm)
  @convex_automated_stopping_spec = args[:convex_automated_stopping_spec] if args.key?(:convex_automated_stopping_spec)
  @convex_stop_config = args[:convex_stop_config] if args.key?(:convex_stop_config)
  @decay_curve_stopping_spec = args[:decay_curve_stopping_spec] if args.key?(:decay_curve_stopping_spec)
  @measurement_selection_type = args[:measurement_selection_type] if args.key?(:measurement_selection_type)
  @median_automated_stopping_spec = args[:median_automated_stopping_spec] if args.key?(:median_automated_stopping_spec)
  @metrics = args[:metrics] if args.key?(:metrics)
  @observation_noise = args[:observation_noise] if args.key?(:observation_noise)
  @parameters = args[:parameters] if args.key?(:parameters)
  @study_stopping_config = args[:study_stopping_config] if args.key?(:study_stopping_config)
  @transfer_learning_config = args[:transfer_learning_config] if args.key?(:transfer_learning_config)
end