Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecConvexStopConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for ConvexStopPolicy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecConvexStopConfig

Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecConvexStopConfig.



60044
60045
60046
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoregressive_orderFixnum

The number of Trial measurements used in autoregressive model for value prediction. A trial won't be considered early stopping if has fewer measurement points. Corresponds to the JSON property autoregressiveOrder

Returns:

  • (Fixnum)


60008
60009
60010
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60008

def autoregressive_order
  @autoregressive_order
end

#learning_rate_parameter_nameString

The hyper-parameter name used in the tuning job that stands for learning rate. Leave it blank if learning rate is not in a parameter in tuning. The learning_rate is used to estimate the objective value of the ongoing trial. Corresponds to the JSON property learningRateParameterName

Returns:

  • (String)


60015
60016
60017
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60015

def learning_rate_parameter_name
  @learning_rate_parameter_name
end

#max_num_stepsFixnum

Steps used in predicting the final objective for early stopped trials. In general, it's set to be the same as the defined steps in training / tuning. When use_steps is false, this field is set to the maximum elapsed seconds. Corresponds to the JSON property maxNumSteps

Returns:

  • (Fixnum)


60022
60023
60024
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60022

def max_num_steps
  @max_num_steps
end

#min_num_stepsFixnum

Minimum number of steps for a trial to complete. Trials which do not have a measurement with num_steps > min_num_steps won't be considered for early stopping. It's ok to set it to 0, and a trial can be early stopped at any stage. By default, min_num_steps is set to be one-tenth of the max_num_steps. When use_steps is false, this field is set to the minimum elapsed seconds. Corresponds to the JSON property minNumSteps

Returns:

  • (Fixnum)


60031
60032
60033
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60031

def min_num_steps
  @min_num_steps
end

#use_secondsBoolean Also known as: use_seconds?

This bool determines whether or not the rule is applied based on elapsed_secs or steps. If use_seconds==false, the early stopping decision is made according to the predicted objective values according to the target steps. If use_seconds==true, elapsed_secs is used instead of steps. Also, in this case, the parameters max_num_steps and min_num_steps are overloaded to contain max_elapsed_seconds and min_elapsed_seconds. Corresponds to the JSON property useSeconds

Returns:

  • (Boolean)


60041
60042
60043
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60041

def use_seconds
  @use_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60049
60050
60051
60052
60053
60054
60055
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60049

def update!(**args)
  @autoregressive_order = args[:autoregressive_order] if args.key?(:autoregressive_order)
  @learning_rate_parameter_name = args[:learning_rate_parameter_name] if args.key?(:learning_rate_parameter_name)
  @max_num_steps = args[:max_num_steps] if args.key?(:max_num_steps)
  @min_num_steps = args[:min_num_steps] if args.key?(:min_num_steps)
  @use_seconds = args[:use_seconds] if args.key?(:use_seconds)
end