Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a single parameter to optimize.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpec

Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpec.



62713
62714
62715
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62713

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categorical_value_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecCategoricalValueSpec

Value specification for a parameter in CATEGORICAL type. Corresponds to the JSON property categoricalValueSpec



62677
62678
62679
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62677

def categorical_value_spec
  @categorical_value_spec
end

#conditional_parameter_specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec>

A conditional parameter node is active if the parameter's value matches the conditional node's parent_value_condition. If two items in conditional_parameter_specs have the same name, they must have disjoint parent_value_condition. Corresponds to the JSON property conditionalParameterSpecs



62685
62686
62687
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62685

def conditional_parameter_specs
  @conditional_parameter_specs
end

#discrete_value_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecDiscreteValueSpec

Value specification for a parameter in DISCRETE type. Corresponds to the JSON property discreteValueSpec



62690
62691
62692
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62690

def discrete_value_spec
  @discrete_value_spec
end

#double_value_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecDoubleValueSpec

Value specification for a parameter in DOUBLE type. Corresponds to the JSON property doubleValueSpec



62695
62696
62697
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62695

def double_value_spec
  @double_value_spec
end

#integer_value_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec

Value specification for a parameter in INTEGER type. Corresponds to the JSON property integerValueSpec



62700
62701
62702
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62700

def integer_value_spec
  @integer_value_spec
end

#parameter_idString

Required. The ID of the parameter. Must not contain whitespaces and must be unique amongst all ParameterSpecs. Corresponds to the JSON property parameterId

Returns:

  • (String)


62706
62707
62708
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62706

def parameter_id
  @parameter_id
end

#scale_typeString

How the parameter should be scaled. Leave unset for CATEGORICAL parameters. Corresponds to the JSON property scaleType

Returns:

  • (String)


62711
62712
62713
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62711

def scale_type
  @scale_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62718
62719
62720
62721
62722
62723
62724
62725
62726
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62718

def update!(**args)
  @categorical_value_spec = args[:categorical_value_spec] if args.key?(:categorical_value_spec)
  @conditional_parameter_specs = args[:conditional_parameter_specs] if args.key?(:conditional_parameter_specs)
  @discrete_value_spec = args[:discrete_value_spec] if args.key?(:discrete_value_spec)
  @double_value_spec = args[:double_value_spec] if args.key?(:double_value_spec)
  @integer_value_spec = args[:integer_value_spec] if args.key?(:integer_value_spec)
  @parameter_id = args[:parameter_id] if args.key?(:parameter_id)
  @scale_type = args[:scale_type] if args.key?(:scale_type)
end