Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a parameter spec with condition from its parent parameter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec

Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec.



62781
62782
62783
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62781

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parameter_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpec

Represents a single parameter to optimize. Corresponds to the JSON property parameterSpec



62764
62765
62766
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62764

def parameter_spec
  @parameter_spec
end

#parent_categorical_valuesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecCategoricalValueCondition

Represents the spec to match categorical values from parent parameter. Corresponds to the JSON property parentCategoricalValues



62769
62770
62771
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62769

def parent_categorical_values
  @parent_categorical_values
end

#parent_discrete_valuesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecDiscreteValueCondition

Represents the spec to match discrete values from parent parameter. Corresponds to the JSON property parentDiscreteValues



62774
62775
62776
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62774

def parent_discrete_values
  @parent_discrete_values
end

#parent_int_valuesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecIntValueCondition

Represents the spec to match integer values from parent parameter. Corresponds to the JSON property parentIntValues



62779
62780
62781
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62779

def parent_int_values
  @parent_int_values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62786
62787
62788
62789
62790
62791
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62786

def update!(**args)
  @parameter_spec = args[:parameter_spec] if args.key?(:parameter_spec)
  @parent_categorical_values = args[:parent_categorical_values] if args.key?(:parent_categorical_values)
  @parent_discrete_values = args[:parent_discrete_values] if args.key?(:parent_discrete_values)
  @parent_int_values = args[:parent_int_values] if args.key?(:parent_int_values)
end