Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution.



64027
64028
64029
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


63985
63986
63987
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63985

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



63990
63991
63992
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63990

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


63995
63996
63997
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63995

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


64000
64001
64002
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64000

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


64005
64006
64007
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64005

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


64010
64011
64012
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64010

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


64015
64016
64017
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64015

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


64020
64021
64022
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64020

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


64025
64026
64027
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64025

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64032
64033
64034
64035
64036
64037
64038
64039
64040
64041
64042
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64032

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end