Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SyntheticExample

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A single instance of generated synthetic data. Each example is made up of one or more named fields, as defined in OutputFieldSpec. These examples are used as few-shot examples to show the model what you want (in GenerateSyntheticDataRequest.examples) and to return generated examples in the response (in GenerateSyntheticDataResponse.synthetic_examples).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SyntheticExample

Returns a new instance of GoogleCloudAiplatformV1beta1SyntheticExample.



63384
63385
63386
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63384

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SyntheticField>

Required. A list of fields that constitute an example. Corresponds to the JSON property fields



63382
63383
63384
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63382

def fields
  @fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63389
63390
63391
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63389

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
end