Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskStatusDetails
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskStatusDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents the additional status details of a task.
Instance Attribute Summary collapse
-
#task_message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskMessage
Represents a single message in a conversation, compliant with the A2A specification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskStatusDetails
constructor
A new instance of GoogleCloudAiplatformV1beta1TaskStatusDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskStatusDetails
Returns a new instance of GoogleCloudAiplatformV1beta1TaskStatusDetails.
61634 61635 61636 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61634 def initialize(**args) update!(**args) end |
Instance Attribute Details
#task_message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskMessage
Represents a single message in a conversation, compliant with the A2A
specification.
Corresponds to the JSON property taskMessage
61632 61633 61634 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61632 def @task_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61639 61640 61641 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61639 def update!(**args) @task_message = args[:task_message] if args.key?(:task_message) end |