Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tensor value type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tensor

Returns a new instance of GoogleCloudAiplatformV1beta1Tensor.



64684
64685
64686
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64684

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valArray<Boolean>

Type specific representations that make it easy to create tensor protos in all languages. Only the representation corresponding to "dtype" can be set. The values hold the flattened representation of the tensor in row major order. BOOL Corresponds to the JSON property boolVal

Returns:

  • (Array<Boolean>)


64616
64617
64618
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64616

def bool_val
  @bool_val
end

#bytes_valArray<String>

STRING Corresponds to the JSON property bytesVal

Returns:

  • (Array<String>)


64621
64622
64623
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64621

def bytes_val
  @bytes_val
end

#double_valArray<Float>

DOUBLE Corresponds to the JSON property doubleVal

Returns:

  • (Array<Float>)


64626
64627
64628
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64626

def double_val
  @double_val
end

#dtypeString

The data type of tensor. Corresponds to the JSON property dtype

Returns:

  • (String)


64631
64632
64633
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64631

def dtype
  @dtype
end

#float_valArray<Float>

FLOAT Corresponds to the JSON property floatVal

Returns:

  • (Array<Float>)


64636
64637
64638
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64636

def float_val
  @float_val
end

#int64_valArray<Fixnum>

INT64 Corresponds to the JSON property int64Val

Returns:

  • (Array<Fixnum>)


64641
64642
64643
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64641

def int64_val
  @int64_val
end

#int_valArray<Fixnum>

INT_8 INT_16 INT_32 Corresponds to the JSON property intVal

Returns:

  • (Array<Fixnum>)


64646
64647
64648
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64646

def int_val
  @int_val
end

#list_valArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>

A list of tensor values. Corresponds to the JSON property listVal



64651
64652
64653
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64651

def list_val
  @list_val
end

#shapeArray<Fixnum>

Shape of the tensor. Corresponds to the JSON property shape

Returns:

  • (Array<Fixnum>)


64656
64657
64658
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64656

def shape
  @shape
end

#string_valArray<String>

STRING Corresponds to the JSON property stringVal

Returns:

  • (Array<String>)


64661
64662
64663
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64661

def string_val
  @string_val
end

#struct_valHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>

A map of string to tensor. Corresponds to the JSON property structVal



64666
64667
64668
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64666

def struct_val
  @struct_val
end

#tensor_valString

Serialized raw tensor content. Corresponds to the JSON property tensorVal NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


64672
64673
64674
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64672

def tensor_val
  @tensor_val
end

#uint64_valArray<Fixnum>

UINT64 Corresponds to the JSON property uint64Val

Returns:

  • (Array<Fixnum>)


64677
64678
64679
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64677

def uint64_val
  @uint64_val
end

#uint_valArray<Fixnum>

UINT8 UINT16 UINT32 Corresponds to the JSON property uintVal

Returns:

  • (Array<Fixnum>)


64682
64683
64684
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64682

def uint_val
  @uint_val
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64689
64690
64691
64692
64693
64694
64695
64696
64697
64698
64699
64700
64701
64702
64703
64704
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64689

def update!(**args)
  @bool_val = args[:bool_val] if args.key?(:bool_val)
  @bytes_val = args[:bytes_val] if args.key?(:bytes_val)
  @double_val = args[:double_val] if args.key?(:double_val)
  @dtype = args[:dtype] if args.key?(:dtype)
  @float_val = args[:float_val] if args.key?(:float_val)
  @int64_val = args[:int64_val] if args.key?(:int64_val)
  @int_val = args[:int_val] if args.key?(:int_val)
  @list_val = args[:list_val] if args.key?(:list_val)
  @shape = args[:shape] if args.key?(:shape)
  @string_val = args[:string_val] if args.key?(:string_val)
  @struct_val = args[:struct_val] if args.key?(:struct_val)
  @tensor_val = args[:tensor_val] if args.key?(:tensor_val)
  @uint64_val = args[:uint64_val] if args.key?(:uint64_val)
  @uint_val = args[:uint_val] if args.key?(:uint_val)
end