Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardBlob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

One blob (e.g, image, graph) viewable on a blob metric plot.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TensorboardBlob

Returns a new instance of GoogleCloudAiplatformV1beta1TensorboardBlob.



64005
64006
64007
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64005

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

Optional. The bytes of the blob is not present unless it's returned by the ReadTensorboardBlobData endpoint. Corresponds to the JSON property data NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


63997
63998
63999
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63997

def data
  @data
end

#idString

Output only. A URI safe key uniquely identifying a blob. Can be used to locate the blob stored in the Cloud Storage bucket of the consumer project. Corresponds to the JSON property id

Returns:

  • (String)


64003
64004
64005
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64003

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64010
64011
64012
64013
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64010

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @id = args[:id] if args.key?(:id)
end