Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTimeSeries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

TensorboardTimeSeries maps to times series produced in training runs

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TensorboardTimeSeries

Returns a new instance of GoogleCloudAiplatformV1beta1TensorboardTimeSeries.



65094
65095
65096
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this TensorboardTimeSeries was created. Corresponds to the JSON property createTime

Returns:

  • (String)


65042
65043
65044
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65042

def create_time
  @create_time
end

#descriptionString

Description of this TensorboardTimeSeries. Corresponds to the JSON property description

Returns:

  • (String)


65047
65048
65049
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65047

def description
  @description
end

#display_nameString

Required. User provided name of this TensorboardTimeSeries. This value should be unique among all TensorboardTimeSeries resources belonging to the same TensorboardRun resource (parent resource). Corresponds to the JSON property displayName

Returns:

  • (String)


65054
65055
65056
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65054

def display_name
  @display_name
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


65060
65061
65062
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65060

def etag
  @etag
end

#metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTimeSeriesMetadata

Describes metadata for a TensorboardTimeSeries. Corresponds to the JSON property metadata



65065
65066
65067
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65065

def 
  @metadata
end

#nameString

Output only. Name of the TensorboardTimeSeries. Corresponds to the JSON property name

Returns:

  • (String)


65070
65071
65072
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65070

def name
  @name
end

#plugin_dataString

Data of the current plugin, with the size limited to 65KB. Corresponds to the JSON property pluginData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


65076
65077
65078
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65076

def plugin_data
  @plugin_data
end

#plugin_nameString

Immutable. Name of the plugin this time series pertain to. Such as Scalar, Tensor, Blob Corresponds to the JSON property pluginName

Returns:

  • (String)


65082
65083
65084
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65082

def plugin_name
  @plugin_name
end

#update_timeString

Output only. Timestamp when this TensorboardTimeSeries was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


65087
65088
65089
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65087

def update_time
  @update_time
end

#value_typeString

Required. Immutable. Type of TensorboardTimeSeries value. Corresponds to the JSON property valueType

Returns:

  • (String)


65092
65093
65094
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65092

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65099
65100
65101
65102
65103
65104
65105
65106
65107
65108
65109
65110
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65099

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @plugin_data = args[:plugin_data] if args.key?(:plugin_data)
  @plugin_name = args[:plugin_name] if args.key?(:plugin_name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
end