Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTimeSeriesMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Describes metadata for a TensorboardTimeSeries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TensorboardTimeSeriesMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1TensorboardTimeSeriesMetadata.



64878
64879
64880
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_blob_sequence_lengthFixnum

Output only. The largest blob sequence length (number of blobs) of all data points in this time series, if its ValueType is BLOB_SEQUENCE. Corresponds to the JSON property maxBlobSequenceLength

Returns:

  • (Fixnum)


64865
64866
64867
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64865

def max_blob_sequence_length
  @max_blob_sequence_length
end

#max_stepFixnum

Output only. Max step index of all data points within a TensorboardTimeSeries. Corresponds to the JSON property maxStep

Returns:

  • (Fixnum)


64870
64871
64872
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64870

def max_step
  @max_step
end

#max_wall_timeString

Output only. Max wall clock timestamp of all data points within a TensorboardTimeSeries. Corresponds to the JSON property maxWallTime

Returns:

  • (String)


64876
64877
64878
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64876

def max_wall_time
  @max_wall_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64883
64884
64885
64886
64887
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64883

def update!(**args)
  @max_blob_sequence_length = args[:max_blob_sequence_length] if args.key?(:max_blob_sequence_length)
  @max_step = args[:max_step] if args.key?(:max_step)
  @max_wall_time = args[:max_wall_time] if args.key?(:max_wall_time)
end