Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TimeSeriesData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

All the data stored in a TensorboardTimeSeries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TimeSeriesData

Returns a new instance of GoogleCloudAiplatformV1beta1TimeSeriesData.



65217
65218
65219
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65217

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tensorboard_time_series_idString

Required. The ID of the TensorboardTimeSeries, which will become the final component of the TensorboardTimeSeries' resource name Corresponds to the JSON property tensorboardTimeSeriesId

Returns:

  • (String)


65204
65205
65206
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65204

def tensorboard_time_series_id
  @tensorboard_time_series_id
end

#value_typeString

Required. Immutable. The value type of this time series. All the values in this time series data must match this value type. Corresponds to the JSON property valueType

Returns:

  • (String)


65210
65211
65212
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65210

def value_type
  @value_type
end

#valuesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TimeSeriesDataPoint>

Required. Data points in this time series. Corresponds to the JSON property values



65215
65216
65217
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65215

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65222
65223
65224
65225
65226
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65222

def update!(**args)
  @tensorboard_time_series_id = args[:tensorboard_time_series_id] if args.key?(:tensorboard_time_series_id)
  @value_type = args[:value_type] if args.key?(:value_type)
  @values = args[:values] if args.key?(:values)
end