Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TimeSeriesDataPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A TensorboardTimeSeries data point.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TimeSeriesDataPoint

Returns a new instance of GoogleCloudAiplatformV1beta1TimeSeriesDataPoint.



63116
63117
63118
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blobsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardBlobSequence

One point viewable on a blob metric plot, but mostly just a wrapper message to work around repeated fields can't be used directly within oneof fields. Corresponds to the JSON property blobs



63094
63095
63096
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63094

def blobs
  @blobs
end

#scalarGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Scalar

One point viewable on a scalar metric plot. Corresponds to the JSON property scalar



63099
63100
63101
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63099

def scalar
  @scalar
end

#stepFixnum

Step index of this data point within the run. Corresponds to the JSON property step

Returns:

  • (Fixnum)


63104
63105
63106
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63104

def step
  @step
end

#tensorGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTensor

One point viewable on a tensor metric plot. Corresponds to the JSON property tensor



63109
63110
63111
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63109

def tensor
  @tensor
end

#wall_timeString

Wall clock timestamp when this data point is generated by the end user. Corresponds to the JSON property wallTime

Returns:

  • (String)


63114
63115
63116
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63114

def wall_time
  @wall_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63121
63122
63123
63124
63125
63126
63127
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63121

def update!(**args)
  @blobs = args[:blobs] if args.key?(:blobs)
  @scalar = args[:scalar] if args.key?(:scalar)
  @step = args[:step] if args.key?(:step)
  @tensor = args[:tensor] if args.key?(:tensor)
  @wall_time = args[:wall_time] if args.key?(:wall_time)
end