Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolComputerUse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Tool to support computer use.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolComputerUse

Returns a new instance of GoogleCloudAiplatformV1beta1ToolComputerUse.



54546
54547
54548
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54546

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#environmentString

Required. The environment being operated. Corresponds to the JSON property environment

Returns:

  • (String)


54534
54535
54536
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54534

def environment
  @environment
end

#excluded_predefined_functionsArray<String>

Optional. By default, predefined functions are included in the final model call. Some of them can be explicitly excluded from being automatically included. This can serve two purposes: 1. Using a more restricted / different action space. 2. Improving the definitions / instructions of predefined functions. Corresponds to the JSON property excludedPredefinedFunctions

Returns:

  • (Array<String>)


54544
54545
54546
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54544

def excluded_predefined_functions
  @excluded_predefined_functions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54551
54552
54553
54554
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54551

def update!(**args)
  @environment = args[:environment] if args.key?(:environment)
  @excluded_predefined_functions = args[:excluded_predefined_functions] if args.key?(:excluded_predefined_functions)
end