Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExample
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A single example of the tool usage.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#extension_operation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExampleExtensionOperation
Identifies one operation of the extension.
-
#function_name ⇒ String
Function name to call.
-
#query ⇒ String
Required.
-
#request_params ⇒ Hash<String,Object>
Request parameters used for executing this tool.
-
#response_params ⇒ Hash<String,Object>
Response parameters generated by this tool.
-
#response_summary ⇒ String
Summary of the tool response to the user query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolUseExample
constructor
A new instance of GoogleCloudAiplatformV1beta1ToolUseExample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolUseExample
Returns a new instance of GoogleCloudAiplatformV1beta1ToolUseExample.
66163 66164 66165 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66163 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. The display name for example.
Corresponds to the JSON property displayName
66131 66132 66133 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66131 def display_name @display_name end |
#extension_operation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExampleExtensionOperation
Identifies one operation of the extension.
Corresponds to the JSON property extensionOperation
66136 66137 66138 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66136 def extension_operation @extension_operation end |
#function_name ⇒ String
Function name to call.
Corresponds to the JSON property functionName
66141 66142 66143 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66141 def function_name @function_name end |
#query ⇒ String
Required. Query that should be routed to this tool.
Corresponds to the JSON property query
66146 66147 66148 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66146 def query @query end |
#request_params ⇒ Hash<String,Object>
Request parameters used for executing this tool.
Corresponds to the JSON property requestParams
66151 66152 66153 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66151 def request_params @request_params end |
#response_params ⇒ Hash<String,Object>
Response parameters generated by this tool.
Corresponds to the JSON property responseParams
66156 66157 66158 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66156 def response_params @response_params end |
#response_summary ⇒ String
Summary of the tool response to the user query.
Corresponds to the JSON property responseSummary
66161 66162 66163 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66161 def response_summary @response_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66168 66169 66170 66171 66172 66173 66174 66175 66176 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66168 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @extension_operation = args[:extension_operation] if args.key?(:extension_operation) @function_name = args[:function_name] if args.key?(:function_name) @query = args[:query] if args.key?(:query) @request_params = args[:request_params] if args.key?(:request_params) @response_params = args[:response_params] if args.key?(:response_params) @response_summary = args[:response_summary] if args.key?(:response_summary) end |