Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Spec for TrajectoryInOrderMatch metric - returns 1 if tool calls in the reference trajectory appear in the predicted trajectory in the same order, else 0.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchSpec

Returns a new instance of GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchSpec.



60794
60795
60796
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60794

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60799
60800
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60799

def update!(**args)
end