Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectorySingleToolUseSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Spec for TrajectorySingleToolUse metric - returns 1 if tool is present in the predicted trajectory, else 0.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrajectorySingleToolUseSpec

Returns a new instance of GoogleCloudAiplatformV1beta1TrajectorySingleToolUseSpec.



66746
66747
66748
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tool_nameString

Required. Spec for tool name to be checked for in the predicted trajectory. Corresponds to the JSON property toolName

Returns:

  • (String)


66744
66745
66746
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66744

def tool_name
  @tool_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66751
66752
66753
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66751

def update!(**args)
  @tool_name = args[:tool_name] if args.key?(:tool_name)
end