Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrialParameter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A message representing a parameter to be tuned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrialParameter

Returns a new instance of GoogleCloudAiplatformV1beta1TrialParameter.



65051
65052
65053
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parameter_idString

Output only. The ID of the parameter. The parameter should be defined in StudySpec's Parameters. Corresponds to the JSON property parameterId

Returns:

  • (String)


65041
65042
65043
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65041

def parameter_id
  @parameter_id
end

#valueObject

Output only. The value of the parameter. number_value will be set if a parameter defined in StudySpec is in type 'INTEGER', 'DOUBLE' or 'DISCRETE'. string_value will be set if a parameter defined in StudySpec is in type ' CATEGORICAL'. Corresponds to the JSON property value

Returns:

  • (Object)


65049
65050
65051
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65049

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65056
65057
65058
65059
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65056

def update!(**args)
  @parameter_id = args[:parameter_id] if args.key?(:parameter_id)
  @value = args[:value] if args.key?(:value)
end