Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelCheckpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

TunedModelCheckpoint for the Tuned Model of a Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelCheckpoint

Returns a new instance of GoogleCloudAiplatformV1beta1TunedModelCheckpoint.



67271
67272
67273
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

The ID of the checkpoint. Corresponds to the JSON property checkpointId

Returns:

  • (String)


67253
67254
67255
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67253

def checkpoint_id
  @checkpoint_id
end

#endpointString

The Endpoint resource name that the checkpoint is deployed to. Format: projects/project/locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


67259
67260
67261
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67259

def endpoint
  @endpoint
end

#epochFixnum

The epoch of the checkpoint. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


67264
67265
67266
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67264

def epoch
  @epoch
end

#stepFixnum

The step of the checkpoint. Corresponds to the JSON property step

Returns:

  • (Fixnum)


67269
67270
67271
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67269

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67276
67277
67278
67279
67280
67281
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67276

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @epoch = args[:epoch] if args.key?(:epoch)
  @step = args[:step] if args.key?(:step)
end