Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserScenario

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Output of user scenario generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UserScenario

Returns a new instance of GoogleCloudAiplatformV1beta1UserScenario.



67860
67861
67862
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67860

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_planString

Conversation plan to drive multi-turn agent run and get simulated agent eval dataset. Corresponds to the JSON property conversationPlan

Returns:

  • (String)


67847
67848
67849
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67847

def conversation_plan
  @conversation_plan
end

#starting_promptString

Starting prompt for the conversation between simulated user and agent under the test. Corresponds to the JSON property startingPrompt

Returns:

  • (String)


67853
67854
67855
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67853

def starting_prompt
  @starting_prompt
end

#test_case_titleString

Represents a short 3-5 word title for eval test case. Corresponds to the JSON property testCaseTitle

Returns:

  • (String)


67858
67859
67860
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67858

def test_case_title
  @test_case_title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67865
67866
67867
67868
67869
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67865

def update!(**args)
  @conversation_plan = args[:conversation_plan] if args.key?(:conversation_plan)
  @starting_prompt = args[:starting_prompt] if args.key?(:starting_prompt)
  @test_case_title = args[:test_case_title] if args.key?(:test_case_title)
end