Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserSpecifiedMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Metadata provided by users.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UserSpecifiedMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1UserSpecifiedMetadata.



65981
65982
65983
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65981

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Required. Key of the metadata. The key must be set with type by CreateRagDataSchema. Corresponds to the JSON property key

Returns:

  • (String)


65974
65975
65976
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65974

def key
  @key
end

#valueGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataValue

Value of Metadata, including all types available in data schema. Corresponds to the JSON property value



65979
65980
65981
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65979

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65986
65987
65988
65989
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65986

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @value = args[:value] if args.key?(:value)
end