Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for GenAiTuningService.ValidateReinforcementTuningReward.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse

Returns a new instance of GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse.



68852
68853
68854
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68852

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorString

Output only. Deprecated: Use error_status instead. In case of an error, this field will be populated with a detailed error message to help with debugging. Corresponds to the JSON property error

Returns:

  • (String)


68819
68820
68821
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68819

def error
  @error
end

#error_statusGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property errorStatus



68829
68830
68831
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68829

def error_status
  @error_status
end

#overall_rewardFloat

Output only. The overall weighted reward. For a CompositeReinforcementTuningRewardConfig, this is the weighted average of all rewards. For a SingleReinforcementTuningRewardConfig, this will be the value of the single reward. Corresponds to the JSON property overallReward

Returns:

  • (Float)


68837
68838
68839
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68837

def overall_reward
  @overall_reward
end

#reward_detailsHash<String,Float>

Output only. Deprecated: Use reward_info_details instead. A map from reward name to the calculated reward for the reward function. This field will only be populated when a CompositeReinforcementTuningRewardConfig is provided in the request. It will not be set for a SingleReinforcementTuningRewardConfig. Corresponds to the JSON property rewardDetails

Returns:

  • (Hash<String,Float>)


68845
68846
68847
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68845

def reward_details
  @reward_details
end

#reward_info_detailsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo>

A map from reward name to reward info. Corresponds to the JSON property rewardInfoDetails



68850
68851
68852
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68850

def reward_info_details
  @reward_info_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68857
68858
68859
68860
68861
68862
68863
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68857

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @error_status = args[:error_status] if args.key?(:error_status)
  @overall_reward = args[:overall_reward] if args.key?(:overall_reward)
  @reward_details = args[:reward_details] if args.key?(:reward_details)
  @reward_info_details = args[:reward_info_details] if args.key?(:reward_info_details)
end