Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Tuning Spec for Veo LoRA Model Tuning.
Instance Attribute Summary collapse
-
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoHyperParameters
Hyperparameters for Veo.
-
#training_dataset_uri ⇒ String
Required.
-
#validation_dataset_uri ⇒ String
Optional.
-
#video_orientation ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1VeoLoraTuningSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
Returns a new instance of GoogleCloudAiplatformV1beta1VeoLoraTuningSpec.
66191 66192 66193 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66191 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoHyperParameters
Hyperparameters for Veo.
Corresponds to the JSON property hyperParameters
66170 66171 66172 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66170 def hyper_parameters @hyper_parameters end |
#training_dataset_uri ⇒ String
Required. Training dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property trainingDatasetUri
66177 66178 66179 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66177 def training_dataset_uri @training_dataset_uri end |
#validation_dataset_uri ⇒ String
Optional. Validation dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property validationDatasetUri
66184 66185 66186 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66184 def validation_dataset_uri @validation_dataset_uri end |
#video_orientation ⇒ String
Optional. The orientation of the video. Defaults to LANDSCAPE.
Corresponds to the JSON property videoOrientation
66189 66190 66191 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66189 def video_orientation @video_orientation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66196 66197 66198 66199 66200 66201 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66196 def update!(**args) @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters) @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri) @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri) @video_orientation = args[:video_orientation] if args.key?(:video_orientation) end |