Class: Google::Apis::AiplatformV1beta1::GoogleCloudLocationListLocationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudLocationListLocationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The response message for Locations.ListLocations.
Instance Attribute Summary collapse
-
#locations ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudLocationLocation>
A list of locations that matches the specified filter in the request.
-
#next_page_token ⇒ String
The standard List next-page token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudLocationListLocationsResponse
constructor
A new instance of GoogleCloudLocationListLocationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudLocationListLocationsResponse
Returns a new instance of GoogleCloudLocationListLocationsResponse.
66817 66818 66819 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66817 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudLocationLocation>
A list of locations that matches the specified filter in the request.
Corresponds to the JSON property locations
66810 66811 66812 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66810 def locations @locations end |
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
66815 66816 66817 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66815 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66822 66823 66824 66825 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66822 def update!(**args) @locations = args[:locations] if args.key?(:locations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |