Class: Google::Apis::AiplatformV1beta1::GoogleIamV1GetPolicyOptions
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleIamV1GetPolicyOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Encapsulates settings provided to GetIamPolicy.
Instance Attribute Summary collapse
-
#requested_policy_version ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIamV1GetPolicyOptions
constructor
A new instance of GoogleIamV1GetPolicyOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIamV1GetPolicyOptions
Returns a new instance of GoogleIamV1GetPolicyOptions.
65343 65344 65345 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#requested_policy_version ⇒ Fixnum
Optional. The maximum policy version that will be used to format the policy.
Valid values are 0, 1, and 3. Requests specifying an invalid value will be
rejected. Requests for policies with any conditional role bindings must
specify version 3. Policies with no conditional role bindings may specify any
valid value or leave the field unset. The policy in the response might use the
policy version that you specified, or it might use a lower policy version. For
example, if you specify version 3, but the policy has no conditional role
bindings, the response uses version 1. To learn which resources support
conditions in their IAM policies, see the IAM documentation.
Corresponds to the JSON property requestedPolicyVersion
65341 65342 65343 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65341 def requested_policy_version @requested_policy_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65348 65349 65350 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65348 def update!(**args) @requested_policy_version = args[:requested_policy_version] if args.key?(:requested_policy_version) end |