Class: Google::Apis::AiplatformV1beta1::GoogleLongrunningOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

This resource represents a long-running operation that is the result of a network API call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleLongrunningOperation

Returns a new instance of GoogleLongrunningOperation.



69888
69889
69890
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#doneBoolean Also known as: done?

If the value is false, it means the operation is still in progress. If true , the operation is completed, and either error or response is available. Corresponds to the JSON property done

Returns:

  • (Boolean)


69849
69850
69851
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69849

def done
  @done
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



69860
69861
69862
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69860

def error
  @error
end

#metadataHash<String,Object>

Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


69868
69869
69870
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69868

def 
  @metadata
end

#nameString

The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the name should be a resource name ending with operations/unique_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


69875
69876
69877
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69875

def name
  @name
end

#responseHash<String,Object>

The normal, successful response of the operation. If the original method returns no data on success, such as Delete, the response is google.protobuf. Empty. If the original method is standard Get/Create/Update, the response should be the resource. For other methods, the response should have the type XxxResponse, where Xxx is the original method name. For example, if the original method name is TakeSnapshot(), the inferred response type is TakeSnapshotResponse. Corresponds to the JSON property response

Returns:

  • (Hash<String,Object>)


69886
69887
69888
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69886

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69893
69894
69895
69896
69897
69898
69899
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69893

def update!(**args)
  @done = args[:done] if args.key?(:done)
  @error = args[:error] if args.key?(:error)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @response = args[:response] if args.key?(:response)
end