Class: Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperiments
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperiments
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Experimental parameters for video generation.
Instance Attribute Summary collapse
-
#anchor_last_frame ⇒ Boolean
(also: #anchor_last_frame?)
Optional.
-
#cfg_scale ⇒ Float
CFG scale for video-transform, perf-generation, a2v, video-textures models.
-
#codec ⇒ String
Optional.
-
#color_alignment ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperimentsColorAlignmentConfig
Configuration for color alignment.
-
#conditioning_frames ⇒ Array<Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperimentsConditioningFrame>
Conditioning frames for veo experimental models ONLY, not to be confused with keyframes (ID:31) in GenerateVideoRequest.
-
#custom_parameters ⇒ Hash<String,Object>
Generic key-value pairs for experimental parameters.
-
#human_pose ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionHumanPose
Human pose parameters for Pose Control Corresponds to the JSON property
humanPose. -
#model_name ⇒ String
Model names, as defined in: xyz Corresponds to the JSON property
modelName. -
#num_diffusion_steps ⇒ Fixnum
Number of diffusion steps Corresponds to the JSON property
numDiffusionSteps. -
#original_request_json ⇒ String
The original REST API request JSON sent by the user, in the instances/ parameters format.
-
#prompt_inputs ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionPromptInputs
"Direct" prompting for Experimental Video Generation.
-
#request_origin_tag ⇒ String
Optional tag for tracking the source of this request.
-
#scheduling_config ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperimentsVeSchedulingConfig
Scheduling configuration for Veo Experimental.
-
#seamless ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionSeamless
Parameters for seamless (edge-continuous) video generation, enabling temporal looping and/or spatial tessellation.
-
#spatial_alignment ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperimentsSpatialAlignmentConfig
Configuration for spatial alignment.
-
#truncate_input_video ⇒ Boolean
(also: #truncate_input_video?)
If true (default), truncate input videos that exceed the model's maximum frame count by applying a frame_selection_config to video_file inputs.
-
#video_transform_mask_gcs_uri ⇒ String
GCS URI of the grayscale video mask for Differential Diffusion.
-
#video_transform_strength ⇒ Float
SDEdit: Scalar noise level (0.0 to 1.0) Maps to sdedit_tmax Corresponds to the JSON property
videoTransformStrength.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiLargeModelsVisionGenerateVideoExperiments
constructor
A new instance of CloudAiLargeModelsVisionGenerateVideoExperiments.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiLargeModelsVisionGenerateVideoExperiments
Returns a new instance of CloudAiLargeModelsVisionGenerateVideoExperiments.
135 136 137 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 135 def initialize(**args) update!(**args) end |
Instance Attribute Details
#anchor_last_frame ⇒ Boolean Also known as: anchor_last_frame?
Optional. If true, anchors the last frame in video generation by generating a
custom border mask.
Corresponds to the JSON property anchorLastFrame
33 34 35 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33 def anchor_last_frame @anchor_last_frame end |
#cfg_scale ⇒ Float
CFG scale for video-transform, perf-generation, a2v, video-textures models.
Corresponds to the JSON property cfgScale
39 40 41 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39 def cfg_scale @cfg_scale end |
#codec ⇒ String
Optional. Video codec to use for output.
Corresponds to the JSON property codec
44 45 46 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44 def codec @codec end |
#color_alignment ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperimentsColorAlignmentConfig
Configuration for color alignment.
Corresponds to the JSON property colorAlignment
49 50 51 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49 def color_alignment @color_alignment end |
#conditioning_frames ⇒ Array<Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperimentsConditioningFrame>
Conditioning frames for veo experimental models ONLY, not to be confused with
keyframes (ID:31) in GenerateVideoRequest.
Corresponds to the JSON property conditioningFrames
55 56 57 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55 def conditioning_frames @conditioning_frames end |
#custom_parameters ⇒ Hash<String,Object>
Generic key-value pairs for experimental parameters. This allows adding new
parameters without changing the dataplane binary.
Corresponds to the JSON property customParameters
61 62 63 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61 def custom_parameters @custom_parameters end |
#human_pose ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionHumanPose
Human pose parameters for Pose Control
Corresponds to the JSON property humanPose
66 67 68 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66 def human_pose @human_pose end |
#model_name ⇒ String
Model names, as defined in: xyz
Corresponds to the JSON property modelName
71 72 73 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 71 def model_name @model_name end |
#num_diffusion_steps ⇒ Fixnum
Number of diffusion steps
Corresponds to the JSON property numDiffusionSteps
76 77 78 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 76 def num_diffusion_steps @num_diffusion_steps end |
#original_request_json ⇒ String
The original REST API request JSON sent by the user, in the instances/
parameters format. Preserved for saving alongside output artifacts so users
can reproduce their requests. This field is populated by the API handler and
is not user-settable.
Corresponds to the JSON property originalRequestJson
84 85 86 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 84 def original_request_json @original_request_json end |
#prompt_inputs ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionPromptInputs
"Direct" prompting for Experimental Video Generation. These will be sent
directly to the LDM without being rewritten.
Corresponds to the JSON property promptInputs
90 91 92 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 90 def prompt_inputs @prompt_inputs end |
#request_origin_tag ⇒ String
Optional tag for tracking the source of this request. Allowed values: "colab",
"comfyui", "curl", "flowresearch", "vertexstudio". Unrecognized tags are
recorded as "unknown" in metrics. Tags do not affect video generation behavior.
Up to 16 characters, ASCII alphanumeric, hyphens, and underscores only.
Corresponds to the JSON property requestOriginTag
98 99 100 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 98 def request_origin_tag @request_origin_tag end |
#scheduling_config ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperimentsVeSchedulingConfig
Scheduling configuration for Veo Experimental.
Corresponds to the JSON property schedulingConfig
103 104 105 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 103 def scheduling_config @scheduling_config end |
#seamless ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionSeamless
Parameters for seamless (edge-continuous) video generation, enabling temporal
looping and/or spatial tessellation.
Corresponds to the JSON property seamless
109 110 111 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 109 def seamless @seamless end |
#spatial_alignment ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperimentsSpatialAlignmentConfig
Configuration for spatial alignment.
Corresponds to the JSON property spatialAlignment
114 115 116 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 114 def spatial_alignment @spatial_alignment end |
#truncate_input_video ⇒ Boolean Also known as: truncate_input_video?
If true (default), truncate input videos that exceed the model's maximum frame
count by applying a frame_selection_config to video_file inputs. Set to
false to preserve the existing fail-fast behavior.
Corresponds to the JSON property truncateInputVideo
121 122 123 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 121 def truncate_input_video @truncate_input_video end |
#video_transform_mask_gcs_uri ⇒ String
GCS URI of the grayscale video mask for Differential Diffusion. Maps to
sdedit_video_tmax_scale_map
Corresponds to the JSON property videoTransformMaskGcsUri
128 129 130 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 128 def video_transform_mask_gcs_uri @video_transform_mask_gcs_uri end |
#video_transform_strength ⇒ Float
SDEdit: Scalar noise level (0.0 to 1.0) Maps to sdedit_tmax
Corresponds to the JSON property videoTransformStrength
133 134 135 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 133 def video_transform_strength @video_transform_strength end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 140 def update!(**args) @anchor_last_frame = args[:anchor_last_frame] if args.key?(:anchor_last_frame) @cfg_scale = args[:cfg_scale] if args.key?(:cfg_scale) @codec = args[:codec] if args.key?(:codec) @color_alignment = args[:color_alignment] if args.key?(:color_alignment) @conditioning_frames = args[:conditioning_frames] if args.key?(:conditioning_frames) @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters) @human_pose = args[:human_pose] if args.key?(:human_pose) @model_name = args[:model_name] if args.key?(:model_name) @num_diffusion_steps = args[:num_diffusion_steps] if args.key?(:num_diffusion_steps) @original_request_json = args[:original_request_json] if args.key?(:original_request_json) @prompt_inputs = args[:prompt_inputs] if args.key?(:prompt_inputs) @request_origin_tag = args[:request_origin_tag] if args.key?(:request_origin_tag) @scheduling_config = args[:scheduling_config] if args.key?(:scheduling_config) @seamless = args[:seamless] if args.key?(:seamless) @spatial_alignment = args[:spatial_alignment] if args.key?(:spatial_alignment) @truncate_input_video = args[:truncate_input_video] if args.key?(:truncate_input_video) @video_transform_mask_gcs_uri = args[:video_transform_mask_gcs_uri] if args.key?(:video_transform_mask_gcs_uri) @video_transform_strength = args[:video_transform_strength] if args.key?(:video_transform_strength) end |