Class: Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperiments
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperiments
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Experimental parameters for video generation.
Instance Attribute Summary collapse
-
#codec ⇒ String
Optional.
-
#conditioning_frames ⇒ Array<Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperimentsConditioningFrame>
Conditioning frames for veo experimental models ONLY, not to be confused with keyframes (ID:31) in GenerateVideoRequest.
-
#human_pose ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionHumanPose
Human pose parameters for Pose Control Corresponds to the JSON property
humanPose. -
#model_name ⇒ String
Model names, as defined in: xyz Corresponds to the JSON property
modelName. -
#num_diffusion_steps ⇒ Fixnum
Number of diffusion steps Corresponds to the JSON property
numDiffusionSteps. -
#prompt_inputs ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionPromptInputs
"Direct" prompting for Experimental Video Generation.
-
#request_origin_tag ⇒ String
Optional tag for tracking the source of this request.
-
#truncate_input_video ⇒ Boolean
(also: #truncate_input_video?)
If true (default), truncate input videos that exceed the model's maximum frame count by applying a frame_selection_config to video_file inputs.
-
#video_transform_mask_gcs_uri ⇒ String
GCS URI of the grayscale video mask for Differential Diffusion.
-
#video_transform_strength ⇒ Float
SDEdit: Scalar noise level (0.0 to 1.0) Maps to sdedit_tmax Corresponds to the JSON property
videoTransformStrength.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiLargeModelsVisionGenerateVideoExperiments
constructor
A new instance of CloudAiLargeModelsVisionGenerateVideoExperiments.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiLargeModelsVisionGenerateVideoExperiments
Returns a new instance of CloudAiLargeModelsVisionGenerateVideoExperiments.
88 89 90 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 88 def initialize(**args) update!(**args) end |
Instance Attribute Details
#codec ⇒ String
Optional. Video codec to use for output.
Corresponds to the JSON property codec
32 33 34 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32 def codec @codec end |
#conditioning_frames ⇒ Array<Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperimentsConditioningFrame>
Conditioning frames for veo experimental models ONLY, not to be confused with
keyframes (ID:31) in GenerateVideoRequest.
Corresponds to the JSON property conditioningFrames
38 39 40 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38 def conditioning_frames @conditioning_frames end |
#human_pose ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionHumanPose
Human pose parameters for Pose Control
Corresponds to the JSON property humanPose
43 44 45 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43 def human_pose @human_pose end |
#model_name ⇒ String
Model names, as defined in: xyz
Corresponds to the JSON property modelName
48 49 50 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48 def model_name @model_name end |
#num_diffusion_steps ⇒ Fixnum
Number of diffusion steps
Corresponds to the JSON property numDiffusionSteps
53 54 55 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53 def num_diffusion_steps @num_diffusion_steps end |
#prompt_inputs ⇒ Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionPromptInputs
"Direct" prompting for Experimental Video Generation. These will be sent
directly to the LDM without being rewritten.
Corresponds to the JSON property promptInputs
59 60 61 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59 def prompt_inputs @prompt_inputs end |
#request_origin_tag ⇒ String
Optional tag for tracking the source of this request. Allowed values: "colab",
"comfyui", "curl", "flowresearch", "vertexstudio". Unrecognized tags are
recorded as "unknown" in metrics. Tags do not affect video generation behavior.
Up to 16 characters, ASCII alphanumeric, hyphens, and underscores only.
Corresponds to the JSON property requestOriginTag
67 68 69 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67 def request_origin_tag @request_origin_tag end |
#truncate_input_video ⇒ Boolean Also known as: truncate_input_video?
If true (default), truncate input videos that exceed the model's maximum frame
count by applying a frame_selection_config to video_file inputs. Set to
false to preserve the existing fail-fast behavior.
Corresponds to the JSON property truncateInputVideo
74 75 76 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 74 def truncate_input_video @truncate_input_video end |
#video_transform_mask_gcs_uri ⇒ String
GCS URI of the grayscale video mask for Differential Diffusion. Maps to
sdedit_video_tmax_scale_map
Corresponds to the JSON property videoTransformMaskGcsUri
81 82 83 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 81 def video_transform_mask_gcs_uri @video_transform_mask_gcs_uri end |
#video_transform_strength ⇒ Float
SDEdit: Scalar noise level (0.0 to 1.0) Maps to sdedit_tmax
Corresponds to the JSON property videoTransformStrength
86 87 88 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 86 def video_transform_strength @video_transform_strength end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 93 def update!(**args) @codec = args[:codec] if args.key?(:codec) @conditioning_frames = args[:conditioning_frames] if args.key?(:conditioning_frames) @human_pose = args[:human_pose] if args.key?(:human_pose) @model_name = args[:model_name] if args.key?(:model_name) @num_diffusion_steps = args[:num_diffusion_steps] if args.key?(:num_diffusion_steps) @prompt_inputs = args[:prompt_inputs] if args.key?(:prompt_inputs) @request_origin_tag = args[:request_origin_tag] if args.key?(:request_origin_tag) @truncate_input_video = args[:truncate_input_video] if args.key?(:truncate_input_video) @video_transform_mask_gcs_uri = args[:video_transform_mask_gcs_uri] if args.key?(:video_transform_mask_gcs_uri) @video_transform_strength = args[:video_transform_strength] if args.key?(:video_transform_strength) end |