Class: Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperimentsOutpaintConfigFrameSource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionGenerateVideoExperimentsOutpaintConfigFrameSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The input frame(s). It can be a full path or a glob pattern to images. The proto can be extended in the future for alternative ways to specify source of frames.
Instance Attribute Summary collapse
-
#glob_pattern ⇒ String
Corresponds to the JSON property
globPattern. -
#horizontal_offset ⇒ Fixnum
Horizontal offset in pixels to shift the input frame from center.
-
#vertical_offset ⇒ Fixnum
Vertical offset in pixels to shift the input frame from center.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiLargeModelsVisionGenerateVideoExperimentsOutpaintConfigFrameSource
constructor
A new instance of CloudAiLargeModelsVisionGenerateVideoExperimentsOutpaintConfigFrameSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiLargeModelsVisionGenerateVideoExperimentsOutpaintConfigFrameSource
Returns a new instance of CloudAiLargeModelsVisionGenerateVideoExperimentsOutpaintConfigFrameSource.
339 340 341 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 339 def initialize(**args) update!(**args) end |
Instance Attribute Details
#glob_pattern ⇒ String
Corresponds to the JSON property globPattern
324 325 326 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 324 def glob_pattern @glob_pattern end |
#horizontal_offset ⇒ Fixnum
Horizontal offset in pixels to shift the input frame from center. Positive
values shift right, negative values shift left. Optional. Default is 0 (
centered).
Corresponds to the JSON property horizontalOffset
331 332 333 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 331 def horizontal_offset @horizontal_offset end |
#vertical_offset ⇒ Fixnum
Vertical offset in pixels to shift the input frame from center. Positive
values shift down, negative values shift up. Optional. Default is 0 (centered).
Corresponds to the JSON property verticalOffset
337 338 339 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 337 def vertical_offset @vertical_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
344 345 346 347 348 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 344 def update!(**args) @glob_pattern = args[:glob_pattern] if args.key?(:glob_pattern) @horizontal_offset = args[:horizontal_offset] if args.key?(:horizontal_offset) @vertical_offset = args[:vertical_offset] if args.key?(:vertical_offset) end |