Class: Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionHumanPose

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiLargeModelsVisionHumanPose

Returns a new instance of CloudAiLargeModelsVisionHumanPose.



320
321
322
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#body_landmarks_gcs_uriString

GCS URI of the human pose video to condition video generation. Corresponds to the JSON property bodyLandmarksGcsUri

Returns:

  • (String)


308
309
310
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 308

def body_landmarks_gcs_uri
  @body_landmarks_gcs_uri
end

#face_landmarks_gcs_uriString

GCS URI of the face landmarks video to condition video generation. Corresponds to the JSON property faceLandmarksGcsUri

Returns:

  • (String)


313
314
315
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 313

def face_landmarks_gcs_uri
  @face_landmarks_gcs_uri
end

#perf_mesh_gcs_uriString

GCS URI of the performance mesh to condition video generation. Corresponds to the JSON property perfMeshGcsUri

Returns:

  • (String)


318
319
320
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 318

def perf_mesh_gcs_uri
  @perf_mesh_gcs_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



325
326
327
328
329
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 325

def update!(**args)
  @body_landmarks_gcs_uri = args[:body_landmarks_gcs_uri] if args.key?(:body_landmarks_gcs_uri)
  @face_landmarks_gcs_uri = args[:face_landmarks_gcs_uri] if args.key?(:face_landmarks_gcs_uri)
  @perf_mesh_gcs_uri = args[:perf_mesh_gcs_uri] if args.key?(:perf_mesh_gcs_uri)
end