Class: Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionSeamless
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::CloudAiLargeModelsVisionSeamless
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#loop ⇒ Boolean
(also: #loop?)
If true, the generated video will be loopable (seamless time looping).
-
#tessellate_horizontal ⇒ Boolean
(also: #tessellate_horizontal?)
If true, the generated video will be tessellatable as a horizontal tessellation.
-
#tessellate_vertical ⇒ Boolean
(also: #tessellate_vertical?)
If true, the generated video will be tessellatable as a vertical tessellation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiLargeModelsVisionSeamless
constructor
A new instance of CloudAiLargeModelsVisionSeamless.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiLargeModelsVisionSeamless
Returns a new instance of CloudAiLargeModelsVisionSeamless.
810 811 812 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 810 def initialize(**args) update!(**args) end |
Instance Attribute Details
#loop ⇒ Boolean Also known as: loop?
If true, the generated video will be loopable (seamless time looping).
Corresponds to the JSON property loop
794 795 796 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 794 def loop @loop end |
#tessellate_horizontal ⇒ Boolean Also known as: tessellate_horizontal?
If true, the generated video will be tessellatable as a horizontal
tessellation.
Corresponds to the JSON property tessellateHorizontal
801 802 803 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 801 def tessellate_horizontal @tessellate_horizontal end |
#tessellate_vertical ⇒ Boolean Also known as: tessellate_vertical?
If true, the generated video will be tessellatable as a vertical tessellation.
Corresponds to the JSON property tessellateVertical
807 808 809 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 807 def tessellate_vertical @tessellate_vertical end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
815 816 817 818 819 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 815 def update!(**args) @loop = args[:loop] if args.key?(:loop) @tessellate_horizontal = args[:tessellate_horizontal] if args.key?(:tessellate_horizontal) @tessellate_vertical = args[:tessellate_vertical] if args.key?(:tessellate_vertical) end |