Class: Google::Apis::AiplatformV1beta1::GenaiStruct
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiStruct
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Instance Attribute Summary collapse
-
#fields ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiField>
Dynamically typed fields.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiStruct
constructor
A new instance of GenaiStruct.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiStruct
Returns a new instance of GenaiStruct.
829 830 831 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 829 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fields ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiField>
Dynamically typed fields. List instead of map because LLMs are sensitive to
ordering, and we want to give users full control.
Corresponds to the JSON property fields
827 828 829 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 827 def fields @fields end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
834 835 836 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 834 def update!(**args) @fields = args[:fields] if args.key?(:fields) end |