Class: Google::Apis::AiplatformV1beta1::GenaiValue
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Value represents a dynamically typed value which can be either null, a
number, a string, a boolean, a recursive struct value, or a list of values. A
producer of value is expected to set one of these variants. Absence of any
variant indicates an error.
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
Represents a boolean value.
-
#list_value ⇒ Google::Apis::AiplatformV1beta1::GenaiListValue
ListValueis a wrapper around a repeated field of values. -
#null_value ⇒ String
Represents a null value.
-
#number_value ⇒ Float
Represents a double value.
-
#string_value ⇒ String
Represents a string value.
-
#struct_value ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiValue
constructor
A new instance of GenaiValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiValue
Returns a new instance of GenaiValue.
878 879 880 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 878 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
Represents a boolean value.
Corresponds to the JSON property boolValue
849 850 851 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 849 def bool_value @bool_value end |
#list_value ⇒ Google::Apis::AiplatformV1beta1::GenaiListValue
ListValue is a wrapper around a repeated field of values.
Corresponds to the JSON property listValue
855 856 857 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 855 def list_value @list_value end |
#null_value ⇒ String
Represents a null value.
Corresponds to the JSON property nullValue
860 861 862 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 860 def null_value @null_value end |
#number_value ⇒ Float
Represents a double value.
Corresponds to the JSON property numberValue
865 866 867 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 865 def number_value @number_value end |
#string_value ⇒ String
Represents a string value.
Corresponds to the JSON property stringValue
870 871 872 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 870 def string_value @string_value end |
#struct_value ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structValue
876 877 878 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 876 def struct_value @struct_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
883 884 885 886 887 888 889 890 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 883 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @list_value = args[:list_value] if args.key?(:list_value) @null_value = args[:null_value] if args.key?(:null_value) @number_value = args[:number_value] if args.key?(:number_value) @string_value = args[:string_value] if args.key?(:string_value) @struct_value = args[:struct_value] if args.key?(:struct_value) end |