Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for the CodeMender agent.
Instance Attribute Summary collapse
-
#find_request ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFindRequest
Request parameters specific to FIND sessions, used for discovering vulnerabilities in a codebase.
-
#fix_request ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFixRequest
Request parameters specific to FIX sessions, used for generating and validating security patches.
-
#model ⇒ String
The name of the model to use for the CodeMender agent.
-
#session_config ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigSessionConfig
The configuration of CodeMender sessions.
-
#session_id ⇒ String
Parameter for grouping multiple interactions that belong to the same CodeMender session.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1CodeMenderAgentConfig
constructor
A new instance of GenaiVertexV1beta1CodeMenderAgentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1CodeMenderAgentConfig
Returns a new instance of GenaiVertexV1beta1CodeMenderAgentConfig.
1307 1308 1309 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1307 def initialize(**args) update!(**args) end |
Instance Attribute Details
#find_request ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFindRequest
Request parameters specific to FIND sessions, used for discovering
vulnerabilities in a codebase.
Corresponds to the JSON property find_request
1282 1283 1284 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1282 def find_request @find_request end |
#fix_request ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFixRequest
Request parameters specific to FIX sessions, used for generating and
validating security patches.
Corresponds to the JSON property fix_request
1288 1289 1290 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1288 def fix_request @fix_request end |
#model ⇒ String
The name of the model to use for the CodeMender agent. One CodeMender session
will only use one model.
Corresponds to the JSON property model
1294 1295 1296 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1294 def model @model end |
#session_config ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigSessionConfig
The configuration of CodeMender sessions.
Corresponds to the JSON property session_config
1299 1300 1301 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1299 def session_config @session_config end |
#session_id ⇒ String
Parameter for grouping multiple interactions that belong to the same
CodeMender session.
Corresponds to the JSON property session_id
1305 1306 1307 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1305 def session_id @session_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1312 1313 1314 1315 1316 1317 1318 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1312 def update!(**args) @find_request = args[:find_request] if args.key?(:find_request) @fix_request = args[:fix_request] if args.key?(:fix_request) @model = args[:model] if args.key?(:model) @session_config = args[:session_config] if args.key?(:session_config) @session_id = args[:session_id] if args.key?(:session_id) end |