Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFileContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFileContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Content of a single file in the codebase.
Instance Attribute Summary collapse
-
#content ⇒ String
The UTF-8 encoded text content of the file.
-
#path ⇒ String
The relative path of the file from the project root.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1CodeMenderAgentConfigFileContent
constructor
A new instance of GenaiVertexV1beta1CodeMenderAgentConfigFileContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1CodeMenderAgentConfigFileContent
Returns a new instance of GenaiVertexV1beta1CodeMenderAgentConfigFileContent.
1335 1336 1337 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1335 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
The UTF-8 encoded text content of the file.
Corresponds to the JSON property content
1328 1329 1330 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1328 def content @content end |
#path ⇒ String
The relative path of the file from the project root.
Corresponds to the JSON property path
1333 1334 1335 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1333 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1340 1341 1342 1343 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1340 def update!(**args) @content = args[:content] if args.key?(:content) @path = args[:path] if args.key?(:path) end |