Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFindRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request parameters specific to FIND sessions, used for discovering vulnerabilities in a codebase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1CodeMenderAgentConfigFindRequest

Returns a new instance of GenaiVertexV1beta1CodeMenderAgentConfigFindRequest.



1502
1503
1504
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Additional context or custom instructions provided by the user to guide the vulnerability analysis. Corresponds to the JSON property description

Returns:

  • (String)


1483
1484
1485
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1483

def description
  @description
end

#finding_idString

The identifier of a specific finding to verify. This is primarily used in VERIFY mode to focus the agent's execution-based validation on a single vulnerability. Corresponds to the JSON property finding_id

Returns:

  • (String)


1490
1491
1492
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1490

def finding_id
  @finding_id
end

#modeString

The mode of the find session. Corresponds to the JSON property mode

Returns:

  • (String)


1495
1496
1497
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1495

def mode
  @mode
end

#source_filesArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFileContent>

A list of source files to provide as context for the scan. Corresponds to the JSON property source_files



1500
1501
1502
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1500

def source_files
  @source_files
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1507
1508
1509
1510
1511
1512
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1507

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @finding_id = args[:finding_id] if args.key?(:finding_id)
  @mode = args[:mode] if args.key?(:mode)
  @source_files = args[:source_files] if args.key?(:source_files)
end