Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFindRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFindRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request parameters specific to FIND sessions, used for discovering vulnerabilities in a codebase.
Instance Attribute Summary collapse
-
#description ⇒ String
Additional context or custom instructions provided by the user to guide the vulnerability analysis.
-
#finding_id ⇒ String
The identifier of a specific finding to verify.
-
#source_files ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFileContent>
A list of source files to provide as context for the scan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1CodeMenderAgentConfigFindRequest
constructor
A new instance of GenaiVertexV1beta1CodeMenderAgentConfigFindRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1CodeMenderAgentConfigFindRequest
Returns a new instance of GenaiVertexV1beta1CodeMenderAgentConfigFindRequest.
1369 1370 1371 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Additional context or custom instructions provided by the user to guide the
vulnerability analysis.
Corresponds to the JSON property description
1355 1356 1357 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1355 def description @description end |
#finding_id ⇒ String
The identifier of a specific finding to verify. This is primarily used in
VERIFY mode to focus the agent's execution-based validation on a single
vulnerability.
Corresponds to the JSON property finding_id
1362 1363 1364 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1362 def finding_id @finding_id end |
#source_files ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFileContent>
A list of source files to provide as context for the scan.
Corresponds to the JSON property source_files
1367 1368 1369 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1367 def source_files @source_files end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1374 1375 1376 1377 1378 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1374 def update!(**args) @description = args[:description] if args.key?(:description) @finding_id = args[:finding_id] if args.key?(:finding_id) @source_files = args[:source_files] if args.key?(:source_files) end |