Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFixRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFixRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request parameters specific to FIX sessions, used for generating and validating security patches.
Instance Attribute Summary collapse
-
#description ⇒ String
Additional context or custom instructions provided by the user to guide the patch generation process.
-
#finding_id ⇒ String
The identifier of the specific security finding to be remediated.
-
#source_files ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFileContent>
A list of source files providing context for the remediation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1CodeMenderAgentConfigFixRequest
constructor
A new instance of GenaiVertexV1beta1CodeMenderAgentConfigFixRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1CodeMenderAgentConfigFixRequest
Returns a new instance of GenaiVertexV1beta1CodeMenderAgentConfigFixRequest.
1755 1756 1757 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1755 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Additional context or custom instructions provided by the user to guide the
patch generation process.
Corresponds to the JSON property description
1741 1742 1743 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1741 def description @description end |
#finding_id ⇒ String
The identifier of the specific security finding to be remediated. This ID maps
to a previously discovered vulnerability.
Corresponds to the JSON property findingId
1747 1748 1749 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1747 def finding_id @finding_id end |
#source_files ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigFileContent>
A list of source files providing context for the remediation. These files are
typically the ones containing the identified vulnerability.
Corresponds to the JSON property sourceFiles
1753 1754 1755 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1753 def source_files @source_files end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1760 1761 1762 1763 1764 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1760 def update!(**args) @description = args[:description] if args.key?(:description) @finding_id = args[:finding_id] if args.key?(:finding_id) @source_files = args[:source_files] if args.key?(:source_files) end |