Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeMenderAgentConfigSessionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The configuration of CodeMender sessions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1CodeMenderAgentConfigSessionConfig

Returns a new instance of GenaiVertexV1beta1CodeMenderAgentConfigSessionConfig.



1438
1439
1440
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_roundsFixnum

The maximum number of interaction rounds the agent is allowed to perform before reaching a timeout. Corresponds to the JSON property max_rounds

Returns:

  • (Fixnum)


1424
1425
1426
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1424

def max_rounds
  @max_rounds
end

#pipeline_modeString

The pipeline mode of a CodeMender session. It can only be used for a find session. Corresponds to the JSON property pipeline_mode

Returns:

  • (String)


1430
1431
1432
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1430

def pipeline_mode
  @pipeline_mode
end

#topologyString

The cognitive architecture or "thinking" topology used by the agent (e.g. " default", "deep"). Corresponds to the JSON property topology

Returns:

  • (String)


1436
1437
1438
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1436

def topology
  @topology
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1443
1444
1445
1446
1447
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1443

def update!(**args)
  @max_rounds = args[:max_rounds] if args.key?(:max_rounds)
  @pipeline_mode = args[:pipeline_mode] if args.key?(:pipeline_mode)
  @topology = args[:topology] if args.key?(:topology)
end