Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ComputerUse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool that can be used by the model to interact with the computer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1ComputerUse

Returns a new instance of GenaiVertexV1beta1ComputerUse.



1595
1596
1597
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disabled_safety_policiesArray<String>

Optional. Disabled safety policies for computer use. Corresponds to the JSON property disabledSafetyPolicies

Returns:

  • (Array<String>)


1577
1578
1579
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1577

def disabled_safety_policies
  @disabled_safety_policies
end

#enable_prompt_injection_detectionBoolean Also known as: enable_prompt_injection_detection?

Whether enable the prompt injection detection check on computer-use request. Corresponds to the JSON property enablePromptInjectionDetection

Returns:

  • (Boolean)


1582
1583
1584
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1582

def enable_prompt_injection_detection
  @enable_prompt_injection_detection
end

#environmentString

The environment being operated. Corresponds to the JSON property environment

Returns:

  • (String)


1588
1589
1590
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1588

def environment
  @environment
end

#excluded_predefined_functionsArray<String>

The list of predefined functions that are excluded from the model call. Corresponds to the JSON property excludedPredefinedFunctions

Returns:

  • (Array<String>)


1593
1594
1595
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1593

def excluded_predefined_functions
  @excluded_predefined_functions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1600
1601
1602
1603
1604
1605
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1600

def update!(**args)
  @disabled_safety_policies = args[:disabled_safety_policies] if args.key?(:disabled_safety_policies)
  @enable_prompt_injection_detection = args[:enable_prompt_injection_detection] if args.key?(:enable_prompt_injection_detection)
  @environment = args[:environment] if args.key?(:environment)
  @excluded_predefined_functions = args[:excluded_predefined_functions] if args.key?(:excluded_predefined_functions)
end