Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ComputerUse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ComputerUse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A tool that can be used by the model to interact with the computer.
Instance Attribute Summary collapse
-
#disabled_safety_policies ⇒ Array<String>
Optional.
-
#enable_prompt_injection_detection ⇒ Boolean
(also: #enable_prompt_injection_detection?)
Whether enable the prompt injection detection check on computer-use request.
-
#environment ⇒ String
The environment being operated.
-
#excluded_predefined_functions ⇒ Array<String>
The list of predefined functions that are excluded from the model call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ComputerUse
constructor
A new instance of GenaiVertexV1beta1ComputerUse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ComputerUse
Returns a new instance of GenaiVertexV1beta1ComputerUse.
1357 1358 1359 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disabled_safety_policies ⇒ Array<String>
Optional. Disabled safety policies for computer use.
Corresponds to the JSON property disabledSafetyPolicies
1339 1340 1341 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1339 def disabled_safety_policies @disabled_safety_policies end |
#enable_prompt_injection_detection ⇒ Boolean Also known as: enable_prompt_injection_detection?
Whether enable the prompt injection detection check on computer-use request.
Corresponds to the JSON property enablePromptInjectionDetection
1344 1345 1346 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1344 def enable_prompt_injection_detection @enable_prompt_injection_detection end |
#environment ⇒ String
The environment being operated.
Corresponds to the JSON property environment
1350 1351 1352 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1350 def environment @environment end |
#excluded_predefined_functions ⇒ Array<String>
The list of predefined functions that are excluded from the model call.
Corresponds to the JSON property excludedPredefinedFunctions
1355 1356 1357 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1355 def excluded_predefined_functions @excluded_predefined_functions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1362 1363 1364 1365 1366 1367 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1362 def update!(**args) @disabled_safety_policies = args[:disabled_safety_policies] if args.key?(:disabled_safety_policies) @enable_prompt_injection_detection = args[:enable_prompt_injection_detection] if args.key?(:enable_prompt_injection_detection) @environment = args[:environment] if args.key?(:environment) @excluded_predefined_functions = args[:excluded_predefined_functions] if args.key?(:excluded_predefined_functions) end |