Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ComputerUse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool that can be used by the model to interact with the computer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1ComputerUse

Returns a new instance of GenaiVertexV1beta1ComputerUse.



1288
1289
1290
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1288

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_prompt_injection_detectionBoolean Also known as: enable_prompt_injection_detection?

Whether enable the prompt injection detection check on computer-use request. Corresponds to the JSON property enablePromptInjectionDetection

Returns:

  • (Boolean)


1275
1276
1277
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1275

def enable_prompt_injection_detection
  @enable_prompt_injection_detection
end

#environmentString

The environment being operated. Corresponds to the JSON property environment

Returns:

  • (String)


1281
1282
1283
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1281

def environment
  @environment
end

#excluded_predefined_functionsArray<String>

The list of predefined functions that are excluded from the model call. Corresponds to the JSON property excludedPredefinedFunctions

Returns:

  • (Array<String>)


1286
1287
1288
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1286

def excluded_predefined_functions
  @excluded_predefined_functions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1293
1294
1295
1296
1297
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1293

def update!(**args)
  @enable_prompt_injection_detection = args[:enable_prompt_injection_detection] if args.key?(:enable_prompt_injection_detection)
  @environment = args[:environment] if args.key?(:environment)
  @excluded_predefined_functions = args[:excluded_predefined_functions] if args.key?(:excluded_predefined_functions)
end