Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ComputerUse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool that can be used by the model to interact with the computer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1ComputerUse

Returns a new instance of GenaiVertexV1beta1ComputerUse.



1464
1465
1466
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#environmentString

The environment being operated. Corresponds to the JSON property environment

Returns:

  • (String)


1457
1458
1459
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1457

def environment
  @environment
end

#excluded_predefined_functionsArray<String>

The list of predefined functions that are excluded from the model call. Corresponds to the JSON property excludedPredefinedFunctions

Returns:

  • (Array<String>)


1462
1463
1464
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1462

def excluded_predefined_functions
  @excluded_predefined_functions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1469
1470
1471
1472
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1469

def update!(**args)
  @environment = args[:environment] if args.key?(:environment)
  @excluded_predefined_functions = args[:excluded_predefined_functions] if args.key?(:excluded_predefined_functions)
end