Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ComputerUse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ComputerUse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A tool that can be used by the model to interact with the computer.
Instance Attribute Summary collapse
-
#environment ⇒ String
The environment being operated.
-
#excluded_predefined_functions ⇒ Array<String>
The list of predefined functions that are excluded from the model call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ComputerUse
constructor
A new instance of GenaiVertexV1beta1ComputerUse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ComputerUse
Returns a new instance of GenaiVertexV1beta1ComputerUse.
1312 1313 1314 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1312 def initialize(**args) update!(**args) end |
Instance Attribute Details
#environment ⇒ String
The environment being operated.
Corresponds to the JSON property environment
1305 1306 1307 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1305 def environment @environment end |
#excluded_predefined_functions ⇒ Array<String>
The list of predefined functions that are excluded from the model call.
Corresponds to the JSON property excluded_predefined_functions
1310 1311 1312 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1310 def excluded_predefined_functions @excluded_predefined_functions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1317 1318 1319 1320 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1317 def update!(**args) @environment = args[:environment] if args.key?(:environment) @excluded_predefined_functions = args[:excluded_predefined_functions] if args.key?(:excluded_predefined_functions) end |