Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CreateInteractionRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CreateInteractionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration parameters for creating an interaction.
Instance Attribute Summary collapse
-
#background ⇒ Boolean
(also: #background?)
Input only.
-
#interaction ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Interaction
Response for InteractionService.CreateInteraction.
-
#store ⇒ Boolean
(also: #store?)
Input only.
-
#stream ⇒ Boolean
(also: #stream?)
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1CreateInteractionRequest
constructor
A new instance of GenaiVertexV1beta1CreateInteractionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1CreateInteractionRequest
Returns a new instance of GenaiVertexV1beta1CreateInteractionRequest.
1549 1550 1551 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1549 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background ⇒ Boolean Also known as: background?
Input only. Whether to run the model interaction in the background.
Corresponds to the JSON property background
1529 1530 1531 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1529 def background @background end |
#interaction ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Interaction
Response for InteractionService.CreateInteraction.
Corresponds to the JSON property interaction
1535 1536 1537 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1535 def interaction @interaction end |
#store ⇒ Boolean Also known as: store?
Input only. Whether to store the response and request for later retrieval.
Corresponds to the JSON property store
1540 1541 1542 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1540 def store @store end |
#stream ⇒ Boolean Also known as: stream?
Input only. Whether the interaction will be streamed.
Corresponds to the JSON property stream
1546 1547 1548 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1546 def stream @stream end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1554 1555 1556 1557 1558 1559 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1554 def update!(**args) @background = args[:background] if args.key?(:background) @interaction = args[:interaction] if args.key?(:interaction) @store = args[:store] if args.key?(:store) @stream = args[:stream] if args.key?(:stream) end |