Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CreateInteractionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration parameters for creating an interaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1CreateInteractionRequest

Returns a new instance of GenaiVertexV1beta1CreateInteractionRequest.



1724
1725
1726
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backgroundBoolean Also known as: background?

Input only. Whether to run the model interaction in the background. Corresponds to the JSON property background

Returns:

  • (Boolean)


1704
1705
1706
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1704

def background
  @background
end

#interactionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Interaction

Response for InteractionService.CreateInteraction. Corresponds to the JSON property interaction



1710
1711
1712
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1710

def interaction
  @interaction
end

#storeBoolean Also known as: store?

Input only. Whether to store the response and request for later retrieval. Corresponds to the JSON property store

Returns:

  • (Boolean)


1715
1716
1717
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1715

def store
  @store
end

#streamBoolean Also known as: stream?

Input only. Whether the interaction will be streamed. Corresponds to the JSON property stream

Returns:

  • (Boolean)


1721
1722
1723
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1721

def stream
  @stream
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1729
1730
1731
1732
1733
1734
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1729

def update!(**args)
  @background = args[:background] if args.key?(:background)
  @interaction = args[:interaction] if args.key?(:interaction)
  @store = args[:store] if args.key?(:store)
  @stream = args[:stream] if args.key?(:stream)
end