Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CreateInteractionRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CreateInteractionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration parameters for creating an interaction.
Instance Attribute Summary collapse
-
#background ⇒ Boolean
(also: #background?)
Input only.
-
#interaction ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Interaction
Response for InteractionService.CreateInteraction.
-
#store ⇒ Boolean
(also: #store?)
Input only.
-
#stream ⇒ Boolean
(also: #stream?)
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1CreateInteractionRequest
constructor
A new instance of GenaiVertexV1beta1CreateInteractionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1CreateInteractionRequest
Returns a new instance of GenaiVertexV1beta1CreateInteractionRequest.
1572 1573 1574 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1572 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background ⇒ Boolean Also known as: background?
Input only. Whether to run the model interaction in the background.
Corresponds to the JSON property background
1552 1553 1554 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1552 def background @background end |
#interaction ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Interaction
Response for InteractionService.CreateInteraction.
Corresponds to the JSON property interaction
1558 1559 1560 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1558 def interaction @interaction end |
#store ⇒ Boolean Also known as: store?
Input only. Whether to store the response and request for later retrieval.
Corresponds to the JSON property store
1563 1564 1565 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1563 def store @store end |
#stream ⇒ Boolean Also known as: stream?
Input only. Whether the interaction will be streamed.
Corresponds to the JSON property stream
1569 1570 1571 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1569 def stream @stream end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1577 1578 1579 1580 1581 1582 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1577 def update!(**args) @background = args[:background] if args.key?(:background) @interaction = args[:interaction] if args.key?(:interaction) @store = args[:store] if args.key?(:store) @stream = args[:stream] if args.key?(:stream) end |