Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1DeepResearchAgentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for the Deep Research agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1DeepResearchAgentConfig

Returns a new instance of GenaiVertexV1beta1DeepResearchAgentConfig.



1705
1706
1707
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1705

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collaborative_planningBoolean Also known as: collaborative_planning?

Enables human-in-the-loop planning for the Deep Research agent. If set to true, the Deep Research agent will provide a research plan in its response. The agent will then proceed only if the user confirms the plan in the next turn. Corresponds to the JSON property collaborative_planning

Returns:

  • (Boolean)


1686
1687
1688
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1686

def collaborative_planning
  @collaborative_planning
end

#enable_bigquery_toolBoolean Also known as: enable_bigquery_tool?

Enables bigquery tool for the Deep Research agent. Corresponds to the JSON property enable_bigquery_tool

Returns:

  • (Boolean)


1692
1693
1694
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1692

def enable_bigquery_tool
  @enable_bigquery_tool
end

#thinking_summariesString

Whether to include thought summaries in the response. Corresponds to the JSON property thinking_summaries

Returns:

  • (String)


1698
1699
1700
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1698

def thinking_summaries
  @thinking_summaries
end

#visualizationString

Whether to include visualizations in the response. Corresponds to the JSON property visualization

Returns:

  • (String)


1703
1704
1705
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1703

def visualization
  @visualization
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1710
1711
1712
1713
1714
1715
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1710

def update!(**args)
  @collaborative_planning = args[:collaborative_planning] if args.key?(:collaborative_planning)
  @enable_bigquery_tool = args[:enable_bigquery_tool] if args.key?(:enable_bigquery_tool)
  @thinking_summaries = args[:thinking_summaries] if args.key?(:thinking_summaries)
  @visualization = args[:visualization] if args.key?(:visualization)
end