Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1DeepResearchAgentConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1DeepResearchAgentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for the Deep Research agent.
Instance Attribute Summary collapse
-
#collaborative_planning ⇒ Boolean
(also: #collaborative_planning?)
Enables human-in-the-loop planning for the Deep Research agent.
-
#thinking_summaries ⇒ String
Whether to include thought summaries in the response.
-
#visualization ⇒ String
Whether to include visualizations in the response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1DeepResearchAgentConfig
constructor
A new instance of GenaiVertexV1beta1DeepResearchAgentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1DeepResearchAgentConfig
Returns a new instance of GenaiVertexV1beta1DeepResearchAgentConfig.
1607 1608 1609 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collaborative_planning ⇒ Boolean Also known as: collaborative_planning?
Enables human-in-the-loop planning for the Deep Research agent. If set to true,
the Deep Research agent will provide a research plan in its response. The
agent will then proceed only if the user confirms the plan in the next turn.
Corresponds to the JSON property collaborative_planning
1594 1595 1596 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1594 def collaborative_planning @collaborative_planning end |
#thinking_summaries ⇒ String
Whether to include thought summaries in the response.
Corresponds to the JSON property thinking_summaries
1600 1601 1602 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1600 def thinking_summaries @thinking_summaries end |
#visualization ⇒ String
Whether to include visualizations in the response.
Corresponds to the JSON property visualization
1605 1606 1607 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1605 def visualization @visualization end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1612 1613 1614 1615 1616 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1612 def update!(**args) @collaborative_planning = args[:collaborative_planning] if args.key?(:collaborative_planning) @thinking_summaries = args[:thinking_summaries] if args.key?(:thinking_summaries) @visualization = args[:visualization] if args.key?(:visualization) end |