Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1DynamicAgentConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1DynamicAgentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for dynamic agents.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1DynamicAgentConfig
constructor
A new instance of GenaiVertexV1beta1DynamicAgentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1DynamicAgentConfig
Returns a new instance of GenaiVertexV1beta1DynamicAgentConfig.
1693 1694 1695 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property config
1691 1692 1693 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1691 def config @config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1698 1699 1700 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1698 def update!(**args) @config = args[:config] if args.key?(:config) end |