Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a single field in a struct.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1Field

Returns a new instance of GenaiVertexV1beta1Field.



2086
2087
2088
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Corresponds to the JSON property name

Returns:

  • (String)


2076
2077
2078
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2076

def name
  @name
end

#valueGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error. Corresponds to the JSON property value



2084
2085
2086
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2084

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2091
2092
2093
2094
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2091

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end