Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileCitation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileCitation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A file citation annotation.
Instance Attribute Summary collapse
-
#custom_metadata ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#document_uri ⇒ String
The URI of the file.
-
#file_name ⇒ String
The name of the file.
-
#media_id ⇒ String
Media ID in-case of image citations, if applicable.
-
#page_number ⇒ Fixnum
Page number of the cited document, if applicable.
-
#source ⇒ String
Source attributed for a portion of the text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FileCitation
constructor
A new instance of GenaiVertexV1beta1FileCitation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FileCitation
Returns a new instance of GenaiVertexV1beta1FileCitation.
1957 1958 1959 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1957 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_metadata ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property customMetadata
1930 1931 1932 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1930 def @custom_metadata end |
#document_uri ⇒ String
The URI of the file.
Corresponds to the JSON property documentUri
1935 1936 1937 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1935 def document_uri @document_uri end |
#file_name ⇒ String
The name of the file.
Corresponds to the JSON property fileName
1940 1941 1942 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1940 def file_name @file_name end |
#media_id ⇒ String
Media ID in-case of image citations, if applicable.
Corresponds to the JSON property mediaId
1945 1946 1947 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1945 def media_id @media_id end |
#page_number ⇒ Fixnum
Page number of the cited document, if applicable.
Corresponds to the JSON property pageNumber
1950 1951 1952 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1950 def page_number @page_number end |
#source ⇒ String
Source attributed for a portion of the text.
Corresponds to the JSON property source
1955 1956 1957 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1955 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1962 1963 1964 1965 1966 1967 1968 1969 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1962 def update!(**args) @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata) @document_uri = args[:document_uri] if args.key?(:document_uri) @file_name = args[:file_name] if args.key?(:file_name) @media_id = args[:media_id] if args.key?(:media_id) @page_number = args[:page_number] if args.key?(:page_number) @source = args[:source] if args.key?(:source) end |