Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileCitation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileCitation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A file citation annotation.
Instance Attribute Summary collapse
-
#custom_metadata ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#document_uri ⇒ String
The URI of the file.
-
#file_name ⇒ String
The name of the file.
-
#media_id ⇒ String
Media ID in-case of image citations, if applicable.
-
#page_number ⇒ Fixnum
Page number of the cited document, if applicable.
-
#source ⇒ String
Source attributed for a portion of the text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FileCitation
constructor
A new instance of GenaiVertexV1beta1FileCitation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FileCitation
Returns a new instance of GenaiVertexV1beta1FileCitation.
1782 1783 1784 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1782 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_metadata ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property custom_metadata
1755 1756 1757 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1755 def @custom_metadata end |
#document_uri ⇒ String
The URI of the file.
Corresponds to the JSON property document_uri
1760 1761 1762 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1760 def document_uri @document_uri end |
#file_name ⇒ String
The name of the file.
Corresponds to the JSON property file_name
1765 1766 1767 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1765 def file_name @file_name end |
#media_id ⇒ String
Media ID in-case of image citations, if applicable.
Corresponds to the JSON property media_id
1770 1771 1772 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1770 def media_id @media_id end |
#page_number ⇒ Fixnum
Page number of the cited document, if applicable.
Corresponds to the JSON property page_number
1775 1776 1777 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1775 def page_number @page_number end |
#source ⇒ String
Source attributed for a portion of the text.
Corresponds to the JSON property source
1780 1781 1782 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1780 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1787 def update!(**args) @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata) @document_uri = args[:document_uri] if args.key?(:document_uri) @file_name = args[:file_name] if args.key?(:file_name) @media_id = args[:media_id] if args.key?(:media_id) @page_number = args[:page_number] if args.key?(:page_number) @source = args[:source] if args.key?(:source) end |