Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearch
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A tool that can be used by the model to search files.
Instance Attribute Summary collapse
-
#file_search_store_names ⇒ Array<String>
The file search store names to search.
-
#metadata_filter ⇒ String
Metadata filter to apply to the semantic retrieval documents and chunks.
-
#top_k ⇒ Fixnum
The number of semantic retrieval chunks to retrieve.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FileSearch
constructor
A new instance of GenaiVertexV1beta1FileSearch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FileSearch
Returns a new instance of GenaiVertexV1beta1FileSearch.
2166 2167 2168 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2166 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_search_store_names ⇒ Array<String>
The file search store names to search.
Corresponds to the JSON property fileSearchStoreNames
2154 2155 2156 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2154 def file_search_store_names @file_search_store_names end |
#metadata_filter ⇒ String
Metadata filter to apply to the semantic retrieval documents and chunks.
Corresponds to the JSON property metadataFilter
2159 2160 2161 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2159 def @metadata_filter end |
#top_k ⇒ Fixnum
The number of semantic retrieval chunks to retrieve.
Corresponds to the JSON property topK
2164 2165 2166 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2164 def top_k @top_k end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2171 2172 2173 2174 2175 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2171 def update!(**args) @file_search_store_names = args[:file_search_store_names] if args.key?(:file_search_store_names) @metadata_filter = args[:metadata_filter] if args.key?(:metadata_filter) @top_k = args[:top_k] if args.key?(:top_k) end |