Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool that can be used by the model to search files.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1FileSearch

Returns a new instance of GenaiVertexV1beta1FileSearch.



2052
2053
2054
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2052

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_search_store_namesArray<String>

The file search store names to search. Corresponds to the JSON property file_search_store_names

Returns:

  • (Array<String>)


2040
2041
2042
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2040

def file_search_store_names
  @file_search_store_names
end

#metadata_filterString

Metadata filter to apply to the semantic retrieval documents and chunks. Corresponds to the JSON property metadata_filter

Returns:

  • (String)


2045
2046
2047
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2045

def 
  @metadata_filter
end

#top_kFixnum

The number of semantic retrieval chunks to retrieve. Corresponds to the JSON property top_k

Returns:

  • (Fixnum)


2050
2051
2052
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2050

def top_k
  @top_k
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2057
2058
2059
2060
2061
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2057

def update!(**args)
  @file_search_store_names = args[:file_search_store_names] if args.key?(:file_search_store_names)
  @metadata_filter = args[:metadata_filter] if args.key?(:metadata_filter)
  @top_k = args[:top_k] if args.key?(:top_k)
end