Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool that can be used by the model to search files.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1FileSearch

Returns a new instance of GenaiVertexV1beta1FileSearch.



1816
1817
1818
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1816

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_search_store_namesArray<String>

The file search store names to search. Corresponds to the JSON property file_search_store_names

Returns:

  • (Array<String>)


1804
1805
1806
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1804

def file_search_store_names
  @file_search_store_names
end

#metadata_filterString

Metadata filter to apply to the semantic retrieval documents and chunks. Corresponds to the JSON property metadata_filter

Returns:

  • (String)


1809
1810
1811
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1809

def 
  @metadata_filter
end

#top_kFixnum

The number of semantic retrieval chunks to retrieve. Corresponds to the JSON property top_k

Returns:

  • (Fixnum)


1814
1815
1816
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1814

def top_k
  @top_k
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1821
1822
1823
1824
1825
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1821

def update!(**args)
  @file_search_store_names = args[:file_search_store_names] if args.key?(:file_search_store_names)
  @metadata_filter = args[:metadata_filter] if args.key?(:metadata_filter)
  @top_k = args[:top_k] if args.key?(:top_k)
end