Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Function

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool that can be used by the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1Function

Returns a new instance of GenaiVertexV1beta1Function.



2205
2206
2207
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2205

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A description of the function. Corresponds to the JSON property description

Returns:

  • (String)


2190
2191
2192
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2190

def description
  @description
end

#nameString

The name of the function. Corresponds to the JSON property name

Returns:

  • (String)


2195
2196
2197
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2195

def name
  @name
end

#parametersGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error. Corresponds to the JSON property parameters



2203
2204
2205
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2203

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2210
2211
2212
2213
2214
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2210

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
end