Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Function
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Function
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A tool that can be used by the model.
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the function.
-
#name ⇒ String
The name of the function.
-
#parameters ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value
Valuerepresents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1Function
constructor
A new instance of GenaiVertexV1beta1Function.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1Function
Returns a new instance of GenaiVertexV1beta1Function.
2128 2129 2130 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
A description of the function.
Corresponds to the JSON property description
2113 2114 2115 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2113 def description @description end |
#name ⇒ String
The name of the function.
Corresponds to the JSON property name
2118 2119 2120 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2118 def name @name end |
#parameters ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value
Value represents a dynamically typed value which can be either null, a
number, a string, a boolean, a recursive struct value, or a list of values. A
producer of value is expected to set one of these variants. Absence of any
variant indicates an error.
Corresponds to the JSON property parameters
2126 2127 2128 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2126 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2133 2134 2135 2136 2137 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2133 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) end |