Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Function

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool that can be used by the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1Function

Returns a new instance of GenaiVertexV1beta1Function.



2189
2190
2191
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A description of the function. Corresponds to the JSON property description

Returns:

  • (String)


2174
2175
2176
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2174

def description
  @description
end

#nameString

The name of the function. Corresponds to the JSON property name

Returns:

  • (String)


2179
2180
2181
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2179

def name
  @name
end

#parametersGoogle::Apis::AiplatformV1beta1::GenaiValue

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error. Corresponds to the JSON property parameters



2187
2188
2189
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2187

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2194
2195
2196
2197
2198
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2194

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
end