Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionCallContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionCallContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A function tool call content block.
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionCallContent
constructor
A new instance of GenaiVertexV1beta1FunctionCallContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionCallContent
Returns a new instance of GenaiVertexV1beta1FunctionCallContent.
2216 2217 2218 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2216 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property arguments
2209 2210 2211 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2209 def arguments @arguments end |
#name ⇒ String
Required. The name of the tool to call.
Corresponds to the JSON property name
2214 2215 2216 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2214 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2221 2222 2223 2224 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2221 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @name = args[:name] if args.key?(:name) end |