Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionCallContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionCallContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A function tool call content block.
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionCallContent
constructor
A new instance of GenaiVertexV1beta1FunctionCallContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionCallContent
Returns a new instance of GenaiVertexV1beta1FunctionCallContent.
1980 1981 1982 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1980 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property arguments
1973 1974 1975 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1973 def arguments @arguments end |
#name ⇒ String
Required. The name of the tool to call.
Corresponds to the JSON property name
1978 1979 1980 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1978 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1985 1986 1987 1988 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1985 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @name = args[:name] if args.key?(:name) end |