Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionCallDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionCallDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#name ⇒ String
Corresponds to the JSON property
name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionCallDelta
constructor
A new instance of GenaiVertexV1beta1FunctionCallDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionCallDelta
Returns a new instance of GenaiVertexV1beta1FunctionCallDelta.
2006 2007 2008 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property arguments
1999 2000 2001 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1999 def arguments @arguments end |
#name ⇒ String
Corresponds to the JSON property name
2004 2005 2006 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2004 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2011 2012 2013 2014 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2011 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @name = args[:name] if args.key?(:name) end |