Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A function tool result content block.
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property
contentList. -
#is_error ⇒ Boolean
(also: #is_error?)
Whether the tool call resulted in an error.
-
#name ⇒ String
The name of the tool that was called.
-
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultContent
constructor
A new instance of GenaiVertexV1beta1FunctionResultContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultContent
Returns a new instance of GenaiVertexV1beta1FunctionResultContent.
2074 2075 2076 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2074 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property contentList
2050 2051 2052 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2050 def content_list @content_list end |
#is_error ⇒ Boolean Also known as: is_error?
Whether the tool call resulted in an error.
Corresponds to the JSON property is_error
2055 2056 2057 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2055 def is_error @is_error end |
#name ⇒ String
The name of the tool that was called.
Corresponds to the JSON property name
2061 2062 2063 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2061 def name @name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
2066 2067 2068 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2066 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
2072 2073 2074 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2072 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2079 2080 2081 2082 2083 2084 2085 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2079 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @is_error = args[:is_error] if args.key?(:is_error) @name = args[:name] if args.key?(:name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |