Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
-
#is_error ⇒ Boolean
(also: #is_error?)
Corresponds to the JSON property
isError. -
#name ⇒ String
Corresponds to the JSON property
name. -
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultDelta
constructor
A new instance of GenaiVertexV1beta1FunctionResultDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultDelta
Returns a new instance of GenaiVertexV1beta1FunctionResultDelta.
2469 2470 2471 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2469 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
Corresponds to the JSON property contentList
2445 2446 2447 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2445 def content_list @content_list end |
#is_error ⇒ Boolean Also known as: is_error?
Corresponds to the JSON property isError
2450 2451 2452 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2450 def is_error @is_error end |
#name ⇒ String
Corresponds to the JSON property name
2456 2457 2458 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2456 def name @name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
2461 2462 2463 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2461 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
2467 2468 2469 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2467 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2474 2475 2476 2477 2478 2479 2480 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2474 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @is_error = args[:is_error] if args.key?(:is_error) @name = args[:name] if args.key?(:name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |