Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property
contentList. -
#is_error ⇒ Boolean
(also: #is_error?)
Corresponds to the JSON property
is_error. -
#name ⇒ String
Corresponds to the JSON property
name. -
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultDelta
constructor
A new instance of GenaiVertexV1beta1FunctionResultDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultDelta
Returns a new instance of GenaiVertexV1beta1FunctionResultDelta.
2355 2356 2357 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2355 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property contentList
2331 2332 2333 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2331 def content_list @content_list end |
#is_error ⇒ Boolean Also known as: is_error?
Corresponds to the JSON property is_error
2336 2337 2338 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2336 def is_error @is_error end |
#name ⇒ String
Corresponds to the JSON property name
2342 2343 2344 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2342 def name @name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
2347 2348 2349 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2347 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
2353 2354 2355 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2353 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2360 2361 2362 2363 2364 2365 2366 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2360 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @is_error = args[:is_error] if args.key?(:is_error) @name = args[:name] if args.key?(:name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |