Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property
contentList. -
#is_error ⇒ Boolean
(also: #is_error?)
Corresponds to the JSON property
is_error. -
#name ⇒ String
Corresponds to the JSON property
name. -
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultDelta
constructor
A new instance of GenaiVertexV1beta1FunctionResultDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultDelta
Returns a new instance of GenaiVertexV1beta1FunctionResultDelta.
2119 2120 2121 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property contentList
2095 2096 2097 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2095 def content_list @content_list end |
#is_error ⇒ Boolean Also known as: is_error?
Corresponds to the JSON property is_error
2100 2101 2102 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2100 def is_error @is_error end |
#name ⇒ String
Corresponds to the JSON property name
2106 2107 2108 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2106 def name @name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
2111 2112 2113 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2111 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
2117 2118 2119 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2117 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2124 2125 2126 2127 2128 2129 2130 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2124 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @is_error = args[:is_error] if args.key?(:is_error) @name = args[:name] if args.key?(:name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |