Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Result of a function tool call.
Instance Attribute Summary collapse
-
#is_error ⇒ Boolean
(also: #is_error?)
Whether the tool call resulted in an error.
-
#name ⇒ String
The name of the tool that was called.
-
#result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value
Valuerepresents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultStep
constructor
A new instance of GenaiVertexV1beta1FunctionResultStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultStep
Returns a new instance of GenaiVertexV1beta1FunctionResultStep.
2636 2637 2638 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_error ⇒ Boolean Also known as: is_error?
Whether the tool call resulted in an error.
Corresponds to the JSON property isError
2620 2621 2622 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2620 def is_error @is_error end |
#name ⇒ String
The name of the tool that was called.
Corresponds to the JSON property name
2626 2627 2628 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2626 def name @name end |
#result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value
Value represents a dynamically typed value which can be either null, a
number, a string, a boolean, a recursive struct value, or a list of values. A
producer of value is expected to set one of these variants. Absence of any
variant indicates an error.
Corresponds to the JSON property result
2634 2635 2636 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2634 def result @result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2641 2642 2643 2644 2645 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2641 def update!(**args) @is_error = args[:is_error] if args.key?(:is_error) @name = args[:name] if args.key?(:name) @result = args[:result] if args.key?(:result) end |