Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Result of a function tool call.
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
-
#is_error ⇒ Boolean
(also: #is_error?)
Whether the tool call resulted in an error.
-
#name ⇒ String
The name of the tool that was called.
-
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultStep
constructor
A new instance of GenaiVertexV1beta1FunctionResultStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultStep
Returns a new instance of GenaiVertexV1beta1FunctionResultStep.
2339 2340 2341 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2339 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
Corresponds to the JSON property contentList
2315 2316 2317 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2315 def content_list @content_list end |
#is_error ⇒ Boolean Also known as: is_error?
Whether the tool call resulted in an error.
Corresponds to the JSON property isError
2320 2321 2322 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2320 def is_error @is_error end |
#name ⇒ String
The name of the tool that was called.
Corresponds to the JSON property name
2326 2327 2328 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2326 def name @name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
2331 2332 2333 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2331 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
2337 2338 2339 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2337 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2344 2345 2346 2347 2348 2349 2350 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2344 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @is_error = args[:is_error] if args.key?(:is_error) @name = args[:name] if args.key?(:name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |