Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Result of a function tool call.
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
-
#is_error ⇒ Boolean
(also: #is_error?)
Whether the tool call resulted in an error.
-
#name ⇒ String
The name of the tool that was called.
-
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultStep
constructor
A new instance of GenaiVertexV1beta1FunctionResultStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1FunctionResultStep
Returns a new instance of GenaiVertexV1beta1FunctionResultStep.
2514 2515 2516 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
Corresponds to the JSON property contentList
2490 2491 2492 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2490 def content_list @content_list end |
#is_error ⇒ Boolean Also known as: is_error?
Whether the tool call resulted in an error.
Corresponds to the JSON property isError
2495 2496 2497 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2495 def is_error @is_error end |
#name ⇒ String
The name of the tool that was called.
Corresponds to the JSON property name
2501 2502 2503 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2501 def name @name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
2506 2507 2508 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2506 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
2512 2513 2514 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2512 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2519 2520 2521 2522 2523 2524 2525 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2519 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @is_error = args[:is_error] if args.key?(:is_error) @name = args[:name] if args.key?(:name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |