Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GenerationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration parameters for model interactions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1GenerationConfig

Returns a new instance of GenaiVertexV1beta1GenerationConfig.



2761
2762
2763
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2761

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#image_configGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageConfig

The configuration for image interaction. Corresponds to the JSON property imageConfig



2699
2700
2701
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2699

def image_config
  @image_config
end

#max_output_tokensFixnum

The maximum number of tokens to include in the response. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


2704
2705
2706
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2704

def max_output_tokens
  @max_output_tokens
end

#seedFixnum

Seed used in decoding for reproducibility. Corresponds to the JSON property seed

Returns:

  • (Fixnum)


2709
2710
2711
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2709

def seed
  @seed
end

#speech_configArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1SpeechConfig>

Configuration for speech interaction. Corresponds to the JSON property speechConfig



2714
2715
2716
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2714

def speech_config
  @speech_config
end

#stop_sequencesArray<String>

A list of character sequences that will stop output interaction. Corresponds to the JSON property stopSequences

Returns:

  • (Array<String>)


2719
2720
2721
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2719

def stop_sequences
  @stop_sequences
end

#temperatureFloat

Controls the randomness of the output. Corresponds to the JSON property temperature

Returns:

  • (Float)


2724
2725
2726
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2724

def temperature
  @temperature
end

#thinking_levelString

The level of thought tokens that the model should generate. Corresponds to the JSON property thinkingLevel

Returns:

  • (String)


2729
2730
2731
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2729

def thinking_level
  @thinking_level
end

#thinking_summariesString

Whether to include thought summaries in the response. Corresponds to the JSON property thinkingSummaries

Returns:

  • (String)


2734
2735
2736
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2734

def thinking_summaries
  @thinking_summaries
end

#tool_choice_configGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ToolChoiceConfig

The tool choice configuration containing allowed tools. Corresponds to the JSON property toolChoiceConfig



2739
2740
2741
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2739

def tool_choice_config
  @tool_choice_config
end

#tool_choice_modeString

The mode of the tool choice. Corresponds to the JSON property toolChoiceMode

Returns:

  • (String)


2744
2745
2746
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2744

def tool_choice_mode
  @tool_choice_mode
end

#top_pFloat

The maximum cumulative probability of tokens to consider when sampling. Corresponds to the JSON property topP

Returns:

  • (Float)


2749
2750
2751
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2749

def top_p
  @top_p
end

#transcription_configGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1TranscriptionConfig

Configuration for speech recognition (transcription). Corresponds to the JSON property transcriptionConfig



2754
2755
2756
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2754

def transcription_config
  @transcription_config
end

#video_configGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1VideoConfig

Configuration options for video generation. Corresponds to the JSON property videoConfig



2759
2760
2761
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2759

def video_config
  @video_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2766
2767
2768
2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2766

def update!(**args)
  @image_config = args[:image_config] if args.key?(:image_config)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @seed = args[:seed] if args.key?(:seed)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences)
  @temperature = args[:temperature] if args.key?(:temperature)
  @thinking_level = args[:thinking_level] if args.key?(:thinking_level)
  @thinking_summaries = args[:thinking_summaries] if args.key?(:thinking_summaries)
  @tool_choice_config = args[:tool_choice_config] if args.key?(:tool_choice_config)
  @tool_choice_mode = args[:tool_choice_mode] if args.key?(:tool_choice_mode)
  @top_p = args[:top_p] if args.key?(:top_p)
  @transcription_config = args[:transcription_config] if args.key?(:transcription_config)
  @video_config = args[:video_config] if args.key?(:video_config)
end