Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GenerationConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GenerationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration parameters for model interactions.
Instance Attribute Summary collapse
-
#image_config ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageConfig
The configuration for image interaction.
-
#max_output_tokens ⇒ Fixnum
The maximum number of tokens to include in the response.
-
#seed ⇒ Fixnum
Seed used in decoding for reproducibility.
-
#speech_config ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1SpeechConfig>
Configuration for speech interaction.
-
#stop_sequences ⇒ Array<String>
A list of character sequences that will stop output interaction.
-
#temperature ⇒ Float
Controls the randomness of the output.
-
#thinking_level ⇒ String
The level of thought tokens that the model should generate.
-
#thinking_summaries ⇒ String
Whether to include thought summaries in the response.
-
#tool_choice_config ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ToolChoiceConfig
The tool choice configuration containing allowed tools.
-
#tool_choice_mode ⇒ String
The mode of the tool choice.
-
#top_p ⇒ Float
The maximum cumulative probability of tokens to consider when sampling.
-
#video_config ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1VideoConfig
Configuration options for video generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1GenerationConfig
constructor
A new instance of GenaiVertexV1beta1GenerationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1GenerationConfig
Returns a new instance of GenaiVertexV1beta1GenerationConfig.
2538 2539 2540 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2538 def initialize(**args) update!(**args) end |
Instance Attribute Details
#image_config ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageConfig
The configuration for image interaction.
Corresponds to the JSON property imageConfig
2481 2482 2483 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2481 def image_config @image_config end |
#max_output_tokens ⇒ Fixnum
The maximum number of tokens to include in the response.
Corresponds to the JSON property maxOutputTokens
2486 2487 2488 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2486 def max_output_tokens @max_output_tokens end |
#seed ⇒ Fixnum
Seed used in decoding for reproducibility.
Corresponds to the JSON property seed
2491 2492 2493 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2491 def seed @seed end |
#speech_config ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1SpeechConfig>
Configuration for speech interaction.
Corresponds to the JSON property speechConfig
2496 2497 2498 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2496 def speech_config @speech_config end |
#stop_sequences ⇒ Array<String>
A list of character sequences that will stop output interaction.
Corresponds to the JSON property stopSequences
2501 2502 2503 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2501 def stop_sequences @stop_sequences end |
#temperature ⇒ Float
Controls the randomness of the output.
Corresponds to the JSON property temperature
2506 2507 2508 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2506 def temperature @temperature end |
#thinking_level ⇒ String
The level of thought tokens that the model should generate.
Corresponds to the JSON property thinkingLevel
2511 2512 2513 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2511 def thinking_level @thinking_level end |
#thinking_summaries ⇒ String
Whether to include thought summaries in the response.
Corresponds to the JSON property thinkingSummaries
2516 2517 2518 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2516 def thinking_summaries @thinking_summaries end |
#tool_choice_config ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ToolChoiceConfig
The tool choice configuration containing allowed tools.
Corresponds to the JSON property toolChoiceConfig
2521 2522 2523 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2521 def tool_choice_config @tool_choice_config end |
#tool_choice_mode ⇒ String
The mode of the tool choice.
Corresponds to the JSON property toolChoiceMode
2526 2527 2528 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2526 def tool_choice_mode @tool_choice_mode end |
#top_p ⇒ Float
The maximum cumulative probability of tokens to consider when sampling.
Corresponds to the JSON property topP
2531 2532 2533 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2531 def top_p @top_p end |
#video_config ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1VideoConfig
Configuration options for video generation.
Corresponds to the JSON property videoConfig
2536 2537 2538 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2536 def video_config @video_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2543 def update!(**args) @image_config = args[:image_config] if args.key?(:image_config) @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens) @seed = args[:seed] if args.key?(:seed) @speech_config = args[:speech_config] if args.key?(:speech_config) @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences) @temperature = args[:temperature] if args.key?(:temperature) @thinking_level = args[:thinking_level] if args.key?(:thinking_level) @thinking_summaries = args[:thinking_summaries] if args.key?(:thinking_summaries) @tool_choice_config = args[:tool_choice_config] if args.key?(:tool_choice_config) @tool_choice_mode = args[:tool_choice_mode] if args.key?(:tool_choice_mode) @top_p = args[:top_p] if args.key?(:top_p) @video_config = args[:video_config] if args.key?(:video_config) end |