Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GenerationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration parameters for model interactions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1GenerationConfig

Returns a new instance of GenaiVertexV1beta1GenerationConfig.



2281
2282
2283
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#image_configGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageConfig

The configuration for image interaction. Corresponds to the JSON property image_config



2229
2230
2231
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2229

def image_config
  @image_config
end

#max_output_tokensFixnum

The maximum number of tokens to include in the response. Corresponds to the JSON property max_output_tokens

Returns:

  • (Fixnum)


2234
2235
2236
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2234

def max_output_tokens
  @max_output_tokens
end

#seedFixnum

Seed used in decoding for reproducibility. Corresponds to the JSON property seed

Returns:

  • (Fixnum)


2239
2240
2241
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2239

def seed
  @seed
end

#speech_configArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1SpeechConfig>

Configuration for speech interaction. Corresponds to the JSON property speech_config



2244
2245
2246
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2244

def speech_config
  @speech_config
end

#stop_sequencesArray<String>

A list of character sequences that will stop output interaction. Corresponds to the JSON property stop_sequences

Returns:

  • (Array<String>)


2249
2250
2251
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2249

def stop_sequences
  @stop_sequences
end

#temperatureFloat

Controls the randomness of the output. Corresponds to the JSON property temperature

Returns:

  • (Float)


2254
2255
2256
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2254

def temperature
  @temperature
end

#thinking_levelString

The level of thought tokens that the model should generate. Corresponds to the JSON property thinking_level

Returns:

  • (String)


2259
2260
2261
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2259

def thinking_level
  @thinking_level
end

#thinking_summariesString

Whether to include thought summaries in the response. Corresponds to the JSON property thinking_summaries

Returns:

  • (String)


2264
2265
2266
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2264

def thinking_summaries
  @thinking_summaries
end

#tool_choice_configGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ToolChoiceConfig

The tool choice configuration containing allowed tools. Corresponds to the JSON property toolChoiceConfig



2269
2270
2271
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2269

def tool_choice_config
  @tool_choice_config
end

#tool_choice_modeString

The mode of the tool choice. Corresponds to the JSON property toolChoiceMode

Returns:

  • (String)


2274
2275
2276
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2274

def tool_choice_mode
  @tool_choice_mode
end

#top_pFloat

The maximum cumulative probability of tokens to consider when sampling. Corresponds to the JSON property top_p

Returns:

  • (Float)


2279
2280
2281
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2279

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2286

def update!(**args)
  @image_config = args[:image_config] if args.key?(:image_config)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @seed = args[:seed] if args.key?(:seed)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences)
  @temperature = args[:temperature] if args.key?(:temperature)
  @thinking_level = args[:thinking_level] if args.key?(:thinking_level)
  @thinking_summaries = args[:thinking_summaries] if args.key?(:thinking_summaries)
  @tool_choice_config = args[:tool_choice_config] if args.key?(:tool_choice_config)
  @tool_choice_mode = args[:tool_choice_mode] if args.key?(:tool_choice_mode)
  @top_p = args[:top_p] if args.key?(:top_p)
end