Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMaps
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A tool that can be used by the model to call Google Maps.
Instance Attribute Summary collapse
-
#enable_widget ⇒ Boolean
(also: #enable_widget?)
Whether to return a widget context token in the tool call result of the response.
-
#latitude ⇒ Float
The latitude of the user's location.
-
#longitude ⇒ Float
The longitude of the user's location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMaps
constructor
A new instance of GenaiVertexV1beta1GoogleMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMaps
Returns a new instance of GenaiVertexV1beta1GoogleMaps.
2513 2514 2515 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2513 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_widget ⇒ Boolean Also known as: enable_widget?
Whether to return a widget context token in the tool call result of the
response.
Corresponds to the JSON property enableWidget
2500 2501 2502 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2500 def @enable_widget end |
#latitude ⇒ Float
The latitude of the user's location.
Corresponds to the JSON property latitude
2506 2507 2508 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2506 def latitude @latitude end |
#longitude ⇒ Float
The longitude of the user's location.
Corresponds to the JSON property longitude
2511 2512 2513 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2511 def longitude @longitude end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2518 2519 2520 2521 2522 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2518 def update!(**args) @enable_widget = args[:enable_widget] if args.key?(:enable_widget) @latitude = args[:latitude] if args.key?(:latitude) @longitude = args[:longitude] if args.key?(:longitude) end |