Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMaps

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool that can be used by the model to call Google Maps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMaps

Returns a new instance of GenaiVertexV1beta1GoogleMaps.



2322
2323
2324
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2322

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_widgetBoolean Also known as: enable_widget?

Whether to return a widget context token in the tool call result of the response. Corresponds to the JSON property enable_widget

Returns:

  • (Boolean)


2309
2310
2311
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2309

def enable_widget
  @enable_widget
end

#latitudeFloat

The latitude of the user's location. Corresponds to the JSON property latitude

Returns:

  • (Float)


2315
2316
2317
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2315

def latitude
  @latitude
end

#longitudeFloat

The longitude of the user's location. Corresponds to the JSON property longitude

Returns:

  • (Float)


2320
2321
2322
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2320

def longitude
  @longitude
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2327
2328
2329
2330
2331
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2327

def update!(**args)
  @enable_widget = args[:enable_widget] if args.key?(:enable_widget)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
end