Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMaps
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A tool that can be used by the model to call Google Maps.
Instance Attribute Summary collapse
-
#enable_widget ⇒ Boolean
(also: #enable_widget?)
Whether to return a widget context token in the tool call result of the response.
-
#latitude ⇒ Float
The latitude of the user's location.
-
#longitude ⇒ Float
The longitude of the user's location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMaps
constructor
A new instance of GenaiVertexV1beta1GoogleMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMaps
Returns a new instance of GenaiVertexV1beta1GoogleMaps.
2322 2323 2324 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2322 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_widget ⇒ Boolean Also known as: enable_widget?
Whether to return a widget context token in the tool call result of the
response.
Corresponds to the JSON property enable_widget
2309 2310 2311 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2309 def @enable_widget end |
#latitude ⇒ Float
The latitude of the user's location.
Corresponds to the JSON property latitude
2315 2316 2317 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2315 def latitude @latitude end |
#longitude ⇒ Float
The longitude of the user's location.
Corresponds to the JSON property longitude
2320 2321 2322 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2320 def longitude @longitude end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2327 2328 2329 2330 2331 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2327 def update!(**args) @enable_widget = args[:enable_widget] if args.key?(:enable_widget) @latitude = args[:latitude] if args.key?(:latitude) @longitude = args[:longitude] if args.key?(:longitude) end |