Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The result of the Google Maps.
Instance Attribute Summary collapse
-
#places ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces>
The places that were found.
-
#widget_context_token ⇒ String
Resource name of the Google Maps widget context token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResult
constructor
A new instance of GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResult
Returns a new instance of GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResult.
2462 2463 2464 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2462 def initialize(**args) update!(**args) end |
Instance Attribute Details
#places ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces>
The places that were found.
Corresponds to the JSON property places
2455 2456 2457 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2455 def places @places end |
#widget_context_token ⇒ String
Resource name of the Google Maps widget context token.
Corresponds to the JSON property widget_context_token
2460 2461 2462 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2460 def @widget_context_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2467 2468 2469 2470 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2467 def update!(**args) @places = args[:places] if args.key?(:places) @widget_context_token = args[:widget_context_token] if args.key?(:widget_context_token) end |