Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#name ⇒ String
Title of the place.
-
#place_id ⇒ String
The ID of the place, in
places/place_id`` format. -
#review_snippets ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet>
Snippets of reviews that are used to generate answers about the features of a given place in Google Maps.
-
#url ⇒ String
URI reference of the place.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces
constructor
A new instance of GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces
Returns a new instance of GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces.
2756 2757 2758 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Title of the place.
Corresponds to the JSON property name
2738 2739 2740 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2738 def name @name end |
#place_id ⇒ String
The ID of the place, in places/place_id`format.
Corresponds to the JSON propertyplaceId`
2743 2744 2745 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2743 def place_id @place_id end |
#review_snippets ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet>
Snippets of reviews that are used to generate answers about the features of a
given place in Google Maps.
Corresponds to the JSON property reviewSnippets
2749 2750 2751 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2749 def review_snippets @review_snippets end |
#url ⇒ String
URI reference of the place.
Corresponds to the JSON property url
2754 2755 2756 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2754 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2761 2762 2763 2764 2765 2766 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2761 def update!(**args) @name = args[:name] if args.key?(:name) @place_id = args[:place_id] if args.key?(:place_id) @review_snippets = args[:review_snippets] if args.key?(:review_snippets) @url = args[:url] if args.key?(:url) end |