Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces

Returns a new instance of GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces.



2689
2690
2691
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2689

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Title of the place. Corresponds to the JSON property name

Returns:

  • (String)


2671
2672
2673
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2671

def name
  @name
end

#place_idString

The ID of the place, in places/place_id`format. Corresponds to the JSON propertyplaceId`

Returns:

  • (String)


2676
2677
2678
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2676

def place_id
  @place_id
end

#review_snippetsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet>

Snippets of reviews that are used to generate answers about the features of a given place in Google Maps. Corresponds to the JSON property reviewSnippets



2682
2683
2684
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2682

def review_snippets
  @review_snippets
end

#urlString

URI reference of the place. Corresponds to the JSON property url

Returns:

  • (String)


2687
2688
2689
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2687

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2694
2695
2696
2697
2698
2699
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2694

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @place_id = args[:place_id] if args.key?(:place_id)
  @review_snippets = args[:review_snippets] if args.key?(:review_snippets)
  @url = args[:url] if args.key?(:url)
end