Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces

Returns a new instance of GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces.



2864
2865
2866
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Title of the place. Corresponds to the JSON property name

Returns:

  • (String)


2846
2847
2848
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2846

def name
  @name
end

#place_idString

The ID of the place, in places/place_id`format. Corresponds to the JSON propertyplaceId`

Returns:

  • (String)


2851
2852
2853
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2851

def place_id
  @place_id
end

#review_snippetsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet>

Snippets of reviews that are used to generate answers about the features of a given place in Google Maps. Corresponds to the JSON property reviewSnippets



2857
2858
2859
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2857

def review_snippets
  @review_snippets
end

#urlString

URI reference of the place. Corresponds to the JSON property url

Returns:

  • (String)


2862
2863
2864
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2862

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2869
2870
2871
2872
2873
2874
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2869

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @place_id = args[:place_id] if args.key?(:place_id)
  @review_snippets = args[:review_snippets] if args.key?(:review_snippets)
  @url = args[:url] if args.key?(:url)
end