Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces

Returns a new instance of GenaiVertexV1beta1GoogleMapsResultContentGoogleMapsResultPlaces.



2498
2499
2500
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2498

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Title of the place. Corresponds to the JSON property name

Returns:

  • (String)


2480
2481
2482
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2480

def name
  @name
end

#place_idString

The ID of the place, in places/place_id`format. Corresponds to the JSON propertyplace_id`

Returns:

  • (String)


2485
2486
2487
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2485

def place_id
  @place_id
end

#review_snippetsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet>

Snippets of reviews that are used to generate answers about the features of a given place in Google Maps. Corresponds to the JSON property review_snippets



2491
2492
2493
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2491

def review_snippets
  @review_snippets
end

#urlString

URI reference of the place. Corresponds to the JSON property url

Returns:

  • (String)


2496
2497
2498
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2496

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2503
2504
2505
2506
2507
2508
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2503

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @place_id = args[:place_id] if args.key?(:place_id)
  @review_snippets = args[:review_snippets] if args.key?(:review_snippets)
  @url = args[:url] if args.key?(:url)
end