Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The configuration for image interaction.
Instance Attribute Summary collapse
-
#aspect_ratio ⇒ String
The aspect ratio of the image to generate.
-
#image_size ⇒ String
Specifies the size of generated images.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ImageConfig
constructor
A new instance of GenaiVertexV1beta1ImageConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ImageConfig
Returns a new instance of GenaiVertexV1beta1ImageConfig.
3128 3129 3130 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aspect_ratio ⇒ String
The aspect ratio of the image to generate. Supported aspect ratios: 1:1, 2:3,
3:2, 3:4, 4:3, 9:16, 16:9, 21:9. If not specified, the model will choose a
default aspect ratio based on any reference images provided.
Corresponds to the JSON property aspectRatio
3120 3121 3122 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3120 def aspect_ratio @aspect_ratio end |
#image_size ⇒ String
Specifies the size of generated images. Supported values are 1K, 2K, 4K.
If not specified, the model will use default value 1K.
Corresponds to the JSON property imageSize
3126 3127 3128 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3126 def image_size @image_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3133 3134 3135 3136 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3133 def update!(**args) @aspect_ratio = args[:aspect_ratio] if args.key?(:aspect_ratio) @image_size = args[:image_size] if args.key?(:image_size) end |