Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The configuration for image interaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1ImageConfig

Returns a new instance of GenaiVertexV1beta1ImageConfig.



2870
2871
2872
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2870

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspect_ratioString

The aspect ratio of the image to generate. Supported aspect ratios: 1:1, 2:3, 3:2, 3:4, 4:3, 9:16, 16:9, 21:9. If not specified, the model will choose a default aspect ratio based on any reference images provided. Corresponds to the JSON property aspect_ratio

Returns:

  • (String)


2862
2863
2864
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2862

def aspect_ratio
  @aspect_ratio
end

#image_sizeString

Specifies the size of generated images. Supported values are 1K, 2K, 4K. If not specified, the model will use default value 1K. Corresponds to the JSON property image_size

Returns:

  • (String)


2868
2869
2870
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2868

def image_size
  @image_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2875
2876
2877
2878
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2875

def update!(**args)
  @aspect_ratio = args[:aspect_ratio] if args.key?(:aspect_ratio)
  @image_size = args[:image_size] if args.key?(:image_size)
end