Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Interaction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response for InteractionService.CreateInteraction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1Interaction

Returns a new instance of GenaiVertexV1beta1Interaction.



3647
3648
3649
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3647

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_interactionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1AgentInteraction

Interaction for generating the completion using agents. Corresponds to the JSON property agentInteraction



3483
3484
3485
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3483

def agent_interaction
  @agent_interaction
end

#contentGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content

The content of the response. Corresponds to the JSON property content



3488
3489
3490
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3488

def content
  @content
end

#content_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList

A list of Content. Corresponds to the JSON property contentList



3493
3494
3495
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3493

def content_list
  @content_list
end

#createdString

Required. Output only. The time at which the response was created in ISO 8601 format (YYYY-MM-DDThh:mm:ssZ). Corresponds to the JSON property created

Returns:

  • (String)


3499
3500
3501
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3499

def created
  @created
end

#env_idString

The environment ID for the interaction. Can be 'remote' for default environment. Corresponds to the JSON property envId

Returns:

  • (String)


3505
3506
3507
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3505

def env_id
  @env_id
end

#environment_idString

Output only. The environment ID for the interaction. Only populated if environment config is set in the request. Corresponds to the JSON property environmentId

Returns:

  • (String)


3511
3512
3513
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3511

def environment_id
  @environment_id
end

#idString

Required. Output only. A unique identifier for the interaction completion. Corresponds to the JSON property id

Returns:

  • (String)


3516
3517
3518
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3516

def id
  @id
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata for the request. It is used for billing and reporting only. Label keys and values can be no longer than 63 characters (Unicode codepoints) and can only contain lowercase letters, numeric characters, underscores, and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3525
3526
3527
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3525

def labels
  @labels
end

#local_environmentGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1LocalEnvironmentConfig

Configuration for an environment that lives on the client connection rather than in a server-managed sandbox. When set (via Interaction.local_environment), the agent's filesystem and shell are treated as living on the client: the agent's built-in environment operations (e.g. reading/listing/editing files and running commands) are suspended on the server and yielded back to the client to execute, with their results returned on a subsequent turn. This is mutually exclusive with a server-managed EnvironmentConfig ( remote_environment), since the environment is either on the client or in a server sandbox, never both. This governs only the agent's built-in environment. Client-declared function tools are always executed on the client regardless of this field. Corresponds to the JSON property localEnvironment



3540
3541
3542
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3540

def local_environment
  @local_environment
end

#model_interactionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ModelInteraction

Interaction for generating the completion using models. Corresponds to the JSON property modelInteraction



3545
3546
3547
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3545

def model_interaction
  @model_interaction
end

#outputsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content>

Output only. Responses from the model. Corresponds to the JSON property outputs



3550
3551
3552
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3550

def outputs
  @outputs
end

#previous_interaction_idString

The ID of the previous interaction, if any. Corresponds to the JSON property previousInteractionId

Returns:

  • (String)


3555
3556
3557
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3555

def previous_interaction_id
  @previous_interaction_id
end

#remote_environmentGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1EnvironmentConfig

Configuration for a custom environment. Corresponds to the JSON property remoteEnvironment



3560
3561
3562
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3560

def remote_environment
  @remote_environment
end

#response_formatGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error. Corresponds to the JSON property responseFormat



3568
3569
3570
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3568

def response_format
  @response_format
end

#response_format_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormatList

Corresponds to the JSON property responseFormatList



3573
3574
3575
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3573

def response_format_list
  @response_format_list
end

#response_format_singletonGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormat

Corresponds to the JSON property responseFormatSingleton



3578
3579
3580
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3578

def response_format_singleton
  @response_format_singleton
end

#response_mime_typeString

The mime type of the response. This is required if response_format is set. Corresponds to the JSON property responseMimeType

Returns:

  • (String)


3583
3584
3585
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3583

def response_mime_type
  @response_mime_type
end

#response_modalitiesArray<String>

The requested modalities of the response (TEXT, IMAGE, AUDIO). Corresponds to the JSON property responseModalities

Returns:

  • (Array<String>)


3588
3589
3590
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3588

def response_modalities
  @response_modalities
end

#roleString

Output only. The role of the interaction. Corresponds to the JSON property role

Returns:

  • (String)


3593
3594
3595
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3593

def role
  @role
end

#safety_settingsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1SafetySetting>

Safety settings for the interaction. Corresponds to the JSON property safety_settings



3598
3599
3600
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3598

def safety_settings
  @safety_settings
end

#statusString

Required. Output only. The status of the interaction. Corresponds to the JSON property status

Returns:

  • (String)


3603
3604
3605
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3603

def status
  @status
end

#step_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepList

A list of Steps. Corresponds to the JSON property stepList



3608
3609
3610
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3608

def step_list
  @step_list
end

#stepsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Step>

Required. Output only. The steps that make up the interaction. Corresponds to the JSON property steps



3613
3614
3615
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3613

def steps
  @steps
end

#string_contentString

A string input for the interaction, it will be processed as a single text input. Corresponds to the JSON property stringContent

Returns:

  • (String)


3619
3620
3621
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3619

def string_content
  @string_content
end

#system_instructionString

System instruction for the interaction. Corresponds to the JSON property systemInstruction

Returns:

  • (String)


3624
3625
3626
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3624

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Tool>

A list of tool declarations the model may call during interaction. Corresponds to the JSON property tools



3629
3630
3631
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3629

def tools
  @tools
end

#turn_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1TurnList

A list of Turns. Corresponds to the JSON property turnList



3634
3635
3636
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3634

def turn_list
  @turn_list
end

#updatedString

Required. Output only. The time at which the response was last updated in ISO 8601 format (YYYY-MM-DDThh:mm:ssZ). Corresponds to the JSON property updated

Returns:

  • (String)


3640
3641
3642
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3640

def updated
  @updated
end

#usageGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsage

Statistics on the interaction request's token usage. Corresponds to the JSON property usage



3645
3646
3647
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3645

def usage
  @usage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
3664
3665
3666
3667
3668
3669
3670
3671
3672
3673
3674
3675
3676
3677
3678
3679
3680
3681
3682
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3652

def update!(**args)
  @agent_interaction = args[:agent_interaction] if args.key?(:agent_interaction)
  @content = args[:content] if args.key?(:content)
  @content_list = args[:content_list] if args.key?(:content_list)
  @created = args[:created] if args.key?(:created)
  @env_id = args[:env_id] if args.key?(:env_id)
  @environment_id = args[:environment_id] if args.key?(:environment_id)
  @id = args[:id] if args.key?(:id)
  @labels = args[:labels] if args.key?(:labels)
  @local_environment = args[:local_environment] if args.key?(:local_environment)
  @model_interaction = args[:model_interaction] if args.key?(:model_interaction)
  @outputs = args[:outputs] if args.key?(:outputs)
  @previous_interaction_id = args[:previous_interaction_id] if args.key?(:previous_interaction_id)
  @remote_environment = args[:remote_environment] if args.key?(:remote_environment)
  @response_format = args[:response_format] if args.key?(:response_format)
  @response_format_list = args[:response_format_list] if args.key?(:response_format_list)
  @response_format_singleton = args[:response_format_singleton] if args.key?(:response_format_singleton)
  @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type)
  @response_modalities = args[:response_modalities] if args.key?(:response_modalities)
  @role = args[:role] if args.key?(:role)
  @safety_settings = args[:safety_settings] if args.key?(:safety_settings)
  @status = args[:status] if args.key?(:status)
  @step_list = args[:step_list] if args.key?(:step_list)
  @steps = args[:steps] if args.key?(:steps)
  @string_content = args[:string_content] if args.key?(:string_content)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
  @turn_list = args[:turn_list] if args.key?(:turn_list)
  @updated = args[:updated] if args.key?(:updated)
  @usage = args[:usage] if args.key?(:usage)
end