Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Interaction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response for InteractionService.CreateInteraction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1Interaction

Returns a new instance of GenaiVertexV1beta1Interaction.



3327
3328
3329
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_interactionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1AgentInteraction

Interaction for generating the completion using agents. Corresponds to the JSON property agentInteraction



3192
3193
3194
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3192

def agent_interaction
  @agent_interaction
end

#contentGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content

The content of the response. Corresponds to the JSON property content



3197
3198
3199
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3197

def content
  @content
end

#content_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList

A list of Content. Corresponds to the JSON property contentList



3202
3203
3204
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3202

def content_list
  @content_list
end

#createdString

Required. Output only. The time at which the response was created in ISO 8601 format (YYYY-MM-DDThh:mm:ssZ). Corresponds to the JSON property created

Returns:

  • (String)


3208
3209
3210
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3208

def created
  @created
end

#env_idString

The environment ID for the interaction. Can be 'remote' for default environment. Corresponds to the JSON property envId

Returns:

  • (String)


3214
3215
3216
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3214

def env_id
  @env_id
end

#environment_idString

Output only. The environment ID for the interaction. Only populated if environment config is set in the request. Corresponds to the JSON property environmentId

Returns:

  • (String)


3220
3221
3222
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3220

def environment_id
  @environment_id
end

#idString

Required. Output only. A unique identifier for the interaction completion. Corresponds to the JSON property id

Returns:

  • (String)


3225
3226
3227
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3225

def id
  @id
end

#model_interactionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ModelInteraction

Interaction for generating the completion using models. Corresponds to the JSON property modelInteraction



3230
3231
3232
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3230

def model_interaction
  @model_interaction
end

#outputsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content>

Output only. Responses from the model. Corresponds to the JSON property outputs



3235
3236
3237
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3235

def outputs
  @outputs
end

#previous_interaction_idString

The ID of the previous interaction, if any. Corresponds to the JSON property previousInteractionId

Returns:

  • (String)


3240
3241
3242
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3240

def previous_interaction_id
  @previous_interaction_id
end

#remote_environmentGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1EnvironmentConfig

Configuration for a custom environment. Corresponds to the JSON property remoteEnvironment



3245
3246
3247
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3245

def remote_environment
  @remote_environment
end

#response_formatGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error. Corresponds to the JSON property responseFormat



3253
3254
3255
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3253

def response_format
  @response_format
end

#response_format_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormatList

Corresponds to the JSON property responseFormatList



3258
3259
3260
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3258

def response_format_list
  @response_format_list
end

#response_format_singletonGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormat

Corresponds to the JSON property responseFormatSingleton



3263
3264
3265
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3263

def response_format_singleton
  @response_format_singleton
end

#response_mime_typeString

The mime type of the response. This is required if response_format is set. Corresponds to the JSON property responseMimeType

Returns:

  • (String)


3268
3269
3270
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3268

def response_mime_type
  @response_mime_type
end

#response_modalitiesArray<String>

The requested modalities of the response (TEXT, IMAGE, AUDIO). Corresponds to the JSON property responseModalities

Returns:

  • (Array<String>)


3273
3274
3275
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3273

def response_modalities
  @response_modalities
end

#roleString

Output only. The role of the interaction. Corresponds to the JSON property role

Returns:

  • (String)


3278
3279
3280
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3278

def role
  @role
end

#statusString

Required. Output only. The status of the interaction. Corresponds to the JSON property status

Returns:

  • (String)


3283
3284
3285
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3283

def status
  @status
end

#step_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepList

A list of Steps. Corresponds to the JSON property stepList



3288
3289
3290
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3288

def step_list
  @step_list
end

#stepsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Step>

Required. Output only. The steps that make up the interaction. Corresponds to the JSON property steps



3293
3294
3295
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3293

def steps
  @steps
end

#string_contentString

A string input for the interaction, it will be processed as a single text input. Corresponds to the JSON property stringContent

Returns:

  • (String)


3299
3300
3301
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3299

def string_content
  @string_content
end

#system_instructionString

System instruction for the interaction. Corresponds to the JSON property systemInstruction

Returns:

  • (String)


3304
3305
3306
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3304

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Tool>

A list of tool declarations the model may call during interaction. Corresponds to the JSON property tools



3309
3310
3311
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3309

def tools
  @tools
end

#turn_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1TurnList

A list of Turns. Corresponds to the JSON property turnList



3314
3315
3316
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3314

def turn_list
  @turn_list
end

#updatedString

Required. Output only. The time at which the response was last updated in ISO 8601 format (YYYY-MM-DDThh:mm:ssZ). Corresponds to the JSON property updated

Returns:

  • (String)


3320
3321
3322
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3320

def updated
  @updated
end

#usageGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsage

Statistics on the interaction request's token usage. Corresponds to the JSON property usage



3325
3326
3327
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3325

def usage
  @usage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3332

def update!(**args)
  @agent_interaction = args[:agent_interaction] if args.key?(:agent_interaction)
  @content = args[:content] if args.key?(:content)
  @content_list = args[:content_list] if args.key?(:content_list)
  @created = args[:created] if args.key?(:created)
  @env_id = args[:env_id] if args.key?(:env_id)
  @environment_id = args[:environment_id] if args.key?(:environment_id)
  @id = args[:id] if args.key?(:id)
  @model_interaction = args[:model_interaction] if args.key?(:model_interaction)
  @outputs = args[:outputs] if args.key?(:outputs)
  @previous_interaction_id = args[:previous_interaction_id] if args.key?(:previous_interaction_id)
  @remote_environment = args[:remote_environment] if args.key?(:remote_environment)
  @response_format = args[:response_format] if args.key?(:response_format)
  @response_format_list = args[:response_format_list] if args.key?(:response_format_list)
  @response_format_singleton = args[:response_format_singleton] if args.key?(:response_format_singleton)
  @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type)
  @response_modalities = args[:response_modalities] if args.key?(:response_modalities)
  @role = args[:role] if args.key?(:role)
  @status = args[:status] if args.key?(:status)
  @step_list = args[:step_list] if args.key?(:step_list)
  @steps = args[:steps] if args.key?(:steps)
  @string_content = args[:string_content] if args.key?(:string_content)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
  @turn_list = args[:turn_list] if args.key?(:turn_list)
  @updated = args[:updated] if args.key?(:updated)
  @usage = args[:usage] if args.key?(:usage)
end