Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Interaction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response for InteractionService.CreateInteraction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1Interaction

Returns a new instance of GenaiVertexV1beta1Interaction.



3502
3503
3504
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_interactionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1AgentInteraction

Interaction for generating the completion using agents. Corresponds to the JSON property agentInteraction



3367
3368
3369
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3367

def agent_interaction
  @agent_interaction
end

#contentGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content

The content of the response. Corresponds to the JSON property content



3372
3373
3374
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3372

def content
  @content
end

#content_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList

A list of Content. Corresponds to the JSON property contentList



3377
3378
3379
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3377

def content_list
  @content_list
end

#createdString

Required. Output only. The time at which the response was created in ISO 8601 format (YYYY-MM-DDThh:mm:ssZ). Corresponds to the JSON property created

Returns:

  • (String)


3383
3384
3385
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3383

def created
  @created
end

#env_idString

The environment ID for the interaction. Can be 'remote' for default environment. Corresponds to the JSON property envId

Returns:

  • (String)


3389
3390
3391
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3389

def env_id
  @env_id
end

#environment_idString

Output only. The environment ID for the interaction. Only populated if environment config is set in the request. Corresponds to the JSON property environmentId

Returns:

  • (String)


3395
3396
3397
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3395

def environment_id
  @environment_id
end

#idString

Required. Output only. A unique identifier for the interaction completion. Corresponds to the JSON property id

Returns:

  • (String)


3400
3401
3402
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3400

def id
  @id
end

#model_interactionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ModelInteraction

Interaction for generating the completion using models. Corresponds to the JSON property modelInteraction



3405
3406
3407
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3405

def model_interaction
  @model_interaction
end

#outputsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content>

Output only. Responses from the model. Corresponds to the JSON property outputs



3410
3411
3412
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3410

def outputs
  @outputs
end

#previous_interaction_idString

The ID of the previous interaction, if any. Corresponds to the JSON property previousInteractionId

Returns:

  • (String)


3415
3416
3417
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3415

def previous_interaction_id
  @previous_interaction_id
end

#remote_environmentGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1EnvironmentConfig

Configuration for a custom environment. Corresponds to the JSON property remoteEnvironment



3420
3421
3422
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3420

def remote_environment
  @remote_environment
end

#response_formatGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error. Corresponds to the JSON property responseFormat



3428
3429
3430
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3428

def response_format
  @response_format
end

#response_format_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormatList

Corresponds to the JSON property responseFormatList



3433
3434
3435
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3433

def response_format_list
  @response_format_list
end

#response_format_singletonGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormat

Corresponds to the JSON property responseFormatSingleton



3438
3439
3440
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3438

def response_format_singleton
  @response_format_singleton
end

#response_mime_typeString

The mime type of the response. This is required if response_format is set. Corresponds to the JSON property responseMimeType

Returns:

  • (String)


3443
3444
3445
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3443

def response_mime_type
  @response_mime_type
end

#response_modalitiesArray<String>

The requested modalities of the response (TEXT, IMAGE, AUDIO). Corresponds to the JSON property responseModalities

Returns:

  • (Array<String>)


3448
3449
3450
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3448

def response_modalities
  @response_modalities
end

#roleString

Output only. The role of the interaction. Corresponds to the JSON property role

Returns:

  • (String)


3453
3454
3455
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3453

def role
  @role
end

#statusString

Required. Output only. The status of the interaction. Corresponds to the JSON property status

Returns:

  • (String)


3458
3459
3460
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3458

def status
  @status
end

#step_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepList

A list of Steps. Corresponds to the JSON property stepList



3463
3464
3465
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3463

def step_list
  @step_list
end

#stepsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Step>

Required. Output only. The steps that make up the interaction. Corresponds to the JSON property steps



3468
3469
3470
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3468

def steps
  @steps
end

#string_contentString

A string input for the interaction, it will be processed as a single text input. Corresponds to the JSON property stringContent

Returns:

  • (String)


3474
3475
3476
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3474

def string_content
  @string_content
end

#system_instructionString

System instruction for the interaction. Corresponds to the JSON property systemInstruction

Returns:

  • (String)


3479
3480
3481
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3479

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Tool>

A list of tool declarations the model may call during interaction. Corresponds to the JSON property tools



3484
3485
3486
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3484

def tools
  @tools
end

#turn_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1TurnList

A list of Turns. Corresponds to the JSON property turnList



3489
3490
3491
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3489

def turn_list
  @turn_list
end

#updatedString

Required. Output only. The time at which the response was last updated in ISO 8601 format (YYYY-MM-DDThh:mm:ssZ). Corresponds to the JSON property updated

Returns:

  • (String)


3495
3496
3497
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3495

def updated
  @updated
end

#usageGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsage

Statistics on the interaction request's token usage. Corresponds to the JSON property usage



3500
3501
3502
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3500

def usage
  @usage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3507

def update!(**args)
  @agent_interaction = args[:agent_interaction] if args.key?(:agent_interaction)
  @content = args[:content] if args.key?(:content)
  @content_list = args[:content_list] if args.key?(:content_list)
  @created = args[:created] if args.key?(:created)
  @env_id = args[:env_id] if args.key?(:env_id)
  @environment_id = args[:environment_id] if args.key?(:environment_id)
  @id = args[:id] if args.key?(:id)
  @model_interaction = args[:model_interaction] if args.key?(:model_interaction)
  @outputs = args[:outputs] if args.key?(:outputs)
  @previous_interaction_id = args[:previous_interaction_id] if args.key?(:previous_interaction_id)
  @remote_environment = args[:remote_environment] if args.key?(:remote_environment)
  @response_format = args[:response_format] if args.key?(:response_format)
  @response_format_list = args[:response_format_list] if args.key?(:response_format_list)
  @response_format_singleton = args[:response_format_singleton] if args.key?(:response_format_singleton)
  @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type)
  @response_modalities = args[:response_modalities] if args.key?(:response_modalities)
  @role = args[:role] if args.key?(:role)
  @status = args[:status] if args.key?(:status)
  @step_list = args[:step_list] if args.key?(:step_list)
  @steps = args[:steps] if args.key?(:steps)
  @string_content = args[:string_content] if args.key?(:string_content)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
  @turn_list = args[:turn_list] if args.key?(:turn_list)
  @updated = args[:updated] if args.key?(:updated)
  @usage = args[:usage] if args.key?(:usage)
end