Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Interaction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response for InteractionService.CreateInteraction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1Interaction

Returns a new instance of GenaiVertexV1beta1Interaction.



3372
3373
3374
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_interactionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1AgentInteraction

Interaction for generating the completion using agents. Corresponds to the JSON property agentInteraction



3237
3238
3239
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3237

def agent_interaction
  @agent_interaction
end

#contentGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content

The content of the response. Corresponds to the JSON property content



3242
3243
3244
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3242

def content
  @content
end

#content_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList

A list of Content. Corresponds to the JSON property contentList



3247
3248
3249
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3247

def content_list
  @content_list
end

#createdString

Required. Output only. The time at which the response was created in ISO 8601 format (YYYY-MM-DDThh:mm:ssZ). Corresponds to the JSON property created

Returns:

  • (String)


3253
3254
3255
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3253

def created
  @created
end

#env_idString

The environment ID for the interaction. Can be 'remote' for default environment. Corresponds to the JSON property env_id

Returns:

  • (String)


3259
3260
3261
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3259

def env_id
  @env_id
end

#environment_idString

Output only. The environment ID for the interaction. Only populated if environment config is set in the request. Corresponds to the JSON property environment_id

Returns:

  • (String)


3265
3266
3267
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3265

def environment_id
  @environment_id
end

#idString

Required. Output only. A unique identifier for the interaction completion. Corresponds to the JSON property id

Returns:

  • (String)


3270
3271
3272
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3270

def id
  @id
end

#model_interactionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ModelInteraction

Interaction for generating the completion using models. Corresponds to the JSON property modelInteraction



3275
3276
3277
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3275

def model_interaction
  @model_interaction
end

#outputsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content>

Output only. Responses from the model. Corresponds to the JSON property outputs



3280
3281
3282
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3280

def outputs
  @outputs
end

#previous_interaction_idString

The ID of the previous interaction, if any. Corresponds to the JSON property previous_interaction_id

Returns:

  • (String)


3285
3286
3287
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3285

def previous_interaction_id
  @previous_interaction_id
end

#remote_environmentGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1EnvironmentConfig

Configuration for a custom environment. Corresponds to the JSON property remoteEnvironment



3290
3291
3292
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3290

def remote_environment
  @remote_environment
end

#response_formatGoogle::Apis::AiplatformV1beta1::GenaiValue

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error. Corresponds to the JSON property response_format



3308
3309
3310
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3308

def response_format
  @response_format
end

#response_format_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormatList

Corresponds to the JSON property responseFormatList



3295
3296
3297
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3295

def response_format_list
  @response_format_list
end

#response_format_singletonGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormat

Corresponds to the JSON property responseFormatSingleton



3300
3301
3302
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3300

def response_format_singleton
  @response_format_singleton
end

#response_mime_typeString

The mime type of the response. This is required if response_format is set. Corresponds to the JSON property response_mime_type

Returns:

  • (String)


3313
3314
3315
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3313

def response_mime_type
  @response_mime_type
end

#response_modalitiesArray<String>

The requested modalities of the response (TEXT, IMAGE, AUDIO). Corresponds to the JSON property response_modalities

Returns:

  • (Array<String>)


3318
3319
3320
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3318

def response_modalities
  @response_modalities
end

#roleString

Output only. The role of the interaction. Corresponds to the JSON property role

Returns:

  • (String)


3323
3324
3325
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3323

def role
  @role
end

#statusString

Required. Output only. The status of the interaction. Corresponds to the JSON property status

Returns:

  • (String)


3328
3329
3330
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3328

def status
  @status
end

#step_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepList

A list of Steps. Corresponds to the JSON property stepList



3333
3334
3335
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3333

def step_list
  @step_list
end

#stepsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Step>

Required. Output only. The steps that make up the interaction. Corresponds to the JSON property steps



3338
3339
3340
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3338

def steps
  @steps
end

#string_contentString

A string input for the interaction, it will be processed as a single text input. Corresponds to the JSON property stringContent

Returns:

  • (String)


3344
3345
3346
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3344

def string_content
  @string_content
end

#system_instructionString

System instruction for the interaction. Corresponds to the JSON property system_instruction

Returns:

  • (String)


3349
3350
3351
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3349

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Tool>

A list of tool declarations the model may call during interaction. Corresponds to the JSON property tools



3354
3355
3356
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3354

def tools
  @tools
end

#turn_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1TurnList

A list of Turns. Corresponds to the JSON property turnList



3359
3360
3361
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3359

def turn_list
  @turn_list
end

#updatedString

Required. Output only. The time at which the response was last updated in ISO 8601 format (YYYY-MM-DDThh:mm:ssZ). Corresponds to the JSON property updated

Returns:

  • (String)


3365
3366
3367
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3365

def updated
  @updated
end

#usageGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsage

Statistics on the interaction request's token usage. Corresponds to the JSON property usage



3370
3371
3372
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3370

def usage
  @usage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3377
3378
3379
3380
3381
3382
3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3377

def update!(**args)
  @agent_interaction = args[:agent_interaction] if args.key?(:agent_interaction)
  @content = args[:content] if args.key?(:content)
  @content_list = args[:content_list] if args.key?(:content_list)
  @created = args[:created] if args.key?(:created)
  @env_id = args[:env_id] if args.key?(:env_id)
  @environment_id = args[:environment_id] if args.key?(:environment_id)
  @id = args[:id] if args.key?(:id)
  @model_interaction = args[:model_interaction] if args.key?(:model_interaction)
  @outputs = args[:outputs] if args.key?(:outputs)
  @previous_interaction_id = args[:previous_interaction_id] if args.key?(:previous_interaction_id)
  @remote_environment = args[:remote_environment] if args.key?(:remote_environment)
  @response_format_list = args[:response_format_list] if args.key?(:response_format_list)
  @response_format_singleton = args[:response_format_singleton] if args.key?(:response_format_singleton)
  @response_format = args[:response_format] if args.key?(:response_format)
  @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type)
  @response_modalities = args[:response_modalities] if args.key?(:response_modalities)
  @role = args[:role] if args.key?(:role)
  @status = args[:status] if args.key?(:status)
  @step_list = args[:step_list] if args.key?(:step_list)
  @steps = args[:steps] if args.key?(:steps)
  @string_content = args[:string_content] if args.key?(:string_content)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
  @turn_list = args[:turn_list] if args.key?(:turn_list)
  @updated = args[:updated] if args.key?(:updated)
  @usage = args[:usage] if args.key?(:usage)
end