Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStreamingEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStreamingEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#content_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentDelta
The content block delta data, used for content.delta events.
-
#content_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStart
The content block start data, used for content.start events.
-
#content_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStop
The content block stop data, used for content.stop events.
-
#error_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ErrorEvent
The error event data, used for error events.
-
#event_id ⇒ String
The event_id token to be used to resume the interaction stream, from this event.
-
#interaction_complete_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompleteEvent
The interaction data, used for interaction.complete events.
-
#interaction_completed_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompletedSseEvent
The interaction data, used for interaction.completed events.
-
#interaction_created_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCreatedSseEvent
The interaction data, used for interaction.created events.
-
#interaction_start_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStartEvent
The interaction data, used for interaction.start events.
-
#interaction_status_update ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStatusUpdate
The interaction status data, used for interaction.status_update events.
-
#metadata ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StreamMetadata
Optional metadata accompanying ANY streamed event.
-
#step_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepDelta
The step delta data, used for step.delta events.
-
#step_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStart
The step start data, used for step.start events.
-
#step_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStop
The step stop data, used for step.stop events.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1InteractionStreamingEvent
constructor
A new instance of GenaiVertexV1beta1InteractionStreamingEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1InteractionStreamingEvent
Returns a new instance of GenaiVertexV1beta1InteractionStreamingEvent.
3871 3872 3873 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentDelta
The content block delta data, used for content.delta events. Legacy content-
based streaming event, used when steps are disabled.
Corresponds to the JSON property contentDelta
3794 3795 3796 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3794 def content_delta @content_delta end |
#content_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStart
The content block start data, used for content.start events. Legacy content-
based streaming event, used when steps are disabled.
Corresponds to the JSON property contentStart
3800 3801 3802 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3800 def content_start @content_start end |
#content_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStop
The content block stop data, used for content.stop events. Legacy content-
based streaming event, used when steps are disabled.
Corresponds to the JSON property contentStop
3806 3807 3808 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3806 def content_stop @content_stop end |
#error_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ErrorEvent
The error event data, used for error events.
Corresponds to the JSON property errorEvent
3811 3812 3813 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3811 def error_event @error_event end |
#event_id ⇒ String
The event_id token to be used to resume the interaction stream, from this
event.
Corresponds to the JSON property eventId
3817 3818 3819 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3817 def event_id @event_id end |
#interaction_complete_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompleteEvent
The interaction data, used for interaction.complete events. Legacy event, used
when steps are disabled.
Corresponds to the JSON property interactionCompleteEvent
3823 3824 3825 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3823 def interaction_complete_event @interaction_complete_event end |
#interaction_completed_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompletedSseEvent
The interaction data, used for interaction.completed events. Used when steps
are enabled.
Corresponds to the JSON property interactionCompletedEvent
3829 3830 3831 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3829 def interaction_completed_event @interaction_completed_event end |
#interaction_created_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCreatedSseEvent
The interaction data, used for interaction.created events. Used when steps are
enabled.
Corresponds to the JSON property interactionCreatedEvent
3835 3836 3837 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3835 def interaction_created_event @interaction_created_event end |
#interaction_start_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStartEvent
The interaction data, used for interaction.start events. Legacy event, used
when steps are disabled.
Corresponds to the JSON property interactionStartEvent
3841 3842 3843 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3841 def interaction_start_event @interaction_start_event end |
#interaction_status_update ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStatusUpdate
The interaction status data, used for interaction.status_update events.
Corresponds to the JSON property interactionStatusUpdate
3846 3847 3848 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3846 def interaction_status_update @interaction_status_update end |
#metadata ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StreamMetadata
Optional metadata accompanying ANY streamed event.
Corresponds to the JSON property metadata
3851 3852 3853 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3851 def @metadata end |
#step_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepDelta
The step delta data, used for step.delta events. Step-based streaming event,
used when steps are enabled.
Corresponds to the JSON property stepDelta
3857 3858 3859 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3857 def step_delta @step_delta end |
#step_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStart
The step start data, used for step.start events. Step-based streaming event,
used when steps are enabled.
Corresponds to the JSON property stepStart
3863 3864 3865 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3863 def step_start @step_start end |
#step_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStop
The step stop data, used for step.stop events. Step-based streaming event,
used when steps are enabled.
Corresponds to the JSON property stepStop
3869 3870 3871 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3869 def step_stop @step_stop end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3876 3877 3878 3879 3880 3881 3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3876 def update!(**args) @content_delta = args[:content_delta] if args.key?(:content_delta) @content_start = args[:content_start] if args.key?(:content_start) @content_stop = args[:content_stop] if args.key?(:content_stop) @error_event = args[:error_event] if args.key?(:error_event) @event_id = args[:event_id] if args.key?(:event_id) @interaction_complete_event = args[:interaction_complete_event] if args.key?(:interaction_complete_event) @interaction_completed_event = args[:interaction_completed_event] if args.key?(:interaction_completed_event) @interaction_created_event = args[:interaction_created_event] if args.key?(:interaction_created_event) @interaction_start_event = args[:interaction_start_event] if args.key?(:interaction_start_event) @interaction_status_update = args[:interaction_status_update] if args.key?(:interaction_status_update) @metadata = args[:metadata] if args.key?(:metadata) @step_delta = args[:step_delta] if args.key?(:step_delta) @step_start = args[:step_start] if args.key?(:step_start) @step_stop = args[:step_stop] if args.key?(:step_stop) end |