Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStreamingEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStreamingEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#content_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentDelta
The content block delta data, used for content.delta events.
-
#content_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStart
The content block start data, used for content.start events.
-
#content_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStop
The content block stop data, used for content.stop events.
-
#error_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ErrorEvent
The error event data, used for error events.
-
#event_id ⇒ String
The event_id token to be used to resume the interaction stream, from this event.
-
#interaction_complete_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompleteEvent
The interaction data, used for interaction.complete events.
-
#interaction_completed_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompletedSseEvent
The interaction data, used for interaction.completed events.
-
#interaction_created_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCreatedSseEvent
The interaction data, used for interaction.created events.
-
#interaction_start_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStartEvent
The interaction data, used for interaction.start events.
-
#interaction_status_update ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStatusUpdate
The interaction status data, used for interaction.status_update events.
-
#metadata ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StreamMetadata
Optional metadata accompanying ANY streamed event.
-
#step_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepDelta
The step delta data, used for step.delta events.
-
#step_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStart
The step start data, used for step.start events.
-
#step_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStop
The step stop data, used for step.stop events.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1InteractionStreamingEvent
constructor
A new instance of GenaiVertexV1beta1InteractionStreamingEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1InteractionStreamingEvent
Returns a new instance of GenaiVertexV1beta1InteractionStreamingEvent.
3647 3648 3649 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3647 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentDelta
The content block delta data, used for content.delta events. Legacy content-
based streaming event, used when steps are disabled.
Corresponds to the JSON property contentDelta
3570 3571 3572 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3570 def content_delta @content_delta end |
#content_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStart
The content block start data, used for content.start events. Legacy content-
based streaming event, used when steps are disabled.
Corresponds to the JSON property contentStart
3576 3577 3578 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3576 def content_start @content_start end |
#content_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStop
The content block stop data, used for content.stop events. Legacy content-
based streaming event, used when steps are disabled.
Corresponds to the JSON property contentStop
3582 3583 3584 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3582 def content_stop @content_stop end |
#error_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ErrorEvent
The error event data, used for error events.
Corresponds to the JSON property errorEvent
3587 3588 3589 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3587 def error_event @error_event end |
#event_id ⇒ String
The event_id token to be used to resume the interaction stream, from this
event.
Corresponds to the JSON property eventId
3593 3594 3595 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3593 def event_id @event_id end |
#interaction_complete_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompleteEvent
The interaction data, used for interaction.complete events. Legacy event, used
when steps are disabled.
Corresponds to the JSON property interactionCompleteEvent
3599 3600 3601 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3599 def interaction_complete_event @interaction_complete_event end |
#interaction_completed_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompletedSseEvent
The interaction data, used for interaction.completed events. Used when steps
are enabled.
Corresponds to the JSON property interactionCompletedEvent
3605 3606 3607 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3605 def interaction_completed_event @interaction_completed_event end |
#interaction_created_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCreatedSseEvent
The interaction data, used for interaction.created events. Used when steps are
enabled.
Corresponds to the JSON property interactionCreatedEvent
3611 3612 3613 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3611 def interaction_created_event @interaction_created_event end |
#interaction_start_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStartEvent
The interaction data, used for interaction.start events. Legacy event, used
when steps are disabled.
Corresponds to the JSON property interactionStartEvent
3617 3618 3619 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3617 def interaction_start_event @interaction_start_event end |
#interaction_status_update ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStatusUpdate
The interaction status data, used for interaction.status_update events.
Corresponds to the JSON property interactionStatusUpdate
3622 3623 3624 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3622 def interaction_status_update @interaction_status_update end |
#metadata ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StreamMetadata
Optional metadata accompanying ANY streamed event.
Corresponds to the JSON property metadata
3627 3628 3629 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3627 def @metadata end |
#step_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepDelta
The step delta data, used for step.delta events. Step-based streaming event,
used when steps are enabled.
Corresponds to the JSON property stepDelta
3633 3634 3635 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3633 def step_delta @step_delta end |
#step_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStart
The step start data, used for step.start events. Step-based streaming event,
used when steps are enabled.
Corresponds to the JSON property stepStart
3639 3640 3641 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3639 def step_start @step_start end |
#step_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStop
The step stop data, used for step.stop events. Step-based streaming event,
used when steps are enabled.
Corresponds to the JSON property stepStop
3645 3646 3647 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3645 def step_stop @step_stop end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3652 3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 3666 3667 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3652 def update!(**args) @content_delta = args[:content_delta] if args.key?(:content_delta) @content_start = args[:content_start] if args.key?(:content_start) @content_stop = args[:content_stop] if args.key?(:content_stop) @error_event = args[:error_event] if args.key?(:error_event) @event_id = args[:event_id] if args.key?(:event_id) @interaction_complete_event = args[:interaction_complete_event] if args.key?(:interaction_complete_event) @interaction_completed_event = args[:interaction_completed_event] if args.key?(:interaction_completed_event) @interaction_created_event = args[:interaction_created_event] if args.key?(:interaction_created_event) @interaction_start_event = args[:interaction_start_event] if args.key?(:interaction_start_event) @interaction_status_update = args[:interaction_status_update] if args.key?(:interaction_status_update) @metadata = args[:metadata] if args.key?(:metadata) @step_delta = args[:step_delta] if args.key?(:step_delta) @step_start = args[:step_start] if args.key?(:step_start) @step_stop = args[:step_stop] if args.key?(:step_stop) end |