Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStreamingEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStreamingEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#content_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentDelta
The content block delta data, used for content.delta events.
-
#content_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStart
The content block start data, used for content.start events.
-
#content_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStop
The content block stop data, used for content.stop events.
-
#error_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ErrorEvent
The error event data, used for error events.
-
#event_id ⇒ String
The event_id token to be used to resume the interaction stream, from this event.
-
#interaction_complete_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompleteEvent
The interaction data, used for interaction.complete events.
-
#interaction_completed_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompletedSseEvent
The interaction data, used for interaction.completed events.
-
#interaction_created_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCreatedSseEvent
The interaction data, used for interaction.created events.
-
#interaction_start_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStartEvent
The interaction data, used for interaction.start events.
-
#interaction_status_update ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStatusUpdate
The interaction status data, used for interaction.status_update events.
-
#metadata ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StreamMetadata
Optional metadata accompanying ANY streamed event.
-
#step_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepDelta
The step delta data, used for step.delta events.
-
#step_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStart
The step start data, used for step.start events.
-
#step_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStop
The step stop data, used for step.stop events.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1InteractionStreamingEvent
constructor
A new instance of GenaiVertexV1beta1InteractionStreamingEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1InteractionStreamingEvent
Returns a new instance of GenaiVertexV1beta1InteractionStreamingEvent.
3538 3539 3540 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3538 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentDelta
The content block delta data, used for content.delta events.
Corresponds to the JSON property contentDelta
3470 3471 3472 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3470 def content_delta @content_delta end |
#content_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStart
The content block start data, used for content.start events.
Corresponds to the JSON property contentStart
3475 3476 3477 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3475 def content_start @content_start end |
#content_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentStop
The content block stop data, used for content.stop events.
Corresponds to the JSON property contentStop
3480 3481 3482 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3480 def content_stop @content_stop end |
#error_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ErrorEvent
The error event data, used for error events.
Corresponds to the JSON property errorEvent
3485 3486 3487 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3485 def error_event @error_event end |
#event_id ⇒ String
The event_id token to be used to resume the interaction stream, from this
event.
Corresponds to the JSON property eventId
3491 3492 3493 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3491 def event_id @event_id end |
#interaction_complete_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompleteEvent
The interaction data, used for interaction.complete events.
Corresponds to the JSON property interactionCompleteEvent
3496 3497 3498 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3496 def interaction_complete_event @interaction_complete_event end |
#interaction_completed_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCompletedSseEvent
The interaction data, used for interaction.completed events.
Corresponds to the JSON property interactionCompletedEvent
3501 3502 3503 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3501 def interaction_completed_event @interaction_completed_event end |
#interaction_created_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionCreatedSseEvent
The interaction data, used for interaction.created events.
Corresponds to the JSON property interactionCreatedEvent
3506 3507 3508 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3506 def interaction_created_event @interaction_created_event end |
#interaction_start_event ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStartEvent
The interaction data, used for interaction.start events.
Corresponds to the JSON property interactionStartEvent
3511 3512 3513 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3511 def interaction_start_event @interaction_start_event end |
#interaction_status_update ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionStatusUpdate
The interaction status data, used for interaction.status_update events.
Corresponds to the JSON property interactionStatusUpdate
3516 3517 3518 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3516 def interaction_status_update @interaction_status_update end |
#metadata ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StreamMetadata
Optional metadata accompanying ANY streamed event.
Corresponds to the JSON property metadata
3521 3522 3523 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3521 def @metadata end |
#step_delta ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepDelta
The step delta data, used for step.delta events.
Corresponds to the JSON property stepDelta
3526 3527 3528 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3526 def step_delta @step_delta end |
#step_start ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStart
The step start data, used for step.start events.
Corresponds to the JSON property stepStart
3531 3532 3533 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3531 def step_start @step_start end |
#step_stop ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1StepStop
The step stop data, used for step.stop events.
Corresponds to the JSON property stepStop
3536 3537 3538 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3536 def step_stop @step_stop end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3543 def update!(**args) @content_delta = args[:content_delta] if args.key?(:content_delta) @content_start = args[:content_start] if args.key?(:content_start) @content_stop = args[:content_stop] if args.key?(:content_stop) @error_event = args[:error_event] if args.key?(:error_event) @event_id = args[:event_id] if args.key?(:event_id) @interaction_complete_event = args[:interaction_complete_event] if args.key?(:interaction_complete_event) @interaction_completed_event = args[:interaction_completed_event] if args.key?(:interaction_completed_event) @interaction_created_event = args[:interaction_created_event] if args.key?(:interaction_created_event) @interaction_start_event = args[:interaction_start_event] if args.key?(:interaction_start_event) @interaction_status_update = args[:interaction_status_update] if args.key?(:interaction_status_update) @metadata = args[:metadata] if args.key?(:metadata) @step_delta = args[:step_delta] if args.key?(:step_delta) @step_start = args[:step_start] if args.key?(:step_start) @step_stop = args[:step_stop] if args.key?(:step_stop) end |