Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Statistics on the interaction request's token usage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1InteractionUsage

Returns a new instance of GenaiVertexV1beta1InteractionUsage.



3730
3731
3732
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3730

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cached_tokens_by_modalityArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsageModalityTokens>

A breakdown of cached token usage by modality. Corresponds to the JSON property cachedTokensByModality



3677
3678
3679
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3677

def cached_tokens_by_modality
  @cached_tokens_by_modality
end

#grounding_tool_countArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsageGroundingToolCount>

Grounding tool count. Corresponds to the JSON property groundingToolCount



3682
3683
3684
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3682

def grounding_tool_count
  @grounding_tool_count
end

#input_tokens_by_modalityArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsageModalityTokens>

A breakdown of input token usage by modality. Corresponds to the JSON property inputTokensByModality



3687
3688
3689
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3687

def input_tokens_by_modality
  @input_tokens_by_modality
end

#output_tokens_by_modalityArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsageModalityTokens>

A breakdown of output token usage by modality. Corresponds to the JSON property outputTokensByModality



3692
3693
3694
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3692

def output_tokens_by_modality
  @output_tokens_by_modality
end

#tool_use_tokens_by_modalityArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsageModalityTokens>

A breakdown of tool-use token usage by modality. Corresponds to the JSON property toolUseTokensByModality



3697
3698
3699
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3697

def tool_use_tokens_by_modality
  @tool_use_tokens_by_modality
end

#total_cached_tokensFixnum

Number of tokens in the cached part of the prompt (the cached content). Corresponds to the JSON property totalCachedTokens

Returns:

  • (Fixnum)


3702
3703
3704
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3702

def total_cached_tokens
  @total_cached_tokens
end

#total_input_tokensFixnum

Number of tokens in the prompt (context). Corresponds to the JSON property totalInputTokens

Returns:

  • (Fixnum)


3707
3708
3709
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3707

def total_input_tokens
  @total_input_tokens
end

#total_output_tokensFixnum

Total number of tokens across all the generated responses. Corresponds to the JSON property totalOutputTokens

Returns:

  • (Fixnum)


3712
3713
3714
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3712

def total_output_tokens
  @total_output_tokens
end

#total_thought_tokensFixnum

Number of tokens of thoughts for thinking models. Corresponds to the JSON property totalThoughtTokens

Returns:

  • (Fixnum)


3717
3718
3719
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3717

def total_thought_tokens
  @total_thought_tokens
end

#total_tokensFixnum

Total token count for the interaction request (prompt + responses + other internal tokens). Corresponds to the JSON property totalTokens

Returns:

  • (Fixnum)


3723
3724
3725
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3723

def total_tokens
  @total_tokens
end

#total_tool_use_tokensFixnum

Number of tokens present in tool-use prompt(s). Corresponds to the JSON property totalToolUseTokens

Returns:

  • (Fixnum)


3728
3729
3730
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3728

def total_tool_use_tokens
  @total_tool_use_tokens
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
3747
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3735

def update!(**args)
  @cached_tokens_by_modality = args[:cached_tokens_by_modality] if args.key?(:cached_tokens_by_modality)
  @grounding_tool_count = args[:grounding_tool_count] if args.key?(:grounding_tool_count)
  @input_tokens_by_modality = args[:input_tokens_by_modality] if args.key?(:input_tokens_by_modality)
  @output_tokens_by_modality = args[:output_tokens_by_modality] if args.key?(:output_tokens_by_modality)
  @tool_use_tokens_by_modality = args[:tool_use_tokens_by_modality] if args.key?(:tool_use_tokens_by_modality)
  @total_cached_tokens = args[:total_cached_tokens] if args.key?(:total_cached_tokens)
  @total_input_tokens = args[:total_input_tokens] if args.key?(:total_input_tokens)
  @total_output_tokens = args[:total_output_tokens] if args.key?(:total_output_tokens)
  @total_thought_tokens = args[:total_thought_tokens] if args.key?(:total_thought_tokens)
  @total_tokens = args[:total_tokens] if args.key?(:total_tokens)
  @total_tool_use_tokens = args[:total_tool_use_tokens] if args.key?(:total_tool_use_tokens)
end