Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Statistics on the interaction request's token usage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1InteractionUsage

Returns a new instance of GenaiVertexV1beta1InteractionUsage.



3666
3667
3668
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3666

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cached_tokens_by_modalityArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsageModalityTokens>

A breakdown of cached token usage by modality. Corresponds to the JSON property cached_tokens_by_modality



3613
3614
3615
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3613

def cached_tokens_by_modality
  @cached_tokens_by_modality
end

#grounding_tool_countArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsageGroundingToolCount>

Grounding tool count. Corresponds to the JSON property grounding_tool_count



3618
3619
3620
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3618

def grounding_tool_count
  @grounding_tool_count
end

#input_tokens_by_modalityArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsageModalityTokens>

A breakdown of input token usage by modality. Corresponds to the JSON property input_tokens_by_modality



3623
3624
3625
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3623

def input_tokens_by_modality
  @input_tokens_by_modality
end

#output_tokens_by_modalityArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsageModalityTokens>

A breakdown of output token usage by modality. Corresponds to the JSON property output_tokens_by_modality



3628
3629
3630
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3628

def output_tokens_by_modality
  @output_tokens_by_modality
end

#tool_use_tokens_by_modalityArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1InteractionUsageModalityTokens>

A breakdown of tool-use token usage by modality. Corresponds to the JSON property tool_use_tokens_by_modality



3633
3634
3635
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3633

def tool_use_tokens_by_modality
  @tool_use_tokens_by_modality
end

#total_cached_tokensFixnum

Number of tokens in the cached part of the prompt (the cached content). Corresponds to the JSON property total_cached_tokens

Returns:

  • (Fixnum)


3638
3639
3640
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3638

def total_cached_tokens
  @total_cached_tokens
end

#total_input_tokensFixnum

Number of tokens in the prompt (context). Corresponds to the JSON property total_input_tokens

Returns:

  • (Fixnum)


3643
3644
3645
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3643

def total_input_tokens
  @total_input_tokens
end

#total_output_tokensFixnum

Total number of tokens across all the generated responses. Corresponds to the JSON property total_output_tokens

Returns:

  • (Fixnum)


3648
3649
3650
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3648

def total_output_tokens
  @total_output_tokens
end

#total_thought_tokensFixnum

Number of tokens of thoughts for thinking models. Corresponds to the JSON property total_thought_tokens

Returns:

  • (Fixnum)


3653
3654
3655
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3653

def total_thought_tokens
  @total_thought_tokens
end

#total_tokensFixnum

Total token count for the interaction request (prompt + responses + other internal tokens). Corresponds to the JSON property total_tokens

Returns:

  • (Fixnum)


3659
3660
3661
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3659

def total_tokens
  @total_tokens
end

#total_tool_use_tokensFixnum

Number of tokens present in tool-use prompt(s). Corresponds to the JSON property total_tool_use_tokens

Returns:

  • (Fixnum)


3664
3665
3666
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3664

def total_tool_use_tokens
  @total_tool_use_tokens
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3671
3672
3673
3674
3675
3676
3677
3678
3679
3680
3681
3682
3683
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3671

def update!(**args)
  @cached_tokens_by_modality = args[:cached_tokens_by_modality] if args.key?(:cached_tokens_by_modality)
  @grounding_tool_count = args[:grounding_tool_count] if args.key?(:grounding_tool_count)
  @input_tokens_by_modality = args[:input_tokens_by_modality] if args.key?(:input_tokens_by_modality)
  @output_tokens_by_modality = args[:output_tokens_by_modality] if args.key?(:output_tokens_by_modality)
  @tool_use_tokens_by_modality = args[:tool_use_tokens_by_modality] if args.key?(:tool_use_tokens_by_modality)
  @total_cached_tokens = args[:total_cached_tokens] if args.key?(:total_cached_tokens)
  @total_input_tokens = args[:total_input_tokens] if args.key?(:total_input_tokens)
  @total_output_tokens = args[:total_output_tokens] if args.key?(:total_output_tokens)
  @total_thought_tokens = args[:total_thought_tokens] if args.key?(:total_thought_tokens)
  @total_tokens = args[:total_tokens] if args.key?(:total_tokens)
  @total_tool_use_tokens = args[:total_tool_use_tokens] if args.key?(:total_tool_use_tokens)
end