Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
MCPServer tool call content.
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#name ⇒ String
Required.
-
#server_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolCallContent
constructor
A new instance of GenaiVertexV1beta1McpServerToolCallContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolCallContent
Returns a new instance of GenaiVertexV1beta1McpServerToolCallContent.
3531 3532 3533 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property arguments
3519 3520 3521 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3519 def arguments @arguments end |
#name ⇒ String
Required. The name of the tool which was called.
Corresponds to the JSON property name
3524 3525 3526 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3524 def name @name end |
#server_name ⇒ String
Required. The name of the used MCP server.
Corresponds to the JSON property server_name
3529 3530 3531 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3529 def server_name @server_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3536 3537 3538 3539 3540 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3536 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @name = args[:name] if args.key?(:name) @server_name = args[:server_name] if args.key?(:server_name) end |