Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#name ⇒ String
Corresponds to the JSON property
name. -
#server_name ⇒ String
Corresponds to the JSON property
serverName.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolCallDelta
constructor
A new instance of GenaiVertexV1beta1McpServerToolCallDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolCallDelta
Returns a new instance of GenaiVertexV1beta1McpServerToolCallDelta.
3799 3800 3801 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property arguments
3787 3788 3789 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3787 def arguments @arguments end |
#name ⇒ String
Corresponds to the JSON property name
3792 3793 3794 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3792 def name @name end |
#server_name ⇒ String
Corresponds to the JSON property serverName
3797 3798 3799 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3797 def server_name @server_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3804 3805 3806 3807 3808 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3804 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @name = args[:name] if args.key?(:name) @server_name = args[:server_name] if args.key?(:server_name) end |