Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#name ⇒ String
Corresponds to the JSON property
name. -
#server_name ⇒ String
Corresponds to the JSON property
server_name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolCallDelta
constructor
A new instance of GenaiVertexV1beta1McpServerToolCallDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolCallDelta
Returns a new instance of GenaiVertexV1beta1McpServerToolCallDelta.
3563 3564 3565 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3563 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property arguments
3551 3552 3553 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3551 def arguments @arguments end |
#name ⇒ String
Corresponds to the JSON property name
3556 3557 3558 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3556 def name @name end |
#server_name ⇒ String
Corresponds to the JSON property server_name
3561 3562 3563 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3561 def server_name @server_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3568 3569 3570 3571 3572 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3568 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @name = args[:name] if args.key?(:name) @server_name = args[:server_name] if args.key?(:server_name) end |