Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
MCPServer tool call step.
Instance Attribute Summary collapse
-
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#name ⇒ String
Required.
-
#server_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolCallStep
constructor
A new instance of GenaiVertexV1beta1McpServerToolCallStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolCallStep
Returns a new instance of GenaiVertexV1beta1McpServerToolCallStep.
3595 3596 3597 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property arguments
3583 3584 3585 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3583 def arguments @arguments end |
#name ⇒ String
Required. The name of the tool which was called.
Corresponds to the JSON property name
3588 3589 3590 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3588 def name @name end |
#server_name ⇒ String
Required. The name of the used MCP server.
Corresponds to the JSON property server_name
3593 3594 3595 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3593 def server_name @server_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3600 3601 3602 3603 3604 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3600 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @name = args[:name] if args.key?(:name) @server_name = args[:server_name] if args.key?(:server_name) end |