Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
MCPServer tool result content.
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property
contentList. -
#name ⇒ String
Name of the tool which is called for this specific tool call.
-
#server_name ⇒ String
The name of the used MCP server.
-
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultContent
constructor
A new instance of GenaiVertexV1beta1McpServerToolResultContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultContent
Returns a new instance of GenaiVertexV1beta1McpServerToolResultContent.
3873 3874 3875 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3873 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property contentList
3850 3851 3852 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3850 def content_list @content_list end |
#name ⇒ String
Name of the tool which is called for this specific tool call.
Corresponds to the JSON property name
3855 3856 3857 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3855 def name @name end |
#server_name ⇒ String
The name of the used MCP server.
Corresponds to the JSON property serverName
3860 3861 3862 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3860 def server_name @server_name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
3865 3866 3867 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3865 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
3871 3872 3873 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3871 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3878 3879 3880 3881 3882 3883 3884 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3878 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @name = args[:name] if args.key?(:name) @server_name = args[:server_name] if args.key?(:server_name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |