Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

MCPServer tool result content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultContent

Returns a new instance of GenaiVertexV1beta1McpServerToolResultContent.



4048
4049
4050
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList

Corresponds to the JSON property contentList



4025
4026
4027
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4025

def content_list
  @content_list
end

#nameString

Name of the tool which is called for this specific tool call. Corresponds to the JSON property name

Returns:

  • (String)


4030
4031
4032
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4030

def name
  @name
end

#server_nameString

The name of the used MCP server. Corresponds to the JSON property serverName

Returns:

  • (String)


4035
4036
4037
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4035

def server_name
  @server_name
end

#string_resultString

Corresponds to the JSON property stringResult

Returns:

  • (String)


4040
4041
4042
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4040

def string_result
  @string_result
end

#struct_resultGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct

Struct represents a structured data value, consisting of fields which map to dynamically typed values. Corresponds to the JSON property structResult



4046
4047
4048
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4046

def struct_result
  @struct_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4053
4054
4055
4056
4057
4058
4059
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4053

def update!(**args)
  @content_list = args[:content_list] if args.key?(:content_list)
  @name = args[:name] if args.key?(:name)
  @server_name = args[:server_name] if args.key?(:server_name)
  @string_result = args[:string_result] if args.key?(:string_result)
  @struct_result = args[:struct_result] if args.key?(:struct_result)
end