Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

MCPServer tool result content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultContent

Returns a new instance of GenaiVertexV1beta1McpServerToolResultContent.



3637
3638
3639
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3637

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList

Corresponds to the JSON property contentList



3614
3615
3616
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3614

def content_list
  @content_list
end

#nameString

Name of the tool which is called for this specific tool call. Corresponds to the JSON property name

Returns:

  • (String)


3619
3620
3621
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3619

def name
  @name
end

#server_nameString

The name of the used MCP server. Corresponds to the JSON property server_name

Returns:

  • (String)


3624
3625
3626
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3624

def server_name
  @server_name
end

#string_resultString

Corresponds to the JSON property stringResult

Returns:

  • (String)


3629
3630
3631
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3629

def string_result
  @string_result
end

#struct_resultGoogle::Apis::AiplatformV1beta1::GenaiStruct

Struct represents a structured data value, consisting of fields which map to dynamically typed values. Corresponds to the JSON property structResult



3635
3636
3637
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3635

def struct_result
  @struct_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3642
3643
3644
3645
3646
3647
3648
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3642

def update!(**args)
  @content_list = args[:content_list] if args.key?(:content_list)
  @name = args[:name] if args.key?(:name)
  @server_name = args[:server_name] if args.key?(:server_name)
  @string_result = args[:string_result] if args.key?(:string_result)
  @struct_result = args[:struct_result] if args.key?(:struct_result)
end