Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#name ⇒ String
Corresponds to the JSON property
name. -
#result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value
Valuerepresents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. -
#server_name ⇒ String
Corresponds to the JSON property
serverName.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultDelta
constructor
A new instance of GenaiVertexV1beta1McpServerToolResultDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultDelta
Returns a new instance of GenaiVertexV1beta1McpServerToolResultDelta.
4265 4266 4267 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4265 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Corresponds to the JSON property name
4250 4251 4252 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4250 def name @name end |
#result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value
Value represents a dynamically typed value which can be either null, a
number, a string, a boolean, a recursive struct value, or a list of values. A
producer of value is expected to set one of these variants. Absence of any
variant indicates an error.
Corresponds to the JSON property result
4258 4259 4260 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4258 def result @result end |
#server_name ⇒ String
Corresponds to the JSON property serverName
4263 4264 4265 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4263 def server_name @server_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4270 4271 4272 4273 4274 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4270 def update!(**args) @name = args[:name] if args.key?(:name) @result = args[:result] if args.key?(:result) @server_name = args[:server_name] if args.key?(:server_name) end |