Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
-
#name ⇒ String
Corresponds to the JSON property
name. -
#server_name ⇒ String
Corresponds to the JSON property
serverName. -
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultDelta
constructor
A new instance of GenaiVertexV1beta1McpServerToolResultDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultDelta
Returns a new instance of GenaiVertexV1beta1McpServerToolResultDelta.
4049 4050 4051 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
Corresponds to the JSON property contentList
4026 4027 4028 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4026 def content_list @content_list end |
#name ⇒ String
Corresponds to the JSON property name
4031 4032 4033 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4031 def name @name end |
#server_name ⇒ String
Corresponds to the JSON property serverName
4036 4037 4038 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4036 def server_name @server_name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
4041 4042 4043 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4041 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
4047 4048 4049 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4047 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4054 4055 4056 4057 4058 4059 4060 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4054 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @name = args[:name] if args.key?(:name) @server_name = args[:server_name] if args.key?(:server_name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |