Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
-
#name ⇒ String
Corresponds to the JSON property
name. -
#server_name ⇒ String
Corresponds to the JSON property
serverName. -
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultDelta
constructor
A new instance of GenaiVertexV1beta1McpServerToolResultDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultDelta
Returns a new instance of GenaiVertexV1beta1McpServerToolResultDelta.
4092 4093 4094 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4092 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
Corresponds to the JSON property contentList
4069 4070 4071 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4069 def content_list @content_list end |
#name ⇒ String
Corresponds to the JSON property name
4074 4075 4076 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4074 def name @name end |
#server_name ⇒ String
Corresponds to the JSON property serverName
4079 4080 4081 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4079 def server_name @server_name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
4084 4085 4086 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4084 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
4090 4091 4092 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4090 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4097 4098 4099 4100 4101 4102 4103 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4097 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @name = args[:name] if args.key?(:name) @server_name = args[:server_name] if args.key?(:server_name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |