Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property
contentList. -
#name ⇒ String
Corresponds to the JSON property
name. -
#server_name ⇒ String
Corresponds to the JSON property
server_name. -
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultDelta
constructor
A new instance of GenaiVertexV1beta1McpServerToolResultDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultDelta
Returns a new instance of GenaiVertexV1beta1McpServerToolResultDelta.
3681 3682 3683 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property contentList
3658 3659 3660 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3658 def content_list @content_list end |
#name ⇒ String
Corresponds to the JSON property name
3663 3664 3665 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3663 def name @name end |
#server_name ⇒ String
Corresponds to the JSON property server_name
3668 3669 3670 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3668 def server_name @server_name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
3673 3674 3675 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3673 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
3679 3680 3681 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3679 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3686 3687 3688 3689 3690 3691 3692 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3686 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @name = args[:name] if args.key?(:name) @server_name = args[:server_name] if args.key?(:server_name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |