Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
MCPServer tool result step.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the tool which is called for this specific tool call.
-
#result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value
Valuerepresents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. -
#server_name ⇒ String
The name of the used MCP server.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultStep
constructor
A new instance of GenaiVertexV1beta1McpServerToolResultStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultStep
Returns a new instance of GenaiVertexV1beta1McpServerToolResultStep.
4299 4300 4301 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the tool which is called for this specific tool call.
Corresponds to the JSON property name
4284 4285 4286 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4284 def name @name end |
#result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value
Value represents a dynamically typed value which can be either null, a
number, a string, a boolean, a recursive struct value, or a list of values. A
producer of value is expected to set one of these variants. Absence of any
variant indicates an error.
Corresponds to the JSON property result
4292 4293 4294 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4292 def result @result end |
#server_name ⇒ String
The name of the used MCP server.
Corresponds to the JSON property serverName
4297 4298 4299 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4297 def server_name @server_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4304 4305 4306 4307 4308 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4304 def update!(**args) @name = args[:name] if args.key?(:name) @result = args[:result] if args.key?(:result) @server_name = args[:server_name] if args.key?(:server_name) end |