Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
MCPServer tool result step.
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
-
#name ⇒ String
Name of the tool which is called for this specific tool call.
-
#server_name ⇒ String
The name of the used MCP server.
-
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultStep
constructor
A new instance of GenaiVertexV1beta1McpServerToolResultStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultStep
Returns a new instance of GenaiVertexV1beta1McpServerToolResultStep.
4093 4094 4095 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4093 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
Corresponds to the JSON property contentList
4070 4071 4072 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4070 def content_list @content_list end |
#name ⇒ String
Name of the tool which is called for this specific tool call.
Corresponds to the JSON property name
4075 4076 4077 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4075 def name @name end |
#server_name ⇒ String
The name of the used MCP server.
Corresponds to the JSON property serverName
4080 4081 4082 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4080 def server_name @server_name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
4085 4086 4087 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4085 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
4091 4092 4093 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4091 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4098 4099 4100 4101 4102 4103 4104 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4098 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @name = args[:name] if args.key?(:name) @server_name = args[:server_name] if args.key?(:server_name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |