Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

MCPServer tool result step.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultStep

Returns a new instance of GenaiVertexV1beta1McpServerToolResultStep.



3961
3962
3963
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList

A list of Content. Corresponds to the JSON property contentList



3938
3939
3940
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3938

def content_list
  @content_list
end

#nameString

Name of the tool which is called for this specific tool call. Corresponds to the JSON property name

Returns:

  • (String)


3943
3944
3945
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3943

def name
  @name
end

#server_nameString

The name of the used MCP server. Corresponds to the JSON property serverName

Returns:

  • (String)


3948
3949
3950
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3948

def server_name
  @server_name
end

#string_resultString

Corresponds to the JSON property stringResult

Returns:

  • (String)


3953
3954
3955
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3953

def string_result
  @string_result
end

#struct_resultGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct

Struct represents a structured data value, consisting of fields which map to dynamically typed values. Corresponds to the JSON property structResult



3959
3960
3961
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3959

def struct_result
  @struct_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3966
3967
3968
3969
3970
3971
3972
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3966

def update!(**args)
  @content_list = args[:content_list] if args.key?(:content_list)
  @name = args[:name] if args.key?(:name)
  @server_name = args[:server_name] if args.key?(:server_name)
  @string_result = args[:string_result] if args.key?(:string_result)
  @struct_result = args[:struct_result] if args.key?(:struct_result)
end