Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
MCPServer tool result step.
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
-
#name ⇒ String
Name of the tool which is called for this specific tool call.
-
#server_name ⇒ String
The name of the used MCP server.
-
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultStep
constructor
A new instance of GenaiVertexV1beta1McpServerToolResultStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultStep
Returns a new instance of GenaiVertexV1beta1McpServerToolResultStep.
4136 4137 4138 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4136 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ContentList
A list of Content.
Corresponds to the JSON property contentList
4113 4114 4115 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4113 def content_list @content_list end |
#name ⇒ String
Name of the tool which is called for this specific tool call.
Corresponds to the JSON property name
4118 4119 4120 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4118 def name @name end |
#server_name ⇒ String
The name of the used MCP server.
Corresponds to the JSON property serverName
4123 4124 4125 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4123 def server_name @server_name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
4128 4129 4130 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4128 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
4134 4135 4136 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4134 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4141 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @name = args[:name] if args.key?(:name) @server_name = args[:server_name] if args.key?(:server_name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |