Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
MCPServer tool result step.
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property
contentList. -
#name ⇒ String
Name of the tool which is called for this specific tool call.
-
#server_name ⇒ String
The name of the used MCP server.
-
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultStep
constructor
A new instance of GenaiVertexV1beta1McpServerToolResultStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultStep
Returns a new instance of GenaiVertexV1beta1McpServerToolResultStep.
3987 3988 3989 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3987 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property contentList
3964 3965 3966 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3964 def content_list @content_list end |
#name ⇒ String
Name of the tool which is called for this specific tool call.
Corresponds to the JSON property name
3969 3970 3971 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3969 def name @name end |
#server_name ⇒ String
The name of the used MCP server.
Corresponds to the JSON property server_name
3974 3975 3976 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3974 def server_name @server_name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
3979 3980 3981 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3979 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
3985 3986 3987 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3985 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3992 3993 3994 3995 3996 3997 3998 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3992 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @name = args[:name] if args.key?(:name) @server_name = args[:server_name] if args.key?(:server_name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |