Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

MCPServer tool result step.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultStep

Returns a new instance of GenaiVertexV1beta1McpServerToolResultStep.



3725
3726
3727
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3725

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_listGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList

Corresponds to the JSON property contentList



3702
3703
3704
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3702

def content_list
  @content_list
end

#nameString

Name of the tool which is called for this specific tool call. Corresponds to the JSON property name

Returns:

  • (String)


3707
3708
3709
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3707

def name
  @name
end

#server_nameString

The name of the used MCP server. Corresponds to the JSON property server_name

Returns:

  • (String)


3712
3713
3714
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3712

def server_name
  @server_name
end

#string_resultString

Corresponds to the JSON property stringResult

Returns:

  • (String)


3717
3718
3719
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3717

def string_result
  @string_result
end

#struct_resultGoogle::Apis::AiplatformV1beta1::GenaiStruct

Struct represents a structured data value, consisting of fields which map to dynamically typed values. Corresponds to the JSON property structResult



3723
3724
3725
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3723

def struct_result
  @struct_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3730
3731
3732
3733
3734
3735
3736
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3730

def update!(**args)
  @content_list = args[:content_list] if args.key?(:content_list)
  @name = args[:name] if args.key?(:name)
  @server_name = args[:server_name] if args.key?(:server_name)
  @string_result = args[:string_result] if args.key?(:string_result)
  @struct_result = args[:struct_result] if args.key?(:struct_result)
end