Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
MCPServer tool result step.
Instance Attribute Summary collapse
-
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property
contentList. -
#name ⇒ String
Name of the tool which is called for this specific tool call.
-
#server_name ⇒ String
The name of the used MCP server.
-
#string_result ⇒ String
Corresponds to the JSON property
stringResult. -
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultStep
constructor
A new instance of GenaiVertexV1beta1McpServerToolResultStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1McpServerToolResultStep
Returns a new instance of GenaiVertexV1beta1McpServerToolResultStep.
3725 3726 3727 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_list ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FunctionResultSubcontentList
Corresponds to the JSON property contentList
3702 3703 3704 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3702 def content_list @content_list end |
#name ⇒ String
Name of the tool which is called for this specific tool call.
Corresponds to the JSON property name
3707 3708 3709 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3707 def name @name end |
#server_name ⇒ String
The name of the used MCP server.
Corresponds to the JSON property server_name
3712 3713 3714 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3712 def server_name @server_name end |
#string_result ⇒ String
Corresponds to the JSON property stringResult
3717 3718 3719 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3717 def string_result @string_result end |
#struct_result ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structResult
3723 3724 3725 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3723 def struct_result @struct_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3730 def update!(**args) @content_list = args[:content_list] if args.key?(:content_list) @name = args[:name] if args.key?(:name) @server_name = args[:server_name] if args.key?(:server_name) @string_result = args[:string_result] if args.key?(:string_result) @struct_result = args[:struct_result] if args.key?(:struct_result) end |