Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ModelOutputStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ModelOutputStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Output generated by the model.
Instance Attribute Summary collapse
-
#content ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content>
Corresponds to the JSON property
content. -
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ModelOutputStep
constructor
A new instance of GenaiVertexV1beta1ModelOutputStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ModelOutputStep
Returns a new instance of GenaiVertexV1beta1ModelOutputStep.
4576 4577 4578 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4576 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content>
Corresponds to the JSON property content
4564 4565 4566 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4564 def content @content end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4574 4575 4576 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4574 def error @error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4581 4582 4583 4584 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4581 def update!(**args) @content = args[:content] if args.key?(:content) @error = args[:error] if args.key?(:error) end |