Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ModelOutputStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Output generated by the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1ModelOutputStep

Returns a new instance of GenaiVertexV1beta1ModelOutputStep.



4355
4356
4357
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4355

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content>

Corresponds to the JSON property content



4343
4344
4345
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4343

def content
  @content
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4353
4354
4355
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4353

def error
  @error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4360
4361
4362
4363
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4360

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @error = args[:error] if args.key?(:error)
end