Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ModelOutputStep
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ModelOutputStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Output generated by the model.
Instance Attribute Summary collapse
-
#content ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content>
Corresponds to the JSON property
content. -
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ModelOutputStep
constructor
A new instance of GenaiVertexV1beta1ModelOutputStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ModelOutputStep
Returns a new instance of GenaiVertexV1beta1ModelOutputStep.
4151 4152 4153 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4151 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content>
Corresponds to the JSON property content
4139 4140 4141 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4139 def content @content end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4149 4150 4151 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4149 def error @error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4156 4157 4158 4159 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4156 def update!(**args) @content = args[:content] if args.key?(:content) @error = args[:error] if args.key?(:error) end |