Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1PlaceCitation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1PlaceCitation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A place citation annotation.
Instance Attribute Summary collapse
-
#name ⇒ String
Title of the place.
-
#place_id ⇒ String
The ID of the place, in
places/place_id`` format. -
#review_snippets ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet>
Snippets of reviews that are used to generate answers about the features of a given place in Google Maps.
-
#url ⇒ String
URI reference of the place.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1PlaceCitation
constructor
A new instance of GenaiVertexV1beta1PlaceCitation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1PlaceCitation
Returns a new instance of GenaiVertexV1beta1PlaceCitation.
4253 4254 4255 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4253 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Title of the place.
Corresponds to the JSON property name
4235 4236 4237 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4235 def name @name end |
#place_id ⇒ String
The ID of the place, in places/place_id`format.
Corresponds to the JSON propertyplaceId`
4240 4241 4242 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4240 def place_id @place_id end |
#review_snippets ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet>
Snippets of reviews that are used to generate answers about the features of a
given place in Google Maps.
Corresponds to the JSON property reviewSnippets
4246 4247 4248 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4246 def review_snippets @review_snippets end |
#url ⇒ String
URI reference of the place.
Corresponds to the JSON property url
4251 4252 4253 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4251 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4258 4259 4260 4261 4262 4263 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4258 def update!(**args) @name = args[:name] if args.key?(:name) @place_id = args[:place_id] if args.key?(:place_id) @review_snippets = args[:review_snippets] if args.key?(:review_snippets) @url = args[:url] if args.key?(:url) end |