Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1PlaceCitation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A place citation annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1PlaceCitation

Returns a new instance of GenaiVertexV1beta1PlaceCitation.



4070
4071
4072
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Title of the place. Corresponds to the JSON property name

Returns:

  • (String)


4052
4053
4054
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4052

def name
  @name
end

#place_idString

The ID of the place, in places/place_id`format. Corresponds to the JSON propertyplace_id`

Returns:

  • (String)


4057
4058
4059
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4057

def place_id
  @place_id
end

#review_snippetsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet>

Snippets of reviews that are used to generate answers about the features of a given place in Google Maps. Corresponds to the JSON property review_snippets



4063
4064
4065
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4063

def review_snippets
  @review_snippets
end

#urlString

URI reference of the place. Corresponds to the JSON property url

Returns:

  • (String)


4068
4069
4070
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4068

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4075
4076
4077
4078
4079
4080
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4075

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @place_id = args[:place_id] if args.key?(:place_id)
  @review_snippets = args[:review_snippets] if args.key?(:review_snippets)
  @url = args[:url] if args.key?(:url)
end