Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1PlaceCitation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A place citation annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1PlaceCitation

Returns a new instance of GenaiVertexV1beta1PlaceCitation.



3808
3809
3810
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Title of the place. Corresponds to the JSON property name

Returns:

  • (String)


3790
3791
3792
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3790

def name
  @name
end

#place_idString

The ID of the place, in places/place_id`format. Corresponds to the JSON propertyplace_id`

Returns:

  • (String)


3795
3796
3797
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3795

def place_id
  @place_id
end

#review_snippetsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet>

Snippets of reviews that are used to generate answers about the features of a given place in Google Maps. Corresponds to the JSON property review_snippets



3801
3802
3803
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3801

def review_snippets
  @review_snippets
end

#urlString

URI reference of the place. Corresponds to the JSON property url

Returns:

  • (String)


3806
3807
3808
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3806

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3813
3814
3815
3816
3817
3818
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3813

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @place_id = args[:place_id] if args.key?(:place_id)
  @review_snippets = args[:review_snippets] if args.key?(:review_snippets)
  @url = args[:url] if args.key?(:url)
end