Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RagStoreConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Use to specify configuration for RAG Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1RagStoreConfig

Returns a new instance of GenaiVertexV1beta1RagStoreConfig.



4115
4116
4117
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rag_resourcesArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RagStoreConfigRagResource>

Optional. The representation of the rag source. Corresponds to the JSON property rag_resources



4098
4099
4100
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4098

def rag_resources
  @rag_resources
end

#rag_retrieval_configGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1RagStoreConfigRagRetrievalConfig

Specifies the context retrieval config. Corresponds to the JSON property rag_retrieval_config



4103
4104
4105
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4103

def rag_retrieval_config
  @rag_retrieval_config
end

#similarity_top_kFixnum

Optional. Number of top k results to return from the selected corpora. Corresponds to the JSON property similarity_top_k

Returns:

  • (Fixnum)


4108
4109
4110
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4108

def similarity_top_k
  @similarity_top_k
end

#vector_distance_thresholdFloat

Optional. Only return results with vector distance smaller than the threshold. Corresponds to the JSON property vector_distance_threshold

Returns:

  • (Float)


4113
4114
4115
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4113

def vector_distance_threshold
  @vector_distance_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4120
4121
4122
4123
4124
4125
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4120

def update!(**args)
  @rag_resources = args[:rag_resources] if args.key?(:rag_resources)
  @rag_retrieval_config = args[:rag_retrieval_config] if args.key?(:rag_retrieval_config)
  @similarity_top_k = args[:similarity_top_k] if args.key?(:similarity_top_k)
  @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold)
end