Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormat
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#audio ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1AudioResponseFormat
Configuration for audio output format.
-
#image ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageResponseFormat
Configuration for image output format.
-
#struct_value ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#text ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextResponseFormat
Configuration for text output format.
-
#video ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1VideoResponseFormat
Configuration for video output format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ResponseFormat
constructor
A new instance of GenaiVertexV1beta1ResponseFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ResponseFormat
Returns a new instance of GenaiVertexV1beta1ResponseFormat.
4877 4878 4879 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4877 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1AudioResponseFormat
Configuration for audio output format.
Corresponds to the JSON property audio
4854 4855 4856 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4854 def audio @audio end |
#image ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageResponseFormat
Configuration for image output format.
Corresponds to the JSON property image
4859 4860 4861 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4859 def image @image end |
#struct_value ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structValue
4865 4866 4867 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4865 def struct_value @struct_value end |
#text ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextResponseFormat
Configuration for text output format.
Corresponds to the JSON property text
4870 4871 4872 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4870 def text @text end |
#video ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1VideoResponseFormat
Configuration for video output format.
Corresponds to the JSON property video
4875 4876 4877 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4875 def video @video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4882 4883 4884 4885 4886 4887 4888 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4882 def update!(**args) @audio = args[:audio] if args.key?(:audio) @image = args[:image] if args.key?(:image) @struct_value = args[:struct_value] if args.key?(:struct_value) @text = args[:text] if args.key?(:text) @video = args[:video] if args.key?(:video) end |