Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormat
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#audio ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1AudioResponseFormat
Configuration for audio output format.
-
#image ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageResponseFormat
Configuration for image output format.
-
#struct_value ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#text ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextResponseFormat
Configuration for text output format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ResponseFormat
constructor
A new instance of GenaiVertexV1beta1ResponseFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ResponseFormat
Returns a new instance of GenaiVertexV1beta1ResponseFormat.
4307 4308 4309 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4307 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1AudioResponseFormat
Configuration for audio output format.
Corresponds to the JSON property audio
4289 4290 4291 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4289 def audio @audio end |
#image ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageResponseFormat
Configuration for image output format.
Corresponds to the JSON property image
4294 4295 4296 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4294 def image @image end |
#struct_value ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structValue
4300 4301 4302 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4300 def struct_value @struct_value end |
#text ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextResponseFormat
Configuration for text output format.
Corresponds to the JSON property text
4305 4306 4307 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4305 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4312 4313 4314 4315 4316 4317 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4312 def update!(**args) @audio = args[:audio] if args.key?(:audio) @image = args[:image] if args.key?(:image) @struct_value = args[:struct_value] if args.key?(:struct_value) @text = args[:text] if args.key?(:text) end |