Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormat
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#audio ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1AudioResponseFormat
Configuration for audio output format.
-
#image ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageResponseFormat
Configuration for image output format.
-
#struct_value ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#text ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextResponseFormat
Configuration for text output format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ResponseFormat
constructor
A new instance of GenaiVertexV1beta1ResponseFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ResponseFormat
Returns a new instance of GenaiVertexV1beta1ResponseFormat.
4108 4109 4110 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1AudioResponseFormat
Configuration for audio output format.
Corresponds to the JSON property audio
4090 4091 4092 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4090 def audio @audio end |
#image ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageResponseFormat
Configuration for image output format.
Corresponds to the JSON property image
4095 4096 4097 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4095 def image @image end |
#struct_value ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structValue
4101 4102 4103 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4101 def struct_value @struct_value end |
#text ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextResponseFormat
Configuration for text output format.
Corresponds to the JSON property text
4106 4107 4108 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4106 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4113 4114 4115 4116 4117 4118 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4113 def update!(**args) @audio = args[:audio] if args.key?(:audio) @image = args[:image] if args.key?(:image) @struct_value = args[:struct_value] if args.key?(:struct_value) @text = args[:text] if args.key?(:text) end |