Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormat
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ResponseFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#audio ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1AudioResponseFormat
Configuration for audio output format.
-
#image ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageResponseFormat
Configuration for image output format.
-
#struct_value ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values. -
#text ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextResponseFormat
Configuration for text output format.
-
#video ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1VideoResponseFormat
Configuration for video output format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ResponseFormat
constructor
A new instance of GenaiVertexV1beta1ResponseFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ResponseFormat
Returns a new instance of GenaiVertexV1beta1ResponseFormat.
3851 3852 3853 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3851 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1AudioResponseFormat
Configuration for audio output format.
Corresponds to the JSON property audio
3828 3829 3830 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3828 def audio @audio end |
#image ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ImageResponseFormat
Configuration for image output format.
Corresponds to the JSON property image
3833 3834 3835 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3833 def image @image end |
#struct_value ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structValue
3839 3840 3841 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3839 def struct_value @struct_value end |
#text ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextResponseFormat
Configuration for text output format.
Corresponds to the JSON property text
3844 3845 3846 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3844 def text @text end |
#video ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1VideoResponseFormat
Configuration for video output format.
Corresponds to the JSON property video
3849 3850 3851 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3849 def video @video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3856 3857 3858 3859 3860 3861 3862 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3856 def update!(**args) @audio = args[:audio] if args.key?(:audio) @image = args[:image] if args.key?(:image) @struct_value = args[:struct_value] if args.key?(:struct_value) @text = args[:text] if args.key?(:text) @video = args[:video] if args.key?(:video) end |