Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Encapsulates a snippet of a user review that answers a question about the features of a specific place in Google Maps.
Instance Attribute Summary collapse
-
#review_id ⇒ String
The ID of the review snippet.
-
#title ⇒ String
Title of the review.
-
#url ⇒ String
A link that corresponds to the user review on Google Maps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ReviewSnippet
constructor
A new instance of GenaiVertexV1beta1ReviewSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ReviewSnippet
Returns a new instance of GenaiVertexV1beta1ReviewSnippet.
5086 5087 5088 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5086 def initialize(**args) update!(**args) end |
Instance Attribute Details
#review_id ⇒ String
The ID of the review snippet.
Corresponds to the JSON property reviewId
5074 5075 5076 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5074 def review_id @review_id end |
#title ⇒ String
Title of the review.
Corresponds to the JSON property title
5079 5080 5081 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5079 def title @title end |
#url ⇒ String
A link that corresponds to the user review on Google Maps.
Corresponds to the JSON property url
5084 5085 5086 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5084 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5091 5092 5093 5094 5095 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5091 def update!(**args) @review_id = args[:review_id] if args.key?(:review_id) @title = args[:title] if args.key?(:title) @url = args[:url] if args.key?(:url) end |