Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Encapsulates a snippet of a user review that answers a question about the features of a specific place in Google Maps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1ReviewSnippet

Returns a new instance of GenaiVertexV1beta1ReviewSnippet.



4859
4860
4861
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4859

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#review_idString

The ID of the review snippet. Corresponds to the JSON property reviewId

Returns:

  • (String)


4847
4848
4849
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4847

def review_id
  @review_id
end

#titleString

Title of the review. Corresponds to the JSON property title

Returns:

  • (String)


4852
4853
4854
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4852

def title
  @title
end

#urlString

A link that corresponds to the user review on Google Maps. Corresponds to the JSON property url

Returns:

  • (String)


4857
4858
4859
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4857

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4864
4865
4866
4867
4868
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4864

def update!(**args)
  @review_id = args[:review_id] if args.key?(:review_id)
  @title = args[:title] if args.key?(:title)
  @url = args[:url] if args.key?(:url)
end