Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Encapsulates a snippet of a user review that answers a question about the features of a specific place in Google Maps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1ReviewSnippet

Returns a new instance of GenaiVertexV1beta1ReviewSnippet.



4655
4656
4657
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#review_idString

The ID of the review snippet. Corresponds to the JSON property reviewId

Returns:

  • (String)


4643
4644
4645
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4643

def review_id
  @review_id
end

#titleString

Title of the review. Corresponds to the JSON property title

Returns:

  • (String)


4648
4649
4650
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4648

def title
  @title
end

#urlString

A link that corresponds to the user review on Google Maps. Corresponds to the JSON property url

Returns:

  • (String)


4653
4654
4655
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4653

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4660
4661
4662
4663
4664
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4660

def update!(**args)
  @review_id = args[:review_id] if args.key?(:review_id)
  @title = args[:title] if args.key?(:title)
  @url = args[:url] if args.key?(:url)
end