Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Encapsulates a snippet of a user review that answers a question about the features of a specific place in Google Maps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1ReviewSnippet

Returns a new instance of GenaiVertexV1beta1ReviewSnippet.



4577
4578
4579
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#review_idString

The ID of the review snippet. Corresponds to the JSON property reviewId

Returns:

  • (String)


4565
4566
4567
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4565

def review_id
  @review_id
end

#titleString

Title of the review. Corresponds to the JSON property title

Returns:

  • (String)


4570
4571
4572
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4570

def title
  @title
end

#urlString

A link that corresponds to the user review on Google Maps. Corresponds to the JSON property url

Returns:

  • (String)


4575
4576
4577
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4575

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4582
4583
4584
4585
4586
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4582

def update!(**args)
  @review_id = args[:review_id] if args.key?(:review_id)
  @title = args[:title] if args.key?(:title)
  @url = args[:url] if args.key?(:url)
end