Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Encapsulates a snippet of a user review that answers a question about the features of a specific place in Google Maps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1ReviewSnippet

Returns a new instance of GenaiVertexV1beta1ReviewSnippet.



4185
4186
4187
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#review_idString

The ID of the review snippet. Corresponds to the JSON property review_id

Returns:

  • (String)


4173
4174
4175
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4173

def review_id
  @review_id
end

#titleString

Title of the review. Corresponds to the JSON property title

Returns:

  • (String)


4178
4179
4180
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4178

def title
  @title
end

#urlString

A link that corresponds to the user review on Google Maps. Corresponds to the JSON property url

Returns:

  • (String)


4183
4184
4185
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4183

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4190
4191
4192
4193
4194
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4190

def update!(**args)
  @review_id = args[:review_id] if args.key?(:review_id)
  @title = args[:title] if args.key?(:title)
  @url = args[:url] if args.key?(:url)
end