Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ReviewSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Encapsulates a snippet of a user review that answers a question about the features of a specific place in Google Maps.
Instance Attribute Summary collapse
-
#review_id ⇒ String
The ID of the review snippet.
-
#title ⇒ String
Title of the review.
-
#url ⇒ String
A link that corresponds to the user review on Google Maps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ReviewSnippet
constructor
A new instance of GenaiVertexV1beta1ReviewSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ReviewSnippet
Returns a new instance of GenaiVertexV1beta1ReviewSnippet.
3929 3930 3931 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3929 def initialize(**args) update!(**args) end |
Instance Attribute Details
#review_id ⇒ String
The ID of the review snippet.
Corresponds to the JSON property review_id
3917 3918 3919 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3917 def review_id @review_id end |
#title ⇒ String
Title of the review.
Corresponds to the JSON property title
3922 3923 3924 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3922 def title @title end |
#url ⇒ String
A link that corresponds to the user review on Google Maps.
Corresponds to the JSON property url
3927 3928 3929 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3927 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3934 3935 3936 3937 3938 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3934 def update!(**args) @review_id = args[:review_id] if args.key?(:review_id) @title = args[:title] if args.key?(:title) @url = args[:url] if args.key?(:url) end |