Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolCallDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolCallDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#code_execution_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionCallDelta
Corresponds to the JSON property
codeExecutionCall. -
#file_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchCallDelta
Corresponds to the JSON property
fileSearchCall. -
#google_maps_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallDelta
Corresponds to the JSON property
googleMapsCall. -
#google_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchCallDelta
Corresponds to the JSON property
googleSearchCall. -
#mcp_server_tool_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
Corresponds to the JSON property
mcpServerToolCall. -
#retrieval_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalCallDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search, etc.
-
#signature ⇒ String
A signature hash for backend validation.
-
#url_context_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextCallDelta
Corresponds to the JSON property
urlContextCall.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolCallDelta
constructor
A new instance of GenaiVertexV1beta1ServerToolCallDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolCallDelta
Returns a new instance of GenaiVertexV1beta1ServerToolCallDelta.
5178 5179 5180 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionCallDelta
Corresponds to the JSON property codeExecutionCall
5139 5140 5141 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5139 def code_execution_call @code_execution_call end |
#file_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchCallDelta
Corresponds to the JSON property fileSearchCall
5144 5145 5146 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5144 def file_search_call @file_search_call end |
#google_maps_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallDelta
Corresponds to the JSON property googleMapsCall
5149 5150 5151 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5149 def google_maps_call @google_maps_call end |
#google_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchCallDelta
Corresponds to the JSON property googleSearchCall
5154 5155 5156 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5154 def google_search_call @google_search_call end |
#mcp_server_tool_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
Corresponds to the JSON property mcpServerToolCall
5159 5160 5161 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5159 def mcp_server_tool_call @mcp_server_tool_call end |
#retrieval_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalCallDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search,
etc. RetrievalType decides which tool is used.
Corresponds to the JSON property retrievalCall
5165 5166 5167 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5165 def retrieval_call @retrieval_call end |
#signature ⇒ String
A signature hash for backend validation.
Corresponds to the JSON property signature
NOTE: Values are automatically base64 encoded/decoded in the client library.
5171 5172 5173 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5171 def signature @signature end |
#url_context_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextCallDelta
Corresponds to the JSON property urlContextCall
5176 5177 5178 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5176 def url_context_call @url_context_call end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5183 def update!(**args) @code_execution_call = args[:code_execution_call] if args.key?(:code_execution_call) @file_search_call = args[:file_search_call] if args.key?(:file_search_call) @google_maps_call = args[:google_maps_call] if args.key?(:google_maps_call) @google_search_call = args[:google_search_call] if args.key?(:google_search_call) @mcp_server_tool_call = args[:mcp_server_tool_call] if args.key?(:mcp_server_tool_call) @retrieval_call = args[:retrieval_call] if args.key?(:retrieval_call) @signature = args[:signature] if args.key?(:signature) @url_context_call = args[:url_context_call] if args.key?(:url_context_call) end |