Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolCallDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolCallDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#code_execution_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionCallDelta
Corresponds to the JSON property
codeExecutionCall. -
#file_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchCallDelta
Corresponds to the JSON property
fileSearchCall. -
#google_maps_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallDelta
Corresponds to the JSON property
googleMapsCall. -
#google_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchCallDelta
Corresponds to the JSON property
googleSearchCall. -
#mcp_server_tool_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
Corresponds to the JSON property
mcpServerToolCall. -
#retrieval_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalCallDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search, etc.
-
#signature ⇒ String
A signature hash for backend validation.
-
#url_context_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextCallDelta
Corresponds to the JSON property
urlContextCall.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolCallDelta
constructor
A new instance of GenaiVertexV1beta1ServerToolCallDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolCallDelta
Returns a new instance of GenaiVertexV1beta1ServerToolCallDelta.
4951 4952 4953 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionCallDelta
Corresponds to the JSON property codeExecutionCall
4912 4913 4914 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4912 def code_execution_call @code_execution_call end |
#file_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchCallDelta
Corresponds to the JSON property fileSearchCall
4917 4918 4919 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4917 def file_search_call @file_search_call end |
#google_maps_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallDelta
Corresponds to the JSON property googleMapsCall
4922 4923 4924 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4922 def google_maps_call @google_maps_call end |
#google_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchCallDelta
Corresponds to the JSON property googleSearchCall
4927 4928 4929 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4927 def google_search_call @google_search_call end |
#mcp_server_tool_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
Corresponds to the JSON property mcpServerToolCall
4932 4933 4934 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4932 def mcp_server_tool_call @mcp_server_tool_call end |
#retrieval_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalCallDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search,
etc. RetrievalType decides which tool is used.
Corresponds to the JSON property retrievalCall
4938 4939 4940 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4938 def retrieval_call @retrieval_call end |
#signature ⇒ String
A signature hash for backend validation.
Corresponds to the JSON property signature
NOTE: Values are automatically base64 encoded/decoded in the client library.
4944 4945 4946 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4944 def signature @signature end |
#url_context_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextCallDelta
Corresponds to the JSON property urlContextCall
4949 4950 4951 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4949 def url_context_call @url_context_call end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4956 def update!(**args) @code_execution_call = args[:code_execution_call] if args.key?(:code_execution_call) @file_search_call = args[:file_search_call] if args.key?(:file_search_call) @google_maps_call = args[:google_maps_call] if args.key?(:google_maps_call) @google_search_call = args[:google_search_call] if args.key?(:google_search_call) @mcp_server_tool_call = args[:mcp_server_tool_call] if args.key?(:mcp_server_tool_call) @retrieval_call = args[:retrieval_call] if args.key?(:retrieval_call) @signature = args[:signature] if args.key?(:signature) @url_context_call = args[:url_context_call] if args.key?(:url_context_call) end |