Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolCallDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolCallDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#code_execution_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionCallDelta
Corresponds to the JSON property
codeExecutionCall. -
#file_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchCallDelta
Corresponds to the JSON property
fileSearchCall. -
#google_maps_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallDelta
Corresponds to the JSON property
googleMapsCall. -
#google_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchCallDelta
Corresponds to the JSON property
googleSearchCall. -
#mcp_server_tool_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
Corresponds to the JSON property
mcpServerToolCall. -
#retrieval_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalCallDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search, etc.
-
#signature ⇒ String
A signature hash for backend validation.
-
#url_context_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextCallDelta
Corresponds to the JSON property
urlContextCall.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolCallDelta
constructor
A new instance of GenaiVertexV1beta1ServerToolCallDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolCallDelta
Returns a new instance of GenaiVertexV1beta1ServerToolCallDelta.
4747 4748 4749 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionCallDelta
Corresponds to the JSON property codeExecutionCall
4708 4709 4710 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4708 def code_execution_call @code_execution_call end |
#file_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchCallDelta
Corresponds to the JSON property fileSearchCall
4713 4714 4715 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4713 def file_search_call @file_search_call end |
#google_maps_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsCallDelta
Corresponds to the JSON property googleMapsCall
4718 4719 4720 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4718 def google_maps_call @google_maps_call end |
#google_search_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchCallDelta
Corresponds to the JSON property googleSearchCall
4723 4724 4725 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4723 def google_search_call @google_search_call end |
#mcp_server_tool_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolCallDelta
Corresponds to the JSON property mcpServerToolCall
4728 4729 4730 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4728 def mcp_server_tool_call @mcp_server_tool_call end |
#retrieval_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalCallDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search,
etc. RetrievalType decides which tool is used.
Corresponds to the JSON property retrievalCall
4734 4735 4736 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4734 def retrieval_call @retrieval_call end |
#signature ⇒ String
A signature hash for backend validation.
Corresponds to the JSON property signature
NOTE: Values are automatically base64 encoded/decoded in the client library.
4740 4741 4742 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4740 def signature @signature end |
#url_context_call ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextCallDelta
Corresponds to the JSON property urlContextCall
4745 4746 4747 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4745 def url_context_call @url_context_call end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4752 def update!(**args) @code_execution_call = args[:code_execution_call] if args.key?(:code_execution_call) @file_search_call = args[:file_search_call] if args.key?(:file_search_call) @google_maps_call = args[:google_maps_call] if args.key?(:google_maps_call) @google_search_call = args[:google_search_call] if args.key?(:google_search_call) @mcp_server_tool_call = args[:mcp_server_tool_call] if args.key?(:mcp_server_tool_call) @retrieval_call = args[:retrieval_call] if args.key?(:retrieval_call) @signature = args[:signature] if args.key?(:signature) @url_context_call = args[:url_context_call] if args.key?(:url_context_call) end |