Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolResultDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolResultDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#code_execution_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionResultDelta
Corresponds to the JSON property
codeExecutionResult. -
#file_search_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchResultDelta
Corresponds to the JSON property
fileSearchResult. -
#google_maps_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultDelta
Corresponds to the JSON property
googleMapsResult. -
#google_search_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchResultDelta
Corresponds to the JSON property
googleSearchResult. -
#mcp_server_tool_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
Corresponds to the JSON property
mcpServerToolResult. -
#retrieval_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalResultDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search, etc.
-
#signature ⇒ String
A signature hash for backend validation.
-
#url_context_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextResultDelta
Corresponds to the JSON property
urlContextResult.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolResultDelta
constructor
A new instance of GenaiVertexV1beta1ServerToolResultDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolResultDelta
Returns a new instance of GenaiVertexV1beta1ServerToolResultDelta.
5014 5015 5016 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionResultDelta
Corresponds to the JSON property codeExecutionResult
4975 4976 4977 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4975 def code_execution_result @code_execution_result end |
#file_search_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchResultDelta
Corresponds to the JSON property fileSearchResult
4980 4981 4982 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4980 def file_search_result @file_search_result end |
#google_maps_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultDelta
Corresponds to the JSON property googleMapsResult
4985 4986 4987 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4985 def google_maps_result @google_maps_result end |
#google_search_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchResultDelta
Corresponds to the JSON property googleSearchResult
4990 4991 4992 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4990 def google_search_result @google_search_result end |
#mcp_server_tool_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
Corresponds to the JSON property mcpServerToolResult
4995 4996 4997 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4995 def mcp_server_tool_result @mcp_server_tool_result end |
#retrieval_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalResultDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search,
etc. ToolResultDelta.type
Corresponds to the JSON property retrievalResult
5001 5002 5003 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5001 def retrieval_result @retrieval_result end |
#signature ⇒ String
A signature hash for backend validation.
Corresponds to the JSON property signature
NOTE: Values are automatically base64 encoded/decoded in the client library.
5007 5008 5009 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5007 def signature @signature end |
#url_context_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextResultDelta
Corresponds to the JSON property urlContextResult
5012 5013 5014 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5012 def url_context_result @url_context_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5019 def update!(**args) @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result) @file_search_result = args[:file_search_result] if args.key?(:file_search_result) @google_maps_result = args[:google_maps_result] if args.key?(:google_maps_result) @google_search_result = args[:google_search_result] if args.key?(:google_search_result) @mcp_server_tool_result = args[:mcp_server_tool_result] if args.key?(:mcp_server_tool_result) @retrieval_result = args[:retrieval_result] if args.key?(:retrieval_result) @signature = args[:signature] if args.key?(:signature) @url_context_result = args[:url_context_result] if args.key?(:url_context_result) end |