Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolResultDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ServerToolResultDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#code_execution_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionResultDelta
Corresponds to the JSON property
codeExecutionResult. -
#file_search_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchResultDelta
Corresponds to the JSON property
fileSearchResult. -
#google_maps_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultDelta
Corresponds to the JSON property
googleMapsResult. -
#google_search_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchResultDelta
Corresponds to the JSON property
googleSearchResult. -
#mcp_server_tool_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
Corresponds to the JSON property
mcpServerToolResult. -
#retrieval_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalResultDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search, etc.
-
#signature ⇒ String
A signature hash for backend validation.
-
#url_context_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextResultDelta
Corresponds to the JSON property
urlContextResult.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolResultDelta
constructor
A new instance of GenaiVertexV1beta1ServerToolResultDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ServerToolResultDelta
Returns a new instance of GenaiVertexV1beta1ServerToolResultDelta.
4810 4811 4812 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4810 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecutionResultDelta
Corresponds to the JSON property codeExecutionResult
4771 4772 4773 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4771 def code_execution_result @code_execution_result end |
#file_search_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearchResultDelta
Corresponds to the JSON property fileSearchResult
4776 4777 4778 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4776 def file_search_result @file_search_result end |
#google_maps_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMapsResultDelta
Corresponds to the JSON property googleMapsResult
4781 4782 4783 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4781 def google_maps_result @google_maps_result end |
#google_search_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearchResultDelta
Corresponds to the JSON property googleSearchResult
4786 4787 4788 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4786 def google_search_result @google_search_result end |
#mcp_server_tool_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServerToolResultDelta
Corresponds to the JSON property mcpServerToolResult
4791 4792 4793 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4791 def mcp_server_tool_result @mcp_server_tool_result end |
#retrieval_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1RetrievalResultDelta
Used by Vertex Retrieval tools such as Parallel AI, Exa AI, Vertex AI Search,
etc. ToolResultDelta.type
Corresponds to the JSON property retrievalResult
4797 4798 4799 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4797 def retrieval_result @retrieval_result end |
#signature ⇒ String
A signature hash for backend validation.
Corresponds to the JSON property signature
NOTE: Values are automatically base64 encoded/decoded in the client library.
4803 4804 4805 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4803 def signature @signature end |
#url_context_result ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContextResultDelta
Corresponds to the JSON property urlContextResult
4808 4809 4810 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4808 def url_context_result @url_context_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4815 4816 4817 4818 4819 4820 4821 4822 4823 4824 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4815 def update!(**args) @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result) @file_search_result = args[:file_search_result] if args.key?(:file_search_result) @google_maps_result = args[:google_maps_result] if args.key?(:google_maps_result) @google_search_result = args[:google_search_result] if args.key?(:google_search_result) @mcp_server_tool_result = args[:mcp_server_tool_result] if args.key?(:mcp_server_tool_result) @retrieval_result = args[:retrieval_result] if args.key?(:retrieval_result) @signature = args[:signature] if args.key?(:signature) @url_context_result = args[:url_context_result] if args.key?(:url_context_result) end |