Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1SpeechConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1SpeechConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The configuration for speech interaction.
Instance Attribute Summary collapse
-
#language ⇒ String
The language of the speech.
-
#speaker ⇒ String
The speaker's name, it should match the speaker name given in the prompt.
-
#voice ⇒ String
The voice of the speaker.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1SpeechConfig
constructor
A new instance of GenaiVertexV1beta1SpeechConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1SpeechConfig
Returns a new instance of GenaiVertexV1beta1SpeechConfig.
3960 3961 3962 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3960 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language ⇒ String
The language of the speech.
Corresponds to the JSON property language
3948 3949 3950 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3948 def language @language end |
#speaker ⇒ String
The speaker's name, it should match the speaker name given in the prompt.
Corresponds to the JSON property speaker
3953 3954 3955 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3953 def speaker @speaker end |
#voice ⇒ String
The voice of the speaker.
Corresponds to the JSON property voice
3958 3959 3960 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3958 def voice @voice end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3965 3966 3967 3968 3969 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3965 def update!(**args) @language = args[:language] if args.key?(:language) @speaker = args[:speaker] if args.key?(:speaker) @voice = args[:voice] if args.key?(:voice) end |