Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Instance Attribute Summary collapse
-
#fields ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Field>
Dynamically typed fields.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1Struct
constructor
A new instance of GenaiVertexV1beta1Struct.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1Struct
Returns a new instance of GenaiVertexV1beta1Struct.
4803 4804 4805 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fields ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Field>
Dynamically typed fields. List instead of map because LLMs are sensitive to
ordering, and we want to give users full control.
Corresponds to the JSON property fields
4801 4802 4803 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4801 def fields @fields end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4808 4809 4810 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4808 def update!(**args) @fields = args[:fields] if args.key?(:fields) end |