Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Struct represents a structured data value, consisting of fields which map to dynamically typed values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1Struct

Returns a new instance of GenaiVertexV1beta1Struct.



4978
4979
4980
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4978

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsArray<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Field>

Dynamically typed fields. List instead of map because LLMs are sensitive to ordering, and we want to give users full control. Corresponds to the JSON property fields



4976
4977
4978
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4976

def fields
  @fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4983
4984
4985
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4983

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
end