Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextContentAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextContentAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Citation information for model-generated content.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
End of the attributed segment, exclusive.
-
#file_citation ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileCitation
A file citation annotation.
-
#place_citation ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1PlaceCitation
A place citation annotation.
-
#start_index ⇒ Fixnum
Start of segment of the response that is attributed to this source.
-
#url_citation ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlCitation
A URL citation annotation.
-
#word_info ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1WordInfo
Word-level ASR annotation for transcription output.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1TextContentAnnotation
constructor
A new instance of GenaiVertexV1beta1TextContentAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1TextContentAnnotation
Returns a new instance of GenaiVertexV1beta1TextContentAnnotation.
5618 5619 5620 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5618 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
End of the attributed segment, exclusive.
Corresponds to the JSON property endIndex
5589 5590 5591 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5589 def end_index @end_index end |
#file_citation ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileCitation
A file citation annotation.
Corresponds to the JSON property fileCitation
5594 5595 5596 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5594 def file_citation @file_citation end |
#place_citation ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1PlaceCitation
A place citation annotation.
Corresponds to the JSON property placeCitation
5599 5600 5601 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5599 def place_citation @place_citation end |
#start_index ⇒ Fixnum
Start of segment of the response that is attributed to this source. Index
indicates the start of the segment, measured in bytes.
Corresponds to the JSON property startIndex
5605 5606 5607 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5605 def start_index @start_index end |
#url_citation ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlCitation
A URL citation annotation.
Corresponds to the JSON property urlCitation
5610 5611 5612 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5610 def url_citation @url_citation end |
#word_info ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1WordInfo
Word-level ASR annotation for transcription output. Carries the word text,
optional timing, and optional speaker attribution.
Corresponds to the JSON property wordInfo
5616 5617 5618 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5616 def word_info @word_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5623 5624 5625 5626 5627 5628 5629 5630 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5623 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @file_citation = args[:file_citation] if args.key?(:file_citation) @place_citation = args[:place_citation] if args.key?(:place_citation) @start_index = args[:start_index] if args.key?(:start_index) @url_citation = args[:url_citation] if args.key?(:url_citation) @word_info = args[:word_info] if args.key?(:word_info) end |