Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextContentAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Citation information for model-generated content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1TextContentAnnotation

Returns a new instance of GenaiVertexV1beta1TextContentAnnotation.



5410
5411
5412
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

End of the attributed segment, exclusive. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


5381
5382
5383
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5381

def end_index
  @end_index
end

#file_citationGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileCitation

A file citation annotation. Corresponds to the JSON property fileCitation



5386
5387
5388
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5386

def file_citation
  @file_citation
end

#place_citationGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1PlaceCitation

A place citation annotation. Corresponds to the JSON property placeCitation



5391
5392
5393
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5391

def place_citation
  @place_citation
end

#start_indexFixnum

Start of segment of the response that is attributed to this source. Index indicates the start of the segment, measured in bytes. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


5397
5398
5399
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5397

def start_index
  @start_index
end

#url_citationGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlCitation

A URL citation annotation. Corresponds to the JSON property urlCitation



5402
5403
5404
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5402

def url_citation
  @url_citation
end

#word_infoGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1WordInfo

Word-level ASR annotation for transcription output. Carries the word text, optional timing, and optional speaker attribution. Corresponds to the JSON property wordInfo



5408
5409
5410
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5408

def word_info
  @word_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5415
5416
5417
5418
5419
5420
5421
5422
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5415

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @file_citation = args[:file_citation] if args.key?(:file_citation)
  @place_citation = args[:place_citation] if args.key?(:place_citation)
  @start_index = args[:start_index] if args.key?(:start_index)
  @url_citation = args[:url_citation] if args.key?(:url_citation)
  @word_info = args[:word_info] if args.key?(:word_info)
end