Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextContentAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Citation information for model-generated content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1TextContentAnnotation

Returns a new instance of GenaiVertexV1beta1TextContentAnnotation.



5062
5063
5064
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

End of the attributed segment, exclusive. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


5039
5040
5041
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5039

def end_index
  @end_index
end

#file_citationGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileCitation

A file citation annotation. Corresponds to the JSON property fileCitation



5044
5045
5046
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5044

def file_citation
  @file_citation
end

#place_citationGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1PlaceCitation

A place citation annotation. Corresponds to the JSON property placeCitation



5049
5050
5051
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5049

def place_citation
  @place_citation
end

#start_indexFixnum

Start of segment of the response that is attributed to this source. Index indicates the start of the segment, measured in bytes. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


5055
5056
5057
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5055

def start_index
  @start_index
end

#url_citationGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlCitation

A URL citation annotation. Corresponds to the JSON property urlCitation



5060
5061
5062
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5060

def url_citation
  @url_citation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5067
5068
5069
5070
5071
5072
5073
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5067

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @file_citation = args[:file_citation] if args.key?(:file_citation)
  @place_citation = args[:place_citation] if args.key?(:place_citation)
  @start_index = args[:start_index] if args.key?(:start_index)
  @url_citation = args[:url_citation] if args.key?(:url_citation)
end