Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextContentAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Citation information for model-generated content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1TextContentAnnotation

Returns a new instance of GenaiVertexV1beta1TextContentAnnotation.



4244
4245
4246
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

End of the attributed segment, exclusive. Corresponds to the JSON property end_index

Returns:

  • (Fixnum)


4221
4222
4223
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4221

def end_index
  @end_index
end

#file_citationGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileCitation

A file citation annotation. Corresponds to the JSON property file_citation



4226
4227
4228
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4226

def file_citation
  @file_citation
end

#place_citationGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1PlaceCitation

A place citation annotation. Corresponds to the JSON property place_citation



4231
4232
4233
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4231

def place_citation
  @place_citation
end

#start_indexFixnum

Start of segment of the response that is attributed to this source. Index indicates the start of the segment, measured in bytes. Corresponds to the JSON property start_index

Returns:

  • (Fixnum)


4237
4238
4239
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4237

def start_index
  @start_index
end

#url_citationGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlCitation

A URL citation annotation. Corresponds to the JSON property url_citation



4242
4243
4244
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4242

def url_citation
  @url_citation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4249
4250
4251
4252
4253
4254
4255
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4249

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @file_citation = args[:file_citation] if args.key?(:file_citation)
  @place_citation = args[:place_citation] if args.key?(:place_citation)
  @start_index = args[:start_index] if args.key?(:start_index)
  @url_citation = args[:url_citation] if args.key?(:url_citation)
end