Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextResponseFormat
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TextResponseFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for text output format.
Instance Attribute Summary collapse
-
#mime_type ⇒ String
The MIME type of the text output.
-
#schema ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1TextResponseFormat
constructor
A new instance of GenaiVertexV1beta1TextResponseFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1TextResponseFormat
Returns a new instance of GenaiVertexV1beta1TextResponseFormat.
4697 4698 4699 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mime_type ⇒ String
The MIME type of the text output.
Corresponds to the JSON property mime_type
4689 4690 4691 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4689 def mime_type @mime_type end |
#schema ⇒ Google::Apis::AiplatformV1beta1::GenaiStruct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property schema
4695 4696 4697 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4695 def schema @schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4702 4703 4704 4705 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4702 def update!(**args) @mime_type = args[:mime_type] if args.key?(:mime_type) @schema = args[:schema] if args.key?(:schema) end |