Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ThoughtContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ThoughtContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A thought content block.
Instance Attribute Summary collapse
-
#signature ⇒ String
Signature to match the backend source to be part of the generation.
-
#summary ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ThoughtSummaryContent>
A summary of the thought.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ThoughtContent
constructor
A new instance of GenaiVertexV1beta1ThoughtContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ThoughtContent
Returns a new instance of GenaiVertexV1beta1ThoughtContent.
4318 4319 4320 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4318 def initialize(**args) update!(**args) end |
Instance Attribute Details
#signature ⇒ String
Signature to match the backend source to be part of the generation.
Corresponds to the JSON property signature
NOTE: Values are automatically base64 encoded/decoded in the client library.
4311 4312 4313 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4311 def signature @signature end |
#summary ⇒ Array<Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ThoughtSummaryContent>
A summary of the thought.
Corresponds to the JSON property summary
4316 4317 4318 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4316 def summary @summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4323 4324 4325 4326 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4323 def update!(**args) @signature = args[:signature] if args.key?(:signature) @summary = args[:summary] if args.key?(:summary) end |