Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ThoughtSignatureDelta
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ThoughtSignatureDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#signature ⇒ String
Signature to match the backend source to be part of the generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1ThoughtSignatureDelta
constructor
A new instance of GenaiVertexV1beta1ThoughtSignatureDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1ThoughtSignatureDelta
Returns a new instance of GenaiVertexV1beta1ThoughtSignatureDelta.
4744 4745 4746 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4744 def initialize(**args) update!(**args) end |
Instance Attribute Details
#signature ⇒ String
Signature to match the backend source to be part of the generation.
Corresponds to the JSON property signature
NOTE: Values are automatically base64 encoded/decoded in the client library.
4742 4743 4744 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4742 def signature @signature end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4749 4750 4751 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4749 def update!(**args) @signature = args[:signature] if args.key?(:signature) end |