Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Tool
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Tool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A tool that can be used by the model.
Instance Attribute Summary collapse
-
#code_execution ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecution
A tool that can be used by the model to execute code.
-
#computer_use ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ComputerUse
A tool that can be used by the model to interact with the computer.
-
#file_search ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearch
A tool that can be used by the model to search files.
-
#function ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Function
A tool that can be used by the model.
-
#google_maps ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMaps
A tool that can be used by the model to call Google Maps.
-
#google_search ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearch
A tool that can be used by the model to search Google.
-
#mcp_server ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServer
A MCPServer is a server that can be called by the model to perform actions.
-
#retrieval ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Retrieval
A tool that can be used by the model to retrieve files.
-
#url_context ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContext
A tool that can be used by the model to fetch URL context.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1Tool
constructor
A new instance of GenaiVertexV1beta1Tool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1Tool
Returns a new instance of GenaiVertexV1beta1Tool.
5424 5425 5426 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecution
A tool that can be used by the model to execute code.
Corresponds to the JSON property codeExecution
5382 5383 5384 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5382 def code_execution @code_execution end |
#computer_use ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ComputerUse
A tool that can be used by the model to interact with the computer.
Corresponds to the JSON property computerUse
5387 5388 5389 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5387 def computer_use @computer_use end |
#file_search ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearch
A tool that can be used by the model to search files.
Corresponds to the JSON property fileSearch
5392 5393 5394 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5392 def file_search @file_search end |
#function ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Function
A tool that can be used by the model.
Corresponds to the JSON property function
5397 5398 5399 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5397 def function @function end |
#google_maps ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMaps
A tool that can be used by the model to call Google Maps.
Corresponds to the JSON property googleMaps
5402 5403 5404 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5402 def google_maps @google_maps end |
#google_search ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearch
A tool that can be used by the model to search Google.
Corresponds to the JSON property googleSearch
5407 5408 5409 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5407 def google_search @google_search end |
#mcp_server ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServer
A MCPServer is a server that can be called by the model to perform actions.
Corresponds to the JSON property mcpServer
5412 5413 5414 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5412 def mcp_server @mcp_server end |
#retrieval ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Retrieval
A tool that can be used by the model to retrieve files.
Corresponds to the JSON property retrieval
5417 5418 5419 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5417 def retrieval @retrieval end |
#url_context ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContext
A tool that can be used by the model to fetch URL context.
Corresponds to the JSON property urlContext
5422 5423 5424 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5422 def url_context @url_context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5429 def update!(**args) @code_execution = args[:code_execution] if args.key?(:code_execution) @computer_use = args[:computer_use] if args.key?(:computer_use) @file_search = args[:file_search] if args.key?(:file_search) @function = args[:function] if args.key?(:function) @google_maps = args[:google_maps] if args.key?(:google_maps) @google_search = args[:google_search] if args.key?(:google_search) @mcp_server = args[:mcp_server] if args.key?(:mcp_server) @retrieval = args[:retrieval] if args.key?(:retrieval) @url_context = args[:url_context] if args.key?(:url_context) end |