Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Tool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool that can be used by the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1Tool

Returns a new instance of GenaiVertexV1beta1Tool.



4873
4874
4875
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_executionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecution

A tool that can be used by the model to execute code. Corresponds to the JSON property codeExecution



4831
4832
4833
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4831

def code_execution
  @code_execution
end

#computer_useGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ComputerUse

A tool that can be used by the model to interact with the computer. Corresponds to the JSON property computerUse



4836
4837
4838
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4836

def computer_use
  @computer_use
end

#file_searchGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearch

A tool that can be used by the model to search files. Corresponds to the JSON property fileSearch



4841
4842
4843
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4841

def file_search
  @file_search
end

#functionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Function

A tool that can be used by the model. Corresponds to the JSON property function



4846
4847
4848
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4846

def function
  @function
end

#google_mapsGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMaps

A tool that can be used by the model to call Google Maps. Corresponds to the JSON property googleMaps



4851
4852
4853
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4851

def google_maps
  @google_maps
end

#google_searchGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearch

A tool that can be used by the model to search Google. Corresponds to the JSON property googleSearch



4856
4857
4858
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4856

def google_search
  @google_search
end

#mcp_serverGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServer

A MCPServer is a server that can be called by the model to perform actions. Corresponds to the JSON property mcpServer



4861
4862
4863
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4861

def mcp_server
  @mcp_server
end

#retrievalGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Retrieval

A tool that can be used by the model to retrieve files. Corresponds to the JSON property retrieval



4866
4867
4868
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4866

def retrieval
  @retrieval
end

#url_contextGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContext

A tool that can be used by the model to fetch URL context. Corresponds to the JSON property urlContext



4871
4872
4873
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4871

def url_context
  @url_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4878

def update!(**args)
  @code_execution = args[:code_execution] if args.key?(:code_execution)
  @computer_use = args[:computer_use] if args.key?(:computer_use)
  @file_search = args[:file_search] if args.key?(:file_search)
  @function = args[:function] if args.key?(:function)
  @google_maps = args[:google_maps] if args.key?(:google_maps)
  @google_search = args[:google_search] if args.key?(:google_search)
  @mcp_server = args[:mcp_server] if args.key?(:mcp_server)
  @retrieval = args[:retrieval] if args.key?(:retrieval)
  @url_context = args[:url_context] if args.key?(:url_context)
end