Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Tool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool that can be used by the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1Tool

Returns a new instance of GenaiVertexV1beta1Tool.



4468
4469
4470
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4468

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_executionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1CodeExecution

A tool that can be used by the model to execute code. Corresponds to the JSON property codeExecution



4426
4427
4428
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4426

def code_execution
  @code_execution
end

#computer_useGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ComputerUse

A tool that can be used by the model to interact with the computer. Corresponds to the JSON property computerUse



4431
4432
4433
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4431

def computer_use
  @computer_use
end

#file_searchGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1FileSearch

A tool that can be used by the model to search files. Corresponds to the JSON property fileSearch



4436
4437
4438
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4436

def file_search
  @file_search
end

#functionGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Function

A tool that can be used by the model. Corresponds to the JSON property function



4441
4442
4443
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4441

def function
  @function
end

#google_mapsGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleMaps

A tool that can be used by the model to call Google Maps. Corresponds to the JSON property googleMaps



4446
4447
4448
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4446

def google_maps
  @google_maps
end

#google_searchGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1GoogleSearch

A tool that can be used by the model to search Google. Corresponds to the JSON property googleSearch



4451
4452
4453
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4451

def google_search
  @google_search
end

#mcp_serverGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1McpServer

A MCPServer is a server that can be called by the model to perform actions. Corresponds to the JSON property mcpServer



4456
4457
4458
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4456

def mcp_server
  @mcp_server
end

#retrievalGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Retrieval

A tool that can be used by the model to retrieve files. Corresponds to the JSON property retrieval



4461
4462
4463
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4461

def retrieval
  @retrieval
end

#url_contextGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1UrlContext

A tool that can be used by the model to fetch URL context. Corresponds to the JSON property urlContext



4466
4467
4468
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4466

def url_context
  @url_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4473
4474
4475
4476
4477
4478
4479
4480
4481
4482
4483
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4473

def update!(**args)
  @code_execution = args[:code_execution] if args.key?(:code_execution)
  @computer_use = args[:computer_use] if args.key?(:computer_use)
  @file_search = args[:file_search] if args.key?(:file_search)
  @function = args[:function] if args.key?(:function)
  @google_maps = args[:google_maps] if args.key?(:google_maps)
  @google_search = args[:google_search] if args.key?(:google_search)
  @mcp_server = args[:mcp_server] if args.key?(:mcp_server)
  @retrieval = args[:retrieval] if args.key?(:retrieval)
  @url_context = args[:url_context] if args.key?(:url_context)
end