Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TranscriptionConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1TranscriptionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for speech recognition (transcription).
Instance Attribute Summary collapse
-
#adaptation_phrases ⇒ Array<String>
Optional.
-
#custom_vocabulary ⇒ Array<String>
Optional.
-
#diarization_mode ⇒ String
Optional.
-
#language_hints ⇒ Array<String>
Required.
-
#timestamp_granularities ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1TranscriptionConfig
constructor
A new instance of GenaiVertexV1beta1TranscriptionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1TranscriptionConfig
Returns a new instance of GenaiVertexV1beta1TranscriptionConfig.
6127 6128 6129 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6127 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adaptation_phrases ⇒ Array<String>
Optional. A list of phrases to bias the ASR model towards.
Corresponds to the JSON property adaptationPhrases
6101 6102 6103 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6101 def adaptation_phrases @adaptation_phrases end |
#custom_vocabulary ⇒ Array<String>
Optional. A list of custom vocabulary phrases to bias the speech recognition
model toward recognizing specific terms.
Corresponds to the JSON property customVocabulary
6107 6108 6109 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6107 def custom_vocabulary @custom_vocabulary end |
#diarization_mode ⇒ String
Optional. Configures speaker diarization. Supported values: "speaker".
Corresponds to the JSON property diarizationMode
6112 6113 6114 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6112 def diarization_mode @diarization_mode end |
#language_hints ⇒ Array<String>
Required. BCP-47 language codes providing hints about the languages present in
the audio. At least one must be specified, or set to ["auto"] to enable
automatic language detection.
Corresponds to the JSON property languageHints
6119 6120 6121 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6119 def language_hints @language_hints end |
#timestamp_granularities ⇒ Array<String>
Optional. The granularity of timestamps to include in the transcription output.
Supported values: "word". If empty, no timestamps are generated.
Corresponds to the JSON property timestampGranularities
6125 6126 6127 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6125 def @timestamp_granularities end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6132 6133 6134 6135 6136 6137 6138 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6132 def update!(**args) @adaptation_phrases = args[:adaptation_phrases] if args.key?(:adaptation_phrases) @custom_vocabulary = args[:custom_vocabulary] if args.key?(:custom_vocabulary) @diarization_mode = args[:diarization_mode] if args.key?(:diarization_mode) @language_hints = args[:language_hints] if args.key?(:language_hints) @timestamp_granularities = args[:timestamp_granularities] if args.key?(:timestamp_granularities) end |