Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1Value

Returns a new instance of GenaiVertexV1beta1Value.



6263
6264
6265
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6263

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Represents a boolean value. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


6229
6230
6231
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6229

def bool_value
  @bool_value
end

#content_valueGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Content

The content of the response. Corresponds to the JSON property contentValue



6235
6236
6237
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6235

def content_value
  @content_value
end

#list_valueGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ListValue

ListValue is a wrapper around a repeated field of values. Corresponds to the JSON property listValue



6240
6241
6242
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6240

def list_value
  @list_value
end

#null_valueString

Represents a null value. Corresponds to the JSON property nullValue

Returns:

  • (String)


6245
6246
6247
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6245

def null_value
  @null_value
end

#number_valueFloat

Represents a double value. Corresponds to the JSON property numberValue

Returns:

  • (Float)


6250
6251
6252
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6250

def number_value
  @number_value
end

#string_valueString

Represents a string value. Corresponds to the JSON property stringValue

Returns:

  • (String)


6255
6256
6257
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6255

def string_value
  @string_value
end

#struct_valueGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct

Struct represents a structured data value, consisting of fields which map to dynamically typed values. Corresponds to the JSON property structValue



6261
6262
6263
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6261

def struct_value
  @struct_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6268
6269
6270
6271
6272
6273
6274
6275
6276
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6268

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @content_value = args[:content_value] if args.key?(:content_value)
  @list_value = args[:list_value] if args.key?(:list_value)
  @null_value = args[:null_value] if args.key?(:null_value)
  @number_value = args[:number_value] if args.key?(:number_value)
  @string_value = args[:string_value] if args.key?(:string_value)
  @struct_value = args[:struct_value] if args.key?(:struct_value)
end