Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Value represents a dynamically typed value which can be either null, a
number, a string, a boolean, a recursive struct value, or a list of values. A
producer of value is expected to set one of these variants. Absence of any
variant indicates an error.
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
Represents a boolean value.
-
#list_value ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ListValue
ListValueis a wrapper around a repeated field of values. -
#null_value ⇒ String
Represents a null value.
-
#number_value ⇒ Float
Represents a double value.
-
#string_value ⇒ String
Represents a string value.
-
#struct_value ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Structrepresents a structured data value, consisting of fields which map to dynamically typed values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenaiVertexV1beta1Value
constructor
A new instance of GenaiVertexV1beta1Value.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenaiVertexV1beta1Value
Returns a new instance of GenaiVertexV1beta1Value.
5931 5932 5933 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
Represents a boolean value.
Corresponds to the JSON property boolValue
5902 5903 5904 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5902 def bool_value @bool_value end |
#list_value ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1ListValue
ListValue is a wrapper around a repeated field of values.
Corresponds to the JSON property listValue
5908 5909 5910 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5908 def list_value @list_value end |
#null_value ⇒ String
Represents a null value.
Corresponds to the JSON property nullValue
5913 5914 5915 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5913 def null_value @null_value end |
#number_value ⇒ Float
Represents a double value.
Corresponds to the JSON property numberValue
5918 5919 5920 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5918 def number_value @number_value end |
#string_value ⇒ String
Represents a string value.
Corresponds to the JSON property stringValue
5923 5924 5925 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5923 def string_value @string_value end |
#struct_value ⇒ Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct
Struct represents a structured data value, consisting of fields which map to
dynamically typed values.
Corresponds to the JSON property structValue
5929 5930 5931 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5929 def struct_value @struct_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5936 5937 5938 5939 5940 5941 5942 5943 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5936 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @list_value = args[:list_value] if args.key?(:list_value) @null_value = args[:null_value] if args.key?(:null_value) @number_value = args[:number_value] if args.key?(:number_value) @string_value = args[:string_value] if args.key?(:string_value) @struct_value = args[:struct_value] if args.key?(:struct_value) end |