Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1Value

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1Value

Returns a new instance of GenaiVertexV1beta1Value.



6106
6107
6108
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6106

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Represents a boolean value. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


6077
6078
6079
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6077

def bool_value
  @bool_value
end

#list_valueGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1ListValue

ListValue is a wrapper around a repeated field of values. Corresponds to the JSON property listValue



6083
6084
6085
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6083

def list_value
  @list_value
end

#null_valueString

Represents a null value. Corresponds to the JSON property nullValue

Returns:

  • (String)


6088
6089
6090
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6088

def null_value
  @null_value
end

#number_valueFloat

Represents a double value. Corresponds to the JSON property numberValue

Returns:

  • (Float)


6093
6094
6095
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6093

def number_value
  @number_value
end

#string_valueString

Represents a string value. Corresponds to the JSON property stringValue

Returns:

  • (String)


6098
6099
6100
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6098

def string_value
  @string_value
end

#struct_valueGoogle::Apis::AiplatformV1beta1::GenaiVertexV1beta1Struct

Struct represents a structured data value, consisting of fields which map to dynamically typed values. Corresponds to the JSON property structValue



6104
6105
6106
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6104

def struct_value
  @struct_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6111
6112
6113
6114
6115
6116
6117
6118
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6111

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @list_value = args[:list_value] if args.key?(:list_value)
  @null_value = args[:null_value] if args.key?(:null_value)
  @number_value = args[:number_value] if args.key?(:number_value)
  @string_value = args[:string_value] if args.key?(:string_value)
  @struct_value = args[:struct_value] if args.key?(:struct_value)
end