Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1VideoConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration options for video generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1VideoConfig

Returns a new instance of GenaiVertexV1beta1VideoConfig.



6780
6781
6782
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6780

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#taskString

Optional task mode for video generation. If not specified, the model automatically determines the appropriate mode based on the provided text prompt and input media. Corresponds to the JSON property task

Returns:

  • (String)


6778
6779
6780
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6778

def task
  @task
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6785
6786
6787
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6785

def update!(**args)
  @task = args[:task] if args.key?(:task)
end