Class: Google::Apis::AiplatformV1beta1::GenaiVertexV1beta1VideoConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration options for video generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenaiVertexV1beta1VideoConfig

Returns a new instance of GenaiVertexV1beta1VideoConfig.



6573
6574
6575
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#taskString

Optional task mode for video generation. If not specified, the model automatically determines the appropriate mode based on the provided text prompt and input media. Corresponds to the JSON property task

Returns:

  • (String)


6571
6572
6573
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6571

def task
  @task
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6578
6579
6580
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6578

def update!(**args)
  @task = args[:task] if args.key?(:task)
end