Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aPart
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aPart
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A single part of a message or artifact. A part carries exactly one kind of content.
Instance Attribute Summary collapse
-
#data ⇒ Hash<String,Object>
Optional.
-
#filename ⇒ String
Optional.
-
#media_type ⇒ String
Optional.
-
#metadata ⇒ Hash<String,Object>
Optional.
-
#raw ⇒ String
Optional.
-
#text ⇒ String
Optional.
-
#url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aPart
constructor
A new instance of GoogleCloudAiplatformV1beta1A2aPart.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aPart
Returns a new instance of GoogleCloudAiplatformV1beta1A2aPart.
6828 6829 6830 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6828 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ Hash<String,Object>
Optional. Structured data content.
Corresponds to the JSON property data
6794 6795 6796 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6794 def data @data end |
#filename ⇒ String
Optional. The name of the file, when the part represents a file.
Corresponds to the JSON property filename
6799 6800 6801 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6799 def filename @filename end |
#media_type ⇒ String
Optional. The IANA media type of the content, e.g. "text/plain" or "image/png".
Corresponds to the JSON property mediaType
6804 6805 6806 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6804 def media_type @media_type end |
#metadata ⇒ Hash<String,Object>
Optional. Additional context or parameters related to the part. Extensions can
be used to strongly type metadata values for specific use cases.
Corresponds to the JSON property metadata
6810 6811 6812 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6810 def @metadata end |
#raw ⇒ String
Optional. Raw binary content.
Corresponds to the JSON property raw
NOTE: Values are automatically base64 encoded/decoded in the client library.
6816 6817 6818 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6816 def raw @raw end |
#text ⇒ String
Optional. Textual content.
Corresponds to the JSON property text
6821 6822 6823 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6821 def text @text end |
#url ⇒ String
Optional. A URL pointing to the content.
Corresponds to the JSON property url
6826 6827 6828 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6826 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6833 6834 6835 6836 6837 6838 6839 6840 6841 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6833 def update!(**args) @data = args[:data] if args.key?(:data) @filename = args[:filename] if args.key?(:filename) @media_type = args[:media_type] if args.key?(:media_type) @metadata = args[:metadata] if args.key?(:metadata) @raw = args[:raw] if args.key?(:raw) @text = args[:text] if args.key?(:text) @url = args[:url] if args.key?(:url) end |