Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTask
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTask
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An A2aTask represents a unit of work.
Instance Attribute Summary collapse
-
#app_id ⇒ String
Optional.
-
#artifacts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifact>
Output only.
-
#context_id ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#expire_time ⇒ String
Optional.
-
#generation ⇒ Fixnum
Output only.
-
#history ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage>
Output only.
-
#metadata ⇒ Hash<String,Object>
Optional.
-
#name ⇒ String
Identifier.
-
#next_event_sequence_number ⇒ Fixnum
Output only.
-
#output ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskOutput
Represents the final output of a task.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskStatus
Represents the status of an A2aTask.
-
#status_details ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskStatusDetails
Represents the additional status details of a task.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#user_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTask
constructor
A new instance of GoogleCloudAiplatformV1beta1A2aTask.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTask
Returns a new instance of GoogleCloudAiplatformV1beta1A2aTask.
7150 7151 7152 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7150 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
Optional. Agent application which created the task.
Corresponds to the JSON property appId
7060 7061 7062 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7060 def app_id @app_id end |
#artifacts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifact>
Output only. The artifacts produced by the task.
Corresponds to the JSON property artifacts
7065 7066 7067 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7065 def artifacts @artifacts end |
#context_id ⇒ String
Optional. A generic identifier for grouping related tasks (e.g., session_id,
workflow_id).
Corresponds to the JSON property contextId
7071 7072 7073 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7071 def context_id @context_id end |
#create_time ⇒ String
Output only. The creation timestamp of the task.
Corresponds to the JSON property createTime
7076 7077 7078 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7076 def create_time @create_time end |
#expire_time ⇒ String
Optional. Timestamp of when this task is considered expired. This is always
provided on output, and is calculated based on the ttl if set on the request
Corresponds to the JSON property expireTime
7082 7083 7084 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7082 def expire_time @expire_time end |
#generation ⇒ Fixnum
Output only. The task generation number.
Corresponds to the JSON property generation
7087 7088 7089 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7087 def generation @generation end |
#history ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage>
Output only. The history of the task messages.
Corresponds to the JSON property history
7092 7093 7094 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7092 def history @history end |
#metadata ⇒ Hash<String,Object>
Optional. Arbitrary, user-defined metadata.
Corresponds to the JSON property metadata
7097 7098 7099 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7097 def @metadata end |
#name ⇒ String
Identifier. The resource name of the task. Format: projects/project/
locations/location/reasoningEngines/reasoning_engine/a2aTasks/a2a_task
or `projects/`project`/locations/`location`/taskStores/`task_store`/a2aTasks/`
a2a_task
Corresponds to the JSON property name
7105 7106 7107 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7105 def name @name end |
#next_event_sequence_number ⇒ Fixnum
Output only. The next event sequence number to be appended to the task. This
value starts at 1 and is guaranteed to be monotonically increasing.
Corresponds to the JSON property nextEventSequenceNumber
7111 7112 7113 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7111 def next_event_sequence_number @next_event_sequence_number end |
#output ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskOutput
Represents the final output of a task.
Corresponds to the JSON property output
7116 7117 7118 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7116 def output @output end |
#state ⇒ String
Output only. The state of the task. The state of a new task is SUBMITTED by
default. The state of a task can only be updated via AppendA2aTaskEvents API.
Corresponds to the JSON property state
7122 7123 7124 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7122 def state @state end |
#status ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskStatus
Represents the status of an A2aTask.
Corresponds to the JSON property status
7127 7128 7129 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7127 def status @status end |
#status_details ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskStatusDetails
Represents the additional status details of a task.
Corresponds to the JSON property statusDetails
7132 7133 7134 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7132 def status_details @status_details end |
#ttl ⇒ String
Optional. Input only. The TTL (Time To Live) for the task. If not set, the
task will expire in 24 hours by default. Valid range: (0 seconds, 1000 days]
Corresponds to the JSON property ttl
7138 7139 7140 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7138 def ttl @ttl end |
#update_time ⇒ String
Output only. The last update timestamp of the task.
Corresponds to the JSON property updateTime
7143 7144 7145 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7143 def update_time @update_time end |
#user_id ⇒ String
Optional. Task owner user ID.
Corresponds to the JSON property userId
7148 7149 7150 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7148 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 7171 7172 7173 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7155 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @artifacts = args[:artifacts] if args.key?(:artifacts) @context_id = args[:context_id] if args.key?(:context_id) @create_time = args[:create_time] if args.key?(:create_time) @expire_time = args[:expire_time] if args.key?(:expire_time) @generation = args[:generation] if args.key?(:generation) @history = args[:history] if args.key?(:history) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @next_event_sequence_number = args[:next_event_sequence_number] if args.key?(:next_event_sequence_number) @output = args[:output] if args.key?(:output) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @status_details = args[:status_details] if args.key?(:status_details) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) @user_id = args[:user_id] if args.key?(:user_id) end |