Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTask

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An A2aTask represents a unit of work.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTask

Returns a new instance of GoogleCloudAiplatformV1beta1A2aTask.



6941
6942
6943
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6941

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

Optional. Agent application which created the task. Corresponds to the JSON property appId

Returns:

  • (String)


6851
6852
6853
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6851

def app_id
  @app_id
end

#artifactsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifact>

Output only. The artifacts produced by the task. Corresponds to the JSON property artifacts



6856
6857
6858
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6856

def artifacts
  @artifacts
end

#context_idString

Optional. A generic identifier for grouping related tasks (e.g., session_id, workflow_id). Corresponds to the JSON property contextId

Returns:

  • (String)


6862
6863
6864
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6862

def context_id
  @context_id
end

#create_timeString

Output only. The creation timestamp of the task. Corresponds to the JSON property createTime

Returns:

  • (String)


6867
6868
6869
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6867

def create_time
  @create_time
end

#expire_timeString

Optional. Timestamp of when this task is considered expired. This is always provided on output, and is calculated based on the ttl if set on the request Corresponds to the JSON property expireTime

Returns:

  • (String)


6873
6874
6875
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6873

def expire_time
  @expire_time
end

#generationFixnum

Output only. The task generation number. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


6878
6879
6880
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6878

def generation
  @generation
end

#historyArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage>

Output only. The history of the task messages. Corresponds to the JSON property history



6883
6884
6885
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6883

def history
  @history
end

#metadataHash<String,Object>

Optional. Arbitrary, user-defined metadata. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


6888
6889
6890
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6888

def 
  @metadata
end

#nameString

Identifier. The resource name of the task. Format: projects/project/ locations/location/reasoningEngines/reasoning_engine/a2aTasks/a2a_task or `projects/`project`/locations/`location`/taskStores/`task_store`/a2aTasks/` a2a_task Corresponds to the JSON property name

Returns:

  • (String)


6896
6897
6898
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6896

def name
  @name
end

#next_event_sequence_numberFixnum

Output only. The next event sequence number to be appended to the task. This value starts at 1 and is guaranteed to be monotonically increasing. Corresponds to the JSON property nextEventSequenceNumber

Returns:

  • (Fixnum)


6902
6903
6904
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6902

def next_event_sequence_number
  @next_event_sequence_number
end

#outputGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskOutput

Represents the final output of a task. Corresponds to the JSON property output



6907
6908
6909
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6907

def output
  @output
end

#stateString

Output only. The state of the task. The state of a new task is SUBMITTED by default. The state of a task can only be updated via AppendA2aTaskEvents API. Corresponds to the JSON property state

Returns:

  • (String)


6913
6914
6915
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6913

def state
  @state
end

#statusGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskStatus

Represents the status of an A2aTask. Corresponds to the JSON property status



6918
6919
6920
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6918

def status
  @status
end

#status_detailsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskStatusDetails

Represents the additional status details of a task. Corresponds to the JSON property statusDetails



6923
6924
6925
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6923

def status_details
  @status_details
end

#ttlString

Optional. Input only. The TTL (Time To Live) for the task. If not set, the task will expire in 24 hours by default. Valid range: (0 seconds, 1000 days] Corresponds to the JSON property ttl

Returns:

  • (String)


6929
6930
6931
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6929

def ttl
  @ttl
end

#update_timeString

Output only. The last update timestamp of the task. Corresponds to the JSON property updateTime

Returns:

  • (String)


6934
6935
6936
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6934

def update_time
  @update_time
end

#user_idString

Optional. Task owner user ID. Corresponds to the JSON property userId

Returns:

  • (String)


6939
6940
6941
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6939

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6946
6947
6948
6949
6950
6951
6952
6953
6954
6955
6956
6957
6958
6959
6960
6961
6962
6963
6964
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6946

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @artifacts = args[:artifacts] if args.key?(:artifacts)
  @context_id = args[:context_id] if args.key?(:context_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @generation = args[:generation] if args.key?(:generation)
  @history = args[:history] if args.key?(:history)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @next_event_sequence_number = args[:next_event_sequence_number] if args.key?(:next_event_sequence_number)
  @output = args[:output] if args.key?(:output)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @status_details = args[:status_details] if args.key?(:status_details)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_id = args[:user_id] if args.key?(:user_id)
end