Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTask

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An A2aTask represents a unit of work.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTask

Returns a new instance of GoogleCloudAiplatformV1beta1A2aTask.



5470
5471
5472
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5470

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#context_idString

Optional. A generic identifier for grouping related tasks (e.g., session_id, workflow_id). Corresponds to the JSON property contextId

Returns:

  • (String)


5413
5414
5415
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5413

def context_id
  @context_id
end

#create_timeString

Output only. The creation timestamp of the task. Corresponds to the JSON property createTime

Returns:

  • (String)


5418
5419
5420
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5418

def create_time
  @create_time
end

#expire_timeString

Optional. Timestamp of when this task is considered expired. This is always provided on output, and is calculated based on the ttl if set on the request Corresponds to the JSON property expireTime

Returns:

  • (String)


5424
5425
5426
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5424

def expire_time
  @expire_time
end

#metadataHash<String,Object>

Optional. Arbitrary, user-defined metadata. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


5429
5430
5431
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5429

def 
  @metadata
end

#nameString

Identifier. The resource name of the task. Format: projects/project/ locations/location/reasoningEngines/reasoning_engine/a2aTasks/a2a_task` Corresponds to the JSON propertyname`

Returns:

  • (String)


5435
5436
5437
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5435

def name
  @name
end

#next_event_sequence_numberFixnum

Output only. The next event sequence number to be appended to the task. This value starts at 1 and is guaranteed to be monotonically increasing. Corresponds to the JSON property nextEventSequenceNumber

Returns:

  • (Fixnum)


5441
5442
5443
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5441

def next_event_sequence_number
  @next_event_sequence_number
end

#outputGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskOutput

Represents the final output of a task. Corresponds to the JSON property output



5446
5447
5448
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5446

def output
  @output
end

#stateString

Output only. The state of the task. The state of a new task is SUBMITTED by default. The state of a task can only be updated via AppendA2aTaskEvents API. Corresponds to the JSON property state

Returns:

  • (String)


5452
5453
5454
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5452

def state
  @state
end

#status_detailsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskStatusDetails

Represents the additional status details of a task. Corresponds to the JSON property statusDetails



5457
5458
5459
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5457

def status_details
  @status_details
end

#ttlString

Optional. Input only. The TTL (Time To Live) for the task. If not set, the task will expire in 24 hours by default. Valid range: (0 seconds, 1000 days] Corresponds to the JSON property ttl

Returns:

  • (String)


5463
5464
5465
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5463

def ttl
  @ttl
end

#update_timeString

Output only. The last update timestamp of the task. Corresponds to the JSON property updateTime

Returns:

  • (String)


5468
5469
5470
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5468

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5475
5476
5477
5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5475

def update!(**args)
  @context_id = args[:context_id] if args.key?(:context_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @next_event_sequence_number = args[:next_event_sequence_number] if args.key?(:next_event_sequence_number)
  @output = args[:output] if args.key?(:output)
  @state = args[:state] if args.key?(:state)
  @status_details = args[:status_details] if args.key?(:status_details)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end