Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a single artifact produced by a task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskArtifact

Returns a new instance of GoogleCloudAiplatformV1beta1A2aTaskArtifact.



7002
7003
7004
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_idString

Required. The unique identifier of the artifact within the task. Corresponds to the JSON property artifactId

Returns:

  • (String)


6974
6975
6976
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6974

def artifact_id
  @artifact_id
end

#descriptionString

Optional. A human-readable description of the artifact. Corresponds to the JSON property description

Returns:

  • (String)


6979
6980
6981
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6979

def description
  @description
end

#display_nameString

Optional. The human-readable name of the artifact. Corresponds to the JSON property displayName

Returns:

  • (String)


6984
6985
6986
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6984

def display_name
  @display_name
end

#extensionsArray<String>

Optional. A2A protocol extensions associated with the artifact. Corresponds to the JSON property extensions

Returns:

  • (Array<String>)


6989
6990
6991
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6989

def extensions
  @extensions
end

#metadataHash<String,Object>

Optional. Additional context or parameters related to the artifact. Extensions can be used to strongly type metadata values for specific use cases. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


6995
6996
6997
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6995

def 
  @metadata
end

#partsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aPart>

Required. The content parts that make up the artifact. Corresponds to the JSON property parts



7000
7001
7002
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7000

def parts
  @parts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7007
7008
7009
7010
7011
7012
7013
7014
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7007

def update!(**args)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @extensions = args[:extensions] if args.key?(:extensions)
  @metadata = args[:metadata] if args.key?(:metadata)
  @parts = args[:parts] if args.key?(:parts)
end