Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifactChange
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifactChange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An event payload describing a change to one of the task's artifacts.
Instance Attribute Summary collapse
-
#append ⇒ Boolean
(also: #append?)
Optional.
-
#artifact ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifact
Represents a single artifact produced by a task.
-
#last_chunk ⇒ Boolean
(also: #last_chunk?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskArtifactChange
constructor
A new instance of GoogleCloudAiplatformV1beta1A2aTaskArtifactChange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskArtifactChange
Returns a new instance of GoogleCloudAiplatformV1beta1A2aTaskArtifactChange.
7248 7249 7250 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7248 def initialize(**args) update!(**args) end |
Instance Attribute Details
#append ⇒ Boolean Also known as: append?
Optional. Whether the artifact parts should be appended to an existing
artifact rather than replacing it.
Corresponds to the JSON property append
7234 7235 7236 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7234 def append @append end |
#artifact ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifact
Represents a single artifact produced by a task.
Corresponds to the JSON property artifact
7240 7241 7242 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7240 def artifact @artifact end |
#last_chunk ⇒ Boolean Also known as: last_chunk?
Optional. Whether this is the last chunk of a streamed artifact.
Corresponds to the JSON property lastChunk
7245 7246 7247 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7245 def last_chunk @last_chunk end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7253 7254 7255 7256 7257 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7253 def update!(**args) @append = args[:append] if args.key?(:append) @artifact = args[:artifact] if args.key?(:artifact) @last_chunk = args[:last_chunk] if args.key?(:last_chunk) end |