Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifactChange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An event payload describing a change to one of the task's artifacts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskArtifactChange

Returns a new instance of GoogleCloudAiplatformV1beta1A2aTaskArtifactChange.



7039
7040
7041
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7039

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appendBoolean Also known as: append?

Optional. Whether the artifact parts should be appended to an existing artifact rather than replacing it. Corresponds to the JSON property append

Returns:

  • (Boolean)


7025
7026
7027
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7025

def append
  @append
end

#artifactGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifact

Represents a single artifact produced by a task. Corresponds to the JSON property artifact



7031
7032
7033
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7031

def artifact
  @artifact
end

#last_chunkBoolean Also known as: last_chunk?

Optional. Whether this is the last chunk of a streamed artifact. Corresponds to the JSON property lastChunk

Returns:

  • (Boolean)


7036
7037
7038
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7036

def last_chunk
  @last_chunk
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7044
7045
7046
7047
7048
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7044

def update!(**args)
  @append = args[:append] if args.key?(:append)
  @artifact = args[:artifact] if args.key?(:artifact)
  @last_chunk = args[:last_chunk] if args.key?(:last_chunk)
end