Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An event that records a single change applied to a task's state.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#event_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskEventData
The data describing the change carried by an A2aTaskEvent.
-
#generation ⇒ Fixnum
Output only.
-
#metadata ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskEvent
constructor
A new instance of GoogleCloudAiplatformV1beta1A2aTaskEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskEvent
Returns a new instance of GoogleCloudAiplatformV1beta1A2aTaskEvent.
7077 7078 7079 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the event was created.
Corresponds to the JSON property createTime
7058 7059 7060 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7058 def create_time @create_time end |
#event_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskEventData
The data describing the change carried by an A2aTaskEvent. Exactly one of the
following changes is set per event.
Corresponds to the JSON property eventData
7064 7065 7066 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7064 def event_data @event_data end |
#generation ⇒ Fixnum
Output only. The generation number of the task after this event is applied.
Corresponds to the JSON property generation
7069 7070 7071 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7069 def generation @generation end |
#metadata ⇒ Hash<String,Object>
Optional. Additional context or parameters related to the event. Extensions
can be used to strongly type metadata values for specific use cases.
Corresponds to the JSON property metadata
7075 7076 7077 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7075 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7082 7083 7084 7085 7086 7087 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7082 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @event_data = args[:event_data] if args.key?(:event_data) @generation = args[:generation] if args.key?(:generation) @metadata = args[:metadata] if args.key?(:metadata) end |