Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskEventData
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskEventData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The data describing the change carried by an A2aTaskEvent. Exactly one of the following changes is set per event.
Instance Attribute Summary collapse
-
#artifact_change ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifactChange
An event payload describing a change to one of the task's artifacts.
-
#history_append ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskHistoryAppend
An event payload that appends a new message to the task history.
-
#metadata_change ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMetadataChange
An event payload describing a change to the task-level metadata.
-
#status_update ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskStatusUpdate
An event payload that updates the task's state and optional status message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskEventData
constructor
A new instance of GoogleCloudAiplatformV1beta1A2aTaskEventData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskEventData
Returns a new instance of GoogleCloudAiplatformV1beta1A2aTaskEventData.
7115 7116 7117 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_change ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskArtifactChange
An event payload describing a change to one of the task's artifacts.
Corresponds to the JSON property artifactChange
7098 7099 7100 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7098 def artifact_change @artifact_change end |
#history_append ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskHistoryAppend
An event payload that appends a new message to the task history.
Corresponds to the JSON property historyAppend
7103 7104 7105 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7103 def history_append @history_append end |
#metadata_change ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMetadataChange
An event payload describing a change to the task-level metadata.
Corresponds to the JSON property metadataChange
7108 7109 7110 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7108 def @metadata_change end |
#status_update ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskStatusUpdate
An event payload that updates the task's state and optional status message.
Corresponds to the JSON property statusUpdate
7113 7114 7115 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7113 def status_update @status_update end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7120 7121 7122 7123 7124 7125 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7120 def update!(**args) @artifact_change = args[:artifact_change] if args.key?(:artifact_change) @history_append = args[:history_append] if args.key?(:history_append) @metadata_change = args[:metadata_change] if args.key?(:metadata_change) @status_update = args[:status_update] if args.key?(:status_update) end |