Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskHistoryAppend
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskHistoryAppend
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An event payload that appends a new message to the task history.
Instance Attribute Summary collapse
-
#message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage
Represents a single message in a conversation, compliant with the A2A specification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskHistoryAppend
constructor
A new instance of GoogleCloudAiplatformV1beta1A2aTaskHistoryAppend.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskHistoryAppend
Returns a new instance of GoogleCloudAiplatformV1beta1A2aTaskHistoryAppend.
7138 7139 7140 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7138 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage
Represents a single message in a conversation, compliant with the A2A
specification.
Corresponds to the JSON property message
7136 7137 7138 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7136 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7143 7144 7145 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7143 def update!(**args) @message = args[:message] if args.key?(:message) end |