Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a single message in a conversation, compliant with the A2A specification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskMessage

Returns a new instance of GoogleCloudAiplatformV1beta1A2aTaskMessage.



7393
7394
7395
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#extensionsArray<String>

Optional. A2A protocol extensions associated with the message. Corresponds to the JSON property extensions

Returns:

  • (Array<String>)


7365
7366
7367
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7365

def extensions
  @extensions
end

#message_idString

Required. The unique identifier of the message. Corresponds to the JSON property messageId

Returns:

  • (String)


7370
7371
7372
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7370

def message_id
  @message_id
end

#metadataHash<String,Object>

Optional. Additional context or parameters related to the message. Extensions can be used to strongly type metadata values for specific use cases. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


7376
7377
7378
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7376

def 
  @metadata
end

#partsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aPart>

Required. The content parts that make up the message. Corresponds to the JSON property parts



7381
7382
7383
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7381

def parts
  @parts
end

#reference_task_idsArray<String>

Optional. The IDs of other tasks referenced by this message. Corresponds to the JSON property referenceTaskIds

Returns:

  • (Array<String>)


7386
7387
7388
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7386

def reference_task_ids
  @reference_task_ids
end

#roleString

Required. The role of the sender of the message. Corresponds to the JSON property role

Returns:

  • (String)


7391
7392
7393
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7391

def role
  @role
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7398
7399
7400
7401
7402
7403
7404
7405
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7398

def update!(**args)
  @extensions = args[:extensions] if args.key?(:extensions)
  @message_id = args[:message_id] if args.key?(:message_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @parts = args[:parts] if args.key?(:parts)
  @reference_task_ids = args[:reference_task_ids] if args.key?(:reference_task_ids)
  @role = args[:role] if args.key?(:role)
end