Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a single message in a conversation, compliant with the A2A specification.
Instance Attribute Summary collapse
-
#extensions ⇒ Array<String>
Optional.
-
#message_id ⇒ String
Required.
-
#metadata ⇒ Hash<String,Object>
Optional.
-
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aPart>
Required.
-
#reference_task_ids ⇒ Array<String>
Optional.
-
#role ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskMessage
constructor
A new instance of GoogleCloudAiplatformV1beta1A2aTaskMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskMessage
Returns a new instance of GoogleCloudAiplatformV1beta1A2aTaskMessage.
7184 7185 7186 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7184 def initialize(**args) update!(**args) end |
Instance Attribute Details
#extensions ⇒ Array<String>
Optional. A2A protocol extensions associated with the message.
Corresponds to the JSON property extensions
7156 7157 7158 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7156 def extensions @extensions end |
#message_id ⇒ String
Required. The unique identifier of the message.
Corresponds to the JSON property messageId
7161 7162 7163 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7161 def @message_id end |
#metadata ⇒ Hash<String,Object>
Optional. Additional context or parameters related to the message. Extensions
can be used to strongly type metadata values for specific use cases.
Corresponds to the JSON property metadata
7167 7168 7169 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7167 def @metadata end |
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aPart>
Required. The content parts that make up the message.
Corresponds to the JSON property parts
7172 7173 7174 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7172 def parts @parts end |
#reference_task_ids ⇒ Array<String>
Optional. The IDs of other tasks referenced by this message.
Corresponds to the JSON property referenceTaskIds
7177 7178 7179 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7177 def reference_task_ids @reference_task_ids end |
#role ⇒ String
Required. The role of the sender of the message.
Corresponds to the JSON property role
7182 7183 7184 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7182 def role @role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7189 7190 7191 7192 7193 7194 7195 7196 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7189 def update!(**args) @extensions = args[:extensions] if args.key?(:extensions) @message_id = args[:message_id] if args.key?(:message_id) @metadata = args[:metadata] if args.key?(:metadata) @parts = args[:parts] if args.key?(:parts) @reference_task_ids = args[:reference_task_ids] if args.key?(:reference_task_ids) @role = args[:role] if args.key?(:role) end |