Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskStatusUpdate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskStatusUpdate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An event payload that updates the task's state and optional status message.
Instance Attribute Summary collapse
-
#message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage
Represents a single message in a conversation, compliant with the A2A specification.
-
#state ⇒ String
Required.
-
#timestamp ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskStatusUpdate
constructor
A new instance of GoogleCloudAiplatformV1beta1A2aTaskStatusUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1A2aTaskStatusUpdate
Returns a new instance of GoogleCloudAiplatformV1beta1A2aTaskStatusUpdate.
7277 7278 7279 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7277 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1A2aTaskMessage
Represents a single message in a conversation, compliant with the A2A
specification.
Corresponds to the JSON property message
7265 7266 7267 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7265 def @message end |
#state ⇒ String
Required. The new state of the task.
Corresponds to the JSON property state
7270 7271 7272 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7270 def state @state end |
#timestamp ⇒ String
Optional. The time at which the status change occurred.
Corresponds to the JSON property timestamp
7275 7276 7277 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7275 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7282 7283 7284 7285 7286 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7282 def update!(**args) @message = args[:message] if args.key?(:message) @state = args[:state] if args.key?(:state) @timestamp = args[:timestamp] if args.key?(:timestamp) end |