Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Agent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A Vertex agent contains instructions and configurations for the LLM to execute a certain task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Agent

Returns a new instance of GoogleCloudAiplatformV1beta1Agent.



6861
6862
6863
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6861

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_agentString

Required. The base agent for the agent. Supported values: * antigravity- preview-05-2026 Corresponds to the JSON property base_agent

Returns:

  • (String)


6802
6803
6804
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6802

def base_agent
  @base_agent
end

#base_environmentObject

Optional. The base environment configuration for the agent. Valid types: * A string value for the environment ID, or remote for the default. * A struct value for the environment_config. Corresponds to the JSON property base_environment

Returns:

  • (Object)


6809
6810
6811
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6809

def base_environment
  @base_environment
end

#createdString

Output only. The time the agent was created. Corresponds to the JSON property created

Returns:

  • (String)


6814
6815
6816
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6814

def created
  @created
end

#descriptionString

Optional. The description of the agent. Corresponds to the JSON property description

Returns:

  • (String)


6819
6820
6821
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6819

def description
  @description
end

#idString

Immutable. The user-specified ID for the agent. This ID becomes the final component of the agent resource name. If not provided, Vertex AI will generate a value for this ID. The ID can be up to 63 characters and must match the regular expression [a-z]([a-z0-9-]0,61[a-z0-9])?. Corresponds to the JSON property id

Returns:

  • (String)


6827
6828
6829
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6827

def id
  @id
end

#metadataHash<String,String>

Optional. The metadata for the agent. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


6832
6833
6834
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6832

def 
  @metadata
end

#nameString

Identifier. The resource name of the agent. Format: projects/project/ locations/location/agents/agent`. Corresponds to the JSON propertyname`

Returns:

  • (String)


6838
6839
6840
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6838

def name
  @name
end

#objectString

Output only. The object type of the resource. For agents, the value is agent. Corresponds to the JSON property object

Returns:

  • (String)


6843
6844
6845
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6843

def object
  @object
end

#system_instructionString

Optional. The instructions for the agent to follow. These instructions are passed to the LLM as a system instruction. Corresponds to the JSON property system_instruction

Returns:

  • (String)


6849
6850
6851
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6849

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentTool>

Optional. The tools available to the agent. Corresponds to the JSON property tools



6854
6855
6856
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6854

def tools
  @tools
end

#updatedString

Output only. The time the agent was last updated. Corresponds to the JSON property updated

Returns:

  • (String)


6859
6860
6861
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6859

def updated
  @updated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6866
6867
6868
6869
6870
6871
6872
6873
6874
6875
6876
6877
6878
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6866

def update!(**args)
  @base_agent = args[:base_agent] if args.key?(:base_agent)
  @base_environment = args[:base_environment] if args.key?(:base_environment)
  @created = args[:created] if args.key?(:created)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @object = args[:object] if args.key?(:object)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
  @updated = args[:updated] if args.key?(:updated)
end