Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Agent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A Vertex agent contains instructions and configurations for the LLM to execute a certain task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Agent

Returns a new instance of GoogleCloudAiplatformV1beta1Agent.



6644
6645
6646
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_agentString

Required. The base agent for the agent. Supported values: * antigravity- preview-05-2026 Corresponds to the JSON property base_agent

Returns:

  • (String)


6585
6586
6587
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6585

def base_agent
  @base_agent
end

#base_environmentObject

Optional. The base environment configuration for the agent. Valid types: * A string value for the environment ID, or remote for the default. * A struct value for the environment_config. Corresponds to the JSON property base_environment

Returns:

  • (Object)


6592
6593
6594
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6592

def base_environment
  @base_environment
end

#createdString

Output only. The time the agent was created. Corresponds to the JSON property created

Returns:

  • (String)


6597
6598
6599
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6597

def created
  @created
end

#descriptionString

Optional. The description of the agent. Corresponds to the JSON property description

Returns:

  • (String)


6602
6603
6604
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6602

def description
  @description
end

#idString

Immutable. The user-specified ID for the agent. This ID becomes the final component of the agent resource name. If not provided, Vertex AI will generate a value for this ID. The ID can be up to 63 characters and must match the regular expression [a-z]([a-z0-9-]0,61[a-z0-9])?. Corresponds to the JSON property id

Returns:

  • (String)


6610
6611
6612
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6610

def id
  @id
end

#metadataHash<String,String>

Optional. The metadata for the agent. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


6615
6616
6617
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6615

def 
  @metadata
end

#nameString

Identifier. The resource name of the agent. Format: projects/project/ locations/location/agents/agent`. Corresponds to the JSON propertyname`

Returns:

  • (String)


6621
6622
6623
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6621

def name
  @name
end

#objectString

Output only. The object type of the resource. For agents, the value is agent. Corresponds to the JSON property object

Returns:

  • (String)


6626
6627
6628
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6626

def object
  @object
end

#system_instructionString

Optional. The instructions for the agent to follow. These instructions are passed to the LLM as a system instruction. Corresponds to the JSON property system_instruction

Returns:

  • (String)


6632
6633
6634
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6632

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentTool>

Optional. The tools available to the agent. Corresponds to the JSON property tools



6637
6638
6639
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6637

def tools
  @tools
end

#updatedString

Output only. The time the agent was last updated. Corresponds to the JSON property updated

Returns:

  • (String)


6642
6643
6644
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6642

def updated
  @updated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6649
6650
6651
6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6649

def update!(**args)
  @base_agent = args[:base_agent] if args.key?(:base_agent)
  @base_environment = args[:base_environment] if args.key?(:base_environment)
  @created = args[:created] if args.key?(:created)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @object = args[:object] if args.key?(:object)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
  @updated = args[:updated] if args.key?(:updated)
end