Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Agent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A Vertex agent contains instructions and configurations for the LLM to execute a certain task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Agent

Returns a new instance of GoogleCloudAiplatformV1beta1Agent.



6177
6178
6179
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6177

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_agentString

Required. The base agent for the agent. Supported values: * antigravity- preview-05-2026 Corresponds to the JSON property base_agent

Returns:

  • (String)


6118
6119
6120
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6118

def base_agent
  @base_agent
end

#base_environmentObject

Optional. The base environment configuration for the agent. Valid types: * A string value for the environment ID, or remote for the default. * A struct value for the environment_config. Corresponds to the JSON property base_environment

Returns:

  • (Object)


6125
6126
6127
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6125

def base_environment
  @base_environment
end

#createdString

Output only. The time the agent was created. Corresponds to the JSON property created

Returns:

  • (String)


6130
6131
6132
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6130

def created
  @created
end

#descriptionString

Optional. The description of the agent. Corresponds to the JSON property description

Returns:

  • (String)


6135
6136
6137
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6135

def description
  @description
end

#idString

Immutable. The user-specified ID for the agent. This ID becomes the final component of the agent resource name. If not provided, Vertex AI will generate a value for this ID. The ID can be up to 63 characters and must match the regular expression [a-z]([a-z0-9-]0,61[a-z0-9])?. Corresponds to the JSON property id

Returns:

  • (String)


6143
6144
6145
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6143

def id
  @id
end

#metadataHash<String,String>

Optional. The metadata for the agent. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


6148
6149
6150
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6148

def 
  @metadata
end

#nameString

Identifier. The resource name of the agent. Format: projects/project/ locations/location/agents/agent`. Corresponds to the JSON propertyname`

Returns:

  • (String)


6154
6155
6156
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6154

def name
  @name
end

#objectString

Output only. The object type of the resource. For agents, the value is agent. Corresponds to the JSON property object

Returns:

  • (String)


6159
6160
6161
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6159

def object
  @object
end

#system_instructionString

Optional. The instructions for the agent to follow. These instructions are passed to the LLM as a system instruction. Corresponds to the JSON property system_instruction

Returns:

  • (String)


6165
6166
6167
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6165

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentTool>

Optional. The tools available to the agent. Corresponds to the JSON property tools



6170
6171
6172
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6170

def tools
  @tools
end

#updatedString

Output only. The time the agent was last updated. Corresponds to the JSON property updated

Returns:

  • (String)


6175
6176
6177
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6175

def updated
  @updated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
6194
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6182

def update!(**args)
  @base_agent = args[:base_agent] if args.key?(:base_agent)
  @base_environment = args[:base_environment] if args.key?(:base_environment)
  @created = args[:created] if args.key?(:created)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @object = args[:object] if args.key?(:object)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
  @updated = args[:updated] if args.key?(:updated)
end