Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Agent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A Vertex agent contains instructions and configurations for the LLM to execute a certain task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Agent

Returns a new instance of GoogleCloudAiplatformV1beta1Agent.



5782
5783
5784
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_agentString

Required. The base agent of the agent. Supported values: - "antigravity- preview-05-2026" Corresponds to the JSON property base_agent

Returns:

  • (String)


5720
5721
5722
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5720

def base_agent
  @base_agent
end

#base_environmentObject

Optional. The environment config of the agent. Valid types are: - string value for environment_id, or 'remote' for default - struct value for EnvironmentConfig. Corresponds to the JSON property base_environment

Returns:

  • (Object)


5727
5728
5729
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5727

def base_environment
  @base_environment
end

#createdString

Output only. Timestamp when the agent was created. Corresponds to the JSON property created

Returns:

  • (String)


5732
5733
5734
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5732

def created
  @created
end

#descriptionString

Optional. The description of the agent. Corresponds to the JSON property description

Returns:

  • (String)


5737
5738
5739
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5737

def description
  @description
end

#idString

Immutable. The ID to use for agent, which will become the final component of the agent resource name. If not provided, Vertex AI will generate a value for this ID. This value may be up to 63 characters, and valid characters are [a- z0-9-]. The first character must be a letter, the last character must be a letter or number. Corresponds to the JSON property id

Returns:

  • (String)


5746
5747
5748
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5746

def id
  @id
end

#metadataHash<String,String>

Optional. The metadata of the agent. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


5751
5752
5753
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5751

def 
  @metadata
end

#nameString

Identifier. The resource name of the Agent. Format: projects/project/ locations/location/agents/agent`. Corresponds to the JSON propertyname`

Returns:

  • (String)


5757
5758
5759
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5757

def name
  @name
end

#objectString

Output only. The object type of this resource. Always set to "agent" in this case. Corresponds to the JSON property object

Returns:

  • (String)


5763
5764
5765
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5763

def object
  @object
end

#system_instructionString

Optional. The detailed struction that the agent should follow. The instruction is passed to LLM as system instruction. Corresponds to the JSON property system_instruction

Returns:

  • (String)


5769
5770
5771
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5769

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentTool>

Optional. A list of tools that are available for the agent during the process of execucting the task. Corresponds to the JSON property tools



5775
5776
5777
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5775

def tools
  @tools
end

#updatedString

Output only. Timestamp when the agent was last updated. Corresponds to the JSON property updated

Returns:

  • (String)


5780
5781
5782
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5780

def updated
  @updated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5787
5788
5789
5790
5791
5792
5793
5794
5795
5796
5797
5798
5799
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5787

def update!(**args)
  @base_agent = args[:base_agent] if args.key?(:base_agent)
  @base_environment = args[:base_environment] if args.key?(:base_environment)
  @created = args[:created] if args.key?(:created)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @object = args[:object] if args.key?(:object)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
  @updated = args[:updated] if args.key?(:updated)
end