Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents an Agent Anomaly Detection Scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope

Returns a new instance of GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope.



7632
7633
7634
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. User-provided display name of the AgentAnomalyDetectionScope. Corresponds to the JSON property displayName

Returns:

  • (String)


7605
7606
7607
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7605

def display_name
  @display_name
end

#log_bucketsArray<String>

Required. Customer-owned Cloud Logging bucket resource names attached to this scope. Format: projects/project/locations/location/buckets/bucket`. Corresponds to the JSON propertylogBuckets`

Returns:

  • (Array<String>)


7611
7612
7613
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7611

def log_buckets
  @log_buckets
end

#nameString

Identifier. The resource name of the AgentAnomalyDetectionScope. Format: projects/project/locations/location/agentAnomalyDetectionScopes/ agent_anomaly_detection_scope` Corresponds to the JSON propertyname`

Returns:

  • (String)


7618
7619
7620
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7618

def name
  @name
end

#observability_bucketsArray<String>

Required. Customer-owned Cloud Observability bucket resource names attached to this scope. Format: projects/project/locations/location/ observationBuckets/observation_bucket`. Corresponds to the JSON propertyobservabilityBuckets`

Returns:

  • (Array<String>)


7625
7626
7627
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7625

def observability_buckets
  @observability_buckets
end

#stateString

Output only. The lifecycle state of the scope. Corresponds to the JSON property state

Returns:

  • (String)


7630
7631
7632
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7630

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7637
7638
7639
7640
7641
7642
7643
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7637

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @log_buckets = args[:log_buckets] if args.key?(:log_buckets)
  @name = args[:name] if args.key?(:name)
  @observability_buckets = args[:observability_buckets] if args.key?(:observability_buckets)
  @state = args[:state] if args.key?(:state)
end