Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents an Agent Anomaly Detection Scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope

Returns a new instance of GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope.



6915
6916
6917
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6915

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. User-provided display name of the AgentAnomalyDetectionScope. Corresponds to the JSON property displayName

Returns:

  • (String)


6888
6889
6890
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6888

def display_name
  @display_name
end

#log_bucketsArray<String>

Required. Customer-owned Cloud Logging bucket resource names attached to this scope. Format: projects/project/locations/location/buckets/bucket`. Corresponds to the JSON propertylogBuckets`

Returns:

  • (Array<String>)


6894
6895
6896
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6894

def log_buckets
  @log_buckets
end

#nameString

Identifier. The resource name of the AgentAnomalyDetectionScope. Format: projects/project/locations/location/agentAnomalyDetectionScopes/ agent_anomaly_detection_scope` Corresponds to the JSON propertyname`

Returns:

  • (String)


6901
6902
6903
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6901

def name
  @name
end

#observability_bucketsArray<String>

Required. Customer-owned Cloud Observability bucket resource names attached to this scope. Format: projects/project/locations/location/ observationBuckets/observation_bucket`. Corresponds to the JSON propertyobservabilityBuckets`

Returns:

  • (Array<String>)


6908
6909
6910
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6908

def observability_buckets
  @observability_buckets
end

#stateString

Output only. The lifecycle state of the scope. Corresponds to the JSON property state

Returns:

  • (String)


6913
6914
6915
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6913

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6920
6921
6922
6923
6924
6925
6926
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6920

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @log_buckets = args[:log_buckets] if args.key?(:log_buckets)
  @name = args[:name] if args.key?(:name)
  @observability_buckets = args[:observability_buckets] if args.key?(:observability_buckets)
  @state = args[:state] if args.key?(:state)
end