Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Resource representing an Agent Anomaly Detection Scope.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Optional.
-
#log_buckets ⇒ Array<String>
Required.
-
#name ⇒ String
Identifier.
-
#observability_buckets ⇒ Array<String>
Required.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope
constructor
A new instance of GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope
Returns a new instance of GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope.
6524 6525 6526 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6524 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Optional. User provided display name of the AgentAnomalyDetectionScope.
Corresponds to the JSON property displayName
6496 6497 6498 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6496 def display_name @display_name end |
#log_buckets ⇒ Array<String>
Required. Customer owned Cloud Logging bucket resource names attached to this
scope. Format: projects/project/locations/location/buckets/bucket`.
Corresponds to the JSON propertylogBuckets`
6502 6503 6504 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6502 def log_buckets @log_buckets end |
#name ⇒ String
Identifier. The resource name of the AgentAnomalyDetectionScope. Format:
projects/project/locations/location/agentAnomalyDetectionScopes/
agent_anomaly_detection_scope`
Corresponds to the JSON propertyname`
6509 6510 6511 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6509 def name @name end |
#observability_buckets ⇒ Array<String>
Required. Customer owned Cloud Observability bucket resource names attached to
this scope. Format: projects/project/locations/location/
observationBuckets/observation_bucket`.
Corresponds to the JSON propertyobservabilityBuckets`
6516 6517 6518 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6516 def observability_buckets @observability_buckets end |
#state ⇒ String
Output only. The lifecycle state of the scope. See State for the semantics
of each value.
Corresponds to the JSON property state
6522 6523 6524 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6522 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6529 6530 6531 6532 6533 6534 6535 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6529 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @log_buckets = args[:log_buckets] if args.key?(:log_buckets) @name = args[:name] if args.key?(:name) @observability_buckets = args[:observability_buckets] if args.key?(:observability_buckets) @state = args[:state] if args.key?(:state) end |