Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Resource representing an Agent Anomaly Detection Scope.
Instance Attribute Summary collapse
-
#auto_enroll ⇒ Boolean
(also: #auto_enroll?)
Optional.
-
#display_name ⇒ String
Optional.
-
#log_buckets ⇒ Array<String>
Required.
-
#name ⇒ String
Identifier.
-
#observability_buckets ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope
constructor
A new instance of GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope
Returns a new instance of GoogleCloudAiplatformV1beta1AgentAnomalyDetectionScope.
6702 6703 6704 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6702 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_enroll ⇒ Boolean Also known as: auto_enroll?
Optional. When true, agents created in Agent Engine that share log and
observability buckets with this scope are automatically enrolled as
MonitoredAgents. When false, agents must be enrolled explicitly via
MonitoredAgent operations.
Corresponds to the JSON property autoEnroll
6674 6675 6676 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6674 def auto_enroll @auto_enroll end |
#display_name ⇒ String
Optional. User provided display name of the AgentAnomalyDetectionScope.
Corresponds to the JSON property displayName
6680 6681 6682 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6680 def display_name @display_name end |
#log_buckets ⇒ Array<String>
Required. Customer owned Cloud Logging bucket resource names attached to this
scope. Format: projects/project/locations/location/buckets/bucket`.
Corresponds to the JSON propertylogBuckets`
6686 6687 6688 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6686 def log_buckets @log_buckets end |
#name ⇒ String
Identifier. The resource name of the AgentAnomalyDetectionScope. Format:
projects/project/locations/location/agentAnomalyDetectionScopes/
agent_anomaly_detection_scope`
Corresponds to the JSON propertyname`
6693 6694 6695 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6693 def name @name end |
#observability_buckets ⇒ Array<String>
Required. Customer owned Cloud Observability bucket resource names attached to
this scope. Format: projects/project/locations/location/
observationBuckets/observation_bucket`.
Corresponds to the JSON propertyobservabilityBuckets`
6700 6701 6702 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6700 def observability_buckets @observability_buckets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6707 6708 6709 6710 6711 6712 6713 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6707 def update!(**args) @auto_enroll = args[:auto_enroll] if args.key?(:auto_enroll) @display_name = args[:display_name] if args.key?(:display_name) @log_buckets = args[:log_buckets] if args.key?(:log_buckets) @name = args[:name] if args.key?(:name) @observability_buckets = args[:observability_buckets] if args.key?(:observability_buckets) end |