Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents configuration for an Agent.
Instance Attribute Summary collapse
-
#agent_id ⇒ String
Required.
-
#agent_type ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#instruction ⇒ String
Optional.
-
#sub_agents ⇒ Array<String>
Optional.
-
#tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1AgentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentConfig
Returns a new instance of GoogleCloudAiplatformV1beta1AgentConfig.
5845 5846 5847 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5845 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
Required. Unique identifier of the agent. This ID is used to refer to this
agent, e.g., in AgentEvent.author, or in the sub_agents field. It must be
unique within the agents map.
Corresponds to the JSON property agentId
5811 5812 5813 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5811 def agent_id @agent_id end |
#agent_type ⇒ String
Optional. The type or class of the agent (e.g., "LlmAgent", "RouterAgent", "
ToolUseAgent"). Useful for the autorater to understand the expected behavior
of the agent.
Corresponds to the JSON property agentType
5818 5819 5820 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5818 def agent_type @agent_type end |
#description ⇒ String
Optional. A high-level description of the agent's role and responsibilities.
Critical for evaluating if the agent is routing tasks correctly.
Corresponds to the JSON property description
5824 5825 5826 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5824 def description @description end |
#instruction ⇒ String
Optional. Provides instructions for the LLM model, guiding the agent's
behavior. Can be static or dynamic. Dynamic instructions can contain
placeholders like variable_name that will be resolved at runtime using the
AgentEvent.state_delta field.
Corresponds to the JSON property instruction
5832 5833 5834 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5832 def instruction @instruction end |
#sub_agents ⇒ Array<String>
Optional. The list of valid agent IDs that this agent can delegate to. This
defines the directed edges in the multi-agent system graph topology.
Corresponds to the JSON property subAgents
5838 5839 5840 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5838 def sub_agents @sub_agents end |
#tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional. The list of tools available to this agent.
Corresponds to the JSON property tools
5843 5844 5845 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5843 def tools @tools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5850 5851 5852 5853 5854 5855 5856 5857 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5850 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @agent_type = args[:agent_type] if args.key?(:agent_type) @description = args[:description] if args.key?(:description) @instruction = args[:instruction] if args.key?(:instruction) @sub_agents = args[:sub_agents] if args.key?(:sub_agents) @tools = args[:tools] if args.key?(:tools) end |