Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents configuration for an Agent.
Instance Attribute Summary collapse
-
#agent_id ⇒ String
Required.
-
#agent_type ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#instruction ⇒ String
Optional.
-
#sub_agents ⇒ Array<String>
Optional.
-
#tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1AgentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentConfig
Returns a new instance of GoogleCloudAiplatformV1beta1AgentConfig.
1162 1163 1164 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
Required. Unique identifier of the agent. This ID is used to refer to this
agent, e.g., in AgentEvent.author, or in the sub_agents field. It must be
unique within the agents map.
Corresponds to the JSON property agentId
1128 1129 1130 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1128 def agent_id @agent_id end |
#agent_type ⇒ String
Optional. The type or class of the agent (e.g., "LlmAgent", "RouterAgent", "
ToolUseAgent"). Useful for the autorater to understand the expected behavior
of the agent.
Corresponds to the JSON property agentType
1135 1136 1137 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1135 def agent_type @agent_type end |
#description ⇒ String
Optional. A high-level description of the agent's role and responsibilities.
Critical for evaluating if the agent is routing tasks correctly.
Corresponds to the JSON property description
1141 1142 1143 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1141 def description @description end |
#instruction ⇒ String
Optional. Provides instructions for the LLM model, guiding the agent's
behavior. Can be static or dynamic. Dynamic instructions can contain
placeholders like variable_name that will be resolved at runtime using the
AgentEvent.state_delta field.
Corresponds to the JSON property instruction
1149 1150 1151 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1149 def instruction @instruction end |
#sub_agents ⇒ Array<String>
Optional. The list of valid agent IDs that this agent can delegate to. This
defines the directed edges in the multi-agent system graph topology.
Corresponds to the JSON property subAgents
1155 1156 1157 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1155 def sub_agents @sub_agents end |
#tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional. The list of tools available to this agent.
Corresponds to the JSON property tools
1160 1161 1162 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1160 def tools @tools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1167 1168 1169 1170 1171 1172 1173 1174 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1167 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @agent_type = args[:agent_type] if args.key?(:agent_type) @description = args[:description] if args.key?(:description) @instruction = args[:instruction] if args.key?(:instruction) @sub_agents = args[:sub_agents] if args.key?(:sub_agents) @tools = args[:tools] if args.key?(:tools) end |