Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents configuration for an Agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentConfig

Returns a new instance of GoogleCloudAiplatformV1beta1AgentConfig.



1153
1154
1155
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1153

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

Required. Unique identifier of the agent. This ID is used to refer to this agent, e.g., in AgentEvent.author, or in the sub_agents field. It must be unique within the agents map. Corresponds to the JSON property agentId

Returns:

  • (String)


1119
1120
1121
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1119

def agent_id
  @agent_id
end

#agent_typeString

Optional. The type or class of the agent (e.g., "LlmAgent", "RouterAgent", " ToolUseAgent"). Useful for the autorater to understand the expected behavior of the agent. Corresponds to the JSON property agentType

Returns:

  • (String)


1126
1127
1128
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1126

def agent_type
  @agent_type
end

#descriptionString

Optional. A high-level description of the agent's role and responsibilities. Critical for evaluating if the agent is routing tasks correctly. Corresponds to the JSON property description

Returns:

  • (String)


1132
1133
1134
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1132

def description
  @description
end

#instructionString

Optional. Provides instructions for the LLM model, guiding the agent's behavior. Can be static or dynamic. Dynamic instructions can contain placeholders like variable_name that will be resolved at runtime using the AgentEvent.state_delta field. Corresponds to the JSON property instruction

Returns:

  • (String)


1140
1141
1142
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1140

def instruction
  @instruction
end

#sub_agentsArray<String>

Optional. The list of valid agent IDs that this agent can delegate to. This defines the directed edges in the multi-agent system graph topology. Corresponds to the JSON property subAgents

Returns:

  • (Array<String>)


1146
1147
1148
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1146

def sub_agents
  @sub_agents
end

#toolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>

Optional. The list of tools available to this agent. Corresponds to the JSON property tools



1151
1152
1153
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1151

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1158
1159
1160
1161
1162
1163
1164
1165
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1158

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @agent_type = args[:agent_type] if args.key?(:agent_type)
  @description = args[:description] if args.key?(:description)
  @instruction = args[:instruction] if args.key?(:instruction)
  @sub_agents = args[:sub_agents] if args.key?(:sub_agents)
  @tools = args[:tools] if args.key?(:tools)
end