Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a single event in the execution trace.
Instance Attribute Summary collapse
-
#active_tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional.
-
#author ⇒ String
Required.
-
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message.
-
#event_time ⇒ String
Optional.
-
#state_delta ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentEvent
constructor
A new instance of GoogleCloudAiplatformV1beta1AgentEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentEvent
Returns a new instance of GoogleCloudAiplatformV1beta1AgentEvent.
1239 1240 1241 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1239 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional. The list of tools that were active/available to the agent at the
time of this event. This overrides the AgentConfig.tools if set.
Corresponds to the JSON property activeTools
1213 1214 1215 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1213 def active_tools @active_tools end |
#author ⇒ String
Required. The ID of the agent or entity that generated this event. Use "user"
to denote events generated by the end-user.
Corresponds to the JSON property author
1219 1220 1221 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1219 def @author end |
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
1226 1227 1228 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1226 def content @content end |
#event_time ⇒ String
Optional. The timestamp when the event occurred.
Corresponds to the JSON property eventTime
1231 1232 1233 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1231 def event_time @event_time end |
#state_delta ⇒ Hash<String,Object>
Optional. The change in the session state caused by this event. This is a key-
value map of fields that were modified or added by the event.
Corresponds to the JSON property stateDelta
1237 1238 1239 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1237 def state_delta @state_delta end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1244 1245 1246 1247 1248 1249 1250 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1244 def update!(**args) @active_tools = args[:active_tools] if args.key?(:active_tools) @author = args[:author] if args.key?(:author) @content = args[:content] if args.key?(:content) @event_time = args[:event_time] if args.key?(:event_time) @state_delta = args[:state_delta] if args.key?(:state_delta) end |