Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a single event in the execution trace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentEvent

Returns a new instance of GoogleCloudAiplatformV1beta1AgentEvent.



1230
1231
1232
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_toolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>

Optional. The list of tools that were active/available to the agent at the time of this event. This overrides the AgentConfig.tools if set. Corresponds to the JSON property activeTools



1204
1205
1206
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1204

def active_tools
  @active_tools
end

#authorString

Required. The ID of the agent or entity that generated this event. Use "user" to denote events generated by the end-user. Corresponds to the JSON property author

Returns:

  • (String)


1210
1211
1212
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1210

def author
  @author
end

#contentGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



1217
1218
1219
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1217

def content
  @content
end

#event_timeString

Optional. The timestamp when the event occurred. Corresponds to the JSON property eventTime

Returns:

  • (String)


1222
1223
1224
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1222

def event_time
  @event_time
end

#state_deltaHash<String,Object>

Optional. The change in the session state caused by this event. This is a key- value map of fields that were modified or added by the event. Corresponds to the JSON property stateDelta

Returns:

  • (Hash<String,Object>)


1228
1229
1230
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1228

def state_delta
  @state_delta
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1235
1236
1237
1238
1239
1240
1241
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 1235

def update!(**args)
  @active_tools = args[:active_tools] if args.key?(:active_tools)
  @author = args[:author] if args.key?(:author)
  @content = args[:content] if args.key?(:content)
  @event_time = args[:event_time] if args.key?(:event_time)
  @state_delta = args[:state_delta] if args.key?(:state_delta)
end