Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentResource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Defines the identity of an agent being monitored.
Instance Attribute Summary collapse
-
#agent ⇒ String
Required.
-
#agent_framework ⇒ String
Optional.
-
#agent_type ⇒ String
Required.
-
#location ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentResource
constructor
A new instance of GoogleCloudAiplatformV1beta1AgentResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentResource
Returns a new instance of GoogleCloudAiplatformV1beta1AgentResource.
8069 8070 8071 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8069 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent ⇒ String
Required. The resource name or identifier of the agent to monitor. The format
depends on agent_type: * REASONING_ENGINE: projects/project/locations/
location/reasoningEngines/reasoning_engine`*CLOUD_RUN_SERVICE,
GKE_WORKLOAD,GCE_INSTANCE: the resource name of the agent's runtime. *
AGENT_TYPE_OTHER: a stable identifier for the agent.
Corresponds to the JSON propertyagent`
8050 8051 8052 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8050 def agent @agent end |
#agent_framework ⇒ String
Optional. The framework used to build the agent, orthogonal to the runtime
agent_type.
Corresponds to the JSON property agentFramework
8056 8057 8058 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8056 def agent_framework @agent_framework end |
#agent_type ⇒ String
Required. The runtime type of the agent.
Corresponds to the JSON property agentType
8061 8062 8063 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8061 def agent_type @agent_type end |
#location ⇒ String
Output only. The Google Cloud location (region) of the agent resource (for
example, us-central1).
Corresponds to the JSON property location
8067 8068 8069 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8067 def location @location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8074 8075 8076 8077 8078 8079 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8074 def update!(**args) @agent = args[:agent] if args.key?(:agent) @agent_framework = args[:agent_framework] if args.key?(:agent_framework) @agent_type = args[:agent_type] if args.key?(:agent_type) @location = args[:location] if args.key?(:location) end |