Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentResource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Defines the identity of an agent being monitored.
Instance Attribute Summary collapse
-
#agent ⇒ String
Required.
-
#agent_framework ⇒ String
Optional.
-
#agent_type ⇒ String
Required.
-
#location ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentResource
constructor
A new instance of GoogleCloudAiplatformV1beta1AgentResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentResource
Returns a new instance of GoogleCloudAiplatformV1beta1AgentResource.
8019 8020 8021 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent ⇒ String
Required. The resource name or identifier of the agent to monitor. The format
depends on agent_type: * REASONING_ENGINE: projects/project/locations/
location/reasoningEngines/reasoning_engine`*CLOUD_RUN_SERVICE,
GKE_WORKLOAD,GCE_INSTANCE: the resource name of the agent's runtime. *
AGENT_TYPE_OTHER: a stable identifier for the agent.
Corresponds to the JSON propertyagent`
8000 8001 8002 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8000 def agent @agent end |
#agent_framework ⇒ String
Optional. The framework used to build the agent, orthogonal to the runtime
agent_type.
Corresponds to the JSON property agentFramework
8006 8007 8008 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8006 def agent_framework @agent_framework end |
#agent_type ⇒ String
Required. The runtime type of the agent.
Corresponds to the JSON property agentType
8011 8012 8013 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8011 def agent_type @agent_type end |
#location ⇒ String
Output only. The Google Cloud location (region) of the agent resource (for
example, us-central1).
Corresponds to the JSON property location
8017 8018 8019 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8017 def location @location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8024 8025 8026 8027 8028 8029 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8024 def update!(**args) @agent = args[:agent] if args.key?(:agent) @agent_framework = args[:agent_framework] if args.key?(:agent_framework) @agent_type = args[:agent_type] if args.key?(:agent_type) @location = args[:location] if args.key?(:location) end |