Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Defines the identity of an agent being monitored.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentResource

Returns a new instance of GoogleCloudAiplatformV1beta1AgentResource.



7810
7811
7812
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentString

Required. The resource name or identifier of the agent to monitor. The format depends on agent_type: * REASONING_ENGINE: projects/project/locations/ location/reasoningEngines/reasoning_engine`*CLOUD_RUN_SERVICE, GKE_WORKLOAD,GCE_INSTANCE: the resource name of the agent's runtime. * AGENT_TYPE_OTHER: a stable identifier for the agent. Corresponds to the JSON propertyagent`

Returns:

  • (String)


7791
7792
7793
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7791

def agent
  @agent
end

#agent_frameworkString

Optional. The framework used to build the agent, orthogonal to the runtime agent_type. Corresponds to the JSON property agentFramework

Returns:

  • (String)


7797
7798
7799
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7797

def agent_framework
  @agent_framework
end

#agent_typeString

Required. The runtime type of the agent. Corresponds to the JSON property agentType

Returns:

  • (String)


7802
7803
7804
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7802

def agent_type
  @agent_type
end

#locationString

Output only. The Google Cloud location (region) of the agent resource (for example, us-central1). Corresponds to the JSON property location

Returns:

  • (String)


7808
7809
7810
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7808

def location
  @location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7815
7816
7817
7818
7819
7820
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7815

def update!(**args)
  @agent = args[:agent] if args.key?(:agent)
  @agent_framework = args[:agent_framework] if args.key?(:agent_framework)
  @agent_type = args[:agent_type] if args.key?(:agent_type)
  @location = args[:location] if args.key?(:location)
end