Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentTool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool provides a list of actions available to the Agent during the process of executing a task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentTool

Returns a new instance of GoogleCloudAiplatformV1beta1AgentTool.



8061
8062
8063
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8061

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headersHash<String,String>

Optional. The headers for the MCP server, such as for authentication. Only applicable when type is mcp_server. Corresponds to the JSON property headers

Returns:

  • (Hash<String,String>)


8041
8042
8043
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8041

def headers
  @headers
end

#nameString

Optional. The name of the MCP server. Only applicable when type is mcp_server. Corresponds to the JSON property name

Returns:

  • (String)


8047
8048
8049
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8047

def name
  @name
end

#typeString

Required. The type of the tool. Supported types: * code_execution * filesystem * google_search * mcp_server * url_context Corresponds to the JSON property type

Returns:

  • (String)


8053
8054
8055
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8053

def type
  @type
end

#urlString

Optional. The URL for the MCP server endpoint. Only applicable when type is mcp_server. Corresponds to the JSON property url

Returns:

  • (String)


8059
8060
8061
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8059

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8066
8067
8068
8069
8070
8071
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8066

def update!(**args)
  @headers = args[:headers] if args.key?(:headers)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
  @url = args[:url] if args.key?(:url)
end