Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentTool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tool provides a list of actions available to the Agent during the process of executing a task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentTool

Returns a new instance of GoogleCloudAiplatformV1beta1AgentTool.



6734
6735
6736
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headersHash<String,String>

Optional. The headers for the MCP server, such as for authentication. Only applicable when type is mcp_server. Corresponds to the JSON property headers

Returns:

  • (Hash<String,String>)


6714
6715
6716
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6714

def headers
  @headers
end

#nameString

Optional. The name of the MCP server. Only applicable when type is mcp_server. Corresponds to the JSON property name

Returns:

  • (String)


6720
6721
6722
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6720

def name
  @name
end

#typeString

Required. The type of the tool. Supported types: * code_execution * filesystem * google_search * mcp_server * url_context Corresponds to the JSON property type

Returns:

  • (String)


6726
6727
6728
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6726

def type
  @type
end

#urlString

Optional. The URL for the MCP server endpoint. Only applicable when type is mcp_server. Corresponds to the JSON property url

Returns:

  • (String)


6732
6733
6734
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6732

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6739
6740
6741
6742
6743
6744
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6739

def update!(**args)
  @headers = args[:headers] if args.key?(:headers)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
  @url = args[:url] if args.key?(:url)
end