Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentTool
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentTool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A tool provides a list of actions available to the Agent during the process of executing a task.
Instance Attribute Summary collapse
-
#headers ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Optional.
-
#type ⇒ String
Required.
-
#url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentTool
constructor
A new instance of GoogleCloudAiplatformV1beta1AgentTool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentTool
Returns a new instance of GoogleCloudAiplatformV1beta1AgentTool.
6360 6361 6362 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6360 def initialize(**args) update!(**args) end |
Instance Attribute Details
#headers ⇒ Hash<String,String>
Optional. The headers for the MCP server, such as for authentication. Only
applicable when type is mcp_server.
Corresponds to the JSON property headers
6340 6341 6342 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6340 def headers @headers end |
#name ⇒ String
Optional. The name of the MCP server. Only applicable when type is
mcp_server.
Corresponds to the JSON property name
6346 6347 6348 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6346 def name @name end |
#type ⇒ String
Required. The type of the tool. Supported types: * code_execution *
filesystem * google_search * mcp_server * url_context
Corresponds to the JSON property type
6352 6353 6354 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6352 def type @type end |
#url ⇒ String
Optional. The URL for the MCP server endpoint. Only applicable when type is
mcp_server.
Corresponds to the JSON property url
6358 6359 6360 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6358 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6365 6366 6367 6368 6369 6370 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6365 def update!(**args) @headers = args[:headers] if args.key?(:headers) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) @url = args[:url] if args.key?(:url) end |