Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentTool
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentTool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A tool provides a list of actions that are available for the Agent during the process of executing the task.
Instance Attribute Summary collapse
-
#headers ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Optional.
-
#type ⇒ String
Required.
-
#url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentTool
constructor
A new instance of GoogleCloudAiplatformV1beta1AgentTool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AgentTool
Returns a new instance of GoogleCloudAiplatformV1beta1AgentTool.
5964 5965 5966 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5964 def initialize(**args) update!(**args) end |
Instance Attribute Details
#headers ⇒ Hash<String,String>
Optional. Headers for the MCP server (e.g., authentication). Only applicable
when type is "mcp".
Corresponds to the JSON property headers
5945 5946 5947 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5945 def headers @headers end |
#name ⇒ String
Optional. The name of the MCP server. Only applicable when type is "mcp".
Corresponds to the JSON property name
5950 5951 5952 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5950 def name @name end |
#type ⇒ String
Required. Type of the tool. Supported types: - "code_execution" - "filesystem"
- "google_search" - "mcp" - "url_context"
Corresponds to the JSON property
type
5956 5957 5958 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5956 def type @type end |
#url ⇒ String
Optional. The full URL for the MCP server endpoint. Only applicable when type
is "mcp".
Corresponds to the JSON property url
5962 5963 5964 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5962 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5969 5970 5971 5972 5973 5974 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5969 def update!(**args) @headers = args[:headers] if args.key?(:headers) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) @url = args[:url] if args.key?(:url) end |