Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AnalyzedSession

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents an analyzed session for a monitored agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AnalyzedSession

Returns a new instance of GoogleCloudAiplatformV1beta1AnalyzedSession.



8163
8164
8165
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_display_nameString

Output only. The human-readable display name of the MonitoredAgent that owns this session. May be empty when the session's agent is not enrolled as a MonitoredAgent; the agent_resource_name is always present and can be used as a fallback identifier. Corresponds to the JSON property agentDisplayName

Returns:

  • (String)


8099
8100
8101
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8099

def agent_display_name
  @agent_display_name
end

#agent_resource_nameString

Output only. The agent resource name. Format: projects/project/locations/ location/reasoningEngines/agent` Corresponds to the JSON propertyagentResourceName`

Returns:

  • (String)


8105
8106
8107
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8105

def agent_resource_name
  @agent_resource_name
end

#agent_stateString

Output only. The current enablement state of the MonitoredAgent that owns this session (for example, ACTIVE, DISABLED, or ENABLING). Defaults to ENABLEMENT_STATE_UNSPECIFIED when the agent is not enrolled or its state is unknown. Corresponds to the JSON property agentState

Returns:

  • (String)


8113
8114
8115
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8113

def agent_state
  @agent_state
end

#assessmentGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Assessment

Contains the detailed assessment for an analyzed session. Corresponds to the JSON property assessment



8118
8119
8120
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8118

def assessment
  @assessment
end

#create_timeString

Output only. The creation time of the session. Corresponds to the JSON property createTime

Returns:

  • (String)


8123
8124
8125
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8123

def create_time
  @create_time
end

#latest_analyzed_timeString

Output only. The latest analyzed time of the session. Corresponds to the JSON property latestAnalyzedTime

Returns:

  • (String)


8128
8129
8130
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8128

def latest_analyzed_time
  @latest_analyzed_time
end

#locationString

Output only. The Google Cloud location (region) of the agent that ran this session (for example, us-central1). Empty when the agent is not enrolled or its location is unknown. Corresponds to the JSON property location

Returns:

  • (String)


8135
8136
8137
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8135

def location
  @location
end

#nameString

Identifier. The resource name of the AnalyzedSession. Corresponds to the JSON property name

Returns:

  • (String)


8140
8141
8142
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8140

def name
  @name
end

#session_idString

Output only. The session ID. Corresponds to the JSON property sessionId

Returns:

  • (String)


8145
8146
8147
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8145

def session_id
  @session_id
end

#session_stateString

Output only. The state of the session. Corresponds to the JSON property sessionState

Returns:

  • (String)


8150
8151
8152
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8150

def session_state
  @session_state
end

#severitiesHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AnalyzedSessionSeveritySummary>

Output only. Map of severity counts for listing analyzed sessions. The key is the string representation of Severity. Populated in BASIC view only. Corresponds to the JSON property severities



8156
8157
8158
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8156

def severities
  @severities
end

#user_idString

Output only. The user ID. Corresponds to the JSON property userId

Returns:

  • (String)


8161
8162
8163
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8161

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8168

def update!(**args)
  @agent_display_name = args[:agent_display_name] if args.key?(:agent_display_name)
  @agent_resource_name = args[:agent_resource_name] if args.key?(:agent_resource_name)
  @agent_state = args[:agent_state] if args.key?(:agent_state)
  @assessment = args[:assessment] if args.key?(:assessment)
  @create_time = args[:create_time] if args.key?(:create_time)
  @latest_analyzed_time = args[:latest_analyzed_time] if args.key?(:latest_analyzed_time)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @session_id = args[:session_id] if args.key?(:session_id)
  @session_state = args[:session_state] if args.key?(:session_state)
  @severities = args[:severities] if args.key?(:severities)
  @user_id = args[:user_id] if args.key?(:user_id)
end