Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AnalyzedSession
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AnalyzedSession
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents an analyzed session for a monitored agent.
Instance Attribute Summary collapse
-
#agent_display_name ⇒ String
Output only.
-
#agent_resource_name ⇒ String
Output only.
-
#agent_state ⇒ String
Output only.
-
#assessment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Assessment
Contains the detailed assessment for an analyzed session.
-
#create_time ⇒ String
Output only.
-
#latest_analyzed_time ⇒ String
Output only.
-
#location ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#session_id ⇒ String
Output only.
-
#session_state ⇒ String
Output only.
-
#severities ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AnalyzedSessionSeveritySummary>
Output only.
-
#user_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AnalyzedSession
constructor
A new instance of GoogleCloudAiplatformV1beta1AnalyzedSession.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AnalyzedSession
Returns a new instance of GoogleCloudAiplatformV1beta1AnalyzedSession.
7436 7437 7438 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_display_name ⇒ String
Output only. The human-readable display name of the MonitoredAgent that owns
this session. May be empty when the session's agent is not enrolled as a
MonitoredAgent; the agent_resource_name is always present and can be used as
a fallback identifier.
Corresponds to the JSON property agentDisplayName
7372 7373 7374 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7372 def agent_display_name @agent_display_name end |
#agent_resource_name ⇒ String
Output only. The agent resource name. Format: projects/project/locations/
location/reasoningEngines/agent`
Corresponds to the JSON propertyagentResourceName`
7378 7379 7380 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7378 def agent_resource_name @agent_resource_name end |
#agent_state ⇒ String
Output only. The current enablement state of the MonitoredAgent that owns this
session (for example, ACTIVE, DISABLED, or ENABLING). Defaults to
ENABLEMENT_STATE_UNSPECIFIED when the agent is not enrolled or its state is
unknown.
Corresponds to the JSON property agentState
7386 7387 7388 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7386 def agent_state @agent_state end |
#assessment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Assessment
Contains the detailed assessment for an analyzed session.
Corresponds to the JSON property assessment
7391 7392 7393 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7391 def assessment @assessment end |
#create_time ⇒ String
Output only. The creation time of the session.
Corresponds to the JSON property createTime
7396 7397 7398 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7396 def create_time @create_time end |
#latest_analyzed_time ⇒ String
Output only. The latest analyzed time of the session.
Corresponds to the JSON property latestAnalyzedTime
7401 7402 7403 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7401 def latest_analyzed_time @latest_analyzed_time end |
#location ⇒ String
Output only. The Google Cloud location (region) of the agent that ran this
session (for example, us-central1). Empty when the agent is not enrolled or
its location is unknown.
Corresponds to the JSON property location
7408 7409 7410 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7408 def location @location end |
#name ⇒ String
Identifier. The resource name of the AnalyzedSession.
Corresponds to the JSON property name
7413 7414 7415 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7413 def name @name end |
#session_id ⇒ String
Output only. The session ID.
Corresponds to the JSON property sessionId
7418 7419 7420 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7418 def session_id @session_id end |
#session_state ⇒ String
Output only. The state of the session.
Corresponds to the JSON property sessionState
7423 7424 7425 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7423 def session_state @session_state end |
#severities ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AnalyzedSessionSeveritySummary>
Output only. Map of severity counts for listing analyzed sessions. The key is
the string representation of Severity. Populated in BASIC view only.
Corresponds to the JSON property severities
7429 7430 7431 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7429 def severities @severities end |
#user_id ⇒ String
Output only. The user ID.
Corresponds to the JSON property userId
7434 7435 7436 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7434 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 7451 7452 7453 7454 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7441 def update!(**args) @agent_display_name = args[:agent_display_name] if args.key?(:agent_display_name) @agent_resource_name = args[:agent_resource_name] if args.key?(:agent_resource_name) @agent_state = args[:agent_state] if args.key?(:agent_state) @assessment = args[:assessment] if args.key?(:assessment) @create_time = args[:create_time] if args.key?(:create_time) @latest_analyzed_time = args[:latest_analyzed_time] if args.key?(:latest_analyzed_time) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @session_id = args[:session_id] if args.key?(:session_id) @session_state = args[:session_state] if args.key?(:session_state) @severities = args[:severities] if args.key?(:severities) @user_id = args[:user_id] if args.key?(:user_id) end |