Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Annotation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Annotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Used to assign specific AnnotationSpec to a particular area of a DataItem or the whole part of the DataItem.
Instance Attribute Summary collapse
-
#annotation_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserActionReference
References an API call.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#payload ⇒ Object
Required.
-
#payload_schema_uri ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Annotation
constructor
A new instance of GoogleCloudAiplatformV1beta1Annotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Annotation
Returns a new instance of GoogleCloudAiplatformV1beta1Annotation.
7181 7182 7183 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7181 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserActionReference
References an API call. It contains more information about long running
operation and Jobs that are triggered by the API call.
Corresponds to the JSON property annotationSource
7127 7128 7129 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7127 def annotation_source @annotation_source end |
#create_time ⇒ String
Output only. Timestamp when this Annotation was created.
Corresponds to the JSON property createTime
7132 7133 7134 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7132 def create_time @create_time end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
7138 7139 7140 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7138 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your Annotations.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. No more than 64 user labels can
be associated with one Annotation(System labels are excluded). See https://goo.
gl/xmQnxf for more information and examples of labels. System reserved label
keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Following system labels exist for each Annotation: * "aiplatform.googleapis.
com/annotation_set_name": optional, name of the UI's annotation set this
Annotation belongs to. If not set, the Annotation is not visible in the UI. * "
aiplatform.googleapis.com/payload_schema": output only, its value is the
payload_schema's title.
Corresponds to the JSON property labels
7154 7155 7156 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7154 def labels @labels end |
#name ⇒ String
Output only. Resource name of the Annotation.
Corresponds to the JSON property name
7159 7160 7161 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7159 def name @name end |
#payload ⇒ Object
Required. The schema of the payload can be found in payload_schema.
Corresponds to the JSON property payload
7164 7165 7166 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7164 def payload @payload end |
#payload_schema_uri ⇒ String
Required. Google Cloud Storage URI points to a YAML file describing payload.
The schema is defined as an OpenAPI 3.0.2 Schema Object. The
schema files that can be used here are found in gs://google-cloud-aiplatform/
schema/dataset/annotation/, note that the chosen schema must be consistent
with the parent Dataset's metadata.
Corresponds to the JSON property payloadSchemaUri
7174 7175 7176 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7174 def payload_schema_uri @payload_schema_uri end |
#update_time ⇒ String
Output only. Timestamp when this Annotation was last updated.
Corresponds to the JSON property updateTime
7179 7180 7181 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7179 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7186 7187 7188 7189 7190 7191 7192 7193 7194 7195 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7186 def update!(**args) @annotation_source = args[:annotation_source] if args.key?(:annotation_source) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @payload = args[:payload] if args.key?(:payload) @payload_schema_uri = args[:payload_schema_uri] if args.key?(:payload_schema_uri) @update_time = args[:update_time] if args.key?(:update_time) end |