Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Artifact
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Artifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Instance of a general artifact.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the Artifact Corresponds to the JSON property
description. -
#display_name ⇒ String
User provided display name of the Artifact.
-
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Artifacts.
-
#metadata ⇒ Hash<String,Object>
Properties of the Artifact.
-
#name ⇒ String
Output only.
-
#schema_title ⇒ String
The title of the schema describing the metadata.
-
#schema_version ⇒ String
The version of the schema in schema_name to use.
-
#state ⇒ String
The state of this Artifact.
-
#update_time ⇒ String
Output only.
-
#uri ⇒ String
The uniform resource identifier of the artifact file.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Artifact
constructor
A new instance of GoogleCloudAiplatformV1beta1Artifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Artifact
Returns a new instance of GoogleCloudAiplatformV1beta1Artifact.
6751 6752 6753 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6751 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Artifact was created.
Corresponds to the JSON property createTime
6677 6678 6679 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6677 def create_time @create_time end |
#description ⇒ String
Description of the Artifact
Corresponds to the JSON property description
6682 6683 6684 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6682 def description @description end |
#display_name ⇒ String
User provided display name of the Artifact. May be up to 128 Unicode
characters.
Corresponds to the JSON property displayName
6688 6689 6690 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6688 def display_name @display_name end |
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
6694 6695 6696 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6694 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Artifacts. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Artifact (System labels are excluded).
Corresponds to the JSON property labels
6703 6704 6705 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6703 def labels @labels end |
#metadata ⇒ Hash<String,Object>
Properties of the Artifact. Top level metadata keys' heading and trailing
spaces will be trimmed. The size of this field should not exceed 200KB.
Corresponds to the JSON property metadata
6709 6710 6711 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6709 def @metadata end |
#name ⇒ String
Output only. The resource name of the Artifact.
Corresponds to the JSON property name
6714 6715 6716 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6714 def name @name end |
#schema_title ⇒ String
The title of the schema describing the metadata. Schema title and version is
expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaTitle
6722 6723 6724 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6722 def schema_title @schema_title end |
#schema_version ⇒ String
The version of the schema in schema_name to use. Schema title and version is
expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaVersion
6730 6731 6732 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6730 def schema_version @schema_version end |
#state ⇒ String
The state of this Artifact. This is a property of the Artifact, and does not
imply or capture any ongoing process. This property is managed by clients (
such as Vertex AI Pipelines), and the system does not prescribe or check the
validity of state transitions.
Corresponds to the JSON property state
6738 6739 6740 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6738 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this Artifact was last updated.
Corresponds to the JSON property updateTime
6743 6744 6745 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6743 def update_time @update_time end |
#uri ⇒ String
The uniform resource identifier of the artifact file. May be empty if there is
no actual artifact file.
Corresponds to the JSON property uri
6749 6750 6751 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6749 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6756 6757 6758 6759 6760 6761 6762 6763 6764 6765 6766 6767 6768 6769 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6756 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @schema_title = args[:schema_title] if args.key?(:schema_title) @schema_version = args[:schema_version] if args.key?(:schema_version) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) @uri = args[:uri] if args.key?(:uri) end |