Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AssessmentDetectorFinding
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AssessmentDetectorFinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The details of a detector's assessment within an analyzed session.
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The detector ID.
-
#display_name ⇒ String
The detector display name.
-
#explanation ⇒ String
The explanation of the finding.
-
#probability ⇒ Float
The probability that this finding is an anomaly, in the range [0.0, 1.0].
-
#recommendations ⇒ Array<String>
The list of recommendations for this detector finding.
-
#severity ⇒ String
The severity of the finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AssessmentDetectorFinding
constructor
A new instance of GoogleCloudAiplatformV1beta1AssessmentDetectorFinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AssessmentDetectorFinding
Returns a new instance of GoogleCloudAiplatformV1beta1AssessmentDetectorFinding.
7908 7909 7910 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7908 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detector_id ⇒ String
The detector ID.
Corresponds to the JSON property detectorId
7881 7882 7883 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7881 def detector_id @detector_id end |
#display_name ⇒ String
The detector display name.
Corresponds to the JSON property displayName
7886 7887 7888 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7886 def display_name @display_name end |
#explanation ⇒ String
The explanation of the finding.
Corresponds to the JSON property explanation
7891 7892 7893 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7891 def explanation @explanation end |
#probability ⇒ Float
The probability that this finding is an anomaly, in the range [0.0, 1.0].
Corresponds to the JSON property probability
7896 7897 7898 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7896 def probability @probability end |
#recommendations ⇒ Array<String>
The list of recommendations for this detector finding.
Corresponds to the JSON property recommendations
7901 7902 7903 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7901 def recommendations @recommendations end |
#severity ⇒ String
The severity of the finding.
Corresponds to the JSON property severity
7906 7907 7908 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7906 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7913 7914 7915 7916 7917 7918 7919 7920 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7913 def update!(**args) @detector_id = args[:detector_id] if args.key?(:detector_id) @display_name = args[:display_name] if args.key?(:display_name) @explanation = args[:explanation] if args.key?(:explanation) @probability = args[:probability] if args.key?(:probability) @recommendations = args[:recommendations] if args.key?(:recommendations) @severity = args[:severity] if args.key?(:severity) end |