Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AssignNotebookRuntimeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for NotebookService.AssignNotebookRuntime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AssignNotebookRuntimeRequest

Returns a new instance of GoogleCloudAiplatformV1beta1AssignNotebookRuntimeRequest.



6665
6666
6667
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#notebook_runtimeGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookRuntime

A runtime is a virtual machine allocated to a particular user for a particular Notebook file on temporary basis with lifetime. Default runtimes have a lifetime of 18 hours, while custom runtimes last for 6 months from their creation or last upgrade. Corresponds to the JSON property notebookRuntime



6652
6653
6654
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6652

def notebook_runtime
  @notebook_runtime
end

#notebook_runtime_idString

Optional. User specified ID for the notebook runtime. Corresponds to the JSON property notebookRuntimeId

Returns:

  • (String)


6657
6658
6659
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6657

def notebook_runtime_id
  @notebook_runtime_id
end

#notebook_runtime_templateString

Required. The resource name of the NotebookRuntimeTemplate based on which a NotebookRuntime will be assigned (reuse or create a new one). Corresponds to the JSON property notebookRuntimeTemplate

Returns:

  • (String)


6663
6664
6665
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6663

def notebook_runtime_template
  @notebook_runtime_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6670
6671
6672
6673
6674
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6670

def update!(**args)
  @notebook_runtime = args[:notebook_runtime] if args.key?(:notebook_runtime)
  @notebook_runtime_id = args[:notebook_runtime_id] if args.key?(:notebook_runtime_id)
  @notebook_runtime_template = args[:notebook_runtime_template] if args.key?(:notebook_runtime_template)
end