Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AsyncQueryReasoningEngineRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AsyncQueryReasoningEngineRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ReasoningEngineExecutionService.AsyncQueryReasoningEngine.
Instance Attribute Summary collapse
-
#input_gcs_uri ⇒ String
Optional.
-
#output_gcs_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AsyncQueryReasoningEngineRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1AsyncQueryReasoningEngineRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AsyncQueryReasoningEngineRequest
Returns a new instance of GoogleCloudAiplatformV1beta1AsyncQueryReasoningEngineRequest.
6697 6698 6699 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#input_gcs_uri ⇒ String
Optional. Input Cloud Storage URI for the Async query. If you are not bringing
your own container (BYOC), the content of the file should be a JSON object
with an input field matching the input field of
QueryReasoningEngineRequest (e.g. "input": ` "user_id": "hello", "message":
"$QUERY"`). For BYOC, the content of the file depends on the the agent
application.
Corresponds to the JSON property inputGcsUri
6689 6690 6691 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6689 def input_gcs_uri @input_gcs_uri end |
#output_gcs_uri ⇒ String
Optional. Output Cloud Storage URI for the Async query. This contains the
final response of the query.
Corresponds to the JSON property outputGcsUri
6695 6696 6697 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6695 def output_gcs_uri @output_gcs_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6702 6703 6704 6705 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6702 def update!(**args) @input_gcs_uri = args[:input_gcs_uri] if args.key?(:input_gcs_uri) @output_gcs_uri = args[:output_gcs_uri] if args.key?(:output_gcs_uri) end |