Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for speech recognition (transcription).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AudioTranscriptionConfig

Returns a new instance of GoogleCloudAiplatformV1beta1AudioTranscriptionConfig.



9431
9432
9433
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adaptation_phrasesArray<String>

Optional. Deprecated: Use custom_vocabulary instead. A list of phrases to bias the speech recognition model towards. Corresponds to the JSON property adaptationPhrases

Returns:

  • (Array<String>)


9393
9394
9395
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9393

def adaptation_phrases
  @adaptation_phrases
end

#custom_vocabularyArray<String>

Optional. A list of custom vocabulary phrases to bias the speech recognition model toward recognizing specific terms. Corresponds to the JSON property customVocabulary

Returns:

  • (Array<String>)


9399
9400
9401
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9399

def custom_vocabulary
  @custom_vocabulary
end

#diarizationBoolean Also known as: diarization?

Optional. Configures speaker diarization. Corresponds to the JSON property diarization

Returns:

  • (Boolean)


9404
9405
9406
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9404

def diarization
  @diarization
end

#language_autoGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionConfigLanguageAuto

Deprecated: Use top-level language_codes instead. Indicates the language of the audio should be automatically detected. Corresponds to the JSON property languageAuto



9411
9412
9413
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9411

def language_auto
  @language_auto
end

#language_codesArray<String>

Optional. BCP-47 language codes providing hints about the languages present in the audio. If omitted or empty, defaults to automatic language detection. Corresponds to the JSON property languageCodes

Returns:

  • (Array<String>)


9417
9418
9419
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9417

def language_codes
  @language_codes
end

#language_hintsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionConfigLanguageHints

Deprecated: Use top-level language_codes instead. Provides hints to the model about possible languages present in the audio. Corresponds to the JSON property languageHints



9423
9424
9425
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9423

def language_hints
  @language_hints
end

#word_timestampBoolean Also known as: word_timestamp?

Optional. Configures word-level timestamp generation. Corresponds to the JSON property wordTimestamp

Returns:

  • (Boolean)


9428
9429
9430
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9428

def word_timestamp
  @word_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9436
9437
9438
9439
9440
9441
9442
9443
9444
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9436

def update!(**args)
  @adaptation_phrases = args[:adaptation_phrases] if args.key?(:adaptation_phrases)
  @custom_vocabulary = args[:custom_vocabulary] if args.key?(:custom_vocabulary)
  @diarization = args[:diarization] if args.key?(:diarization)
  @language_auto = args[:language_auto] if args.key?(:language_auto)
  @language_codes = args[:language_codes] if args.key?(:language_codes)
  @language_hints = args[:language_hints] if args.key?(:language_hints)
  @word_timestamp = args[:word_timestamp] if args.key?(:word_timestamp)
end