Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for speech recognition (transcription).
Instance Attribute Summary collapse
-
#adaptation_phrases ⇒ Array<String>
Optional.
-
#custom_vocabulary ⇒ Array<String>
Optional.
-
#diarization ⇒ Boolean
(also: #diarization?)
Optional.
-
#language_auto ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionConfigLanguageAuto
Indicates the language of the audio should be automatically detected.
-
#language_hints ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionConfigLanguageHints
Provides hints to the model about possible languages present in the audio.
-
#word_timestamp ⇒ Boolean
(also: #word_timestamp?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AudioTranscriptionConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1AudioTranscriptionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AudioTranscriptionConfig
Returns a new instance of GoogleCloudAiplatformV1beta1AudioTranscriptionConfig.
9184 9185 9186 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9184 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adaptation_phrases ⇒ Array<String>
Optional. A list of phrases to bias the ASR model towards.
Corresponds to the JSON property adaptationPhrases
9154 9155 9156 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9154 def adaptation_phrases @adaptation_phrases end |
#custom_vocabulary ⇒ Array<String>
Optional. A list of custom vocabulary phrases to bias the speech recognition
model toward recognizing specific terms.
Corresponds to the JSON property customVocabulary
9160 9161 9162 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9160 def custom_vocabulary @custom_vocabulary end |
#diarization ⇒ Boolean Also known as: diarization?
Optional. Configures speaker diarization.
Corresponds to the JSON property diarization
9165 9166 9167 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9165 def diarization @diarization end |
#language_auto ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionConfigLanguageAuto
Indicates the language of the audio should be automatically detected.
Corresponds to the JSON property languageAuto
9171 9172 9173 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9171 def language_auto @language_auto end |
#language_hints ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscriptionConfigLanguageHints
Provides hints to the model about possible languages present in the audio.
Corresponds to the JSON property languageHints
9176 9177 9178 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9176 def language_hints @language_hints end |
#word_timestamp ⇒ Boolean Also known as: word_timestamp?
Optional. Configures word-level timestamp generation.
Corresponds to the JSON property wordTimestamp
9181 9182 9183 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9181 def @word_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9189 9190 9191 9192 9193 9194 9195 9196 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9189 def update!(**args) @adaptation_phrases = args[:adaptation_phrases] if args.key?(:adaptation_phrases) @custom_vocabulary = args[:custom_vocabulary] if args.key?(:custom_vocabulary) @diarization = args[:diarization] if args.key?(:diarization) @language_auto = args[:language_auto] if args.key?(:language_auto) @language_hints = args[:language_hints] if args.key?(:language_hints) @word_timestamp = args[:word_timestamp] if args.key?(:word_timestamp) end |