Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AugmentPromptResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AugmentPromptResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for AugmentPrompt.
Instance Attribute Summary collapse
-
#augmented_prompt ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Augmented prompt, only text format is supported for now.
-
#facts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Fact>
Retrieved facts from RAG data sources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AugmentPromptResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1AugmentPromptResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AugmentPromptResponse
Returns a new instance of GoogleCloudAiplatformV1beta1AugmentPromptResponse.
2132 2133 2134 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2132 def initialize(**args) update!(**args) end |
Instance Attribute Details
#augmented_prompt ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Augmented prompt, only text format is supported for now.
Corresponds to the JSON property augmentedPrompt
2125 2126 2127 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2125 def augmented_prompt @augmented_prompt end |
#facts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Fact>
Retrieved facts from RAG data sources.
Corresponds to the JSON property facts
2130 2131 2132 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2130 def facts @facts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2137 2138 2139 2140 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2137 def update!(**args) @augmented_prompt = args[:augmented_prompt] if args.key?(:augmented_prompt) @facts = args[:facts] if args.key?(:facts) end |