Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchDedicatedResources

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A description of resources that are used for performing batch operations, are dedicated to a Model, and need manual configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchDedicatedResources

Returns a new instance of GoogleCloudAiplatformV1beta1BatchDedicatedResources.



2756
2757
2758
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2756

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#flex_startGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FlexStart

FlexStart is used to schedule the deployment workload on DWS resource. It contains the max duration of the deployment. Corresponds to the JSON property flexStart



2729
2730
2731
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2729

def flex_start
  @flex_start
end

#machine_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



2734
2735
2736
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2734

def machine_spec
  @machine_spec
end

#max_replica_countFixnum

Immutable. The maximum number of machine replicas the batch operation may be scaled to. The default value is 10. Corresponds to the JSON property maxReplicaCount

Returns:

  • (Fixnum)


2740
2741
2742
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2740

def max_replica_count
  @max_replica_count
end

#spotBoolean Also known as: spot?

Optional. If true, schedule the deployment workload on spot VMs. Corresponds to the JSON property spot

Returns:

  • (Boolean)


2746
2747
2748
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2746

def spot
  @spot
end

#starting_replica_countFixnum

Immutable. The number of machine replicas used at the start of the batch operation. If not set, Vertex AI decides starting number, not greater than max_replica_count Corresponds to the JSON property startingReplicaCount

Returns:

  • (Fixnum)


2754
2755
2756
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2754

def starting_replica_count
  @starting_replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2761
2762
2763
2764
2765
2766
2767
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 2761

def update!(**args)
  @flex_start = args[:flex_start] if args.key?(:flex_start)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @max_replica_count = args[:max_replica_count] if args.key?(:max_replica_count)
  @spot = args[:spot] if args.key?(:spot)
  @starting_replica_count = args[:starting_replica_count] if args.key?(:starting_replica_count)
end