Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchMigrateResourcesOperationMetadataPartialResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a partial result in batch migration operation for one MigrateResourceRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchMigrateResourcesOperationMetadataPartialResult

Returns a new instance of GoogleCloudAiplatformV1beta1BatchMigrateResourcesOperationMetadataPartialResult.



10435
10436
10437
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10435

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datasetString

Migrated dataset resource name. Corresponds to the JSON property dataset

Returns:

  • (String)


10412
10413
10414
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10412

def dataset
  @dataset
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



10422
10423
10424
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10422

def error
  @error
end

#modelString

Migrated model resource name. Corresponds to the JSON property model

Returns:

  • (String)


10427
10428
10429
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10427

def model
  @model
end

#requestGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MigrateResourceRequest

Config of migrating one resource from automl.googleapis.com, datalabeling. googleapis.com and ml.googleapis.com to Vertex AI. Corresponds to the JSON property request



10433
10434
10435
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10433

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10440
10441
10442
10443
10444
10445
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10440

def update!(**args)
  @dataset = args[:dataset] if args.key?(:dataset)
  @error = args[:error] if args.key?(:error)
  @model = args[:model] if args.key?(:model)
  @request = args[:request] if args.key?(:request)
end