Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchMigrateResourcesOperationMetadataPartialResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchMigrateResourcesOperationMetadataPartialResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a partial result in batch migration operation for one MigrateResourceRequest.
Instance Attribute Summary collapse
-
#dataset ⇒ String
Migrated dataset resource name.
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#model ⇒ String
Migrated model resource name.
-
#request ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MigrateResourceRequest
Config of migrating one resource from automl.googleapis.com, datalabeling.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchMigrateResourcesOperationMetadataPartialResult
constructor
A new instance of GoogleCloudAiplatformV1beta1BatchMigrateResourcesOperationMetadataPartialResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchMigrateResourcesOperationMetadataPartialResult
Returns a new instance of GoogleCloudAiplatformV1beta1BatchMigrateResourcesOperationMetadataPartialResult.
9092 9093 9094 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9092 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset ⇒ String
Migrated dataset resource name.
Corresponds to the JSON property dataset
9069 9070 9071 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9069 def dataset @dataset end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
9079 9080 9081 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9079 def error @error end |
#model ⇒ String
Migrated model resource name.
Corresponds to the JSON property model
9084 9085 9086 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9084 def model @model end |
#request ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MigrateResourceRequest
Config of migrating one resource from automl.googleapis.com, datalabeling.
googleapis.com and ml.googleapis.com to Vertex AI.
Corresponds to the JSON property request
9090 9091 9092 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9090 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9097 9098 9099 9100 9101 9102 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9097 def update!(**args) @dataset = args[:dataset] if args.key?(:dataset) @error = args[:error] if args.key?(:error) @model = args[:model] if args.key?(:model) @request = args[:request] if args.key?(:request) end |