Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchMigrateResourcesOperationMetadataPartialResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a partial result in batch migration operation for one MigrateResourceRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchMigrateResourcesOperationMetadataPartialResult

Returns a new instance of GoogleCloudAiplatformV1beta1BatchMigrateResourcesOperationMetadataPartialResult.



7747
7748
7749
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datasetString

Migrated dataset resource name. Corresponds to the JSON property dataset

Returns:

  • (String)


7724
7725
7726
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7724

def dataset
  @dataset
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



7734
7735
7736
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7734

def error
  @error
end

#modelString

Migrated model resource name. Corresponds to the JSON property model

Returns:

  • (String)


7739
7740
7741
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7739

def model
  @model
end

#requestGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MigrateResourceRequest

Config of migrating one resource from automl.googleapis.com, datalabeling. googleapis.com and ml.googleapis.com to Vertex AI. Corresponds to the JSON property request



7745
7746
7747
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7745

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7752
7753
7754
7755
7756
7757
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 7752

def update!(**args)
  @dataset = args[:dataset] if args.key?(:dataset)
  @error = args[:error] if args.key?(:error)
  @model = args[:model] if args.key?(:model)
  @request = args[:request] if args.key?(:request)
end