Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchPredictionJobInputConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchPredictionJobInputConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configures the input to BatchPredictionJob. See Model. supported_input_storage_formats for Model's supported input formats, and how instances should be expressed via any of them.
Instance Attribute Summary collapse
-
#bigquery_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQuerySource
The BigQuery location for the input content.
-
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource
The Google Cloud Storage location for the input content.
-
#instances_format ⇒ String
Required.
-
#vertex_multimodal_dataset_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexMultimodalDatasetSource
The Vertex Multimodal Dataset for the input content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchPredictionJobInputConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1BatchPredictionJobInputConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchPredictionJobInputConfig
Returns a new instance of GoogleCloudAiplatformV1beta1BatchPredictionJobInputConfig.
3328 3329 3330 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3328 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQuerySource
The BigQuery location for the input content.
Corresponds to the JSON property bigquerySource
3310 3311 3312 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3310 def bigquery_source @bigquery_source end |
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
3315 3316 3317 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3315 def gcs_source @gcs_source end |
#instances_format ⇒ String
Required. The format in which instances are given, must be one of the Model's
supported_input_storage_formats.
Corresponds to the JSON property instancesFormat
3321 3322 3323 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3321 def instances_format @instances_format end |
#vertex_multimodal_dataset_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexMultimodalDatasetSource
The Vertex Multimodal Dataset for the input content.
Corresponds to the JSON property vertexMultimodalDatasetSource
3326 3327 3328 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3326 def vertex_multimodal_dataset_source @vertex_multimodal_dataset_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3333 3334 3335 3336 3337 3338 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3333 def update!(**args) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @instances_format = args[:instances_format] if args.key?(:instances_format) @vertex_multimodal_dataset_source = args[:vertex_multimodal_dataset_source] if args.key?(:vertex_multimodal_dataset_source) end |