Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchPredictionJobOutputConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchPredictionJobOutputConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configures the output of BatchPredictionJob. See Model. supported_output_storage_formats for supported output formats, and how predictions are expressed via any of them.
Instance Attribute Summary collapse
-
#bigquery_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryDestination
The BigQuery location for the output content.
-
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#predictions_format ⇒ String
Required.
-
#vertex_multimodal_dataset_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexMultimodalDatasetDestination
The details for a Vertex Multimodal Dataset output.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchPredictionJobOutputConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1BatchPredictionJobOutputConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchPredictionJobOutputConfig
Returns a new instance of GoogleCloudAiplatformV1beta1BatchPredictionJobOutputConfig.
9551 9552 9553 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9551 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryDestination
The BigQuery location for the output content.
Corresponds to the JSON property bigqueryDestination
9533 9534 9535 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9533 def bigquery_destination @bigquery_destination end |
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcsDestination
9538 9539 9540 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9538 def gcs_destination @gcs_destination end |
#predictions_format ⇒ String
Required. The format in which Vertex AI gives the predictions, must be one of
the Model's supported_output_storage_formats.
Corresponds to the JSON property predictionsFormat
9544 9545 9546 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9544 def predictions_format @predictions_format end |
#vertex_multimodal_dataset_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexMultimodalDatasetDestination
The details for a Vertex Multimodal Dataset output.
Corresponds to the JSON property vertexMultimodalDatasetDestination
9549 9550 9551 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9549 def vertex_multimodal_dataset_destination @vertex_multimodal_dataset_destination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9556 9557 9558 9559 9560 9561 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9556 def update!(**args) @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @predictions_format = args[:predictions_format] if args.key?(:predictions_format) @vertex_multimodal_dataset_destination = args[:vertex_multimodal_dataset_destination] if args.key?(:vertex_multimodal_dataset_destination) end |