Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchPredictionJobOutputConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configures the output of BatchPredictionJob. See Model. supported_output_storage_formats for supported output formats, and how predictions are expressed via any of them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchPredictionJobOutputConfig

Returns a new instance of GoogleCloudAiplatformV1beta1BatchPredictionJobOutputConfig.



8206
8207
8208
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property bigqueryDestination



8188
8189
8190
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8188

def bigquery_destination
  @bigquery_destination
end

#gcs_destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcsDestination



8193
8194
8195
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8193

def gcs_destination
  @gcs_destination
end

#predictions_formatString

Required. The format in which Vertex AI gives the predictions, must be one of the Model's supported_output_storage_formats. Corresponds to the JSON property predictionsFormat

Returns:

  • (String)


8199
8200
8201
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8199

def predictions_format
  @predictions_format
end

#vertex_multimodal_dataset_destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexMultimodalDatasetDestination

The details for a Vertex Multimodal Dataset output. Corresponds to the JSON property vertexMultimodalDatasetDestination



8204
8205
8206
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8204

def vertex_multimodal_dataset_destination
  @vertex_multimodal_dataset_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8211
8212
8213
8214
8215
8216
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8211

def update!(**args)
  @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @predictions_format = args[:predictions_format] if args.key?(:predictions_format)
  @vertex_multimodal_dataset_destination = args[:vertex_multimodal_dataset_destination] if args.key?(:vertex_multimodal_dataset_destination)
end