Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchPredictionJobOutputInfo
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchPredictionJobOutputInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Further describes this job's output. Supplements output_config.
Instance Attribute Summary collapse
-
#bigquery_output_dataset ⇒ String
Output only.
-
#bigquery_output_table ⇒ String
Output only.
-
#gcs_output_directory ⇒ String
Output only.
-
#vertex_multimodal_dataset_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchPredictionJobOutputInfo
constructor
A new instance of GoogleCloudAiplatformV1beta1BatchPredictionJobOutputInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchPredictionJobOutputInfo
Returns a new instance of GoogleCloudAiplatformV1beta1BatchPredictionJobOutputInfo.
9594 9595 9596 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_output_dataset ⇒ String
Output only. The path of the BigQuery dataset created, in bq://projectId.
bqDatasetId format, into which the prediction output is written.
Corresponds to the JSON property bigqueryOutputDataset
9572 9573 9574 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9572 def bigquery_output_dataset @bigquery_output_dataset end |
#bigquery_output_table ⇒ String
Output only. The name of the BigQuery table created, in predictions_ format,
into which the prediction output is written. Can be used by UI to generate the
BigQuery output path, for example.
Corresponds to the JSON property bigqueryOutputTable
9579 9580 9581 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9579 def bigquery_output_table @bigquery_output_table end |
#gcs_output_directory ⇒ String
Output only. The full path of the Cloud Storage directory created, into which
the prediction output is written.
Corresponds to the JSON property gcsOutputDirectory
9585 9586 9587 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9585 def gcs_output_directory @gcs_output_directory end |
#vertex_multimodal_dataset_name ⇒ String
Output only. The resource name of the Vertex Managed Dataset created, into
which the prediction output is written. Format: projects/project/locations/
location/datasets/dataset`
Corresponds to the JSON propertyvertexMultimodalDatasetName`
9592 9593 9594 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9592 def vertex_multimodal_dataset_name @vertex_multimodal_dataset_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9599 9600 9601 9602 9603 9604 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9599 def update!(**args) @bigquery_output_dataset = args[:bigquery_output_dataset] if args.key?(:bigquery_output_dataset) @bigquery_output_table = args[:bigquery_output_table] if args.key?(:bigquery_output_table) @gcs_output_directory = args[:gcs_output_directory] if args.key?(:gcs_output_directory) @vertex_multimodal_dataset_name = args[:vertex_multimodal_dataset_name] if args.key?(:vertex_multimodal_dataset_name) end |