Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for FeaturestoreService.BatchReadFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequest.



11020
11021
11022
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_read_instancesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigqueryReadInstances



10986
10987
10988
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10986

def bigquery_read_instances
  @bigquery_read_instances
end

#csv_read_instancesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CsvSource

The storage details for CSV input content. Corresponds to the JSON property csvReadInstances



10991
10992
10993
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10991

def csv_read_instances
  @csv_read_instances
end

#destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureValueDestination

A destination location for Feature values and format. Corresponds to the JSON property destination



10996
10997
10998
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10996

def destination
  @destination
end

#entity_type_specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequestEntityTypeSpec>

Required. Specifies EntityType grouping Features to read values of and settings. Corresponds to the JSON property entityTypeSpecs



11002
11003
11004
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11002

def entity_type_specs
  @entity_type_specs
end

#pass_through_fieldsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequestPassThroughField>

When not empty, the specified fields in the *_read_instances source will be joined as-is in the output, in addition to those fields from the Featurestore Entity. For BigQuery source, the type of the pass-through values will be automatically inferred. For CSV source, the pass-through values will be passed as opaque bytes. Corresponds to the JSON property passThroughFields



11011
11012
11013
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11011

def pass_through_fields
  @pass_through_fields
end

#start_timeString

Optional. Excludes Feature values with feature generation timestamp before this timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp, if present, must not have higher than millisecond precision. Corresponds to the JSON property startTime

Returns:

  • (String)


11018
11019
11020
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11018

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11025
11026
11027
11028
11029
11030
11031
11032
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11025

def update!(**args)
  @bigquery_read_instances = args[:bigquery_read_instances] if args.key?(:bigquery_read_instances)
  @csv_read_instances = args[:csv_read_instances] if args.key?(:csv_read_instances)
  @destination = args[:destination] if args.key?(:destination)
  @entity_type_specs = args[:entity_type_specs] if args.key?(:entity_type_specs)
  @pass_through_fields = args[:pass_through_fields] if args.key?(:pass_through_fields)
  @start_time = args[:start_time] if args.key?(:start_time)
end