Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for FeaturestoreService.BatchReadFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequest.



9863
9864
9865
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_read_instancesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigqueryReadInstances



9829
9830
9831
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9829

def bigquery_read_instances
  @bigquery_read_instances
end

#csv_read_instancesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CsvSource

The storage details for CSV input content. Corresponds to the JSON property csvReadInstances



9834
9835
9836
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9834

def csv_read_instances
  @csv_read_instances
end

#destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureValueDestination

A destination location for Feature values and format. Corresponds to the JSON property destination



9839
9840
9841
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9839

def destination
  @destination
end

#entity_type_specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequestEntityTypeSpec>

Required. Specifies EntityType grouping Features to read values of and settings. Corresponds to the JSON property entityTypeSpecs



9845
9846
9847
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9845

def entity_type_specs
  @entity_type_specs
end

#pass_through_fieldsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequestPassThroughField>

When not empty, the specified fields in the *_read_instances source will be joined as-is in the output, in addition to those fields from the Featurestore Entity. For BigQuery source, the type of the pass-through values will be automatically inferred. For CSV source, the pass-through values will be passed as opaque bytes. Corresponds to the JSON property passThroughFields



9854
9855
9856
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9854

def pass_through_fields
  @pass_through_fields
end

#start_timeString

Optional. Excludes Feature values with feature generation timestamp before this timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp, if present, must not have higher than millisecond precision. Corresponds to the JSON property startTime

Returns:

  • (String)


9861
9862
9863
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9861

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9868
9869
9870
9871
9872
9873
9874
9875
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9868

def update!(**args)
  @bigquery_read_instances = args[:bigquery_read_instances] if args.key?(:bigquery_read_instances)
  @csv_read_instances = args[:csv_read_instances] if args.key?(:csv_read_instances)
  @destination = args[:destination] if args.key?(:destination)
  @entity_type_specs = args[:entity_type_specs] if args.key?(:entity_type_specs)
  @pass_through_fields = args[:pass_through_fields] if args.key?(:pass_through_fields)
  @start_time = args[:start_time] if args.key?(:start_time)
end