Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for FeaturestoreService.BatchReadFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequest.



9489
9490
9491
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9489

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_read_instancesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigqueryReadInstances



9455
9456
9457
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9455

def bigquery_read_instances
  @bigquery_read_instances
end

#csv_read_instancesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CsvSource

The storage details for CSV input content. Corresponds to the JSON property csvReadInstances



9460
9461
9462
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9460

def csv_read_instances
  @csv_read_instances
end

#destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureValueDestination

A destination location for Feature values and format. Corresponds to the JSON property destination



9465
9466
9467
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9465

def destination
  @destination
end

#entity_type_specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequestEntityTypeSpec>

Required. Specifies EntityType grouping Features to read values of and settings. Corresponds to the JSON property entityTypeSpecs



9471
9472
9473
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9471

def entity_type_specs
  @entity_type_specs
end

#pass_through_fieldsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchReadFeatureValuesRequestPassThroughField>

When not empty, the specified fields in the *_read_instances source will be joined as-is in the output, in addition to those fields from the Featurestore Entity. For BigQuery source, the type of the pass-through values will be automatically inferred. For CSV source, the pass-through values will be passed as opaque bytes. Corresponds to the JSON property passThroughFields



9480
9481
9482
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9480

def pass_through_fields
  @pass_through_fields
end

#start_timeString

Optional. Excludes Feature values with feature generation timestamp before this timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp, if present, must not have higher than millisecond precision. Corresponds to the JSON property startTime

Returns:

  • (String)


9487
9488
9489
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9487

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9494
9495
9496
9497
9498
9499
9500
9501
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9494

def update!(**args)
  @bigquery_read_instances = args[:bigquery_read_instances] if args.key?(:bigquery_read_instances)
  @csv_read_instances = args[:csv_read_instances] if args.key?(:csv_read_instances)
  @destination = args[:destination] if args.key?(:destination)
  @entity_type_specs = args[:entity_type_specs] if args.key?(:entity_type_specs)
  @pass_through_fields = args[:pass_through_fields] if args.key?(:pass_through_fields)
  @start_time = args[:start_time] if args.key?(:start_time)
end