Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The BigQuery location for the output content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BigQueryDestination

Returns a new instance of GoogleCloudAiplatformV1beta1BigQueryDestination.



8435
8436
8437
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8435

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#output_uriString

Required. BigQuery URI to a project or table, up to 2000 characters long. When only the project is specified, the Dataset and Table is created. When the full table reference is specified, the Dataset must exist and table must not exist. Accepted forms: * BigQuery path. For example: bq://projectId or bq:// projectId.bqDatasetId or bq://projectId.bqDatasetId.bqTableId. Corresponds to the JSON property outputUri

Returns:

  • (String)


8433
8434
8435
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8433

def output_uri
  @output_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8440
8441
8442
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8440

def update!(**args)
  @output_uri = args[:output_uri] if args.key?(:output_uri)
end