Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Blob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Blob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A content blob. A Blob contains data of a specific media type. It is used to represent images, audio, and video.
Instance Attribute Summary collapse
-
#data ⇒ String
Required.
-
#display_name ⇒ String
Optional.
-
#mime_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Blob
constructor
A new instance of GoogleCloudAiplatformV1beta1Blob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Blob
Returns a new instance of GoogleCloudAiplatformV1beta1Blob.
3915 3916 3917 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3915 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ String
Required. The raw bytes of the data.
Corresponds to the JSON property data
NOTE: Values are automatically base64 encoded/decoded in the client library.
3900 3901 3902 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3900 def data @data end |
#display_name ⇒ String
Optional. The display name of the blob. Used to provide a label or filename to
distinguish blobs. This field is only returned in PromptMessage for prompt
management. It is used in the Gemini calls only when server-side tools (
code_execution, google_search, and url_context) are enabled.
Corresponds to the JSON property displayName
3908 3909 3910 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3908 def display_name @display_name end |
#mime_type ⇒ String
Required. The IANA standard MIME type of the source data.
Corresponds to the JSON property mimeType
3913 3914 3915 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3913 def mime_type @mime_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3920 3921 3922 3923 3924 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 3920 def update!(**args) @data = args[:data] if args.key?(:data) @display_name = args[:display_name] if args.key?(:display_name) @mime_type = args[:mime_type] if args.key?(:mime_type) end |