Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BlurBaselineConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BlurBaselineConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Config for blur baseline. When enabled, a linear path from the maximally blurred image to the input image is created. Using a blurred baseline instead of zero (black image) is motivated by the BlurIG approach explained here: https://arxiv.org/abs/2004.03383
Instance Attribute Summary collapse
-
#max_blur_sigma ⇒ Float
The standard deviation of the blur kernel for the blurred baseline.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BlurBaselineConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1BlurBaselineConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BlurBaselineConfig
Returns a new instance of GoogleCloudAiplatformV1beta1BlurBaselineConfig.
11464 11465 11466 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11464 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_blur_sigma ⇒ Float
The standard deviation of the blur kernel for the blurred baseline. The same
blurring parameter is used for both the height and the width dimension. If not
set, the method defaults to the zero (i.e. black for images) baseline.
Corresponds to the JSON property maxBlurSigma
11462 11463 11464 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11462 def max_blur_sigma @max_blur_sigma end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11469 11470 11471 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11469 def update!(**args) @max_blur_sigma = args[:max_blur_sigma] if args.key?(:max_blur_sigma) end |