Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BlurBaselineConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BlurBaselineConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Config for blur baseline. When enabled, a linear path from the maximally blurred image to the input image is created. Using a blurred baseline instead of zero (black image) is motivated by the BlurIG approach explained here: https://arxiv.org/abs/2004.03383
Instance Attribute Summary collapse
-
#max_blur_sigma ⇒ Float
The standard deviation of the blur kernel for the blurred baseline.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BlurBaselineConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1BlurBaselineConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1BlurBaselineConfig
Returns a new instance of GoogleCloudAiplatformV1beta1BlurBaselineConfig.
11152 11153 11154 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11152 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_blur_sigma ⇒ Float
The standard deviation of the blur kernel for the blurred baseline. The same
blurring parameter is used for both the height and the width dimension. If not
set, the method defaults to the zero (i.e. black for images) baseline.
Corresponds to the JSON property maxBlurSigma
11150 11151 11152 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11150 def max_blur_sigma @max_blur_sigma end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11157 11158 11159 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11157 def update!(**args) @max_blur_sigma = args[:max_blur_sigma] if args.key?(:max_blur_sigma) end |