Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CachedContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CachedContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A resource used in LLM queries for users to explicitly specify what to cache and how to cache.
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Optional.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#expire_time ⇒ String
Timestamp of when this resource is considered expired.
-
#model ⇒ String
Immutable.
-
#name ⇒ String
Immutable.
-
#system_instruction ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message.
-
#tool_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolConfig
Tool config.
-
#tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional.
-
#ttl ⇒ String
Input only.
-
#update_time ⇒ String
Output only.
-
#usage_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CachedContentUsageMetadata
Metadata on the usage of the cached content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CachedContent
constructor
A new instance of GoogleCloudAiplatformV1beta1CachedContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CachedContent
Returns a new instance of GoogleCloudAiplatformV1beta1CachedContent.
10383 10384 10385 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10383 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Optional. Input only. Immutable. The content to cache
Corresponds to the JSON property contents
10310 10311 10312 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10310 def contents @contents end |
#create_time ⇒ String
Output only. Creation time of the cache entry.
Corresponds to the JSON property createTime
10315 10316 10317 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10315 def create_time @create_time end |
#display_name ⇒ String
Optional. Immutable. The user-generated meaningful display name of the cached
content.
Corresponds to the JSON property displayName
10321 10322 10323 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10321 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
10327 10328 10329 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10327 def encryption_spec @encryption_spec end |
#expire_time ⇒ String
Timestamp of when this resource is considered expired. This is always
provided on output, regardless of what was sent on input.
Corresponds to the JSON property expireTime
10333 10334 10335 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10333 def expire_time @expire_time end |
#model ⇒ String
Immutable. The name of the Model to use for cached content. Currently, only
the published Gemini base models are supported, in form of projects/PROJECT/
locations/LOCATION/publishers/google/models/MODEL
Corresponds to the JSON property model
10340 10341 10342 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10340 def model @model end |
#name ⇒ String
Immutable. Identifier. The server-generated resource name of the cached
content Format: projects/project/locations/location/cachedContents/
cached_content
Corresponds to the JSON property name
10347 10348 10349 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10347 def name @name end |
#system_instruction ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property systemInstruction
10354 10355 10356 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10354 def system_instruction @system_instruction end |
#tool_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolConfig
Tool config. This config is shared for all tools provided in the request.
Corresponds to the JSON property toolConfig
10359 10360 10361 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10359 def tool_config @tool_config end |
#tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional. Input only. Immutable. A list of Tools the model may use to
generate the next response
Corresponds to the JSON property tools
10365 10366 10367 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10365 def tools @tools end |
#ttl ⇒ String
Input only. The TTL for this resource. The expiration time is computed: now +
TTL.
Corresponds to the JSON property ttl
10371 10372 10373 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10371 def ttl @ttl end |
#update_time ⇒ String
Output only. When the cache entry was last updated in UTC time.
Corresponds to the JSON property updateTime
10376 10377 10378 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10376 def update_time @update_time end |
#usage_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CachedContentUsageMetadata
Metadata on the usage of the cached content.
Corresponds to the JSON property usageMetadata
10381 10382 10383 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10381 def @usage_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10388 10389 10390 10391 10392 10393 10394 10395 10396 10397 10398 10399 10400 10401 10402 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10388 def update!(**args) @contents = args[:contents] if args.key?(:contents) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @expire_time = args[:expire_time] if args.key?(:expire_time) @model = args[:model] if args.key?(:model) @name = args[:name] if args.key?(:name) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @tool_config = args[:tool_config] if args.key?(:tool_config) @tools = args[:tools] if args.key?(:tools) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata) end |