Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CachedContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CachedContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A resource used in LLM queries for users to explicitly specify what to cache and how to cache.
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Optional.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#expire_time ⇒ String
Timestamp of when this resource is considered expired.
-
#model ⇒ String
Immutable.
-
#name ⇒ String
Immutable.
-
#system_instruction ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message.
-
#tool_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolConfig
Tool config.
-
#tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional.
-
#ttl ⇒ String
Input only.
-
#update_time ⇒ String
Output only.
-
#usage_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CachedContentUsageMetadata
Metadata on the usage of the cached content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CachedContent
constructor
A new instance of GoogleCloudAiplatformV1beta1CachedContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CachedContent
Returns a new instance of GoogleCloudAiplatformV1beta1CachedContent.
9238 9239 9240 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9238 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Optional. Input only. Immutable. The content to cache
Corresponds to the JSON property contents
9165 9166 9167 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9165 def contents @contents end |
#create_time ⇒ String
Output only. Creation time of the cache entry.
Corresponds to the JSON property createTime
9170 9171 9172 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9170 def create_time @create_time end |
#display_name ⇒ String
Optional. Immutable. The user-generated meaningful display name of the cached
content.
Corresponds to the JSON property displayName
9176 9177 9178 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9176 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
9182 9183 9184 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9182 def encryption_spec @encryption_spec end |
#expire_time ⇒ String
Timestamp of when this resource is considered expired. This is always
provided on output, regardless of what was sent on input.
Corresponds to the JSON property expireTime
9188 9189 9190 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9188 def expire_time @expire_time end |
#model ⇒ String
Immutable. The name of the Model to use for cached content. Currently, only
the published Gemini base models are supported, in form of projects/PROJECT/
locations/LOCATION/publishers/google/models/MODEL
Corresponds to the JSON property model
9195 9196 9197 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9195 def model @model end |
#name ⇒ String
Immutable. Identifier. The server-generated resource name of the cached
content Format: projects/project/locations/location/cachedContents/
cached_content
Corresponds to the JSON property name
9202 9203 9204 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9202 def name @name end |
#system_instruction ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property systemInstruction
9209 9210 9211 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9209 def system_instruction @system_instruction end |
#tool_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolConfig
Tool config. This config is shared for all tools provided in the request.
Corresponds to the JSON property toolConfig
9214 9215 9216 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9214 def tool_config @tool_config end |
#tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional. Input only. Immutable. A list of Tools the model may use to
generate the next response
Corresponds to the JSON property tools
9220 9221 9222 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9220 def tools @tools end |
#ttl ⇒ String
Input only. The TTL for this resource. The expiration time is computed: now +
TTL.
Corresponds to the JSON property ttl
9226 9227 9228 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9226 def ttl @ttl end |
#update_time ⇒ String
Output only. When the cache entry was last updated in UTC time.
Corresponds to the JSON property updateTime
9231 9232 9233 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9231 def update_time @update_time end |
#usage_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CachedContentUsageMetadata
Metadata on the usage of the cached content.
Corresponds to the JSON property usageMetadata
9236 9237 9238 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9236 def @usage_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9243 9244 9245 9246 9247 9248 9249 9250 9251 9252 9253 9254 9255 9256 9257 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9243 def update!(**args) @contents = args[:contents] if args.key?(:contents) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @expire_time = args[:expire_time] if args.key?(:expire_time) @model = args[:model] if args.key?(:model) @name = args[:name] if args.key?(:name) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @tool_config = args[:tool_config] if args.key?(:tool_config) @tools = args[:tools] if args.key?(:tools) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata) end |