Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CachedContent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A resource used in LLM queries for users to explicitly specify what to cache and how to cache.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CachedContent

Returns a new instance of GoogleCloudAiplatformV1beta1CachedContent.



4112
4113
4114
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>

Optional. Input only. Immutable. The content to cache Corresponds to the JSON property contents



4039
4040
4041
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4039

def contents
  @contents
end

#create_timeString

Output only. Creation time of the cache entry. Corresponds to the JSON property createTime

Returns:

  • (String)


4044
4045
4046
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4044

def create_time
  @create_time
end

#display_nameString

Optional. Immutable. The user-generated meaningful display name of the cached content. Corresponds to the JSON property displayName

Returns:

  • (String)


4050
4051
4052
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4050

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



4056
4057
4058
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4056

def encryption_spec
  @encryption_spec
end

#expire_timeString

Timestamp of when this resource is considered expired. This is always provided on output, regardless of what was sent on input. Corresponds to the JSON property expireTime

Returns:

  • (String)


4062
4063
4064
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4062

def expire_time
  @expire_time
end

#modelString

Immutable. The name of the Model to use for cached content. Currently, only the published Gemini base models are supported, in form of projects/PROJECT/ locations/LOCATION/publishers/google/models/MODEL Corresponds to the JSON property model

Returns:

  • (String)


4069
4070
4071
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4069

def model
  @model
end

#nameString

Immutable. Identifier. The server-generated resource name of the cached content Format: projects/project/locations/location/cachedContents/ cached_content Corresponds to the JSON property name

Returns:

  • (String)


4076
4077
4078
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4076

def name
  @name
end

#system_instructionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property systemInstruction



4083
4084
4085
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4083

def system_instruction
  @system_instruction
end

#tool_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolConfig

Tool config. This config is shared for all tools provided in the request. Corresponds to the JSON property toolConfig



4088
4089
4090
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4088

def tool_config
  @tool_config
end

#toolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>

Optional. Input only. Immutable. A list of Tools the model may use to generate the next response Corresponds to the JSON property tools



4094
4095
4096
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4094

def tools
  @tools
end

#ttlString

Input only. The TTL for this resource. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


4100
4101
4102
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4100

def ttl
  @ttl
end

#update_timeString

Output only. When the cache entry was last updated in UTC time. Corresponds to the JSON property updateTime

Returns:

  • (String)


4105
4106
4107
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4105

def update_time
  @update_time
end

#usage_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CachedContentUsageMetadata

Metadata on the usage of the cached content. Corresponds to the JSON property usageMetadata



4110
4111
4112
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4110

def 
  @usage_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4117
4118
4119
4120
4121
4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4117

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @model = args[:model] if args.key?(:model)
  @name = args[:name] if args.key?(:name)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tool_config = args[:tool_config] if args.key?(:tool_config)
  @tools = args[:tools] if args.key?(:tools)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
  @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata)
end