Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CachedContentUsageMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CachedContentUsageMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Metadata on the usage of the cached content.
Instance Attribute Summary collapse
-
#audio_duration_seconds ⇒ Fixnum
Duration of audio in seconds.
-
#image_count ⇒ Fixnum
Number of images.
-
#text_count ⇒ Fixnum
Number of text characters.
-
#total_token_count ⇒ Fixnum
Total number of tokens that the cached content consumes.
-
#video_duration_seconds ⇒ Fixnum
Duration of video in seconds.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CachedContentUsageMetadata
constructor
A new instance of GoogleCloudAiplatformV1beta1CachedContentUsageMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CachedContentUsageMetadata
Returns a new instance of GoogleCloudAiplatformV1beta1CachedContentUsageMetadata.
9289 9290 9291 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_duration_seconds ⇒ Fixnum
Duration of audio in seconds.
Corresponds to the JSON property audioDurationSeconds
9267 9268 9269 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9267 def audio_duration_seconds @audio_duration_seconds end |
#image_count ⇒ Fixnum
Number of images.
Corresponds to the JSON property imageCount
9272 9273 9274 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9272 def image_count @image_count end |
#text_count ⇒ Fixnum
Number of text characters.
Corresponds to the JSON property textCount
9277 9278 9279 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9277 def text_count @text_count end |
#total_token_count ⇒ Fixnum
Total number of tokens that the cached content consumes.
Corresponds to the JSON property totalTokenCount
9282 9283 9284 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9282 def total_token_count @total_token_count end |
#video_duration_seconds ⇒ Fixnum
Duration of video in seconds.
Corresponds to the JSON property videoDurationSeconds
9287 9288 9289 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9287 def video_duration_seconds @video_duration_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9294 9295 9296 9297 9298 9299 9300 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9294 def update!(**args) @audio_duration_seconds = args[:audio_duration_seconds] if args.key?(:audio_duration_seconds) @image_count = args[:image_count] if args.key?(:image_count) @text_count = args[:text_count] if args.key?(:text_count) @total_token_count = args[:total_token_count] if args.key?(:total_token_count) @video_duration_seconds = args[:video_duration_seconds] if args.key?(:video_duration_seconds) end |