Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Responses from model or agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CandidateResponse

Returns a new instance of GoogleCloudAiplatformV1beta1CandidateResponse.



11889
11890
11891
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData

Represents data specific to multi-turn agent evaluations. Corresponds to the JSON property agentData



11856
11857
11858
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11856

def agent_data
  @agent_data
end

#candidateString

Required. The name of the candidate that produced the response. Corresponds to the JSON property candidate

Returns:

  • (String)


11861
11862
11863
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11861

def candidate
  @candidate
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



11871
11872
11873
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11871

def error
  @error
end

#eventsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>

Optional. Intermediate events (such as tool calls and responses) that led to the final response. Corresponds to the JSON property events



11877
11878
11879
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11877

def events
  @events
end

#textString

Text response. Corresponds to the JSON property text

Returns:

  • (String)


11882
11883
11884
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11882

def text
  @text
end

#valueObject

Fields and values that can be used to populate the response template. Corresponds to the JSON property value

Returns:

  • (Object)


11887
11888
11889
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11887

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11894
11895
11896
11897
11898
11899
11900
11901
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11894

def update!(**args)
  @agent_data = args[:agent_data] if args.key?(:agent_data)
  @candidate = args[:candidate] if args.key?(:candidate)
  @error = args[:error] if args.key?(:error)
  @events = args[:events] if args.key?(:events)
  @text = args[:text] if args.key?(:text)
  @value = args[:value] if args.key?(:value)
end