Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Responses from model or agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CandidateResponse

Returns a new instance of GoogleCloudAiplatformV1beta1CandidateResponse.



10732
10733
10734
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData

Represents data specific to multi-turn agent evaluations. Corresponds to the JSON property agentData



10699
10700
10701
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10699

def agent_data
  @agent_data
end

#candidateString

Required. The name of the candidate that produced the response. Corresponds to the JSON property candidate

Returns:

  • (String)


10704
10705
10706
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10704

def candidate
  @candidate
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



10714
10715
10716
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10714

def error
  @error
end

#eventsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>

Optional. Intermediate events (such as tool calls and responses) that led to the final response. Corresponds to the JSON property events



10720
10721
10722
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10720

def events
  @events
end

#textString

Text response. Corresponds to the JSON property text

Returns:

  • (String)


10725
10726
10727
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10725

def text
  @text
end

#valueObject

Fields and values that can be used to populate the response template. Corresponds to the JSON property value

Returns:

  • (Object)


10730
10731
10732
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10730

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10737
10738
10739
10740
10741
10742
10743
10744
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10737

def update!(**args)
  @agent_data = args[:agent_data] if args.key?(:agent_data)
  @candidate = args[:candidate] if args.key?(:candidate)
  @error = args[:error] if args.key?(:error)
  @events = args[:events] if args.key?(:events)
  @text = args[:text] if args.key?(:text)
  @value = args[:value] if args.key?(:value)
end