Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Responses from model or agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CandidateResponse

Returns a new instance of GoogleCloudAiplatformV1beta1CandidateResponse.



9587
9588
9589
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData

Represents data specific to multi-turn agent evaluations. Corresponds to the JSON property agentData



9554
9555
9556
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9554

def agent_data
  @agent_data
end

#candidateString

Required. The name of the candidate that produced the response. Corresponds to the JSON property candidate

Returns:

  • (String)


9559
9560
9561
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9559

def candidate
  @candidate
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



9569
9570
9571
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9569

def error
  @error
end

#eventsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>

Optional. Intermediate events (such as tool calls and responses) that led to the final response. Corresponds to the JSON property events



9575
9576
9577
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9575

def events
  @events
end

#textString

Text response. Corresponds to the JSON property text

Returns:

  • (String)


9580
9581
9582
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9580

def text
  @text
end

#valueObject

Fields and values that can be used to populate the response template. Corresponds to the JSON property value

Returns:

  • (Object)


9585
9586
9587
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9585

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9592
9593
9594
9595
9596
9597
9598
9599
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9592

def update!(**args)
  @agent_data = args[:agent_data] if args.key?(:agent_data)
  @candidate = args[:candidate] if args.key?(:candidate)
  @error = args[:error] if args.key?(:error)
  @events = args[:events] if args.key?(:events)
  @text = args[:text] if args.key?(:text)
  @value = args[:value] if args.key?(:value)
end