Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Responses from model or agent.
Instance Attribute Summary collapse
-
#agent_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData
Represents data specific to multi-turn agent evaluations.
-
#candidate ⇒ String
Required.
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Optional.
-
#text ⇒ String
Text response.
-
#value ⇒ Object
Fields and values that can be used to populate the response template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CandidateResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1CandidateResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CandidateResponse
Returns a new instance of GoogleCloudAiplatformV1beta1CandidateResponse.
9191 9192 9193 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9191 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData
Represents data specific to multi-turn agent evaluations.
Corresponds to the JSON property agentData
9158 9159 9160 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9158 def agent_data @agent_data end |
#candidate ⇒ String
Required. The name of the candidate that produced the response.
Corresponds to the JSON property candidate
9163 9164 9165 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9163 def candidate @candidate end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
9173 9174 9175 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9173 def error @error end |
#events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Optional. Intermediate events (such as tool calls and responses) that led to
the final response.
Corresponds to the JSON property events
9179 9180 9181 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9179 def events @events end |
#text ⇒ String
Text response.
Corresponds to the JSON property text
9184 9185 9186 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9184 def text @text end |
#value ⇒ Object
Fields and values that can be used to populate the response template.
Corresponds to the JSON property value
9189 9190 9191 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9189 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9196 9197 9198 9199 9200 9201 9202 9203 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9196 def update!(**args) @agent_data = args[:agent_data] if args.key?(:agent_data) @candidate = args[:candidate] if args.key?(:candidate) @error = args[:error] if args.key?(:error) @events = args[:events] if args.key?(:events) @text = args[:text] if args.key?(:text) @value = args[:value] if args.key?(:value) end |