Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Responses from model or agent.
Instance Attribute Summary collapse
-
#agent_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData
Represents data specific to multi-turn agent evaluations.
-
#candidate ⇒ String
Required.
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Optional.
-
#text ⇒ String
Text response.
-
#value ⇒ Object
Fields and values that can be used to populate the response template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CandidateResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1CandidateResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CandidateResponse
Returns a new instance of GoogleCloudAiplatformV1beta1CandidateResponse.
4425 4426 4427 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4425 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData
Represents data specific to multi-turn agent evaluations.
Corresponds to the JSON property agentData
4392 4393 4394 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4392 def agent_data @agent_data end |
#candidate ⇒ String
Required. The name of the candidate that produced the response.
Corresponds to the JSON property candidate
4397 4398 4399 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4397 def candidate @candidate end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4407 4408 4409 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4407 def error @error end |
#events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Optional. Intermediate events (such as tool calls and responses) that led to
the final response.
Corresponds to the JSON property events
4413 4414 4415 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4413 def events @events end |
#text ⇒ String
Text response.
Corresponds to the JSON property text
4418 4419 4420 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4418 def text @text end |
#value ⇒ Object
Fields and values that can be used to populate the response template.
Corresponds to the JSON property value
4423 4424 4425 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4423 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4430 4431 4432 4433 4434 4435 4436 4437 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4430 def update!(**args) @agent_data = args[:agent_data] if args.key?(:agent_data) @candidate = args[:candidate] if args.key?(:candidate) @error = args[:error] if args.key?(:error) @events = args[:events] if args.key?(:events) @text = args[:text] if args.key?(:text) @value = args[:value] if args.key?(:value) end |