Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Responses from model or agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CandidateResponse

Returns a new instance of GoogleCloudAiplatformV1beta1CandidateResponse.



4391
4392
4393
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData

Represents data specific to multi-turn agent evaluations. Corresponds to the JSON property agentData



4358
4359
4360
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4358

def agent_data
  @agent_data
end

#candidateString

Required. The name of the candidate that produced the response. Corresponds to the JSON property candidate

Returns:

  • (String)


4363
4364
4365
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4363

def candidate
  @candidate
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4373
4374
4375
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4373

def error
  @error
end

#eventsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>

Optional. Intermediate events (such as tool calls and responses) that led to the final response. Corresponds to the JSON property events



4379
4380
4381
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4379

def events
  @events
end

#textString

Text response. Corresponds to the JSON property text

Returns:

  • (String)


4384
4385
4386
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4384

def text
  @text
end

#valueObject

Fields and values that can be used to populate the response template. Corresponds to the JSON property value

Returns:

  • (Object)


4389
4390
4391
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4389

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4396
4397
4398
4399
4400
4401
4402
4403
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4396

def update!(**args)
  @agent_data = args[:agent_data] if args.key?(:agent_data)
  @candidate = args[:candidate] if args.key?(:candidate)
  @error = args[:error] if args.key?(:error)
  @events = args[:events] if args.key?(:events)
  @text = args[:text] if args.key?(:text)
  @value = args[:value] if args.key?(:value)
end