Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Result for a single candidate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CandidateResult

Returns a new instance of GoogleCloudAiplatformV1beta1CandidateResult.



11949
11950
11951
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11949

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_resultsObject

Optional. Additional results for the metric. Corresponds to the JSON property additionalResults

Returns:

  • (Object)


11911
11912
11913
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11911

def additional_results
  @additional_results
end

#candidateString

Required. The candidate that is being evaluated. The value is the same as the candidate name in the EvaluationRequest. Corresponds to the JSON property candidate

Returns:

  • (String)


11917
11918
11919
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11917

def candidate
  @candidate
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



11927
11928
11929
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11927

def error
  @error
end

#explanationString

Optional. The explanation for the metric. Corresponds to the JSON property explanation

Returns:

  • (String)


11932
11933
11934
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11932

def explanation
  @explanation
end

#metricString

Required. The metric that was evaluated. Corresponds to the JSON property metric

Returns:

  • (String)


11937
11938
11939
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11937

def metric
  @metric
end

#rubric_verdictsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricVerdict>

Optional. The rubric verdicts for the metric. Corresponds to the JSON property rubricVerdicts



11942
11943
11944
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11942

def rubric_verdicts
  @rubric_verdicts
end

#scoreFloat

Optional. The score for the metric. Corresponds to the JSON property score

Returns:

  • (Float)


11947
11948
11949
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11947

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11954
11955
11956
11957
11958
11959
11960
11961
11962
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11954

def update!(**args)
  @additional_results = args[:additional_results] if args.key?(:additional_results)
  @candidate = args[:candidate] if args.key?(:candidate)
  @error = args[:error] if args.key?(:error)
  @explanation = args[:explanation] if args.key?(:explanation)
  @metric = args[:metric] if args.key?(:metric)
  @rubric_verdicts = args[:rubric_verdicts] if args.key?(:rubric_verdicts)
  @score = args[:score] if args.key?(:score)
end