Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Result for a single candidate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CandidateResult

Returns a new instance of GoogleCloudAiplatformV1beta1CandidateResult.



11698
11699
11700
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_resultsObject

Optional. Additional results for the metric. Corresponds to the JSON property additionalResults

Returns:

  • (Object)


11660
11661
11662
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11660

def additional_results
  @additional_results
end

#candidateString

Required. The candidate that is being evaluated. The value is the same as the candidate name in the EvaluationRequest. Corresponds to the JSON property candidate

Returns:

  • (String)


11666
11667
11668
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11666

def candidate
  @candidate
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



11676
11677
11678
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11676

def error
  @error
end

#explanationString

Optional. The explanation for the metric. Corresponds to the JSON property explanation

Returns:

  • (String)


11681
11682
11683
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11681

def explanation
  @explanation
end

#metricString

Required. The metric that was evaluated. Corresponds to the JSON property metric

Returns:

  • (String)


11686
11687
11688
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11686

def metric
  @metric
end

#rubric_verdictsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricVerdict>

Optional. The rubric verdicts for the metric. Corresponds to the JSON property rubricVerdicts



11691
11692
11693
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11691

def rubric_verdicts
  @rubric_verdicts
end

#scoreFloat

Optional. The score for the metric. Corresponds to the JSON property score

Returns:

  • (Float)


11696
11697
11698
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11696

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11703
11704
11705
11706
11707
11708
11709
11710
11711
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11703

def update!(**args)
  @additional_results = args[:additional_results] if args.key?(:additional_results)
  @candidate = args[:candidate] if args.key?(:candidate)
  @error = args[:error] if args.key?(:error)
  @explanation = args[:explanation] if args.key?(:explanation)
  @metric = args[:metric] if args.key?(:metric)
  @rubric_verdicts = args[:rubric_verdicts] if args.key?(:rubric_verdicts)
  @score = args[:score] if args.key?(:score)
end