Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Result for a single candidate.
Instance Attribute Summary collapse
-
#additional_results ⇒ Object
Optional.
-
#candidate ⇒ String
Required.
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#explanation ⇒ String
Optional.
-
#metric ⇒ String
Required.
-
#rubric_verdicts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricVerdict>
Optional.
-
#score ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CandidateResult
constructor
A new instance of GoogleCloudAiplatformV1beta1CandidateResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CandidateResult
Returns a new instance of GoogleCloudAiplatformV1beta1CandidateResult.
10792 10793 10794 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10792 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_results ⇒ Object
Optional. Additional results for the metric.
Corresponds to the JSON property additionalResults
10754 10755 10756 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10754 def additional_results @additional_results end |
#candidate ⇒ String
Required. The candidate that is being evaluated. The value is the same as the
candidate name in the EvaluationRequest.
Corresponds to the JSON property candidate
10760 10761 10762 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10760 def candidate @candidate end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
10770 10771 10772 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10770 def error @error end |
#explanation ⇒ String
Optional. The explanation for the metric.
Corresponds to the JSON property explanation
10775 10776 10777 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10775 def explanation @explanation end |
#metric ⇒ String
Required. The metric that was evaluated.
Corresponds to the JSON property metric
10780 10781 10782 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10780 def metric @metric end |
#rubric_verdicts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricVerdict>
Optional. The rubric verdicts for the metric.
Corresponds to the JSON property rubricVerdicts
10785 10786 10787 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10785 def rubric_verdicts @rubric_verdicts end |
#score ⇒ Float
Optional. The score for the metric.
Corresponds to the JSON property score
10790 10791 10792 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10790 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10797 10798 10799 10800 10801 10802 10803 10804 10805 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10797 def update!(**args) @additional_results = args[:additional_results] if args.key?(:additional_results) @candidate = args[:candidate] if args.key?(:candidate) @error = args[:error] if args.key?(:error) @explanation = args[:explanation] if args.key?(:explanation) @metric = args[:metric] if args.key?(:metric) @rubric_verdicts = args[:rubric_verdicts] if args.key?(:rubric_verdicts) @score = args[:score] if args.key?(:score) end |