Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
This message will be placed in the metadata field of a google.longrunning. Operation associated with a CheckTrialEarlyStoppingState request.
Instance Attribute Summary collapse
-
#generic_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenericOperationMetadata
Generic Metadata shared by all operations.
-
#study ⇒ String
The name of the Study that the Trial belongs to.
-
#trial ⇒ String
The Trial name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata
constructor
A new instance of GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata
Returns a new instance of GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata.
9712 9713 9714 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generic_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenericOperationMetadata
Generic Metadata shared by all operations.
Corresponds to the JSON property genericMetadata
9700 9701 9702 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9700 def @generic_metadata end |
#study ⇒ String
The name of the Study that the Trial belongs to.
Corresponds to the JSON property study
9705 9706 9707 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9705 def study @study end |
#trial ⇒ String
The Trial name.
Corresponds to the JSON property trial
9710 9711 9712 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9710 def trial @trial end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9717 9718 9719 9720 9721 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9717 def update!(**args) @generic_metadata = args[:generic_metadata] if args.key?(:generic_metadata) @study = args[:study] if args.key?(:study) @trial = args[:trial] if args.key?(:trial) end |