Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

This message will be placed in the metadata field of a google.longrunning. Operation associated with a CheckTrialEarlyStoppingState request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata

Returns a new instance of GoogleCloudAiplatformV1beta1CheckTrialEarlyStoppingStateMetatdata.



9316
9317
9318
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generic_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenericOperationMetadata

Generic Metadata shared by all operations. Corresponds to the JSON property genericMetadata



9304
9305
9306
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9304

def 
  @generic_metadata
end

#studyString

The name of the Study that the Trial belongs to. Corresponds to the JSON property study

Returns:

  • (String)


9309
9310
9311
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9309

def study
  @study
end

#trialString

The Trial name. Corresponds to the JSON property trial

Returns:

  • (String)


9314
9315
9316
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9314

def trial
  @trial
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9321
9322
9323
9324
9325
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9321

def update!(**args)
  @generic_metadata = args[:generic_metadata] if args.key?(:generic_metadata)
  @study = args[:study] if args.key?(:study)
  @trial = args[:trial] if args.key?(:trial)
end