Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Citation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Citation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A citation for a piece of generatedcontent.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
Output only.
-
#license ⇒ String
Output only.
-
#publication_date ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#start_index ⇒ Fixnum
Output only.
-
#title ⇒ String
Output only.
-
#uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Citation
constructor
A new instance of GoogleCloudAiplatformV1beta1Citation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Citation
Returns a new instance of GoogleCloudAiplatformV1beta1Citation.
9467 9468 9469 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9467 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
Output only. The end index of the citation in the content.
Corresponds to the JSON property endIndex
9433 9434 9435 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9433 def end_index @end_index end |
#license ⇒ String
Output only. The license of the source of the citation.
Corresponds to the JSON property license
9438 9439 9440 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9438 def license @license end |
#publication_date ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property publicationDate
9450 9451 9452 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9450 def publication_date @publication_date end |
#start_index ⇒ Fixnum
Output only. The start index of the citation in the content.
Corresponds to the JSON property startIndex
9455 9456 9457 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9455 def start_index @start_index end |
#title ⇒ String
Output only. The title of the source of the citation.
Corresponds to the JSON property title
9460 9461 9462 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9460 def title @title end |
#uri ⇒ String
Output only. The URI of the source of the citation.
Corresponds to the JSON property uri
9465 9466 9467 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9465 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9472 9473 9474 9475 9476 9477 9478 9479 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9472 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @license = args[:license] if args.key?(:license) @publication_date = args[:publication_date] if args.key?(:publication_date) @start_index = args[:start_index] if args.key?(:start_index) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |