Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Citation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A citation for a piece of generatedcontent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Citation

Returns a new instance of GoogleCloudAiplatformV1beta1Citation.



4648
4649
4650
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4648

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Output only. The end index of the citation in the content. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


4614
4615
4616
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4614

def end_index
  @end_index
end

#licenseString

Output only. The license of the source of the citation. Corresponds to the JSON property license

Returns:

  • (String)


4619
4620
4621
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4619

def license
  @license
end

#publication_dateGoogle::Apis::AiplatformV1beta1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property publicationDate



4631
4632
4633
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4631

def publication_date
  @publication_date
end

#start_indexFixnum

Output only. The start index of the citation in the content. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


4636
4637
4638
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4636

def start_index
  @start_index
end

#titleString

Output only. The title of the source of the citation. Corresponds to the JSON property title

Returns:

  • (String)


4641
4642
4643
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4641

def title
  @title
end

#uriString

Output only. The URI of the source of the citation. Corresponds to the JSON property uri

Returns:

  • (String)


4646
4647
4648
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4646

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4653
4654
4655
4656
4657
4658
4659
4660
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4653

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @license = args[:license] if args.key?(:license)
  @publication_date = args[:publication_date] if args.key?(:publication_date)
  @start_index = args[:start_index] if args.key?(:start_index)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end