Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Claim

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Claim that is extracted from the input text and facts that support it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Claim

Returns a new instance of GoogleCloudAiplatformV1beta1Claim.



11077
11078
11079
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11077

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Index in the input text where the claim ends (exclusive). Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


11060
11061
11062
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11060

def end_index
  @end_index
end

#fact_indexesArray<Fixnum>

Indexes of the facts supporting this claim. Corresponds to the JSON property factIndexes

Returns:

  • (Array<Fixnum>)


11065
11066
11067
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11065

def fact_indexes
  @fact_indexes
end

#scoreFloat

Confidence score of this corroboration. Corresponds to the JSON property score

Returns:

  • (Float)


11070
11071
11072
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11070

def score
  @score
end

#start_indexFixnum

Index in the input text where the claim starts (inclusive). Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


11075
11076
11077
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11075

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11082
11083
11084
11085
11086
11087
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11082

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @fact_indexes = args[:fact_indexes] if args.key?(:fact_indexes)
  @score = args[:score] if args.key?(:score)
  @start_index = args[:start_index] if args.key?(:start_index)
end