Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Claim

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Claim that is extracted from the input text and facts that support it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Claim

Returns a new instance of GoogleCloudAiplatformV1beta1Claim.



9921
9922
9923
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Index in the input text where the claim ends (exclusive). Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


9904
9905
9906
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9904

def end_index
  @end_index
end

#fact_indexesArray<Fixnum>

Indexes of the facts supporting this claim. Corresponds to the JSON property factIndexes

Returns:

  • (Array<Fixnum>)


9909
9910
9911
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9909

def fact_indexes
  @fact_indexes
end

#scoreFloat

Confidence score of this corroboration. Corresponds to the JSON property score

Returns:

  • (Float)


9914
9915
9916
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9914

def score
  @score
end

#start_indexFixnum

Index in the input text where the claim starts (inclusive). Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


9919
9920
9921
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9919

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9926
9927
9928
9929
9930
9931
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9926

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @fact_indexes = args[:fact_indexes] if args.key?(:fact_indexes)
  @score = args[:score] if args.key?(:score)
  @start_index = args[:start_index] if args.key?(:start_index)
end