Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Claim

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Claim that is extracted from the input text and facts that support it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Claim

Returns a new instance of GoogleCloudAiplatformV1beta1Claim.



4706
4707
4708
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Index in the input text where the claim ends (exclusive). Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


4689
4690
4691
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4689

def end_index
  @end_index
end

#fact_indexesArray<Fixnum>

Indexes of the facts supporting this claim. Corresponds to the JSON property factIndexes

Returns:

  • (Array<Fixnum>)


4694
4695
4696
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4694

def fact_indexes
  @fact_indexes
end

#scoreFloat

Confidence score of this corroboration. Corresponds to the JSON property score

Returns:

  • (Float)


4699
4700
4701
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4699

def score
  @score
end

#start_indexFixnum

Index in the input text where the claim starts (inclusive). Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


4704
4705
4706
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4704

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4711
4712
4713
4714
4715
4716
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 4711

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @fact_indexes = args[:fact_indexes] if args.key?(:fact_indexes)
  @score = args[:score] if args.key?(:score)
  @start_index = args[:start_index] if args.key?(:start_index)
end