Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CompletionStats
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CompletionStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch.
Instance Attribute Summary collapse
-
#failed_count ⇒ Fixnum
Output only.
-
#incomplete_count ⇒ Fixnum
Output only.
-
#successful_count ⇒ Fixnum
Output only.
-
#successful_forecast_point_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CompletionStats
constructor
A new instance of GoogleCloudAiplatformV1beta1CompletionStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CompletionStats
Returns a new instance of GoogleCloudAiplatformV1beta1CompletionStats.
10278 10279 10280 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10278 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed_count ⇒ Fixnum
Output only. The number of entities for which any error was encountered.
Corresponds to the JSON property failedCount
10255 10256 10257 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10255 def failed_count @failed_count end |
#incomplete_count ⇒ Fixnum
Output only. In cases when enough errors are encountered a job, pipeline, or
operation may be failed as a whole. Below is the number of entities for which
the processing had not been finished (either in successful or failed state).
Set to -1 if the number is unknown (for example, the operation failed before
the total entity number could be collected).
Corresponds to the JSON property incompleteCount
10264 10265 10266 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10264 def incomplete_count @incomplete_count end |
#successful_count ⇒ Fixnum
Output only. The number of entities that had been processed successfully.
Corresponds to the JSON property successfulCount
10269 10270 10271 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10269 def successful_count @successful_count end |
#successful_forecast_point_count ⇒ Fixnum
Output only. The number of the successful forecast points that are generated
by the forecasting model. This is ONLY used by the forecasting batch
prediction.
Corresponds to the JSON property successfulForecastPointCount
10276 10277 10278 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10276 def successful_forecast_point_count @successful_forecast_point_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10283 10284 10285 10286 10287 10288 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10283 def update!(**args) @failed_count = args[:failed_count] if args.key?(:failed_count) @incomplete_count = args[:incomplete_count] if args.key?(:incomplete_count) @successful_count = args[:successful_count] if args.key?(:successful_count) @successful_forecast_point_count = args[:successful_forecast_point_count] if args.key?(:successful_forecast_point_count) end |