Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CompletionStats
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CompletionStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch.
Instance Attribute Summary collapse
-
#failed_count ⇒ Fixnum
Output only.
-
#incomplete_count ⇒ Fixnum
Output only.
-
#successful_count ⇒ Fixnum
Output only.
-
#successful_forecast_point_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CompletionStats
constructor
A new instance of GoogleCloudAiplatformV1beta1CompletionStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CompletionStats
Returns a new instance of GoogleCloudAiplatformV1beta1CompletionStats.
9882 9883 9884 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9882 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed_count ⇒ Fixnum
Output only. The number of entities for which any error was encountered.
Corresponds to the JSON property failedCount
9859 9860 9861 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9859 def failed_count @failed_count end |
#incomplete_count ⇒ Fixnum
Output only. In cases when enough errors are encountered a job, pipeline, or
operation may be failed as a whole. Below is the number of entities for which
the processing had not been finished (either in successful or failed state).
Set to -1 if the number is unknown (for example, the operation failed before
the total entity number could be collected).
Corresponds to the JSON property incompleteCount
9868 9869 9870 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9868 def incomplete_count @incomplete_count end |
#successful_count ⇒ Fixnum
Output only. The number of entities that had been processed successfully.
Corresponds to the JSON property successfulCount
9873 9874 9875 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9873 def successful_count @successful_count end |
#successful_forecast_point_count ⇒ Fixnum
Output only. The number of the successful forecast points that are generated
by the forecasting model. This is ONLY used by the forecasting batch
prediction.
Corresponds to the JSON property successfulForecastPointCount
9880 9881 9882 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9880 def successful_forecast_point_count @successful_forecast_point_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9887 9888 9889 9890 9891 9892 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9887 def update!(**args) @failed_count = args[:failed_count] if args.key?(:failed_count) @incomplete_count = args[:incomplete_count] if args.key?(:incomplete_count) @successful_count = args[:successful_count] if args.key?(:successful_count) @successful_forecast_point_count = args[:successful_forecast_point_count] if args.key?(:successful_forecast_point_count) end |