Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContainerSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The spec of a Container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ContainerSpec

Returns a new instance of GoogleCloudAiplatformV1beta1ContainerSpec.



10482
10483
10484
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

The arguments to be passed when starting the container. Corresponds to the JSON property args

Returns:

  • (Array<String>)


10463
10464
10465
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10463

def args
  @args
end

#commandArray<String>

The command to be invoked when the container is started. It overrides the entrypoint instruction in Dockerfile when provided. Corresponds to the JSON property command

Returns:

  • (Array<String>)


10469
10470
10471
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10469

def command
  @command
end

#envArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EnvVar>

Environment variables to be passed to the container. Maximum limit is 100. Corresponds to the JSON property env



10474
10475
10476
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10474

def env
  @env
end

#image_uriString

Required. The URI of a container image in the Container Registry that is to be run on each worker replica. Corresponds to the JSON property imageUri

Returns:

  • (String)


10480
10481
10482
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10480

def image_uri
  @image_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10487
10488
10489
10490
10491
10492
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10487

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @command = args[:command] if args.key?(:command)
  @env = args[:env] if args.key?(:env)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
end