Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Instance Attribute Summary collapse
-
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>
Required.
-
#role ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Content
constructor
A new instance of GoogleCloudAiplatformV1beta1Content.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Content
Returns a new instance of GoogleCloudAiplatformV1beta1Content.
10057 10058 10059 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10057 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>
Required. A list of Part objects that make up a single message. Parts of a
message can have different MIME types. A Content message must have at least
one Part.
Corresponds to the JSON property parts
10049 10050 10051 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10049 def parts @parts end |
#role ⇒ String
Optional. The producer of the content. Must be either 'user' or 'model'. If
not set, the service will default to 'user'.
Corresponds to the JSON property role
10055 10056 10057 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10055 def role @role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10062 10063 10064 10065 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10062 def update!(**args) @parts = args[:parts] if args.key?(:parts) @role = args[:role] if args.key?(:role) end |