Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Content

Returns a new instance of GoogleCloudAiplatformV1beta1Content.



5238
5239
5240
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>

Required. A list of Part objects that make up a single message. Parts of a message can have different MIME types. A Content message must have at least one Part. Corresponds to the JSON property parts



5230
5231
5232
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5230

def parts
  @parts
end

#roleString

Optional. The producer of the content. Must be either 'user' or 'model'. If not set, the service will default to 'user'. Corresponds to the JSON property role

Returns:

  • (String)


5236
5237
5238
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5236

def role
  @role
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5243
5244
5245
5246
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5243

def update!(**args)
  @parts = args[:parts] if args.key?(:parts)
  @role = args[:role] if args.key?(:role)
end