Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContentsExample
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContentsExample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A single example of a conversation with the model.
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Required.
-
#expected_contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContentsExampleExpectedContent>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ContentsExample
constructor
A new instance of GoogleCloudAiplatformV1beta1ContentsExample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ContentsExample
Returns a new instance of GoogleCloudAiplatformV1beta1ContentsExample.
5304 5305 5306 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5304 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Required. The content of the conversation with the model that resulted in the
expected output.
Corresponds to the JSON property contents
5295 5296 5297 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5295 def contents @contents end |
#expected_contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContentsExampleExpectedContent>
Required. The expected output for the given contents. To represent multi-
step reasoning, this is a repeated field that contains the iterative steps of
the expected output.
Corresponds to the JSON property expectedContents
5302 5303 5304 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5302 def expected_contents @expected_contents end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5309 5310 5311 5312 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5309 def update!(**args) @contents = args[:contents] if args.key?(:contents) @expected_contents = args[:expected_contents] if args.key?(:expected_contents) end |