Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Context
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Context
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Instance of a general context.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the Context Corresponds to the JSON property
description. -
#display_name ⇒ String
User provided display name of the Context.
-
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Contexts.
-
#metadata ⇒ Hash<String,Object>
Properties of the Context.
-
#name ⇒ String
Immutable.
-
#parent_contexts ⇒ Array<String>
Output only.
-
#schema_title ⇒ String
The title of the schema describing the metadata.
-
#schema_version ⇒ String
The version of the schema in schema_name to use.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Context
constructor
A new instance of GoogleCloudAiplatformV1beta1Context.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Context
Returns a new instance of GoogleCloudAiplatformV1beta1Context.
12820 12821 12822 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12820 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Context was created.
Corresponds to the JSON property createTime
12755 12756 12757 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12755 def create_time @create_time end |
#description ⇒ String
Description of the Context
Corresponds to the JSON property description
12760 12761 12762 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12760 def description @description end |
#display_name ⇒ String
User provided display name of the Context. May be up to 128 Unicode characters.
Corresponds to the JSON property displayName
12765 12766 12767 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12765 def display_name @display_name end |
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
12771 12772 12773 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12771 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Contexts. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Context (System labels are excluded).
Corresponds to the JSON property labels
12780 12781 12782 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12780 def labels @labels end |
#metadata ⇒ Hash<String,Object>
Properties of the Context. Top level metadata keys' heading and trailing
spaces will be trimmed. The size of this field should not exceed 200KB.
Corresponds to the JSON property metadata
12786 12787 12788 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12786 def @metadata end |
#name ⇒ String
Immutable. The resource name of the Context.
Corresponds to the JSON property name
12791 12792 12793 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12791 def name @name end |
#parent_contexts ⇒ Array<String>
Output only. A list of resource names of Contexts that are parents of this
Context. A Context may have at most 10 parent_contexts.
Corresponds to the JSON property parentContexts
12797 12798 12799 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12797 def parent_contexts @parent_contexts end |
#schema_title ⇒ String
The title of the schema describing the metadata. Schema title and version is
expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaTitle
12805 12806 12807 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12805 def schema_title @schema_title end |
#schema_version ⇒ String
The version of the schema in schema_name to use. Schema title and version is
expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaVersion
12813 12814 12815 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12813 def schema_version @schema_version end |
#update_time ⇒ String
Output only. Timestamp when this Context was last updated.
Corresponds to the JSON property updateTime
12818 12819 12820 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12818 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12825 12826 12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12825 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @parent_contexts = args[:parent_contexts] if args.key?(:parent_contexts) @schema_title = args[:schema_title] if args.key?(:schema_title) @schema_version = args[:schema_version] if args.key?(:schema_version) @update_time = args[:update_time] if args.key?(:update_time) end |