Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ConversationTurn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a single turn/invocation in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ConversationTurn

Returns a new instance of GoogleCloudAiplatformV1beta1ConversationTurn.



10724
10725
10726
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eventsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentEvent>

Optional. The list of events that occurred during this turn. Corresponds to the JSON property events



10711
10712
10713
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10711

def events
  @events
end

#turn_idString

Optional. A unique identifier for the turn. Useful for referencing specific turns across systems. Corresponds to the JSON property turnId

Returns:

  • (String)


10717
10718
10719
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10717

def turn_id
  @turn_id
end

#turn_indexFixnum

Required. The 0-based index of the turn in the conversation sequence. Corresponds to the JSON property turnIndex

Returns:

  • (Fixnum)


10722
10723
10724
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10722

def turn_index
  @turn_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10729
10730
10731
10732
10733
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10729

def update!(**args)
  @events = args[:events] if args.key?(:events)
  @turn_id = args[:turn_id] if args.key?(:turn_id)
  @turn_index = args[:turn_index] if args.key?(:turn_index)
end