Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ConversationTurn
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ConversationTurn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a single turn/invocation in the conversation.
Instance Attribute Summary collapse
-
#events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentEvent>
Optional.
-
#turn_id ⇒ String
Optional.
-
#turn_index ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ConversationTurn
constructor
A new instance of GoogleCloudAiplatformV1beta1ConversationTurn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ConversationTurn
Returns a new instance of GoogleCloudAiplatformV1beta1ConversationTurn.
5448 5449 5450 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5448 def initialize(**args) update!(**args) end |
Instance Attribute Details
#events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentEvent>
Optional. The list of events that occurred during this turn.
Corresponds to the JSON property events
5435 5436 5437 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5435 def events @events end |
#turn_id ⇒ String
Optional. A unique identifier for the turn. Useful for referencing specific
turns across systems.
Corresponds to the JSON property turnId
5441 5442 5443 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5441 def turn_id @turn_id end |
#turn_index ⇒ Fixnum
Required. The 0-based index of the turn in the conversation sequence.
Corresponds to the JSON property turnIndex
5446 5447 5448 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5446 def turn_index @turn_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5453 5454 5455 5456 5457 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5453 def update!(**args) @events = args[:events] if args.key?(:events) @turn_id = args[:turn_id] if args.key?(:turn_id) @turn_index = args[:turn_index] if args.key?(:turn_index) end |