Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CopyModelRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CopyModelRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ModelService.CopyModel.
Instance Attribute Summary collapse
-
#custom_service_account ⇒ String
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#model_id ⇒ String
Optional.
-
#parent_model ⇒ String
Optional.
-
#source_model ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CopyModelRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1CopyModelRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CopyModelRequest
Returns a new instance of GoogleCloudAiplatformV1beta1CopyModelRequest.
12020 12021 12022 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_service_account ⇒ String
Optional. The user-provided custom service account to use to do the copy model.
If empty, Vertex AI Service Agent will be used to access resources needed
to upload the model. This account must belong to the destination project where
the model is copied to, i.e., the project specified in the parent field of
this request and have the Vertex AI Service Agent role in the source project.
Requires the user copying the Model to have the iam.serviceAccounts.actAs
permission on this service account.
Corresponds to the JSON property customServiceAccount
11992 11993 11994 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11992 def custom_service_account @custom_service_account end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
11998 11999 12000 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11998 def encryption_spec @encryption_spec end |
#model_id ⇒ String
Optional. Copy source_model into a new Model with this ID. The ID will become
the final component of the model resource name. This value may be up to 63
characters, and valid characters are [a-z0-9_-]. The first character cannot
be a number or hyphen.
Corresponds to the JSON property modelId
12006 12007 12008 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12006 def model_id @model_id end |
#parent_model ⇒ String
Optional. Specify this field to copy source_model into this existing Model as
a new version. Format: projects/project/locations/location/models/model`
Corresponds to the JSON propertyparentModel`
12012 12013 12014 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12012 def parent_model @parent_model end |
#source_model ⇒ String
Required. The resource name of the Model to copy. That Model must be in the
same Project. Format: projects/project/locations/location/models/model`
Corresponds to the JSON propertysourceModel`
12018 12019 12020 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12018 def source_model @source_model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12025 12026 12027 12028 12029 12030 12031 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12025 def update!(**args) @custom_service_account = args[:custom_service_account] if args.key?(:custom_service_account) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @model_id = args[:model_id] if args.key?(:model_id) @parent_model = args[:parent_model] if args.key?(:parent_model) @source_model = args[:source_model] if args.key?(:source_model) end |