Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CountTokensResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CountTokensResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for PredictionService.CountTokens.
Instance Attribute Summary collapse
-
#prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModalityTokenCount>
Output only.
-
#total_billable_characters ⇒ Fixnum
The total number of billable characters counted across all instances from the request.
-
#total_tokens ⇒ Fixnum
The total number of tokens counted across all instances from the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CountTokensResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1CountTokensResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CountTokensResponse
Returns a new instance of GoogleCloudAiplatformV1beta1CountTokensResponse.
5731 5732 5733 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5731 def initialize(**args) update!(**args) end |
Instance Attribute Details
#prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModalityTokenCount>
Output only. List of modalities that were processed in the request input.
Corresponds to the JSON property promptTokensDetails
5718 5719 5720 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5718 def prompt_tokens_details @prompt_tokens_details end |
#total_billable_characters ⇒ Fixnum
The total number of billable characters counted across all instances from the
request.
Corresponds to the JSON property totalBillableCharacters
5724 5725 5726 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5724 def total_billable_characters @total_billable_characters end |
#total_tokens ⇒ Fixnum
The total number of tokens counted across all instances from the request.
Corresponds to the JSON property totalTokens
5729 5730 5731 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5729 def total_tokens @total_tokens end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5736 5737 5738 5739 5740 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 5736 def update!(**args) @prompt_tokens_details = args[:prompt_tokens_details] if args.key?(:prompt_tokens_details) @total_billable_characters = args[:total_billable_characters] if args.key?(:total_billable_characters) @total_tokens = args[:total_tokens] if args.key?(:total_tokens) end |