Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ModelMonitoringService.CreateModelMonitoringJob.
Instance Attribute Summary collapse
-
#model_monitoring_job ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJob
Represents a model monitoring job that analyze dataset using different monitoring algorithm.
-
#model_monitoring_job_id ⇒ String
Optional.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest
Returns a new instance of GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest.
13912 13913 13914 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#model_monitoring_job ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJob
Represents a model monitoring job that analyze dataset using different
monitoring algorithm.
Corresponds to the JSON property modelMonitoringJob
13896 13897 13898 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13896 def model_monitoring_job @model_monitoring_job end |
#model_monitoring_job_id ⇒ String
Optional. The ID to use for the Model Monitoring Job, which will become the
final component of the model monitoring job resource name. The maximum length
is 63 characters, and valid characters are /^[a-z]([a-z0-9-]0,61[a-z0-9])?$/
.
Corresponds to the JSON property modelMonitoringJobId
13904 13905 13906 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13904 def model_monitoring_job_id @model_monitoring_job_id end |
#parent ⇒ String
Required. The parent of the ModelMonitoringJob. Format: projects/project/
locations/location/modelMoniitors/model_monitor`
Corresponds to the JSON propertyparent`
13910 13911 13912 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13910 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13917 13918 13919 13920 13921 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13917 def update!(**args) @model_monitoring_job = args[:model_monitoring_job] if args.key?(:model_monitoring_job) @model_monitoring_job_id = args[:model_monitoring_job_id] if args.key?(:model_monitoring_job_id) @parent = args[:parent] if args.key?(:parent) end |