Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ModelMonitoringService.CreateModelMonitoringJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest

Returns a new instance of GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest.



13559
13560
13561
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13559

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#model_monitoring_jobGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJob

Represents a model monitoring job that analyze dataset using different monitoring algorithm. Corresponds to the JSON property modelMonitoringJob



13543
13544
13545
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13543

def model_monitoring_job
  @model_monitoring_job
end

#model_monitoring_job_idString

Optional. The ID to use for the Model Monitoring Job, which will become the final component of the model monitoring job resource name. The maximum length is 63 characters, and valid characters are /^[a-z]([a-z0-9-]0,61[a-z0-9])?$/ . Corresponds to the JSON property modelMonitoringJobId

Returns:

  • (String)


13551
13552
13553
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13551

def model_monitoring_job_id
  @model_monitoring_job_id
end

#parentString

Required. The parent of the ModelMonitoringJob. Format: projects/project/ locations/location/modelMoniitors/model_monitor` Corresponds to the JSON propertyparent`

Returns:

  • (String)


13557
13558
13559
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13557

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13564
13565
13566
13567
13568
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13564

def update!(**args)
  @model_monitoring_job = args[:model_monitoring_job] if args.key?(:model_monitoring_job)
  @model_monitoring_job_id = args[:model_monitoring_job_id] if args.key?(:model_monitoring_job_id)
  @parent = args[:parent] if args.key?(:parent)
end