Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ModelMonitoringService.CreateModelMonitoringJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest

Returns a new instance of GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest.



12646
12647
12648
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#model_monitoring_jobGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJob

Represents a model monitoring job that analyze dataset using different monitoring algorithm. Corresponds to the JSON property modelMonitoringJob



12630
12631
12632
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12630

def model_monitoring_job
  @model_monitoring_job
end

#model_monitoring_job_idString

Optional. The ID to use for the Model Monitoring Job, which will become the final component of the model monitoring job resource name. The maximum length is 63 characters, and valid characters are /^[a-z]([a-z0-9-]0,61[a-z0-9])?$/ . Corresponds to the JSON property modelMonitoringJobId

Returns:

  • (String)


12638
12639
12640
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12638

def model_monitoring_job_id
  @model_monitoring_job_id
end

#parentString

Required. The parent of the ModelMonitoringJob. Format: projects/project/ locations/location/modelMoniitors/model_monitor` Corresponds to the JSON propertyparent`

Returns:

  • (String)


12644
12645
12646
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12644

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12651
12652
12653
12654
12655
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12651

def update!(**args)
  @model_monitoring_job = args[:model_monitoring_job] if args.key?(:model_monitoring_job)
  @model_monitoring_job_id = args[:model_monitoring_job_id] if args.key?(:model_monitoring_job_id)
  @parent = args[:parent] if args.key?(:parent)
end