Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ModelMonitoringService.CreateModelMonitoringJob.
Instance Attribute Summary collapse
-
#model_monitoring_job ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJob
Represents a model monitoring job that analyze dataset using different monitoring algorithm.
-
#model_monitoring_job_id ⇒ String
Optional.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest
Returns a new instance of GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest.
12185 12186 12187 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#model_monitoring_job ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJob
Represents a model monitoring job that analyze dataset using different
monitoring algorithm.
Corresponds to the JSON property modelMonitoringJob
12169 12170 12171 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12169 def model_monitoring_job @model_monitoring_job end |
#model_monitoring_job_id ⇒ String
Optional. The ID to use for the Model Monitoring Job, which will become the
final component of the model monitoring job resource name. The maximum length
is 63 characters, and valid characters are /^[a-z]([a-z0-9-]0,61[a-z0-9])?$/
.
Corresponds to the JSON property modelMonitoringJobId
12177 12178 12179 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12177 def model_monitoring_job_id @model_monitoring_job_id end |
#parent ⇒ String
Required. The parent of the ModelMonitoringJob. Format: projects/project/
locations/location/modelMoniitors/model_monitor`
Corresponds to the JSON propertyparent`
12183 12184 12185 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12183 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12190 12191 12192 12193 12194 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12190 def update!(**args) @model_monitoring_job = args[:model_monitoring_job] if args.key?(:model_monitoring_job) @model_monitoring_job_id = args[:model_monitoring_job_id] if args.key?(:model_monitoring_job_id) @parent = args[:parent] if args.key?(:parent) end |