Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreatePipelineJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for PipelineService.CreatePipelineJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreatePipelineJobRequest

Returns a new instance of GoogleCloudAiplatformV1beta1CreatePipelineJobRequest.



12802
12803
12804
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12802

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The resource name of the Location to create the PipelineJob in. Format: projects/project/locations/location` Corresponds to the JSON propertyparent`

Returns:

  • (String)


12787
12788
12789
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12787

def parent
  @parent
end

#pipeline_jobGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJob

An instance of a machine learning PipelineJob. Corresponds to the JSON property pipelineJob



12792
12793
12794
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12792

def pipeline_job
  @pipeline_job
end

#pipeline_job_idString

The ID to use for the PipelineJob, which will become the final component of the PipelineJob name. If not provided, an ID will be automatically generated. This value should be less than 128 characters, and valid characters are /a-z-/ . Corresponds to the JSON property pipelineJobId

Returns:

  • (String)


12800
12801
12802
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12800

def pipeline_job_id
  @pipeline_job_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12807
12808
12809
12810
12811
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12807

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job)
  @pipeline_job_id = args[:pipeline_job_id] if args.key?(:pipeline_job_id)
end