Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateRagDataSchemaRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateRagDataSchemaRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for VertexRagDataService.CreateRagDataSchema.
Instance Attribute Summary collapse
-
#parent ⇒ String
Required.
-
#rag_data_schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagDataSchema
The schema of the user specified metadata.
-
#rag_data_schema_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateRagDataSchemaRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1CreateRagDataSchemaRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateRagDataSchemaRequest
Returns a new instance of GoogleCloudAiplatformV1beta1CreateRagDataSchemaRequest.
14104 14105 14106 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parent ⇒ String
Required. The resource name of the RagCorpus to create the RagDataSchema in.
Format: projects/project/locations/location/ragCorpora/rag_corpus`
Corresponds to the JSON propertyparent`
14088 14089 14090 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14088 def parent @parent end |
#rag_data_schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagDataSchema
The schema of the user specified metadata.
Corresponds to the JSON property ragDataSchema
14093 14094 14095 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14093 def rag_data_schema @rag_data_schema end |
#rag_data_schema_id ⇒ String
Optional. The ID to use for the RagDataSchema, which will become the final
component of the RagDataSchema's resource name if the user chooses to specify.
Otherwise, RagDataSchema id will be generated by system. This value should be
up to 63 characters, and valid characters are /a-z-/. The first character must
be a letter, the last could be a letter or a number.
Corresponds to the JSON property ragDataSchemaId
14102 14103 14104 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14102 def rag_data_schema_id @rag_data_schema_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14109 14110 14111 14112 14113 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14109 def update!(**args) @parent = args[:parent] if args.key?(:parent) @rag_data_schema = args[:rag_data_schema] if args.key?(:rag_data_schema) @rag_data_schema_id = args[:rag_data_schema_id] if args.key?(:rag_data_schema_id) end |