Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateRagDataSchemaRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for VertexRagDataService.CreateRagDataSchema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateRagDataSchemaRequest

Returns a new instance of GoogleCloudAiplatformV1beta1CreateRagDataSchemaRequest.



6326
6327
6328
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The resource name of the RagCorpus to create the RagDataSchema in. Format: projects/project/locations/location/ragCorpora/rag_corpus` Corresponds to the JSON propertyparent`

Returns:

  • (String)


6310
6311
6312
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6310

def parent
  @parent
end

#rag_data_schemaGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagDataSchema

The schema of the user specified metadata. Corresponds to the JSON property ragDataSchema



6315
6316
6317
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6315

def rag_data_schema
  @rag_data_schema
end

#rag_data_schema_idString

Optional. The ID to use for the RagDataSchema, which will become the final component of the RagDataSchema's resource name if the user chooses to specify. Otherwise, RagDataSchema id will be generated by system. This value should be up to 63 characters, and valid characters are /a-z-/. The first character must be a letter, the last could be a letter or a number. Corresponds to the JSON property ragDataSchemaId

Returns:

  • (String)


6324
6325
6326
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6324

def rag_data_schema_id
  @rag_data_schema_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6331
6332
6333
6334
6335
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 6331

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @rag_data_schema = args[:rag_data_schema] if args.key?(:rag_data_schema)
  @rag_data_schema_id = args[:rag_data_schema_id] if args.key?(:rag_data_schema_id)
end