Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateRagMetadataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for CreateRagMetadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateRagMetadataRequest

Returns a new instance of GoogleCloudAiplatformV1beta1CreateRagMetadataRequest.



14141
14142
14143
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The parent resource where this metadata will be created. Format: projects/project_number/locations/location_id/ragCorpora/rag_corpus/ ragFiles/rag_file` Corresponds to the JSON propertyparent`

Returns:

  • (String)


14125
14126
14127
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14125

def parent
  @parent
end

#rag_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadata

Metadata for RagFile provided by users. Corresponds to the JSON property ragMetadata



14130
14131
14132
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14130

def 
  @rag_metadata
end

#rag_metadata_idString

Optional. The ID to use for the metadata, which will become the final component of the metadata's resource name if the user chooses to specify. Otherwise, metadata id will be generated by system. This value should be up to 63 characters, and valid characters are /a-z-/. The first character must be a letter, the last could be a letter or a number. Corresponds to the JSON property ragMetadataId

Returns:

  • (String)


14139
14140
14141
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14139

def 
  @rag_metadata_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14146
14147
14148
14149
14150
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14146

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @rag_metadata = args[:rag_metadata] if args.key?(:rag_metadata)
  @rag_metadata_id = args[:rag_metadata_id] if args.key?(:rag_metadata_id)
end