Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateRagMetadataRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateRagMetadataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for CreateRagMetadata.
Instance Attribute Summary collapse
-
#parent ⇒ String
Required.
-
#rag_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadata
Metadata for RagFile provided by users.
-
#rag_metadata_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateRagMetadataRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1CreateRagMetadataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateRagMetadataRequest
Returns a new instance of GoogleCloudAiplatformV1beta1CreateRagMetadataRequest.
12875 12876 12877 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12875 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parent ⇒ String
Required. The parent resource where this metadata will be created. Format:
projects/project_number/locations/location_id/ragCorpora/rag_corpus/
ragFiles/rag_file`
Corresponds to the JSON propertyparent`
12859 12860 12861 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12859 def parent @parent end |
#rag_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadata
Metadata for RagFile provided by users.
Corresponds to the JSON property ragMetadata
12864 12865 12866 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12864 def @rag_metadata end |
#rag_metadata_id ⇒ String
Optional. The ID to use for the metadata, which will become the final
component of the metadata's resource name if the user chooses to specify.
Otherwise, metadata id will be generated by system. This value should be up to
63 characters, and valid characters are /a-z-/. The first character must be a
letter, the last could be a letter or a number.
Corresponds to the JSON property ragMetadataId
12873 12874 12875 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12873 def @rag_metadata_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12880 12881 12882 12883 12884 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12880 def update!(**args) @parent = args[:parent] if args.key?(:parent) @rag_metadata = args[:rag_metadata] if args.key?(:rag_metadata) @rag_metadata_id = args[:rag_metadata_id] if args.key?(:rag_metadata_id) end |