Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateRagMetadataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for CreateRagMetadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateRagMetadataRequest

Returns a new instance of GoogleCloudAiplatformV1beta1CreateRagMetadataRequest.



12592
12593
12594
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12592

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The parent resource where this metadata will be created. Format: projects/project_number/locations/location_id/ragCorpora/rag_corpus/ ragFiles/rag_file` Corresponds to the JSON propertyparent`

Returns:

  • (String)


12576
12577
12578
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12576

def parent
  @parent
end

#rag_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadata

Metadata for RagFile provided by users. Corresponds to the JSON property ragMetadata



12581
12582
12583
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12581

def 
  @rag_metadata
end

#rag_metadata_idString

Optional. The ID to use for the metadata, which will become the final component of the metadata's resource name if the user chooses to specify. Otherwise, metadata id will be generated by system. This value should be up to 63 characters, and valid characters are /a-z-/. The first character must be a letter, the last could be a letter or a number. Corresponds to the JSON property ragMetadataId

Returns:

  • (String)


12590
12591
12592
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12590

def 
  @rag_metadata_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12597
12598
12599
12600
12601
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12597

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @rag_metadata = args[:rag_metadata] if args.key?(:rag_metadata)
  @rag_metadata_id = args[:rag_metadata_id] if args.key?(:rag_metadata_id)
end