Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateRagMetadataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for CreateRagMetadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CreateRagMetadataRequest

Returns a new instance of GoogleCloudAiplatformV1beta1CreateRagMetadataRequest.



11195
11196
11197
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11195

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The parent resource where this metadata will be created. Format: projects/project_number/locations/location_id/ragCorpora/rag_corpus/ ragFiles/rag_file` Corresponds to the JSON propertyparent`

Returns:

  • (String)


11179
11180
11181
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11179

def parent
  @parent
end

#rag_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadata

Metadata for RagFile provided by users. Corresponds to the JSON property ragMetadata



11184
11185
11186
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11184

def 
  @rag_metadata
end

#rag_metadata_idString

Optional. The ID to use for the metadata, which will become the final component of the metadata's resource name if the user chooses to specify. Otherwise, metadata id will be generated by system. This value should be up to 63 characters, and valid characters are /a-z-/. The first character must be a letter, the last could be a letter or a number. Corresponds to the JSON property ragMetadataId

Returns:

  • (String)


11193
11194
11195
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11193

def 
  @rag_metadata_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11200
11201
11202
11203
11204
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11200

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @rag_metadata = args[:rag_metadata] if args.key?(:rag_metadata)
  @rag_metadata_id = args[:rag_metadata_id] if args.key?(:rag_metadata_id)
end