Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a job that runs custom workloads such as a Docker container or a Python package. A CustomJob can have multiple worker pools and each worker pool can have its own machine and input spec. A CustomJob will be cleaned up once the job enters terminal state (failed or succeeded).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CustomJob

Returns a new instance of GoogleCloudAiplatformV1beta1CustomJob.



12778
12779
12780
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12778

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the CustomJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


12690
12691
12692
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12690

def create_time
  @create_time
end

#display_nameString

Required. The display name of the CustomJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


12696
12697
12698
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12696

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



12702
12703
12704
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12702

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the CustomJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


12708
12709
12710
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12708

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



12718
12719
12720
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12718

def error
  @error
end

#job_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property jobSpec



12723
12724
12725
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12723

def job_spec
  @job_spec
end

#labelsHash<String,String>

The labels with user-defined metadata to organize CustomJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


12732
12733
12734
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12732

def labels
  @labels
end

#nameString

Output only. Resource name of a CustomJob. Corresponds to the JSON property name

Returns:

  • (String)


12737
12738
12739
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12737

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


12742
12743
12744
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12742

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


12748
12749
12750
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12748

def satisfies_pzs
  @satisfies_pzs
end

#start_timeString

Output only. Time when the CustomJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


12755
12756
12757
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12755

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


12760
12761
12762
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12760

def state
  @state
end

#update_timeString

Output only. Time when the CustomJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


12765
12766
12767
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12765

def update_time
  @update_time
end

#web_access_urisHash<String,String>

Output only. URIs for accessing interactive shells (one URI for each training node). Only available if job_spec.enable_web_access is true. The keys are names of each node in the training job; for example, workerpool0-0 for the primary node, workerpool1-0 for the first node in the second worker pool, and workerpool1-1 for the second node in the second worker pool. The values are the URIs for each node's interactive shell. Corresponds to the JSON property webAccessUris

Returns:

  • (Hash<String,String>)


12776
12777
12778
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12776

def web_access_uris
  @web_access_uris
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12783
12784
12785
12786
12787
12788
12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12783

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @job_spec = args[:job_spec] if args.key?(:job_spec)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
  @web_access_uris = args[:web_access_uris] if args.key?(:web_access_uris)
end