Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a job that runs custom workloads such as a Docker container or a Python package. A CustomJob can have multiple worker pools and each worker pool can have its own machine and input spec. A CustomJob will be cleaned up once the job enters terminal state (failed or succeeded).
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#job_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomJobSpec
Represents the spec of a CustomJob.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize CustomJobs.
-
#name ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#web_access_uris ⇒ Hash<String,String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CustomJob
constructor
A new instance of GoogleCloudAiplatformV1beta1CustomJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CustomJob
Returns a new instance of GoogleCloudAiplatformV1beta1CustomJob.
12956 12957 12958 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12956 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the CustomJob was created.
Corresponds to the JSON property createTime
12868 12869 12870 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12868 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the CustomJob. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
12874 12875 12876 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12874 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
12880 12881 12882 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12880 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the CustomJob entered any of the following states:
JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED.
Corresponds to the JSON property endTime
12886 12887 12888 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12886 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
12896 12897 12898 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12896 def error @error end |
#job_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomJobSpec
Represents the spec of a CustomJob.
Corresponds to the JSON property jobSpec
12901 12902 12903 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12901 def job_spec @job_spec end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize CustomJobs. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
12910 12911 12912 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12910 def labels @labels end |
#name ⇒ String
Output only. Resource name of a CustomJob.
Corresponds to the JSON property name
12915 12916 12917 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12915 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
12920 12921 12922 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12920 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
12926 12927 12928 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12926 def satisfies_pzs @satisfies_pzs end |
#start_time ⇒ String
Output only. Time when the CustomJob for the first time entered the
JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
12933 12934 12935 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12933 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
12938 12939 12940 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12938 def state @state end |
#update_time ⇒ String
Output only. Time when the CustomJob was most recently updated.
Corresponds to the JSON property updateTime
12943 12944 12945 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12943 def update_time @update_time end |
#web_access_uris ⇒ Hash<String,String>
Output only. URIs for accessing interactive shells (one URI for each
training node). Only available if job_spec.enable_web_access is true. The
keys are names of each node in the training job; for example, workerpool0-0
for the primary node, workerpool1-0 for the first node in the second worker
pool, and workerpool1-1 for the second node in the second worker pool. The
values are the URIs for each node's interactive shell.
Corresponds to the JSON property webAccessUris
12954 12955 12956 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12954 def web_access_uris @web_access_uris end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12961 12962 12963 12964 12965 12966 12967 12968 12969 12970 12971 12972 12973 12974 12975 12976 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12961 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @job_spec = args[:job_spec] if args.key?(:job_spec) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) @web_access_uris = args[:web_access_uris] if args.key?(:web_access_uris) end |