Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DataItem
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DataItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A piece of data in a Dataset. Could be an image, a video, a document or plain text.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#payload ⇒ Object
Required.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DataItem
constructor
A new instance of GoogleCloudAiplatformV1beta1DataItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DataItem
Returns a new instance of GoogleCloudAiplatformV1beta1DataItem.
13044 13045 13046 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13044 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this DataItem was created.
Corresponds to the JSON property createTime
12996 12997 12998 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12996 def create_time @create_time end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
13002 13003 13004 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13002 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your DataItems.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. No more than 64 user labels can
be associated with one DataItem(System labels are excluded). See https://goo.
gl/xmQnxf for more information and examples of labels. System reserved label
keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
13013 13014 13015 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13013 def labels @labels end |
#name ⇒ String
Output only. The resource name of the DataItem.
Corresponds to the JSON property name
13018 13019 13020 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13018 def name @name end |
#payload ⇒ Object
Required. The data that the DataItem represents (for example, an image or a
text snippet). The schema of the payload is stored in the parent Dataset's
metadata schema's dataItemSchemaUri field.
Corresponds to the JSON property payload
13025 13026 13027 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13025 def payload @payload end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
13030 13031 13032 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13030 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
13036 13037 13038 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13036 def satisfies_pzs @satisfies_pzs end |
#update_time ⇒ String
Output only. Timestamp when this DataItem was last updated.
Corresponds to the JSON property updateTime
13042 13043 13044 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13042 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13049 13050 13051 13052 13053 13054 13055 13056 13057 13058 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13049 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @payload = args[:payload] if args.key?(:payload) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @update_time = args[:update_time] if args.key?(:update_time) end |