Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DataItemView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A container for a single DataItem and Annotations on it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DataItemView

Returns a new instance of GoogleCloudAiplatformV1beta1DataItemView.



13549
13550
13551
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13549

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Annotation>

The Annotations on the DataItem. If too many Annotations should be returned for the DataItem, this field will be truncated per annotations_limit in request. If it was, then the has_truncated_annotations will be set to true. Corresponds to the JSON property annotations



13531
13532
13533
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13531

def annotations
  @annotations
end

#data_itemGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DataItem

A piece of data in a Dataset. Could be an image, a video, a document or plain text. Corresponds to the JSON property dataItem



13537
13538
13539
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13537

def data_item
  @data_item
end

#has_truncated_annotationsBoolean Also known as: has_truncated_annotations?

True if and only if the Annotations field has been truncated. It happens if more Annotations for this DataItem met the request's annotation_filter than are allowed to be returned by annotations_limit. Note that if Annotations field is not being returned due to field mask, then this field will not be set to true no matter how many Annotations are there. Corresponds to the JSON property hasTruncatedAnnotations

Returns:

  • (Boolean)


13546
13547
13548
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13546

def has_truncated_annotations
  @has_truncated_annotations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13554
13555
13556
13557
13558
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13554

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @data_item = args[:data_item] if args.key?(:data_item)
  @has_truncated_annotations = args[:has_truncated_annotations] if args.key?(:has_truncated_annotations)
end