Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DataLabelingJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DataLabelingJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
DataLabelingJob is used to trigger a human labeling job on unlabeled data from the following Dataset:
Instance Attribute Summary collapse
-
#active_learning_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ActiveLearningConfig
Parameters that configure the active learning pipeline.
-
#annotation_labels ⇒ Hash<String,String>
Labels to assign to annotations generated by this DataLabelingJob.
-
#create_time ⇒ String
Output only.
-
#current_spend ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeMoney
Represents an amount of money with its currency type.
-
#datasets ⇒ Array<String>
Required.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#inputs ⇒ Object
Required.
-
#inputs_schema_uri ⇒ String
Required.
-
#instruction_uri ⇒ String
Required.
-
#labeler_count ⇒ Fixnum
Required.
-
#labeling_progress ⇒ Fixnum
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your DataLabelingJobs.
-
#name ⇒ String
Output only.
-
#specialist_pools ⇒ Array<String>
The SpecialistPools' resource names associated with this job.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DataLabelingJob
constructor
A new instance of GoogleCloudAiplatformV1beta1DataLabelingJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DataLabelingJob
Returns a new instance of GoogleCloudAiplatformV1beta1DataLabelingJob.
14599 14600 14601 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14599 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_learning_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ActiveLearningConfig
Parameters that configure the active learning pipeline. Active learning will
label the data incrementally by several iterations. For every iteration, it
will select a batch of data based on the sampling strategy.
Corresponds to the JSON property activeLearningConfig
14484 14485 14486 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14484 def active_learning_config @active_learning_config end |
#annotation_labels ⇒ Hash<String,String>
Labels to assign to annotations generated by this DataLabelingJob. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels. System reserved label keys are prefixed
with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property annotationLabels
14494 14495 14496 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14494 def annotation_labels @annotation_labels end |
#create_time ⇒ String
Output only. Timestamp when this DataLabelingJob was created.
Corresponds to the JSON property createTime
14499 14500 14501 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14499 def create_time @create_time end |
#current_spend ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeMoney
Represents an amount of money with its currency type.
Corresponds to the JSON property currentSpend
14504 14505 14506 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14504 def current_spend @current_spend end |
#datasets ⇒ Array<String>
Required. Dataset resource names. Right now we only support labeling from a
single Dataset. Format: projects/project/locations/location/datasets/
dataset`
Corresponds to the JSON propertydatasets`
14511 14512 14513 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14511 def datasets @datasets end |
#display_name ⇒ String
Required. The user-defined name of the DataLabelingJob. The name can be up to
128 characters long and can consist of any UTF-8 characters. Display name of a
DataLabelingJob.
Corresponds to the JSON property displayName
14518 14519 14520 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14518 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
14524 14525 14526 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14524 def encryption_spec @encryption_spec end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
14534 14535 14536 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14534 def error @error end |
#inputs ⇒ Object
Required. Input config parameters for the DataLabelingJob.
Corresponds to the JSON property inputs
14539 14540 14541 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14539 def inputs @inputs end |
#inputs_schema_uri ⇒ String
Required. Points to a YAML file stored on Google Cloud Storage describing the
config for a specific type of DataLabelingJob. The schema files that can be
used here are found in the https://storage.googleapis.com/google-cloud-
aiplatform bucket in the /schema/datalabelingjob/inputs/ folder.
Corresponds to the JSON property inputsSchemaUri
14547 14548 14549 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14547 def inputs_schema_uri @inputs_schema_uri end |
#instruction_uri ⇒ String
Required. The Google Cloud Storage location of the instruction pdf. This pdf
is shared with labelers, and provides detailed description on how to label
DataItems in Datasets.
Corresponds to the JSON property instructionUri
14554 14555 14556 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14554 def instruction_uri @instruction_uri end |
#labeler_count ⇒ Fixnum
Required. Number of labelers to work on each DataItem.
Corresponds to the JSON property labelerCount
14559 14560 14561 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14559 def labeler_count @labeler_count end |
#labeling_progress ⇒ Fixnum
Output only. Current labeling job progress percentage scaled in interval [0,
100], indicating the percentage of DataItems that has been finished.
Corresponds to the JSON property labelingProgress
14565 14566 14567 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14565 def labeling_progress @labeling_progress end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your DataLabelingJobs. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels. System reserved label keys are prefixed
with "aiplatform.googleapis.com/" and are immutable. Following system labels
exist for each DataLabelingJob: * "aiplatform.googleapis.com/schema": output
only, its value is the inputs_schema's title.
Corresponds to the JSON property labels
14577 14578 14579 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14577 def labels @labels end |
#name ⇒ String
Output only. Resource name of the DataLabelingJob.
Corresponds to the JSON property name
14582 14583 14584 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14582 def name @name end |
#specialist_pools ⇒ Array<String>
The SpecialistPools' resource names associated with this job.
Corresponds to the JSON property specialistPools
14587 14588 14589 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14587 def specialist_pools @specialist_pools end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
14592 14593 14594 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14592 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this DataLabelingJob was updated most recently.
Corresponds to the JSON property updateTime
14597 14598 14599 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14597 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14604 14605 14606 14607 14608 14609 14610 14611 14612 14613 14614 14615 14616 14617 14618 14619 14620 14621 14622 14623 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14604 def update!(**args) @active_learning_config = args[:active_learning_config] if args.key?(:active_learning_config) @annotation_labels = args[:annotation_labels] if args.key?(:annotation_labels) @create_time = args[:create_time] if args.key?(:create_time) @current_spend = args[:current_spend] if args.key?(:current_spend) @datasets = args[:datasets] if args.key?(:datasets) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @error = args[:error] if args.key?(:error) @inputs = args[:inputs] if args.key?(:inputs) @inputs_schema_uri = args[:inputs_schema_uri] if args.key?(:inputs_schema_uri) @instruction_uri = args[:instruction_uri] if args.key?(:instruction_uri) @labeler_count = args[:labeler_count] if args.key?(:labeler_count) @labeling_progress = args[:labeling_progress] if args.key?(:labeling_progress) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @specialist_pools = args[:specialist_pools] if args.key?(:specialist_pools) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |