Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DataLabelingJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

DataLabelingJob is used to trigger a human labeling job on unlabeled data from the following Dataset:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DataLabelingJob

Returns a new instance of GoogleCloudAiplatformV1beta1DataLabelingJob.



13686
13687
13688
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_learning_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ActiveLearningConfig

Parameters that configure the active learning pipeline. Active learning will label the data incrementally by several iterations. For every iteration, it will select a batch of data based on the sampling strategy. Corresponds to the JSON property activeLearningConfig



13571
13572
13573
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13571

def active_learning_config
  @active_learning_config
end

#annotation_labelsHash<String,String>

Labels to assign to annotations generated by this DataLabelingJob. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property annotationLabels

Returns:

  • (Hash<String,String>)


13581
13582
13583
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13581

def annotation_labels
  @annotation_labels
end

#create_timeString

Output only. Timestamp when this DataLabelingJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


13586
13587
13588
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13586

def create_time
  @create_time
end

#current_spendGoogle::Apis::AiplatformV1beta1::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property currentSpend



13591
13592
13593
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13591

def current_spend
  @current_spend
end

#datasetsArray<String>

Required. Dataset resource names. Right now we only support labeling from a single Dataset. Format: projects/project/locations/location/datasets/ dataset` Corresponds to the JSON propertydatasets`

Returns:

  • (Array<String>)


13598
13599
13600
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13598

def datasets
  @datasets
end

#display_nameString

Required. The user-defined name of the DataLabelingJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Display name of a DataLabelingJob. Corresponds to the JSON property displayName

Returns:

  • (String)


13605
13606
13607
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13605

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



13611
13612
13613
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13611

def encryption_spec
  @encryption_spec
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



13621
13622
13623
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13621

def error
  @error
end

#inputsObject

Required. Input config parameters for the DataLabelingJob. Corresponds to the JSON property inputs

Returns:

  • (Object)


13626
13627
13628
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13626

def inputs
  @inputs
end

#inputs_schema_uriString

Required. Points to a YAML file stored on Google Cloud Storage describing the config for a specific type of DataLabelingJob. The schema files that can be used here are found in the https://storage.googleapis.com/google-cloud- aiplatform bucket in the /schema/datalabelingjob/inputs/ folder. Corresponds to the JSON property inputsSchemaUri

Returns:

  • (String)


13634
13635
13636
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13634

def inputs_schema_uri
  @inputs_schema_uri
end

#instruction_uriString

Required. The Google Cloud Storage location of the instruction pdf. This pdf is shared with labelers, and provides detailed description on how to label DataItems in Datasets. Corresponds to the JSON property instructionUri

Returns:

  • (String)


13641
13642
13643
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13641

def instruction_uri
  @instruction_uri
end

#labeler_countFixnum

Required. Number of labelers to work on each DataItem. Corresponds to the JSON property labelerCount

Returns:

  • (Fixnum)


13646
13647
13648
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13646

def labeler_count
  @labeler_count
end

#labeling_progressFixnum

Output only. Current labeling job progress percentage scaled in interval [0, 100], indicating the percentage of DataItems that has been finished. Corresponds to the JSON property labelingProgress

Returns:

  • (Fixnum)


13652
13653
13654
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13652

def labeling_progress
  @labeling_progress
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your DataLabelingJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for each DataLabelingJob: * "aiplatform.googleapis.com/schema": output only, its value is the inputs_schema's title. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


13664
13665
13666
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13664

def labels
  @labels
end

#nameString

Output only. Resource name of the DataLabelingJob. Corresponds to the JSON property name

Returns:

  • (String)


13669
13670
13671
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13669

def name
  @name
end

#specialist_poolsArray<String>

The SpecialistPools' resource names associated with this job. Corresponds to the JSON property specialistPools

Returns:

  • (Array<String>)


13674
13675
13676
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13674

def specialist_pools
  @specialist_pools
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


13679
13680
13681
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13679

def state
  @state
end

#update_timeString

Output only. Timestamp when this DataLabelingJob was updated most recently. Corresponds to the JSON property updateTime

Returns:

  • (String)


13684
13685
13686
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13684

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13691
13692
13693
13694
13695
13696
13697
13698
13699
13700
13701
13702
13703
13704
13705
13706
13707
13708
13709
13710
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13691

def update!(**args)
  @active_learning_config = args[:active_learning_config] if args.key?(:active_learning_config)
  @annotation_labels = args[:annotation_labels] if args.key?(:annotation_labels)
  @create_time = args[:create_time] if args.key?(:create_time)
  @current_spend = args[:current_spend] if args.key?(:current_spend)
  @datasets = args[:datasets] if args.key?(:datasets)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @error = args[:error] if args.key?(:error)
  @inputs = args[:inputs] if args.key?(:inputs)
  @inputs_schema_uri = args[:inputs_schema_uri] if args.key?(:inputs_schema_uri)
  @instruction_uri = args[:instruction_uri] if args.key?(:instruction_uri)
  @labeler_count = args[:labeler_count] if args.key?(:labeler_count)
  @labeling_progress = args[:labeling_progress] if args.key?(:labeling_progress)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @specialist_pools = args[:specialist_pools] if args.key?(:specialist_pools)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end