Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Dataset
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Dataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A collection of DataItems and Annotations on them.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_item_count ⇒ Fixnum
Output only.
-
#description ⇒ String
The description of the Dataset.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Datasets.
-
#metadata ⇒ Object
Required.
-
#metadata_artifact ⇒ String
Output only.
-
#metadata_schema_uri ⇒ String
Required.
-
#model_reference ⇒ String
Optional.
-
#name ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#saved_queries ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SavedQuery>
All SavedQueries belong to the Dataset will be returned in List/Get Dataset response.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Dataset
constructor
A new instance of GoogleCloudAiplatformV1beta1Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Dataset
Returns a new instance of GoogleCloudAiplatformV1beta1Dataset.
13825 13826 13827 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13825 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Dataset was created.
Corresponds to the JSON property createTime
13720 13721 13722 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13720 def create_time @create_time end |
#data_item_count ⇒ Fixnum
Output only. The number of DataItems in this Dataset. Only apply for non-
structured Dataset.
Corresponds to the JSON property dataItemCount
13726 13727 13728 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13726 def data_item_count @data_item_count end |
#description ⇒ String
The description of the Dataset.
Corresponds to the JSON property description
13731 13732 13733 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13731 def description @description end |
#display_name ⇒ String
Required. The user-defined name of the Dataset. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
13737 13738 13739 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13737 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
13743 13744 13745 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13743 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
13749 13750 13751 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13749 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Datasets. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Dataset (System labels are excluded). See https://goo.gl/
xmQnxf for more information and examples of labels. System reserved label keys
are prefixed with "aiplatform.googleapis.com/" and are immutable. Following
system labels exist for each Dataset: * "aiplatform.googleapis.com/
dataset_metadata_schema": output only, its value is the metadata_schema's
title.
Corresponds to the JSON property labels
13763 13764 13765 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13763 def labels @labels end |
#metadata ⇒ Object
Required. Additional information about the Dataset.
Corresponds to the JSON property metadata
13768 13769 13770 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13768 def @metadata end |
#metadata_artifact ⇒ String
Output only. The resource name of the Artifact that was created in
MetadataStore when creating the Dataset. The Artifact resource name pattern is
projects/project/locations/location/metadataStores/metadata_store/
artifacts/artifact`.
Corresponds to the JSON propertymetadataArtifact`
13776 13777 13778 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13776 def @metadata_artifact end |
#metadata_schema_uri ⇒ String
Required. Points to a YAML file stored on Google Cloud Storage describing
additional information about the Dataset. The schema is defined as an OpenAPI
3.0.2 Schema Object. The schema files that can be used here are found in gs://
google-cloud-aiplatform/schema/dataset/metadata/.
Corresponds to the JSON property metadataSchemaUri
13784 13785 13786 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13784 def @metadata_schema_uri end |
#model_reference ⇒ String
Optional. Reference to the public base model last used by the dataset. Only
set for prompt datasets.
Corresponds to the JSON property modelReference
13790 13791 13792 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13790 def model_reference @model_reference end |
#name ⇒ String
Output only. Identifier. The resource name of the Dataset. Format: projects/
project/locations/location/datasets/dataset`
Corresponds to the JSON propertyname`
13796 13797 13798 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13796 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
13801 13802 13803 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13801 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
13807 13808 13809 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13807 def satisfies_pzs @satisfies_pzs end |
#saved_queries ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SavedQuery>
All SavedQueries belong to the Dataset will be returned in List/Get Dataset
response. The annotation_specs field will not be populated except for UI cases
which will only use annotation_spec_count. In CreateDataset request, a
SavedQuery is created together if this field is set, up to one SavedQuery can
be set in CreateDatasetRequest. The SavedQuery should not contain any
AnnotationSpec.
Corresponds to the JSON property savedQueries
13818 13819 13820 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13818 def saved_queries @saved_queries end |
#update_time ⇒ String
Output only. Timestamp when this Dataset was last updated.
Corresponds to the JSON property updateTime
13823 13824 13825 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13823 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13830 13831 13832 13833 13834 13835 13836 13837 13838 13839 13840 13841 13842 13843 13844 13845 13846 13847 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13830 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_item_count = args[:data_item_count] if args.key?(:data_item_count) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @metadata_artifact = args[:metadata_artifact] if args.key?(:metadata_artifact) @metadata_schema_uri = args[:metadata_schema_uri] if args.key?(:metadata_schema_uri) @model_reference = args[:model_reference] if args.key?(:model_reference) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @saved_queries = args[:saved_queries] if args.key?(:saved_queries) @update_time = args[:update_time] if args.key?(:update_time) end |