Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Dataset
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Dataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A collection of DataItems and Annotations on them.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_item_count ⇒ Fixnum
Output only.
-
#description ⇒ String
The description of the Dataset.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Datasets.
-
#metadata ⇒ Object
Required.
-
#metadata_artifact ⇒ String
Output only.
-
#metadata_schema_uri ⇒ String
Required.
-
#model_reference ⇒ String
Optional.
-
#name ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#saved_queries ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SavedQuery>
All SavedQueries belong to the Dataset will be returned in List/Get Dataset response.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Dataset
constructor
A new instance of GoogleCloudAiplatformV1beta1Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Dataset
Returns a new instance of GoogleCloudAiplatformV1beta1Dataset.
12602 12603 12604 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Dataset was created.
Corresponds to the JSON property createTime
12497 12498 12499 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12497 def create_time @create_time end |
#data_item_count ⇒ Fixnum
Output only. The number of DataItems in this Dataset. Only apply for non-
structured Dataset.
Corresponds to the JSON property dataItemCount
12503 12504 12505 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12503 def data_item_count @data_item_count end |
#description ⇒ String
The description of the Dataset.
Corresponds to the JSON property description
12508 12509 12510 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12508 def description @description end |
#display_name ⇒ String
Required. The user-defined name of the Dataset. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
12514 12515 12516 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12514 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
12520 12521 12522 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12520 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
12526 12527 12528 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12526 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Datasets. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Dataset (System labels are excluded). See https://goo.gl/
xmQnxf for more information and examples of labels. System reserved label keys
are prefixed with "aiplatform.googleapis.com/" and are immutable. Following
system labels exist for each Dataset: * "aiplatform.googleapis.com/
dataset_metadata_schema": output only, its value is the metadata_schema's
title.
Corresponds to the JSON property labels
12540 12541 12542 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12540 def labels @labels end |
#metadata ⇒ Object
Required. Additional information about the Dataset.
Corresponds to the JSON property metadata
12545 12546 12547 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12545 def @metadata end |
#metadata_artifact ⇒ String
Output only. The resource name of the Artifact that was created in
MetadataStore when creating the Dataset. The Artifact resource name pattern is
projects/project/locations/location/metadataStores/metadata_store/
artifacts/artifact`.
Corresponds to the JSON propertymetadataArtifact`
12553 12554 12555 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12553 def @metadata_artifact end |
#metadata_schema_uri ⇒ String
Required. Points to a YAML file stored on Google Cloud Storage describing
additional information about the Dataset. The schema is defined as an OpenAPI
3.0.2 Schema Object. The schema files that can be used here are found in gs://
google-cloud-aiplatform/schema/dataset/metadata/.
Corresponds to the JSON property metadataSchemaUri
12561 12562 12563 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12561 def @metadata_schema_uri end |
#model_reference ⇒ String
Optional. Reference to the public base model last used by the dataset. Only
set for prompt datasets.
Corresponds to the JSON property modelReference
12567 12568 12569 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12567 def model_reference @model_reference end |
#name ⇒ String
Output only. Identifier. The resource name of the Dataset. Format: projects/
project/locations/location/datasets/dataset`
Corresponds to the JSON propertyname`
12573 12574 12575 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12573 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
12578 12579 12580 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12578 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
12584 12585 12586 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12584 def satisfies_pzs @satisfies_pzs end |
#saved_queries ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SavedQuery>
All SavedQueries belong to the Dataset will be returned in List/Get Dataset
response. The annotation_specs field will not be populated except for UI cases
which will only use annotation_spec_count. In CreateDataset request, a
SavedQuery is created together if this field is set, up to one SavedQuery can
be set in CreateDatasetRequest. The SavedQuery should not contain any
AnnotationSpec.
Corresponds to the JSON property savedQueries
12595 12596 12597 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12595 def saved_queries @saved_queries end |
#update_time ⇒ String
Output only. Timestamp when this Dataset was last updated.
Corresponds to the JSON property updateTime
12600 12601 12602 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12600 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12607 12608 12609 12610 12611 12612 12613 12614 12615 12616 12617 12618 12619 12620 12621 12622 12623 12624 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12607 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_item_count = args[:data_item_count] if args.key?(:data_item_count) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @metadata_artifact = args[:metadata_artifact] if args.key?(:metadata_artifact) @metadata_schema_uri = args[:metadata_schema_uri] if args.key?(:metadata_schema_uri) @model_reference = args[:model_reference] if args.key?(:model_reference) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @saved_queries = args[:saved_queries] if args.key?(:saved_queries) @update_time = args[:update_time] if args.key?(:update_time) end |