Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetStats
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Statistics computed over a tuning dataset.
Instance Attribute Summary collapse
-
#contents_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#dropped_example_indices ⇒ Array<Fixnum>
Output only.
-
#dropped_example_reasons ⇒ Array<String>
Output only.
-
#reinforcement_tuning_user_dataset_examples ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningUserDatasetExamples
Sample reinforcement tuning user data in the training dataset.
-
#total_billable_character_count ⇒ Fixnum
Output only.
-
#total_billable_token_count ⇒ Fixnum
Output only.
-
#total_tuning_character_count ⇒ Fixnum
Output only.
-
#tuning_dataset_example_count ⇒ Fixnum
Output only.
-
#tuning_step_count ⇒ Fixnum
Output only.
-
#user_dataset_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Output only.
-
#user_input_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#user_message_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#user_output_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DatasetStats
constructor
A new instance of GoogleCloudAiplatformV1beta1DatasetStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DatasetStats
Returns a new instance of GoogleCloudAiplatformV1beta1DatasetStats.
15333 15334 15335 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15333 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property contentsPerExampleDistribution
15268 15269 15270 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15268 def contents_per_example_distribution @contents_per_example_distribution end |
#dropped_example_indices ⇒ Array<Fixnum>
Output only. A partial sample of the indices (starting from 1) of the dropped
examples.
Corresponds to the JSON property droppedExampleIndices
15274 15275 15276 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15274 def dropped_example_indices @dropped_example_indices end |
#dropped_example_reasons ⇒ Array<String>
Output only. For each index in dropped_example_indices, the user-facing
reason why the example was dropped.
Corresponds to the JSON property droppedExampleReasons
15280 15281 15282 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15280 def dropped_example_reasons @dropped_example_reasons end |
#reinforcement_tuning_user_dataset_examples ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningUserDatasetExamples
Sample reinforcement tuning user data in the training dataset. The contents
are truncated for better UI showing.
Corresponds to the JSON property reinforcementTuningUserDatasetExamples
15286 15287 15288 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15286 def reinforcement_tuning_user_dataset_examples @reinforcement_tuning_user_dataset_examples end |
#total_billable_character_count ⇒ Fixnum
Output only. Number of billable characters in the tuning dataset.
Corresponds to the JSON property totalBillableCharacterCount
15291 15292 15293 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15291 def total_billable_character_count @total_billable_character_count end |
#total_billable_token_count ⇒ Fixnum
Output only. Number of billable tokens in the tuning dataset.
Corresponds to the JSON property totalBillableTokenCount
15296 15297 15298 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15296 def total_billable_token_count @total_billable_token_count end |
#total_tuning_character_count ⇒ Fixnum
Output only. Number of tuning characters in the tuning dataset.
Corresponds to the JSON property totalTuningCharacterCount
15301 15302 15303 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15301 def total_tuning_character_count @total_tuning_character_count end |
#tuning_dataset_example_count ⇒ Fixnum
Output only. Number of examples in the tuning dataset.
Corresponds to the JSON property tuningDatasetExampleCount
15306 15307 15308 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15306 def tuning_dataset_example_count @tuning_dataset_example_count end |
#tuning_step_count ⇒ Fixnum
Output only. Number of tuning steps for this Tuning Job.
Corresponds to the JSON property tuningStepCount
15311 15312 15313 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15311 def tuning_step_count @tuning_step_count end |
#user_dataset_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Output only. Sample user messages in the training dataset uri.
Corresponds to the JSON property userDatasetExamples
15316 15317 15318 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15316 def user_dataset_examples @user_dataset_examples end |
#user_input_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userInputTokenDistribution
15321 15322 15323 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15321 def user_input_token_distribution @user_input_token_distribution end |
#user_message_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userMessagePerExampleDistribution
15326 15327 15328 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15326 def @user_message_per_example_distribution end |
#user_output_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userOutputTokenDistribution
15331 15332 15333 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15331 def user_output_token_distribution @user_output_token_distribution end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15338 def update!(**args) @contents_per_example_distribution = args[:contents_per_example_distribution] if args.key?(:contents_per_example_distribution) @dropped_example_indices = args[:dropped_example_indices] if args.key?(:dropped_example_indices) @dropped_example_reasons = args[:dropped_example_reasons] if args.key?(:dropped_example_reasons) @reinforcement_tuning_user_dataset_examples = args[:reinforcement_tuning_user_dataset_examples] if args.key?(:reinforcement_tuning_user_dataset_examples) @total_billable_character_count = args[:total_billable_character_count] if args.key?(:total_billable_character_count) @total_billable_token_count = args[:total_billable_token_count] if args.key?(:total_billable_token_count) @total_tuning_character_count = args[:total_tuning_character_count] if args.key?(:total_tuning_character_count) @tuning_dataset_example_count = args[:tuning_dataset_example_count] if args.key?(:tuning_dataset_example_count) @tuning_step_count = args[:tuning_step_count] if args.key?(:tuning_step_count) @user_dataset_examples = args[:user_dataset_examples] if args.key?(:user_dataset_examples) @user_input_token_distribution = args[:user_input_token_distribution] if args.key?(:user_input_token_distribution) @user_message_per_example_distribution = args[:user_message_per_example_distribution] if args.key?(:user_message_per_example_distribution) @user_output_token_distribution = args[:user_output_token_distribution] if args.key?(:user_output_token_distribution) end |