Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetStats
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Statistics computed over a tuning dataset.
Instance Attribute Summary collapse
-
#contents_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#dropped_example_indices ⇒ Array<Fixnum>
Output only.
-
#dropped_example_reasons ⇒ Array<String>
Output only.
-
#reinforcement_tuning_user_dataset_examples ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningUserDatasetExamples
Sample reinforcement tuning user data in the training dataset.
-
#total_billable_character_count ⇒ Fixnum
Output only.
-
#total_billable_token_count ⇒ Fixnum
Output only.
-
#total_tuning_character_count ⇒ Fixnum
Output only.
-
#tuning_dataset_example_count ⇒ Fixnum
Output only.
-
#tuning_step_count ⇒ Fixnum
Output only.
-
#user_dataset_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Output only.
-
#user_input_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#user_message_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#user_output_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DatasetStats
constructor
A new instance of GoogleCloudAiplatformV1beta1DatasetStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DatasetStats
Returns a new instance of GoogleCloudAiplatformV1beta1DatasetStats.
14968 14969 14970 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14968 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property contentsPerExampleDistribution
14903 14904 14905 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14903 def contents_per_example_distribution @contents_per_example_distribution end |
#dropped_example_indices ⇒ Array<Fixnum>
Output only. A partial sample of the indices (starting from 1) of the dropped
examples.
Corresponds to the JSON property droppedExampleIndices
14909 14910 14911 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14909 def dropped_example_indices @dropped_example_indices end |
#dropped_example_reasons ⇒ Array<String>
Output only. For each index in dropped_example_indices, the user-facing
reason why the example was dropped.
Corresponds to the JSON property droppedExampleReasons
14915 14916 14917 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14915 def dropped_example_reasons @dropped_example_reasons end |
#reinforcement_tuning_user_dataset_examples ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningUserDatasetExamples
Sample reinforcement tuning user data in the training dataset. The contents
are truncated for better UI showing.
Corresponds to the JSON property reinforcementTuningUserDatasetExamples
14921 14922 14923 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14921 def reinforcement_tuning_user_dataset_examples @reinforcement_tuning_user_dataset_examples end |
#total_billable_character_count ⇒ Fixnum
Output only. Number of billable characters in the tuning dataset.
Corresponds to the JSON property totalBillableCharacterCount
14926 14927 14928 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14926 def total_billable_character_count @total_billable_character_count end |
#total_billable_token_count ⇒ Fixnum
Output only. Number of billable tokens in the tuning dataset.
Corresponds to the JSON property totalBillableTokenCount
14931 14932 14933 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14931 def total_billable_token_count @total_billable_token_count end |
#total_tuning_character_count ⇒ Fixnum
Output only. Number of tuning characters in the tuning dataset.
Corresponds to the JSON property totalTuningCharacterCount
14936 14937 14938 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14936 def total_tuning_character_count @total_tuning_character_count end |
#tuning_dataset_example_count ⇒ Fixnum
Output only. Number of examples in the tuning dataset.
Corresponds to the JSON property tuningDatasetExampleCount
14941 14942 14943 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14941 def tuning_dataset_example_count @tuning_dataset_example_count end |
#tuning_step_count ⇒ Fixnum
Output only. Number of tuning steps for this Tuning Job.
Corresponds to the JSON property tuningStepCount
14946 14947 14948 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14946 def tuning_step_count @tuning_step_count end |
#user_dataset_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Output only. Sample user messages in the training dataset uri.
Corresponds to the JSON property userDatasetExamples
14951 14952 14953 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14951 def user_dataset_examples @user_dataset_examples end |
#user_input_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userInputTokenDistribution
14956 14957 14958 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14956 def user_input_token_distribution @user_input_token_distribution end |
#user_message_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userMessagePerExampleDistribution
14961 14962 14963 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14961 def @user_message_per_example_distribution end |
#user_output_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userOutputTokenDistribution
14966 14967 14968 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14966 def user_output_token_distribution @user_output_token_distribution end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14973 14974 14975 14976 14977 14978 14979 14980 14981 14982 14983 14984 14985 14986 14987 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14973 def update!(**args) @contents_per_example_distribution = args[:contents_per_example_distribution] if args.key?(:contents_per_example_distribution) @dropped_example_indices = args[:dropped_example_indices] if args.key?(:dropped_example_indices) @dropped_example_reasons = args[:dropped_example_reasons] if args.key?(:dropped_example_reasons) @reinforcement_tuning_user_dataset_examples = args[:reinforcement_tuning_user_dataset_examples] if args.key?(:reinforcement_tuning_user_dataset_examples) @total_billable_character_count = args[:total_billable_character_count] if args.key?(:total_billable_character_count) @total_billable_token_count = args[:total_billable_token_count] if args.key?(:total_billable_token_count) @total_tuning_character_count = args[:total_tuning_character_count] if args.key?(:total_tuning_character_count) @tuning_dataset_example_count = args[:tuning_dataset_example_count] if args.key?(:tuning_dataset_example_count) @tuning_step_count = args[:tuning_step_count] if args.key?(:tuning_step_count) @user_dataset_examples = args[:user_dataset_examples] if args.key?(:user_dataset_examples) @user_input_token_distribution = args[:user_input_token_distribution] if args.key?(:user_input_token_distribution) @user_message_per_example_distribution = args[:user_message_per_example_distribution] if args.key?(:user_message_per_example_distribution) @user_output_token_distribution = args[:user_output_token_distribution] if args.key?(:user_output_token_distribution) end |