Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetStats
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Statistics computed over a tuning dataset.
Instance Attribute Summary collapse
-
#contents_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#dropped_example_indices ⇒ Array<Fixnum>
Output only.
-
#dropped_example_reasons ⇒ Array<String>
Output only.
-
#reinforcement_tuning_user_dataset_examples ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningUserDatasetExamples
Sample reinforcement tuning user data in the training dataset.
-
#total_billable_character_count ⇒ Fixnum
Output only.
-
#total_billable_token_count ⇒ Fixnum
Output only.
-
#total_tuning_character_count ⇒ Fixnum
Output only.
-
#tuning_dataset_example_count ⇒ Fixnum
Output only.
-
#tuning_step_count ⇒ Fixnum
Output only.
-
#user_dataset_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Output only.
-
#user_input_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#user_message_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#user_output_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DatasetStats
constructor
A new instance of GoogleCloudAiplatformV1beta1DatasetStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DatasetStats
Returns a new instance of GoogleCloudAiplatformV1beta1DatasetStats.
13594 13595 13596 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property contentsPerExampleDistribution
13529 13530 13531 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13529 def contents_per_example_distribution @contents_per_example_distribution end |
#dropped_example_indices ⇒ Array<Fixnum>
Output only. A partial sample of the indices (starting from 1) of the dropped
examples.
Corresponds to the JSON property droppedExampleIndices
13535 13536 13537 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13535 def dropped_example_indices @dropped_example_indices end |
#dropped_example_reasons ⇒ Array<String>
Output only. For each index in dropped_example_indices, the user-facing
reason why the example was dropped.
Corresponds to the JSON property droppedExampleReasons
13541 13542 13543 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13541 def dropped_example_reasons @dropped_example_reasons end |
#reinforcement_tuning_user_dataset_examples ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningUserDatasetExamples
Sample reinforcement tuning user data in the training dataset. The contents
are truncated for better UI showing.
Corresponds to the JSON property reinforcementTuningUserDatasetExamples
13547 13548 13549 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13547 def reinforcement_tuning_user_dataset_examples @reinforcement_tuning_user_dataset_examples end |
#total_billable_character_count ⇒ Fixnum
Output only. Number of billable characters in the tuning dataset.
Corresponds to the JSON property totalBillableCharacterCount
13552 13553 13554 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13552 def total_billable_character_count @total_billable_character_count end |
#total_billable_token_count ⇒ Fixnum
Output only. Number of billable tokens in the tuning dataset.
Corresponds to the JSON property totalBillableTokenCount
13557 13558 13559 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13557 def total_billable_token_count @total_billable_token_count end |
#total_tuning_character_count ⇒ Fixnum
Output only. Number of tuning characters in the tuning dataset.
Corresponds to the JSON property totalTuningCharacterCount
13562 13563 13564 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13562 def total_tuning_character_count @total_tuning_character_count end |
#tuning_dataset_example_count ⇒ Fixnum
Output only. Number of examples in the tuning dataset.
Corresponds to the JSON property tuningDatasetExampleCount
13567 13568 13569 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13567 def tuning_dataset_example_count @tuning_dataset_example_count end |
#tuning_step_count ⇒ Fixnum
Output only. Number of tuning steps for this Tuning Job.
Corresponds to the JSON property tuningStepCount
13572 13573 13574 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13572 def tuning_step_count @tuning_step_count end |
#user_dataset_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Output only. Sample user messages in the training dataset uri.
Corresponds to the JSON property userDatasetExamples
13577 13578 13579 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13577 def user_dataset_examples @user_dataset_examples end |
#user_input_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userInputTokenDistribution
13582 13583 13584 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13582 def user_input_token_distribution @user_input_token_distribution end |
#user_message_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userMessagePerExampleDistribution
13587 13588 13589 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13587 def @user_message_per_example_distribution end |
#user_output_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userOutputTokenDistribution
13592 13593 13594 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13592 def user_output_token_distribution @user_output_token_distribution end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13599 13600 13601 13602 13603 13604 13605 13606 13607 13608 13609 13610 13611 13612 13613 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13599 def update!(**args) @contents_per_example_distribution = args[:contents_per_example_distribution] if args.key?(:contents_per_example_distribution) @dropped_example_indices = args[:dropped_example_indices] if args.key?(:dropped_example_indices) @dropped_example_reasons = args[:dropped_example_reasons] if args.key?(:dropped_example_reasons) @reinforcement_tuning_user_dataset_examples = args[:reinforcement_tuning_user_dataset_examples] if args.key?(:reinforcement_tuning_user_dataset_examples) @total_billable_character_count = args[:total_billable_character_count] if args.key?(:total_billable_character_count) @total_billable_token_count = args[:total_billable_token_count] if args.key?(:total_billable_token_count) @total_tuning_character_count = args[:total_tuning_character_count] if args.key?(:total_tuning_character_count) @tuning_dataset_example_count = args[:tuning_dataset_example_count] if args.key?(:tuning_dataset_example_count) @tuning_step_count = args[:tuning_step_count] if args.key?(:tuning_step_count) @user_dataset_examples = args[:user_dataset_examples] if args.key?(:user_dataset_examples) @user_input_token_distribution = args[:user_input_token_distribution] if args.key?(:user_input_token_distribution) @user_message_per_example_distribution = args[:user_message_per_example_distribution] if args.key?(:user_message_per_example_distribution) @user_output_token_distribution = args[:user_output_token_distribution] if args.key?(:user_output_token_distribution) end |