Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetStats
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Statistics computed over a tuning dataset.
Instance Attribute Summary collapse
-
#contents_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#dropped_example_indices ⇒ Array<Fixnum>
Output only.
-
#dropped_example_reasons ⇒ Array<String>
Output only.
-
#reinforcement_tuning_user_dataset_examples ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningUserDatasetExamples
Sample reinforcement tuning user data in the training dataset.
-
#total_billable_character_count ⇒ Fixnum
Output only.
-
#total_billable_token_count ⇒ Fixnum
Output only.
-
#total_tuning_character_count ⇒ Fixnum
Output only.
-
#tuning_dataset_example_count ⇒ Fixnum
Output only.
-
#tuning_step_count ⇒ Fixnum
Output only.
-
#user_dataset_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Output only.
-
#user_input_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#user_message_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
-
#user_output_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DatasetStats
constructor
A new instance of GoogleCloudAiplatformV1beta1DatasetStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DatasetStats
Returns a new instance of GoogleCloudAiplatformV1beta1DatasetStats.
13772 13773 13774 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property contentsPerExampleDistribution
13707 13708 13709 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13707 def contents_per_example_distribution @contents_per_example_distribution end |
#dropped_example_indices ⇒ Array<Fixnum>
Output only. A partial sample of the indices (starting from 1) of the dropped
examples.
Corresponds to the JSON property droppedExampleIndices
13713 13714 13715 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13713 def dropped_example_indices @dropped_example_indices end |
#dropped_example_reasons ⇒ Array<String>
Output only. For each index in dropped_example_indices, the user-facing
reason why the example was dropped.
Corresponds to the JSON property droppedExampleReasons
13719 13720 13721 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13719 def dropped_example_reasons @dropped_example_reasons end |
#reinforcement_tuning_user_dataset_examples ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningUserDatasetExamples
Sample reinforcement tuning user data in the training dataset. The contents
are truncated for better UI showing.
Corresponds to the JSON property reinforcementTuningUserDatasetExamples
13725 13726 13727 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13725 def reinforcement_tuning_user_dataset_examples @reinforcement_tuning_user_dataset_examples end |
#total_billable_character_count ⇒ Fixnum
Output only. Number of billable characters in the tuning dataset.
Corresponds to the JSON property totalBillableCharacterCount
13730 13731 13732 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13730 def total_billable_character_count @total_billable_character_count end |
#total_billable_token_count ⇒ Fixnum
Output only. Number of billable tokens in the tuning dataset.
Corresponds to the JSON property totalBillableTokenCount
13735 13736 13737 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13735 def total_billable_token_count @total_billable_token_count end |
#total_tuning_character_count ⇒ Fixnum
Output only. Number of tuning characters in the tuning dataset.
Corresponds to the JSON property totalTuningCharacterCount
13740 13741 13742 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13740 def total_tuning_character_count @total_tuning_character_count end |
#tuning_dataset_example_count ⇒ Fixnum
Output only. Number of examples in the tuning dataset.
Corresponds to the JSON property tuningDatasetExampleCount
13745 13746 13747 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13745 def tuning_dataset_example_count @tuning_dataset_example_count end |
#tuning_step_count ⇒ Fixnum
Output only. Number of tuning steps for this Tuning Job.
Corresponds to the JSON property tuningStepCount
13750 13751 13752 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13750 def tuning_step_count @tuning_step_count end |
#user_dataset_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Output only. Sample user messages in the training dataset uri.
Corresponds to the JSON property userDatasetExamples
13755 13756 13757 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13755 def user_dataset_examples @user_dataset_examples end |
#user_input_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userInputTokenDistribution
13760 13761 13762 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13760 def user_input_token_distribution @user_input_token_distribution end |
#user_message_per_example_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userMessagePerExampleDistribution
13765 13766 13767 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13765 def @user_message_per_example_distribution end |
#user_output_token_distribution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DatasetDistribution
Distribution computed over a tuning dataset.
Corresponds to the JSON property userOutputTokenDistribution
13770 13771 13772 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13770 def user_output_token_distribution @user_output_token_distribution end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13777 13778 13779 13780 13781 13782 13783 13784 13785 13786 13787 13788 13789 13790 13791 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13777 def update!(**args) @contents_per_example_distribution = args[:contents_per_example_distribution] if args.key?(:contents_per_example_distribution) @dropped_example_indices = args[:dropped_example_indices] if args.key?(:dropped_example_indices) @dropped_example_reasons = args[:dropped_example_reasons] if args.key?(:dropped_example_reasons) @reinforcement_tuning_user_dataset_examples = args[:reinforcement_tuning_user_dataset_examples] if args.key?(:reinforcement_tuning_user_dataset_examples) @total_billable_character_count = args[:total_billable_character_count] if args.key?(:total_billable_character_count) @total_billable_token_count = args[:total_billable_token_count] if args.key?(:total_billable_token_count) @total_tuning_character_count = args[:total_tuning_character_count] if args.key?(:total_tuning_character_count) @tuning_dataset_example_count = args[:tuning_dataset_example_count] if args.key?(:tuning_dataset_example_count) @tuning_step_count = args[:tuning_step_count] if args.key?(:tuning_step_count) @user_dataset_examples = args[:user_dataset_examples] if args.key?(:user_dataset_examples) @user_input_token_distribution = args[:user_input_token_distribution] if args.key?(:user_input_token_distribution) @user_message_per_example_distribution = args[:user_message_per_example_distribution] if args.key?(:user_message_per_example_distribution) @user_output_token_distribution = args[:user_output_token_distribution] if args.key?(:user_output_token_distribution) end |