Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeleteFeatureValuesRequestSelectEntity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Message to select entity. If an entity id is selected, all the feature values corresponding to the entity id will be deleted, including the entityId.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeleteFeatureValuesRequestSelectEntity

Returns a new instance of GoogleCloudAiplatformV1beta1DeleteFeatureValuesRequestSelectEntity.



12650
12651
12652
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entity_id_selectorGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EntityIdSelector

Selector for entityId. Getting ids from the given source. Corresponds to the JSON property entityIdSelector



12648
12649
12650
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12648

def entity_id_selector
  @entity_id_selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12655
12656
12657
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12655

def update!(**args)
  @entity_id_selector = args[:entity_id_selector] if args.key?(:entity_id_selector)
end