Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeleteFeatureValuesRequestSelectTimeRangeAndFeature
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeleteFeatureValuesRequestSelectTimeRangeAndFeature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Message to select time range and feature. Values of the selected feature generated within an inclusive time range will be deleted. Using this option permanently deletes the feature values from the specified feature IDs within the specified time range. This might include data from the online storage. If you want to retain any deleted historical data in the online storage, you must re-ingest it.
Instance Attribute Summary collapse
-
#feature_selector ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelector
Selector for Features of an EntityType.
-
#skip_online_storage_delete ⇒ Boolean
(also: #skip_online_storage_delete?)
If set, data will not be deleted from online storage.
-
#time_range ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeleteFeatureValuesRequestSelectTimeRangeAndFeature
constructor
A new instance of GoogleCloudAiplatformV1beta1DeleteFeatureValuesRequestSelectTimeRangeAndFeature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeleteFeatureValuesRequestSelectTimeRangeAndFeature
Returns a new instance of GoogleCloudAiplatformV1beta1DeleteFeatureValuesRequestSelectTimeRangeAndFeature.
13167 13168 13169 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13167 def initialize(**args) update!(**args) end |
Instance Attribute Details
#feature_selector ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelector
Selector for Features of an EntityType.
Corresponds to the JSON property featureSelector
13149 13150 13151 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13149 def feature_selector @feature_selector end |
#skip_online_storage_delete ⇒ Boolean Also known as: skip_online_storage_delete?
If set, data will not be deleted from online storage. When time range is older
than the data in online storage, setting this to be true will make the
deletion have no impact on online serving.
Corresponds to the JSON property skipOnlineStorageDelete
13156 13157 13158 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13156 def skip_online_storage_delete @skip_online_storage_delete end |
#time_range ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property timeRange
13165 13166 13167 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13165 def time_range @time_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13172 13173 13174 13175 13176 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13172 def update!(**args) @feature_selector = args[:feature_selector] if args.key?(:feature_selector) @skip_online_storage_delete = args[:skip_online_storage_delete] if args.key?(:skip_online_storage_delete) @time_range = args[:time_range] if args.key?(:time_range) end |