Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployPublisherModelRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ModelGardenService.DeployPublisherModel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployPublisherModelRequest

Returns a new instance of GoogleCloudAiplatformV1beta1DeployPublisherModelRequest.



8265
8266
8267
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accept_eulaBoolean Also known as: accept_eula?

Optional. Whether the user accepts the End User License Agreement (EULA) for the model. Corresponds to the JSON property acceptEula

Returns:

  • (Boolean)


8229
8230
8231
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8229

def accept_eula
  @accept_eula
end

#dedicated_resourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DedicatedResources

A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



8236
8237
8238
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8236

def dedicated_resources
  @dedicated_resources
end

#endpoint_display_nameString

Optional. The user-specified display name of the endpoint. If not set, a default name will be used. Corresponds to the JSON property endpointDisplayName

Returns:

  • (String)


8242
8243
8244
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8242

def endpoint_display_name
  @endpoint_display_name
end

#hugging_face_access_tokenString

Optional. The Hugging Face read access token used to access the model artifacts of gated models. Corresponds to the JSON property huggingFaceAccessToken

Returns:

  • (String)


8248
8249
8250
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8248

def hugging_face_access_token
  @hugging_face_access_token
end

#modelString

Required. The model to deploy. Format: 1. publishers/publisher/models/ publisher_model@version_id`, orpublishers/hf-hugging-face-author/models/ hugging-face-model-name@001. 2. Hugging Face model ID likegoogle/gemma-2- 2b-it. 3. Custom model Google Cloud Storage URI likegs://bucket. 4. Custom model zip file likehttps://example.com/a.zip`. Corresponds to the JSON property model

Returns:

  • (String)


8257
8258
8259
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8257

def model
  @model
end

#model_display_nameString

Optional. The user-specified display name of the uploaded model. If not set, a default name will be used. Corresponds to the JSON property modelDisplayName

Returns:

  • (String)


8263
8264
8265
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8263

def model_display_name
  @model_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8270
8271
8272
8273
8274
8275
8276
8277
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8270

def update!(**args)
  @accept_eula = args[:accept_eula] if args.key?(:accept_eula)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @endpoint_display_name = args[:endpoint_display_name] if args.key?(:endpoint_display_name)
  @hugging_face_access_token = args[:hugging_face_access_token] if args.key?(:hugging_face_access_token)
  @model = args[:model] if args.key?(:model)
  @model_display_name = args[:model_display_name] if args.key?(:model_display_name)
end