Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployPublisherModelRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployPublisherModelRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ModelGardenService.DeployPublisherModel.
Instance Attribute Summary collapse
-
#accept_eula ⇒ Boolean
(also: #accept_eula?)
Optional.
-
#dedicated_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DedicatedResources
A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration.
-
#endpoint_display_name ⇒ String
Optional.
-
#hugging_face_access_token ⇒ String
Optional.
-
#model ⇒ String
Required.
-
#model_display_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployPublisherModelRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1DeployPublisherModelRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployPublisherModelRequest
Returns a new instance of GoogleCloudAiplatformV1beta1DeployPublisherModelRequest.
8199 8200 8201 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8199 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accept_eula ⇒ Boolean Also known as: accept_eula?
Optional. Whether the user accepts the End User License Agreement (EULA) for
the model.
Corresponds to the JSON property acceptEula
8163 8164 8165 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8163 def accept_eula @accept_eula end |
#dedicated_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DedicatedResources
A description of resources that are dedicated to a DeployedModel or
DeployedIndex, and that need a higher degree of manual configuration.
Corresponds to the JSON property dedicatedResources
8170 8171 8172 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8170 def dedicated_resources @dedicated_resources end |
#endpoint_display_name ⇒ String
Optional. The user-specified display name of the endpoint. If not set, a
default name will be used.
Corresponds to the JSON property endpointDisplayName
8176 8177 8178 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8176 def endpoint_display_name @endpoint_display_name end |
#hugging_face_access_token ⇒ String
Optional. The Hugging Face read access token used to access the model
artifacts of gated models.
Corresponds to the JSON property huggingFaceAccessToken
8182 8183 8184 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8182 def hugging_face_access_token @hugging_face_access_token end |
#model ⇒ String
Required. The model to deploy. Format: 1. publishers/publisher/models/
publisher_model@version_id`, orpublishers/hf-hugging-face-author/models/
hugging-face-model-name@001. 2. Hugging Face model ID likegoogle/gemma-2-
2b-it. 3. Custom model Google Cloud Storage URI likegs://bucket. 4. Custom
model zip file likehttps://example.com/a.zip`.
Corresponds to the JSON property model
8191 8192 8193 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8191 def model @model end |
#model_display_name ⇒ String
Optional. The user-specified display name of the uploaded model. If not set, a
default name will be used.
Corresponds to the JSON property modelDisplayName
8197 8198 8199 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8197 def model_display_name @model_display_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8204 def update!(**args) @accept_eula = args[:accept_eula] if args.key?(:accept_eula) @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources) @endpoint_display_name = args[:endpoint_display_name] if args.key?(:endpoint_display_name) @hugging_face_access_token = args[:hugging_face_access_token] if args.key?(:hugging_face_access_token) @model = args[:model] if args.key?(:model) @model_display_name = args[:model_display_name] if args.key?(:model_display_name) end |