Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ModelGardenService.Deploy.
Instance Attribute Summary collapse
-
#custom_model ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestCustomModel
The custom model to deploy from model weights in a Google Cloud Storage URI or Model Registry model.
-
#deploy_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestDeployConfig
The deploy config to use for the deployment.
-
#endpoint_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestEndpointConfig
The endpoint config to use for the deployment.
-
#hugging_face_model_id ⇒ String
The Hugging Face model to deploy.
-
#model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestModelConfig
The model config to use for the deployment.
-
#publisher_model_name ⇒ String
The Model Garden model to deploy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1DeployRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployRequest
Returns a new instance of GoogleCloudAiplatformV1beta1DeployRequest.
13103 13104 13105 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13103 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_model ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestCustomModel
The custom model to deploy from model weights in a Google Cloud Storage URI or
Model Registry model.
Corresponds to the JSON property customModel
13073 13074 13075 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13073 def custom_model @custom_model end |
#deploy_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestDeployConfig
The deploy config to use for the deployment.
Corresponds to the JSON property deployConfig
13078 13079 13080 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13078 def deploy_config @deploy_config end |
#endpoint_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestEndpointConfig
The endpoint config to use for the deployment.
Corresponds to the JSON property endpointConfig
13083 13084 13085 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13083 def endpoint_config @endpoint_config end |
#hugging_face_model_id ⇒ String
The Hugging Face model to deploy. Format: Hugging Face model ID like google/
gemma-2-2b-it.
Corresponds to the JSON property huggingFaceModelId
13089 13090 13091 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13089 def hugging_face_model_id @hugging_face_model_id end |
#model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestModelConfig
The model config to use for the deployment.
Corresponds to the JSON property modelConfig
13094 13095 13096 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13094 def model_config @model_config end |
#publisher_model_name ⇒ String
The Model Garden model to deploy. Format: publishers/publisher/models/
publisher_model@version_id`, orpublishers/hf-hugging-face-author/models/
hugging-face-model-name@001.
Corresponds to the JSON propertypublisherModelName`
13101 13102 13103 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13101 def publisher_model_name @publisher_model_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13108 13109 13110 13111 13112 13113 13114 13115 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13108 def update!(**args) @custom_model = args[:custom_model] if args.key?(:custom_model) @deploy_config = args[:deploy_config] if args.key?(:deploy_config) @endpoint_config = args[:endpoint_config] if args.key?(:endpoint_config) @hugging_face_model_id = args[:hugging_face_model_id] if args.key?(:hugging_face_model_id) @model_config = args[:model_config] if args.key?(:model_config) @publisher_model_name = args[:publisher_model_name] if args.key?(:publisher_model_name) end |