Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ModelGardenService.Deploy.
Instance Attribute Summary collapse
-
#custom_model ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestCustomModel
The custom model to deploy from model weights in a Google Cloud Storage URI or Model Registry model.
-
#deploy_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestDeployConfig
The deploy config to use for the deployment.
-
#endpoint_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestEndpointConfig
The endpoint config to use for the deployment.
-
#hugging_face_model_id ⇒ String
The Hugging Face model to deploy.
-
#model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestModelConfig
The model config to use for the deployment.
-
#publisher_model_name ⇒ String
The Model Garden model to deploy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1DeployRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployRequest
Returns a new instance of GoogleCloudAiplatformV1beta1DeployRequest.
8252 8253 8254 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8252 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_model ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestCustomModel
The custom model to deploy from model weights in a Google Cloud Storage URI or
Model Registry model.
Corresponds to the JSON property customModel
8222 8223 8224 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8222 def custom_model @custom_model end |
#deploy_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestDeployConfig
The deploy config to use for the deployment.
Corresponds to the JSON property deployConfig
8227 8228 8229 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8227 def deploy_config @deploy_config end |
#endpoint_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestEndpointConfig
The endpoint config to use for the deployment.
Corresponds to the JSON property endpointConfig
8232 8233 8234 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8232 def endpoint_config @endpoint_config end |
#hugging_face_model_id ⇒ String
The Hugging Face model to deploy. Format: Hugging Face model ID like google/
gemma-2-2b-it.
Corresponds to the JSON property huggingFaceModelId
8238 8239 8240 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8238 def hugging_face_model_id @hugging_face_model_id end |
#model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestModelConfig
The model config to use for the deployment.
Corresponds to the JSON property modelConfig
8243 8244 8245 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8243 def model_config @model_config end |
#publisher_model_name ⇒ String
The Model Garden model to deploy. Format: publishers/publisher/models/
publisher_model@version_id`, orpublishers/hf-hugging-face-author/models/
hugging-face-model-name@001.
Corresponds to the JSON propertypublisherModelName`
8250 8251 8252 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8250 def publisher_model_name @publisher_model_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8257 8258 8259 8260 8261 8262 8263 8264 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8257 def update!(**args) @custom_model = args[:custom_model] if args.key?(:custom_model) @deploy_config = args[:deploy_config] if args.key?(:deploy_config) @endpoint_config = args[:endpoint_config] if args.key?(:endpoint_config) @hugging_face_model_id = args[:hugging_face_model_id] if args.key?(:hugging_face_model_id) @model_config = args[:model_config] if args.key?(:model_config) @publisher_model_name = args[:publisher_model_name] if args.key?(:publisher_model_name) end |