Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestCustomModel
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestCustomModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The custom model to deploy from model weights in a Google Cloud Storage URI or Model Registry model.
Instance Attribute Summary collapse
-
#gcs_uri ⇒ String
Immutable.
-
#model_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployRequestCustomModel
constructor
A new instance of GoogleCloudAiplatformV1beta1DeployRequestCustomModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployRequestCustomModel
Returns a new instance of GoogleCloudAiplatformV1beta1DeployRequestCustomModel.
16112 16113 16114 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16112 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_uri ⇒ String
Immutable. The Google Cloud Storage URI of the custom model, storing weights
and config files (which can be used to infer the base model).
Corresponds to the JSON property gcsUri
16105 16106 16107 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16105 def gcs_uri @gcs_uri end |
#model_id ⇒ String
Optional. Deprecated. Use ModelConfig.model_user_id instead.
Corresponds to the JSON property modelId
16110 16111 16112 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16110 def model_id @model_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16117 16118 16119 16120 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16117 def update!(**args) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @model_id = args[:model_id] if args.key?(:model_id) end |