Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestCustomModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The custom model to deploy from model weights in a Google Cloud Storage URI or Model Registry model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployRequestCustomModel

Returns a new instance of GoogleCloudAiplatformV1beta1DeployRequestCustomModel.



15747
15748
15749
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_uriString

Immutable. The Google Cloud Storage URI of the custom model, storing weights and config files (which can be used to infer the base model). Corresponds to the JSON property gcsUri

Returns:

  • (String)


15740
15741
15742
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15740

def gcs_uri
  @gcs_uri
end

#model_idString

Optional. Deprecated. Use ModelConfig.model_user_id instead. Corresponds to the JSON property modelId

Returns:

  • (String)


15745
15746
15747
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15745

def model_id
  @model_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15752
15753
15754
15755
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15752

def update!(**args)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @model_id = args[:model_id] if args.key?(:model_id)
end