Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestDeployConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The deploy config to use for the deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployRequestDeployConfig

Returns a new instance of GoogleCloudAiplatformV1beta1DeployRequestDeployConfig.



8383
8384
8385
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8383

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dedicated_resourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DedicatedResources

A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



8368
8369
8370
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8368

def dedicated_resources
  @dedicated_resources
end

#fast_tryout_enabledBoolean Also known as: fast_tryout_enabled?

Optional. If true, enable the QMT fast tryout feature for this model if possible. Corresponds to the JSON property fastTryoutEnabled

Returns:

  • (Boolean)


8374
8375
8376
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8374

def fast_tryout_enabled
  @fast_tryout_enabled
end

#system_labelsHash<String,String>

Optional. System labels for Model Garden deployments. These labels are managed by Google and for tracking purposes only. Corresponds to the JSON property systemLabels

Returns:

  • (Hash<String,String>)


8381
8382
8383
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8381

def system_labels
  @system_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8388
8389
8390
8391
8392
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8388

def update!(**args)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @fast_tryout_enabled = args[:fast_tryout_enabled] if args.key?(:fast_tryout_enabled)
  @system_labels = args[:system_labels] if args.key?(:system_labels)
end