Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployRequestDeployConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The deploy config to use for the deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployRequestDeployConfig

Returns a new instance of GoogleCloudAiplatformV1beta1DeployRequestDeployConfig.



8317
8318
8319
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8317

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dedicated_resourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DedicatedResources

A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



8302
8303
8304
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8302

def dedicated_resources
  @dedicated_resources
end

#fast_tryout_enabledBoolean Also known as: fast_tryout_enabled?

Optional. If true, enable the QMT fast tryout feature for this model if possible. Corresponds to the JSON property fastTryoutEnabled

Returns:

  • (Boolean)


8308
8309
8310
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8308

def fast_tryout_enabled
  @fast_tryout_enabled
end

#system_labelsHash<String,String>

Optional. System labels for Model Garden deployments. These labels are managed by Google and for tracking purposes only. Corresponds to the JSON property systemLabels

Returns:

  • (Hash<String,String>)


8315
8316
8317
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8315

def system_labels
  @system_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8322
8323
8324
8325
8326
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 8322

def update!(**args)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @fast_tryout_enabled = args[:fast_tryout_enabled] if args.key?(:fast_tryout_enabled)
  @system_labels = args[:system_labels] if args.key?(:system_labels)
end