Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModel
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A deployment of a Model. Endpoints contain one or more DeployedModels.
Instance Attribute Summary collapse
-
#automatic_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AutomaticResources
A description of resources that to large degree are decided by Agent Platform, and require only a modest additional configuration.
-
#checkpoint_id ⇒ String
The checkpoint id of the model.
-
#create_time ⇒ String
Output only.
-
#dedicated_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DedicatedResources
A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration.
-
#disable_container_logging ⇒ Boolean
(also: #disable_container_logging?)
For custom-trained Models and AutoML Tabular Models, the container of the DeployedModel instances will send
stderrandstdoutstreams to Cloud Logging by default. -
#disable_explanations ⇒ Boolean
(also: #disable_explanations?)
If true, deploy the model without explainable feature, regardless the existence of Model.explanation_spec or explanation_spec.
-
#display_name ⇒ String
The display name of the DeployedModel.
-
#enable_access_logging ⇒ Boolean
(also: #enable_access_logging?)
If true, online prediction access logs are sent to Cloud Logging.
-
#enable_container_logging ⇒ Boolean
(also: #enable_container_logging?)
If true, the container of the DeployedModel instances will send
stderrandstdoutstreams to Cloud Logging. -
#explanation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpec
Specification of Model explanation.
-
#faster_deployment_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FasterDeploymentConfig
Configuration for faster model deployment.
-
#full_fine_tuned_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FullFineTunedResources
Resources for an fft model.
-
#gdc_connected_model ⇒ String
GDC pretrained / Gemini model name.
-
#id ⇒ String
Immutable.
-
#model ⇒ String
The resource name of the Model that this is the deployment of.
-
#model_version_id ⇒ String
Output only.
-
#private_endpoints ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateEndpoints
PrivateEndpoints proto is used to provide paths for users to send requests privately.
-
#rollout_options ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RolloutOptions
Configuration for rolling deployments.
-
#service_account ⇒ String
The service account that the DeployedModel's container runs as.
-
#shared_resources ⇒ String
The resource name of the shared DeploymentResourcePool to deploy on.
-
#speculative_decoding_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SpeculativeDecodingSpec
Configuration for Speculative Decoding.
-
#status ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModelStatus
Runtime status of the deployed model.
-
#system_labels ⇒ Hash<String,String>
System labels to apply to Model Garden deployments.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployedModel
constructor
A new instance of GoogleCloudAiplatformV1beta1DeployedModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployedModel
Returns a new instance of GoogleCloudAiplatformV1beta1DeployedModel.
14206 14207 14208 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automatic_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AutomaticResources
A description of resources that to large degree are decided by Agent Platform,
and require only a modest additional configuration. Each Model supporting
these resources documents its specific guidelines.
Corresponds to the JSON property automaticResources
14059 14060 14061 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14059 def automatic_resources @automatic_resources end |
#checkpoint_id ⇒ String
The checkpoint id of the model.
Corresponds to the JSON property checkpointId
14064 14065 14066 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14064 def checkpoint_id @checkpoint_id end |
#create_time ⇒ String
Output only. Timestamp when the DeployedModel was created.
Corresponds to the JSON property createTime
14069 14070 14071 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14069 def create_time @create_time end |
#dedicated_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DedicatedResources
A description of resources that are dedicated to a DeployedModel or
DeployedIndex, and that need a higher degree of manual configuration.
Corresponds to the JSON property dedicatedResources
14075 14076 14077 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14075 def dedicated_resources @dedicated_resources end |
#disable_container_logging ⇒ Boolean Also known as: disable_container_logging?
For custom-trained Models and AutoML Tabular Models, the container of the
DeployedModel instances will send stderr and stdout streams to Cloud
Logging by default. Please note that the logs incur cost, which are subject to
Cloud Logging pricing. User can
disable container logging by setting this flag to true.
Corresponds to the JSON property disableContainerLogging
14084 14085 14086 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14084 def disable_container_logging @disable_container_logging end |
#disable_explanations ⇒ Boolean Also known as: disable_explanations?
If true, deploy the model without explainable feature, regardless the
existence of Model.explanation_spec or explanation_spec.
Corresponds to the JSON property disableExplanations
14091 14092 14093 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14091 def disable_explanations @disable_explanations end |
#display_name ⇒ String
The display name of the DeployedModel. If not provided upon creation, the
Model's display_name is used.
Corresponds to the JSON property displayName
14098 14099 14100 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14098 def display_name @display_name end |
#enable_access_logging ⇒ Boolean Also known as: enable_access_logging?
If true, online prediction access logs are sent to Cloud Logging. These logs
are like standard server access logs, containing information like timestamp
and latency for each prediction request. Note that logs may incur a cost,
especially if your project receives prediction requests at a high queries per
second rate (QPS). Estimate your costs before enabling this option.
Corresponds to the JSON property enableAccessLogging
14107 14108 14109 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14107 def enable_access_logging @enable_access_logging end |
#enable_container_logging ⇒ Boolean Also known as: enable_container_logging?
If true, the container of the DeployedModel instances will send stderr and
stdout streams to Cloud Logging. Only supported for custom-trained Models and
AutoML Tabular Models.
Corresponds to the JSON property enableContainerLogging
14115 14116 14117 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14115 def enable_container_logging @enable_container_logging end |
#explanation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpec
Specification of Model explanation.
Corresponds to the JSON property explanationSpec
14121 14122 14123 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14121 def explanation_spec @explanation_spec end |
#faster_deployment_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FasterDeploymentConfig
Configuration for faster model deployment.
Corresponds to the JSON property fasterDeploymentConfig
14126 14127 14128 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14126 def faster_deployment_config @faster_deployment_config end |
#full_fine_tuned_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FullFineTunedResources
Resources for an fft model.
Corresponds to the JSON property fullFineTunedResources
14131 14132 14133 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14131 def full_fine_tuned_resources @full_fine_tuned_resources end |
#gdc_connected_model ⇒ String
GDC pretrained / Gemini model name. The model name is a plain model name, e.g.
gemini-1.5-flash-002.
Corresponds to the JSON property gdcConnectedModel
14137 14138 14139 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14137 def gdc_connected_model @gdc_connected_model end |
#id ⇒ String
Immutable. The ID of the DeployedModel. If not provided upon deployment,
Vertex AI will generate a value for this ID. This value should be 1-10
characters, and valid characters are /[0-9]/.
Corresponds to the JSON property id
14144 14145 14146 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14144 def id @id end |
#model ⇒ String
The resource name of the Model that this is the deployment of. Note that the
Model may be in a different location than the DeployedModel's Endpoint. The
resource name may contain version id or version alias to specify the version.
Example: projects/project/locations/location/models/model@2 or
projects/project/locations/location/models/model@golden if no version
is specified, the default version will be deployed.
Corresponds to the JSON property model
14154 14155 14156 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14154 def model @model end |
#model_version_id ⇒ String
Output only. The version ID of the model that is deployed.
Corresponds to the JSON property modelVersionId
14159 14160 14161 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14159 def model_version_id @model_version_id end |
#private_endpoints ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateEndpoints
PrivateEndpoints proto is used to provide paths for users to send requests
privately. To send request via private service access, use predict_http_uri,
explain_http_uri or health_http_uri. To send request via private service
connect, use service_attachment.
Corresponds to the JSON property privateEndpoints
14167 14168 14169 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14167 def private_endpoints @private_endpoints end |
#rollout_options ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RolloutOptions
Configuration for rolling deployments.
Corresponds to the JSON property rolloutOptions
14172 14173 14174 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14172 def @rollout_options end |
#service_account ⇒ String
The service account that the DeployedModel's container runs as. Specify the
email address of the service account. If this service account is not specified,
the container runs as a service account that doesn't have access to the
resource project. Users deploying the Model must have the iam.serviceAccounts.
actAs permission on this service account.
Corresponds to the JSON property serviceAccount
14181 14182 14183 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14181 def service_account @service_account end |
#shared_resources ⇒ String
The resource name of the shared DeploymentResourcePool to deploy on. Format:
projects/project/locations/location/deploymentResourcePools/
deployment_resource_pool`
Corresponds to the JSON propertysharedResources`
14188 14189 14190 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14188 def shared_resources @shared_resources end |
#speculative_decoding_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SpeculativeDecodingSpec
Configuration for Speculative Decoding.
Corresponds to the JSON property speculativeDecodingSpec
14193 14194 14195 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14193 def speculative_decoding_spec @speculative_decoding_spec end |
#status ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModelStatus
Runtime status of the deployed model.
Corresponds to the JSON property status
14198 14199 14200 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14198 def status @status end |
#system_labels ⇒ Hash<String,String>
System labels to apply to Model Garden deployments. System labels are managed
by Google for internal use only.
Corresponds to the JSON property systemLabels
14204 14205 14206 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14204 def system_labels @system_labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 14230 14231 14232 14233 14234 14235 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14211 def update!(**args) @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources) @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources) @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging) @disable_explanations = args[:disable_explanations] if args.key?(:disable_explanations) @display_name = args[:display_name] if args.key?(:display_name) @enable_access_logging = args[:enable_access_logging] if args.key?(:enable_access_logging) @enable_container_logging = args[:enable_container_logging] if args.key?(:enable_container_logging) @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec) @faster_deployment_config = args[:faster_deployment_config] if args.key?(:faster_deployment_config) @full_fine_tuned_resources = args[:full_fine_tuned_resources] if args.key?(:full_fine_tuned_resources) @gdc_connected_model = args[:gdc_connected_model] if args.key?(:gdc_connected_model) @id = args[:id] if args.key?(:id) @model = args[:model] if args.key?(:model) @model_version_id = args[:model_version_id] if args.key?(:model_version_id) @private_endpoints = args[:private_endpoints] if args.key?(:private_endpoints) @rollout_options = args[:rollout_options] if args.key?(:rollout_options) @service_account = args[:service_account] if args.key?(:service_account) @shared_resources = args[:shared_resources] if args.key?(:shared_resources) @speculative_decoding_spec = args[:speculative_decoding_spec] if args.key?(:speculative_decoding_spec) @status = args[:status] if args.key?(:status) @system_labels = args[:system_labels] if args.key?(:system_labels) end |