Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A deployment of a Model. Endpoints contain one or more DeployedModels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployedModel

Returns a new instance of GoogleCloudAiplatformV1beta1DeployedModel.



13729
13730
13731
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automatic_resourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AutomaticResources

A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines. Corresponds to the JSON property automaticResources



13582
13583
13584
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13582

def automatic_resources
  @automatic_resources
end

#checkpoint_idString

The checkpoint id of the model. Corresponds to the JSON property checkpointId

Returns:

  • (String)


13587
13588
13589
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13587

def checkpoint_id
  @checkpoint_id
end

#create_timeString

Output only. Timestamp when the DeployedModel was created. Corresponds to the JSON property createTime

Returns:

  • (String)


13592
13593
13594
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13592

def create_time
  @create_time
end

#dedicated_resourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DedicatedResources

A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



13598
13599
13600
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13598

def dedicated_resources
  @dedicated_resources
end

#disable_container_loggingBoolean Also known as: disable_container_logging?

For custom-trained Models and AutoML Tabular Models, the container of the DeployedModel instances will send stderr and stdout streams to Cloud Logging by default. Please note that the logs incur cost, which are subject to Cloud Logging pricing. User can disable container logging by setting this flag to true. Corresponds to the JSON property disableContainerLogging

Returns:

  • (Boolean)


13607
13608
13609
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13607

def disable_container_logging
  @disable_container_logging
end

#disable_explanationsBoolean Also known as: disable_explanations?

If true, deploy the model without explainable feature, regardless the existence of Model.explanation_spec or explanation_spec. Corresponds to the JSON property disableExplanations

Returns:

  • (Boolean)


13614
13615
13616
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13614

def disable_explanations
  @disable_explanations
end

#display_nameString

The display name of the DeployedModel. If not provided upon creation, the Model's display_name is used. Corresponds to the JSON property displayName

Returns:

  • (String)


13621
13622
13623
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13621

def display_name
  @display_name
end

#enable_access_loggingBoolean Also known as: enable_access_logging?

If true, online prediction access logs are sent to Cloud Logging. These logs are like standard server access logs, containing information like timestamp and latency for each prediction request. Note that logs may incur a cost, especially if your project receives prediction requests at a high queries per second rate (QPS). Estimate your costs before enabling this option. Corresponds to the JSON property enableAccessLogging

Returns:

  • (Boolean)


13630
13631
13632
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13630

def enable_access_logging
  @enable_access_logging
end

#enable_container_loggingBoolean Also known as: enable_container_logging?

If true, the container of the DeployedModel instances will send stderr and stdout streams to Cloud Logging. Only supported for custom-trained Models and AutoML Tabular Models. Corresponds to the JSON property enableContainerLogging

Returns:

  • (Boolean)


13638
13639
13640
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13638

def enable_container_logging
  @enable_container_logging
end

#explanation_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpec

Specification of Model explanation. Corresponds to the JSON property explanationSpec



13644
13645
13646
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13644

def explanation_spec
  @explanation_spec
end

#faster_deployment_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FasterDeploymentConfig

Configuration for faster model deployment. Corresponds to the JSON property fasterDeploymentConfig



13649
13650
13651
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13649

def faster_deployment_config
  @faster_deployment_config
end

#full_fine_tuned_resourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FullFineTunedResources

Resources for an fft model. Corresponds to the JSON property fullFineTunedResources



13654
13655
13656
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13654

def full_fine_tuned_resources
  @full_fine_tuned_resources
end

#gdc_connected_modelString

GDC pretrained / Gemini model name. The model name is a plain model name, e.g. gemini-1.5-flash-002. Corresponds to the JSON property gdcConnectedModel

Returns:

  • (String)


13660
13661
13662
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13660

def gdc_connected_model
  @gdc_connected_model
end

#idString

Immutable. The ID of the DeployedModel. If not provided upon deployment, Vertex AI will generate a value for this ID. This value should be 1-10 characters, and valid characters are /[0-9]/. Corresponds to the JSON property id

Returns:

  • (String)


13667
13668
13669
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13667

def id
  @id
end

#modelString

The resource name of the Model that this is the deployment of. Note that the Model may be in a different location than the DeployedModel's Endpoint. The resource name may contain version id or version alias to specify the version. Example: projects/project/locations/location/models/model@2 or projects/project/locations/location/models/model@golden if no version is specified, the default version will be deployed. Corresponds to the JSON property model

Returns:

  • (String)


13677
13678
13679
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13677

def model
  @model
end

#model_version_idString

Output only. The version ID of the model that is deployed. Corresponds to the JSON property modelVersionId

Returns:

  • (String)


13682
13683
13684
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13682

def model_version_id
  @model_version_id
end

#private_endpointsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateEndpoints

PrivateEndpoints proto is used to provide paths for users to send requests privately. To send request via private service access, use predict_http_uri, explain_http_uri or health_http_uri. To send request via private service connect, use service_attachment. Corresponds to the JSON property privateEndpoints



13690
13691
13692
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13690

def private_endpoints
  @private_endpoints
end

#rollout_optionsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RolloutOptions

Configuration for rolling deployments. Corresponds to the JSON property rolloutOptions



13695
13696
13697
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13695

def rollout_options
  @rollout_options
end

#service_accountString

The service account that the DeployedModel's container runs as. Specify the email address of the service account. If this service account is not specified, the container runs as a service account that doesn't have access to the resource project. Users deploying the Model must have the iam.serviceAccounts. actAs permission on this service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


13704
13705
13706
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13704

def 
  @service_account
end

#shared_resourcesString

The resource name of the shared DeploymentResourcePool to deploy on. Format: projects/project/locations/location/deploymentResourcePools/ deployment_resource_pool` Corresponds to the JSON propertysharedResources`

Returns:

  • (String)


13711
13712
13713
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13711

def shared_resources
  @shared_resources
end

#speculative_decoding_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SpeculativeDecodingSpec

Configuration for Speculative Decoding. Corresponds to the JSON property speculativeDecodingSpec



13716
13717
13718
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13716

def speculative_decoding_spec
  @speculative_decoding_spec
end

#statusGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModelStatus

Runtime status of the deployed model. Corresponds to the JSON property status



13721
13722
13723
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13721

def status
  @status
end

#system_labelsHash<String,String>

System labels to apply to Model Garden deployments. System labels are managed by Google for internal use only. Corresponds to the JSON property systemLabels

Returns:

  • (Hash<String,String>)


13727
13728
13729
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13727

def system_labels
  @system_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13734
13735
13736
13737
13738
13739
13740
13741
13742
13743
13744
13745
13746
13747
13748
13749
13750
13751
13752
13753
13754
13755
13756
13757
13758
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13734

def update!(**args)
  @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging)
  @disable_explanations = args[:disable_explanations] if args.key?(:disable_explanations)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_access_logging = args[:enable_access_logging] if args.key?(:enable_access_logging)
  @enable_container_logging = args[:enable_container_logging] if args.key?(:enable_container_logging)
  @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec)
  @faster_deployment_config = args[:faster_deployment_config] if args.key?(:faster_deployment_config)
  @full_fine_tuned_resources = args[:full_fine_tuned_resources] if args.key?(:full_fine_tuned_resources)
  @gdc_connected_model = args[:gdc_connected_model] if args.key?(:gdc_connected_model)
  @id = args[:id] if args.key?(:id)
  @model = args[:model] if args.key?(:model)
  @model_version_id = args[:model_version_id] if args.key?(:model_version_id)
  @private_endpoints = args[:private_endpoints] if args.key?(:private_endpoints)
  @rollout_options = args[:rollout_options] if args.key?(:rollout_options)
  @service_account = args[:service_account] if args.key?(:service_account)
  @shared_resources = args[:shared_resources] if args.key?(:shared_resources)
  @speculative_decoding_spec = args[:speculative_decoding_spec] if args.key?(:speculative_decoding_spec)
  @status = args[:status] if args.key?(:status)
  @system_labels = args[:system_labels] if args.key?(:system_labels)
end