Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModelStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Runtime status of the deployed model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployedModelStatus

Returns a new instance of GoogleCloudAiplatformV1beta1DeployedModelStatus.



15228
15229
15230
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_replica_countFixnum

Output only. The number of available replicas of the deployed model. Corresponds to the JSON property availableReplicaCount

Returns:

  • (Fixnum)


15216
15217
15218
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15216

def available_replica_count
  @available_replica_count
end

#last_update_timeString

Output only. The time at which the status was last updated. Corresponds to the JSON property lastUpdateTime

Returns:

  • (String)


15221
15222
15223
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15221

def last_update_time
  @last_update_time
end

#messageString

Output only. The latest deployed model's status message (if any). Corresponds to the JSON property message

Returns:

  • (String)


15226
15227
15228
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15226

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15233
15234
15235
15236
15237
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15233

def update!(**args)
  @available_replica_count = args[:available_replica_count] if args.key?(:available_replica_count)
  @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
  @message = args[:message] if args.key?(:message)
end