Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModelStatus
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModelStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Runtime status of the deployed model.
Instance Attribute Summary collapse
-
#available_replica_count ⇒ Fixnum
Output only.
-
#last_update_time ⇒ String
Output only.
-
#message ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployedModelStatus
constructor
A new instance of GoogleCloudAiplatformV1beta1DeployedModelStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DeployedModelStatus
Returns a new instance of GoogleCloudAiplatformV1beta1DeployedModelStatus.
9026 9027 9028 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_replica_count ⇒ Fixnum
Output only. The number of available replicas of the deployed model.
Corresponds to the JSON property availableReplicaCount
9014 9015 9016 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9014 def available_replica_count @available_replica_count end |
#last_update_time ⇒ String
Output only. The time at which the status was last updated.
Corresponds to the JSON property lastUpdateTime
9019 9020 9021 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9019 def last_update_time @last_update_time end |
#message ⇒ String
Output only. The latest deployed model's status message (if any).
Corresponds to the JSON property message
9024 9025 9026 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9024 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9031 9032 9033 9034 9035 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9031 def update!(**args) @available_replica_count = args[:available_replica_count] if args.key?(:available_replica_count) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @message = args[:message] if args.key?(:message) end |