Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DistillationSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DistillationSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Tuning Spec for Distillation.
Instance Attribute Summary collapse
-
#base_teacher_model ⇒ String
The base teacher model that is being distilled.
-
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DistillationHyperParameters
Hyperparameters for Distillation.
-
#pipeline_root_directory ⇒ String
Deprecated.
-
#prompt_dataset_uri ⇒ String
Optional.
-
#student_model ⇒ String
The student model that is being tuned, e.g., "google/gemma-2b-1.1-it".
-
#training_dataset_uri ⇒ String
Deprecated.
-
#tuned_teacher_model_source ⇒ String
The resource name of the Tuned teacher model.
-
#tuning_mode ⇒ String
Optional.
-
#validation_dataset_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DistillationSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1DistillationSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DistillationSpec
Returns a new instance of GoogleCloudAiplatformV1beta1DistillationSpec.
15637 15638 15639 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_teacher_model ⇒ String
The base teacher model that is being distilled. See Supported models.
Corresponds to the JSON property baseTeacherModel
15587 15588 15589 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15587 def base_teacher_model @base_teacher_model end |
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DistillationHyperParameters
Hyperparameters for Distillation.
Corresponds to the JSON property hyperParameters
15592 15593 15594 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15592 def hyper_parameters @hyper_parameters end |
#pipeline_root_directory ⇒ String
Deprecated. A path in a Cloud Storage bucket, which will be treated as the
root output directory of the distillation pipeline. It is used by the system
to generate the paths of output artifacts.
Corresponds to the JSON property pipelineRootDirectory
15599 15600 15601 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15599 def pipeline_root_directory @pipeline_root_directory end |
#prompt_dataset_uri ⇒ String
Optional. Cloud Storage path to file containing prompt dataset for
distillation. The dataset must be formatted as a JSONL file.
Corresponds to the JSON property promptDatasetUri
15605 15606 15607 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15605 def prompt_dataset_uri @prompt_dataset_uri end |
#student_model ⇒ String
The student model that is being tuned, e.g., "google/gemma-2b-1.1-it".
Deprecated. Use base_model instead.
Corresponds to the JSON property studentModel
15611 15612 15613 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15611 def student_model @student_model end |
#training_dataset_uri ⇒ String
Deprecated. Cloud Storage path to file containing training dataset for tuning.
The dataset must be formatted as a JSONL file.
Corresponds to the JSON property trainingDatasetUri
15617 15618 15619 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15617 def training_dataset_uri @training_dataset_uri end |
#tuned_teacher_model_source ⇒ String
The resource name of the Tuned teacher model. Format: projects/project/
locations/location/models/model`.
Corresponds to the JSON propertytunedTeacherModelSource`
15623 15624 15625 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15623 def tuned_teacher_model_source @tuned_teacher_model_source end |
#tuning_mode ⇒ String
Optional. Specifies the tuning mode for distillation (sft part). This feature
is only available for open source models.
Corresponds to the JSON property tuningMode
15629 15630 15631 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15629 def tuning_mode @tuning_mode end |
#validation_dataset_uri ⇒ String
Optional. Cloud Storage path to file containing validation dataset for tuning.
The dataset must be formatted as a JSONL file.
Corresponds to the JSON property validationDatasetUri
15635 15636 15637 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15635 def validation_dataset_uri @validation_dataset_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15642 15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15642 def update!(**args) @base_teacher_model = args[:base_teacher_model] if args.key?(:base_teacher_model) @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters) @pipeline_root_directory = args[:pipeline_root_directory] if args.key?(:pipeline_root_directory) @prompt_dataset_uri = args[:prompt_dataset_uri] if args.key?(:prompt_dataset_uri) @student_model = args[:student_model] if args.key?(:student_model) @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri) @tuned_teacher_model_source = args[:tuned_teacher_model_source] if args.key?(:tuned_teacher_model_source) @tuning_mode = args[:tuning_mode] if args.key?(:tuning_mode) @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri) end |