Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DistillationSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Tuning Spec for Distillation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DistillationSpec

Returns a new instance of GoogleCloudAiplatformV1beta1DistillationSpec.



9408
9409
9410
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_teacher_modelString

The base teacher model that is being distilled. See Supported models. Corresponds to the JSON property baseTeacherModel

Returns:

  • (String)


9358
9359
9360
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9358

def base_teacher_model
  @base_teacher_model
end

#hyper_parametersGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DistillationHyperParameters

Hyperparameters for Distillation. Corresponds to the JSON property hyperParameters



9363
9364
9365
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9363

def hyper_parameters
  @hyper_parameters
end

#pipeline_root_directoryString

Deprecated. A path in a Cloud Storage bucket, which will be treated as the root output directory of the distillation pipeline. It is used by the system to generate the paths of output artifacts. Corresponds to the JSON property pipelineRootDirectory

Returns:

  • (String)


9370
9371
9372
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9370

def pipeline_root_directory
  @pipeline_root_directory
end

#prompt_dataset_uriString

Optional. Cloud Storage path to file containing prompt dataset for distillation. The dataset must be formatted as a JSONL file. Corresponds to the JSON property promptDatasetUri

Returns:

  • (String)


9376
9377
9378
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9376

def prompt_dataset_uri
  @prompt_dataset_uri
end

#student_modelString

The student model that is being tuned, e.g., "google/gemma-2b-1.1-it". Deprecated. Use base_model instead. Corresponds to the JSON property studentModel

Returns:

  • (String)


9382
9383
9384
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9382

def student_model
  @student_model
end

#training_dataset_uriString

Deprecated. Cloud Storage path to file containing training dataset for tuning. The dataset must be formatted as a JSONL file. Corresponds to the JSON property trainingDatasetUri

Returns:

  • (String)


9388
9389
9390
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9388

def training_dataset_uri
  @training_dataset_uri
end

#tuned_teacher_model_sourceString

The resource name of the Tuned teacher model. Format: projects/project/ locations/location/models/model`. Corresponds to the JSON propertytunedTeacherModelSource`

Returns:

  • (String)


9394
9395
9396
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9394

def tuned_teacher_model_source
  @tuned_teacher_model_source
end

#tuning_modeString

Optional. Specifies the tuning mode for distillation (sft part). This feature is only available for open source models. Corresponds to the JSON property tuningMode

Returns:

  • (String)


9400
9401
9402
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9400

def tuning_mode
  @tuning_mode
end

#validation_dataset_uriString

Optional. Cloud Storage path to file containing validation dataset for tuning. The dataset must be formatted as a JSONL file. Corresponds to the JSON property validationDatasetUri

Returns:

  • (String)


9406
9407
9408
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9406

def validation_dataset_uri
  @validation_dataset_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9413
9414
9415
9416
9417
9418
9419
9420
9421
9422
9423
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9413

def update!(**args)
  @base_teacher_model = args[:base_teacher_model] if args.key?(:base_teacher_model)
  @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters)
  @pipeline_root_directory = args[:pipeline_root_directory] if args.key?(:pipeline_root_directory)
  @prompt_dataset_uri = args[:prompt_dataset_uri] if args.key?(:prompt_dataset_uri)
  @student_model = args[:student_model] if args.key?(:student_model)
  @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri)
  @tuned_teacher_model_source = args[:tuned_teacher_model_source] if args.key?(:tuned_teacher_model_source)
  @tuning_mode = args[:tuning_mode] if args.key?(:tuning_mode)
  @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri)
end