Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DnsPeeringConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

DNS peering configuration. These configurations are used to create DNS peering zones in the Vertex tenant project VPC, enabling resolution of records within the specified domain hosted in the target network's Cloud DNS.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DnsPeeringConfig

Returns a new instance of GoogleCloudAiplatformV1beta1DnsPeeringConfig.



17274
17275
17276
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

Required. The DNS name suffix of the zone being peered to, e.g., "my-internal- domain.corp.". Must end with a dot. Corresponds to the JSON property domain

Returns:

  • (String)


17259
17260
17261
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17259

def domain
  @domain
end

#target_networkString

Required. The VPC network name in the target_project where the DNS zone specified by 'domain' is visible. Corresponds to the JSON property targetNetwork

Returns:

  • (String)


17265
17266
17267
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17265

def target_network
  @target_network
end

#target_projectString

Required. The project ID hosting the Cloud DNS managed zone that contains the ' domain'. The Vertex AI Service Agent requires the dns.peer role on this project. Corresponds to the JSON property targetProject

Returns:

  • (String)


17272
17273
17274
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17272

def target_project
  @target_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17279
17280
17281
17282
17283
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17279

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @target_network = args[:target_network] if args.key?(:target_network)
  @target_project = args[:target_project] if args.key?(:target_project)
end