Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DnsPeeringConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DnsPeeringConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
DNS peering configuration. These configurations are used to create DNS peering zones in the Vertex tenant project VPC, enabling resolution of records within the specified domain hosted in the target network's Cloud DNS.
Instance Attribute Summary collapse
-
#domain ⇒ String
Required.
-
#target_network ⇒ String
Required.
-
#target_project ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DnsPeeringConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1DnsPeeringConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DnsPeeringConfig
Returns a new instance of GoogleCloudAiplatformV1beta1DnsPeeringConfig.
17274 17275 17276 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17274 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
Required. The DNS name suffix of the zone being peered to, e.g., "my-internal-
domain.corp.". Must end with a dot.
Corresponds to the JSON property domain
17259 17260 17261 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17259 def domain @domain end |
#target_network ⇒ String
Required. The VPC network name in the target_project where the DNS zone
specified by 'domain' is visible.
Corresponds to the JSON property targetNetwork
17265 17266 17267 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17265 def target_network @target_network end |
#target_project ⇒ String
Required. The project ID hosting the Cloud DNS managed zone that contains the '
domain'. The Vertex AI Service Agent requires the dns.peer role on this
project.
Corresponds to the JSON property targetProject
17272 17273 17274 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17272 def target_project @target_project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17279 17280 17281 17282 17283 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17279 def update!(**args) @domain = args[:domain] if args.key?(:domain) @target_network = args[:target_network] if args.key?(:target_network) @target_project = args[:target_project] if args.key?(:target_project) end |