Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DynamicRetrievalConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Describes the options to customize dynamic retrieval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DynamicRetrievalConfig

Returns a new instance of GoogleCloudAiplatformV1beta1DynamicRetrievalConfig.



16930
16931
16932
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16930

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dynamic_thresholdFloat

Optional. The threshold to be used in dynamic retrieval. If not set, a system default value is used. Corresponds to the JSON property dynamicThreshold

Returns:

  • (Float)


16923
16924
16925
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16923

def dynamic_threshold
  @dynamic_threshold
end

#modeString

The mode of the predictor to be used in dynamic retrieval. Corresponds to the JSON property mode

Returns:

  • (String)


16928
16929
16930
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16928

def mode
  @mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16935
16936
16937
16938
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16935

def update!(**args)
  @dynamic_threshold = args[:dynamic_threshold] if args.key?(:dynamic_threshold)
  @mode = args[:mode] if args.key?(:mode)
end