Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DynamicRetrievalConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Describes the options to customize dynamic retrieval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DynamicRetrievalConfig

Returns a new instance of GoogleCloudAiplatformV1beta1DynamicRetrievalConfig.



15548
15549
15550
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15548

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dynamic_thresholdFloat

Optional. The threshold to be used in dynamic retrieval. If not set, a system default value is used. Corresponds to the JSON property dynamicThreshold

Returns:

  • (Float)


15541
15542
15543
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15541

def dynamic_threshold
  @dynamic_threshold
end

#modeString

The mode of the predictor to be used in dynamic retrieval. Corresponds to the JSON property mode

Returns:

  • (String)


15546
15547
15548
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15546

def mode
  @mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15553
15554
15555
15556
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15553

def update!(**args)
  @dynamic_threshold = args[:dynamic_threshold] if args.key?(:dynamic_threshold)
  @mode = args[:mode] if args.key?(:mode)
end