Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DynamicRetrievalConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DynamicRetrievalConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Describes the options to customize dynamic retrieval.
Instance Attribute Summary collapse
-
#dynamic_threshold ⇒ Float
Optional.
-
#mode ⇒ String
The mode of the predictor to be used in dynamic retrieval.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DynamicRetrievalConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1DynamicRetrievalConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1DynamicRetrievalConfig
Returns a new instance of GoogleCloudAiplatformV1beta1DynamicRetrievalConfig.
9431 9432 9433 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9431 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dynamic_threshold ⇒ Float
Optional. The threshold to be used in dynamic retrieval. If not set, a system
default value is used.
Corresponds to the JSON property dynamicThreshold
9424 9425 9426 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9424 def dynamic_threshold @dynamic_threshold end |
#mode ⇒ String
The mode of the predictor to be used in dynamic retrieval.
Corresponds to the JSON property mode
9429 9430 9431 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9429 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9436 9437 9438 9439 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9436 def update!(**args) @dynamic_threshold = args[:dynamic_threshold] if args.key?(:dynamic_threshold) @mode = args[:mode] if args.key?(:mode) end |