Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for PredictionService.EmbedContent.
Instance Attribute Summary collapse
-
#auto_truncate ⇒ Boolean
(also: #auto_truncate?)
Optional.
-
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message.
-
#embed_content_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentRequestEmbedContentConfig
Configurations for the EmbedContent API.
-
#output_dimensionality ⇒ Fixnum
Optional.
-
#task_type ⇒ String
Optional.
-
#title ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EmbedContentRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1EmbedContentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EmbedContentRequest
Returns a new instance of GoogleCloudAiplatformV1beta1EmbedContentRequest.
15602 15603 15604 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_truncate ⇒ Boolean Also known as: auto_truncate?
Optional. Deprecated: Please use EmbedContentConfig.auto_truncate instead.
Whether to silently truncate the input content if it's longer than the maximum
sequence length.
Corresponds to the JSON property autoTruncate
15568 15569 15570 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15568 def auto_truncate @auto_truncate end |
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
15576 15577 15578 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15576 def content @content end |
#embed_content_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentRequestEmbedContentConfig
Configurations for the EmbedContent API.
Corresponds to the JSON property embedContentConfig
15581 15582 15583 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15581 def @embed_content_config end |
#output_dimensionality ⇒ Fixnum
Optional. Deprecated: Please use EmbedContentConfig.output_dimensionality
instead. Reduced dimension for the output embedding. If set, excessive values
in the output embedding are truncated from the end.
Corresponds to the JSON property outputDimensionality
15588 15589 15590 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15588 def output_dimensionality @output_dimensionality end |
#task_type ⇒ String
Optional. Deprecated: Please use EmbedContentConfig.task_type instead. The
task type of the embedding.
Corresponds to the JSON property taskType
15594 15595 15596 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15594 def task_type @task_type end |
#title ⇒ String
Optional. Deprecated: Please use EmbedContentConfig.title instead. The title
for the text.
Corresponds to the JSON property title
15600 15601 15602 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15600 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15607 15608 15609 15610 15611 15612 15613 15614 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15607 def update!(**args) @auto_truncate = args[:auto_truncate] if args.key?(:auto_truncate) @content = args[:content] if args.key?(:content) @embed_content_config = args[:embed_content_config] if args.key?(:embed_content_config) @output_dimensionality = args[:output_dimensionality] if args.key?(:output_dimensionality) @task_type = args[:task_type] if args.key?(:task_type) @title = args[:title] if args.key?(:title) end |