Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentRequestEmbedContentConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentRequestEmbedContentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configurations for the EmbedContent API.
Instance Attribute Summary collapse
-
#audio_track_extraction ⇒ Boolean
(also: #audio_track_extraction?)
Optional.
-
#auto_truncate ⇒ Boolean
(also: #auto_truncate?)
Optional.
-
#document_ocr ⇒ Boolean
(also: #document_ocr?)
Optional.
-
#output_dimensionality ⇒ Fixnum
Optional.
-
#task_type ⇒ String
Optional.
-
#title ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EmbedContentRequestEmbedContentConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1EmbedContentRequestEmbedContentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EmbedContentRequestEmbedContentConfig
Returns a new instance of GoogleCloudAiplatformV1beta1EmbedContentRequestEmbedContentConfig.
9541 9542 9543 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9541 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_track_extraction ⇒ Boolean Also known as: audio_track_extraction?
Optional. Whether to extract audio from video content.
Corresponds to the JSON property audioTrackExtraction
9507 9508 9509 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9507 def audio_track_extraction @audio_track_extraction end |
#auto_truncate ⇒ Boolean Also known as: auto_truncate?
Optional. Whether to silently truncate the input content if it's longer than
the maximum sequence length. Only applicable to text-only embedding models.
Corresponds to the JSON property autoTruncate
9514 9515 9516 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9514 def auto_truncate @auto_truncate end |
#document_ocr ⇒ Boolean Also known as: document_ocr?
Optional. Whether to enable OCR for document content.
Corresponds to the JSON property documentOcr
9520 9521 9522 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9520 def document_ocr @document_ocr end |
#output_dimensionality ⇒ Fixnum
Optional. Reduced dimension for the output embedding. If set, excessive values
in the output embedding are truncated from the end.
Corresponds to the JSON property outputDimensionality
9527 9528 9529 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9527 def output_dimensionality @output_dimensionality end |
#task_type ⇒ String
Optional. The task type of the embedding. Only applicable to text-only
embedding models.
Corresponds to the JSON property taskType
9533 9534 9535 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9533 def task_type @task_type end |
#title ⇒ String
Optional. The title for the text. Only applicable to text-only embedding
models.
Corresponds to the JSON property title
9539 9540 9541 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9539 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9546 9547 9548 9549 9550 9551 9552 9553 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9546 def update!(**args) @audio_track_extraction = args[:audio_track_extraction] if args.key?(:audio_track_extraction) @auto_truncate = args[:auto_truncate] if args.key?(:auto_truncate) @document_ocr = args[:document_ocr] if args.key?(:document_ocr) @output_dimensionality = args[:output_dimensionality] if args.key?(:output_dimensionality) @task_type = args[:task_type] if args.key?(:task_type) @title = args[:title] if args.key?(:title) end |