Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for PredictionService.EmbedContent.
Instance Attribute Summary collapse
-
#embedding ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentResponseEmbedding
A list of floats representing an embedding.
-
#truncated ⇒ Boolean
(also: #truncated?)
Whether the input content was truncated before generating the embedding.
-
#usage_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UsageMetadata
Usage metadata about the content generation request and response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EmbedContentResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1EmbedContentResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EmbedContentResponse
Returns a new instance of GoogleCloudAiplatformV1beta1EmbedContentResponse.
16163 16164 16165 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16163 def initialize(**args) update!(**args) end |
Instance Attribute Details
#embedding ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentResponseEmbedding
A list of floats representing an embedding.
Corresponds to the JSON property embedding
16149 16150 16151 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16149 def @embedding end |
#truncated ⇒ Boolean Also known as: truncated?
Whether the input content was truncated before generating the embedding.
Corresponds to the JSON property truncated
16154 16155 16156 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16154 def truncated @truncated end |
#usage_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UsageMetadata
Usage metadata about the content generation request and response. This message
provides a detailed breakdown of token usage and other relevant metrics.
Corresponds to the JSON property usageMetadata
16161 16162 16163 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16161 def @usage_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16168 16169 16170 16171 16172 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16168 def update!(**args) @embedding = args[:embedding] if args.key?(:embedding) @truncated = args[:truncated] if args.key?(:truncated) @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata) end |