Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for PredictionService.EmbedContent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EmbedContentResponse

Returns a new instance of GoogleCloudAiplatformV1beta1EmbedContentResponse.



14428
14429
14430
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#embeddingGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentResponseEmbedding

A list of floats representing an embedding. Corresponds to the JSON property embedding



14414
14415
14416
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14414

def embedding
  @embedding
end

#truncatedBoolean Also known as: truncated?

Whether the input content was truncated before generating the embedding. Corresponds to the JSON property truncated

Returns:

  • (Boolean)


14419
14420
14421
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14419

def truncated
  @truncated
end

#usage_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UsageMetadata

Usage metadata about the content generation request and response. This message provides a detailed breakdown of token usage and other relevant metrics. Corresponds to the JSON property usageMetadata



14426
14427
14428
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14426

def 
  @usage_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14433
14434
14435
14436
14437
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14433

def update!(**args)
  @embedding = args[:embedding] if args.key?(:embedding)
  @truncated = args[:truncated] if args.key?(:truncated)
  @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata)
end