Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for PredictionService.EmbedContent.
Instance Attribute Summary collapse
-
#embedding ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentResponseEmbedding
A list of floats representing an embedding.
-
#truncated ⇒ Boolean
(also: #truncated?)
Whether the input content was truncated before generating the embedding.
-
#usage_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UsageMetadata
Usage metadata about the content generation request and response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EmbedContentResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1EmbedContentResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EmbedContentResponse
Returns a new instance of GoogleCloudAiplatformV1beta1EmbedContentResponse.
9643 9644 9645 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9643 def initialize(**args) update!(**args) end |
Instance Attribute Details
#embedding ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EmbedContentResponseEmbedding
A list of floats representing an embedding.
Corresponds to the JSON property embedding
9629 9630 9631 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9629 def @embedding end |
#truncated ⇒ Boolean Also known as: truncated?
Whether the input content was truncated before generating the embedding.
Corresponds to the JSON property truncated
9634 9635 9636 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9634 def truncated @truncated end |
#usage_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UsageMetadata
Usage metadata about the content generation request and response. This message
provides a detailed breakdown of token usage and other relevant metrics.
Corresponds to the JSON property usageMetadata
9641 9642 9643 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9641 def @usage_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9648 9649 9650 9651 9652 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9648 def update!(**args) @embedding = args[:embedding] if args.key?(:embedding) @truncated = args[:truncated] if args.key?(:truncated) @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata) end |