Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EncryptionSpec

Returns a new instance of GoogleCloudAiplatformV1beta1EncryptionSpec.



16267
16268
16269
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16267

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_key_nameString

Required. Resource name of the Cloud KMS key used to protect the resource. The Cloud KMS key must be in the same region as the resource. It must have the format projects/project/locations/location/keyRings/key_ring/cryptoKeys/ crypto_key`. Corresponds to the JSON propertykmsKeyName`

Returns:

  • (String)


16265
16266
16267
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16265

def kms_key_name
  @kms_key_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16272
16273
16274
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16272

def update!(**args)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
end