Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Endpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Endpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Models are deployed into it, and afterwards Endpoint is called to obtain predictions and explanations.
Instance Attribute Summary collapse
-
#client_connection_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ClientConnectionConfig
Configurations (e.g. inference timeout) that are applied on your endpoints.
-
#create_time ⇒ String
Output only.
-
#dedicated_endpoint_dns ⇒ String
Output only.
-
#dedicated_endpoint_enabled ⇒ Boolean
(also: #dedicated_endpoint_enabled?)
If true, the endpoint will be exposed through a dedicated DNS [Endpoint. dedicated_endpoint_dns].
-
#deployed_models ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModel>
Output only.
-
#description ⇒ String
The description of the Endpoint.
-
#display_name ⇒ String
Required.
-
#enable_private_service_connect ⇒ Boolean
(also: #enable_private_service_connect?)
Deprecated: If true, expose the Endpoint via private service connect.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#gdc_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GdcConfig
Google Distributed Cloud (GDC) config.
-
#gen_ai_advanced_features_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenAiAdvancedFeaturesConfig
Configuration for GenAiAdvancedFeatures.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Endpoints.
-
#model_deployment_monitoring_job ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#network ⇒ String
Optional.
-
#predict_request_response_logging_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictRequestResponseLoggingConfig
Configuration for logging request-response to a BigQuery table.
-
#private_service_connect_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig
Represents configuration for private service connect.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#traffic_split ⇒ Hash<String,Fixnum>
A map from a DeployedModel's ID to the percentage of this Endpoint's traffic that should be forwarded to that DeployedModel.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Endpoint
constructor
A new instance of GoogleCloudAiplatformV1beta1Endpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Endpoint
Returns a new instance of GoogleCloudAiplatformV1beta1Endpoint.
9830 9831 9832 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_connection_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ClientConnectionConfig
Configurations (e.g. inference timeout) that are applied on your endpoints.
Corresponds to the JSON property clientConnectionConfig
9686 9687 9688 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9686 def client_connection_config @client_connection_config end |
#create_time ⇒ String
Output only. Timestamp when this Endpoint was created.
Corresponds to the JSON property createTime
9691 9692 9693 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9691 def create_time @create_time end |
#dedicated_endpoint_dns ⇒ String
Output only. DNS of the dedicated endpoint. Will only be populated if
dedicated_endpoint_enabled is true. Depending on the features enabled, uid
might be a random number or a string. For example, if fast_tryout is enabled,
uid will be fasttryout. Format: https://endpoint_id.region-uid.
prediction.vertexai.goog.
Corresponds to the JSON property dedicatedEndpointDns
9700 9701 9702 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9700 def dedicated_endpoint_dns @dedicated_endpoint_dns end |
#dedicated_endpoint_enabled ⇒ Boolean Also known as: dedicated_endpoint_enabled?
If true, the endpoint will be exposed through a dedicated DNS [Endpoint.
dedicated_endpoint_dns]. Your request to the dedicated DNS will be isolated
from other users' traffic and will have better performance and reliability.
Note: Once you enabled dedicated endpoint, you won't be able to send request
to the shared DNS region-aiplatform.googleapis.com. The limitation will be
removed soon.
Corresponds to the JSON property dedicatedEndpointEnabled
9710 9711 9712 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9710 def dedicated_endpoint_enabled @dedicated_endpoint_enabled end |
#deployed_models ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModel>
Output only. The models deployed in this Endpoint. To add or remove
DeployedModels use EndpointService.DeployModel and EndpointService.
UndeployModel respectively.
Corresponds to the JSON property deployedModels
9718 9719 9720 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9718 def deployed_models @deployed_models end |
#description ⇒ String
The description of the Endpoint.
Corresponds to the JSON property description
9723 9724 9725 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9723 def description @description end |
#display_name ⇒ String
Required. The display name of the Endpoint. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
9729 9730 9731 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9729 def display_name @display_name end |
#enable_private_service_connect ⇒ Boolean Also known as: enable_private_service_connect?
Deprecated: If true, expose the Endpoint via private service connect. Only one
of the fields, network or enable_private_service_connect, can be set.
Corresponds to the JSON property enablePrivateServiceConnect
9735 9736 9737 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9735 def enable_private_service_connect @enable_private_service_connect end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
9742 9743 9744 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9742 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
9748 9749 9750 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9748 def etag @etag end |
#gdc_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GdcConfig
Google Distributed Cloud (GDC) config.
Corresponds to the JSON property gdcConfig
9753 9754 9755 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9753 def gdc_config @gdc_config end |
#gen_ai_advanced_features_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenAiAdvancedFeaturesConfig
Configuration for GenAiAdvancedFeatures.
Corresponds to the JSON property genAiAdvancedFeaturesConfig
9758 9759 9760 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9758 def gen_ai_advanced_features_config @gen_ai_advanced_features_config end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Endpoints. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
9767 9768 9769 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9767 def labels @labels end |
#model_deployment_monitoring_job ⇒ String
Output only. Resource name of the Model Monitoring job associated with this
Endpoint if monitoring is enabled by JobService.
CreateModelDeploymentMonitoringJob. Format: projects/project/locations/
location/modelDeploymentMonitoringJobs/model_deployment_monitoring_job`
Corresponds to the JSON propertymodelDeploymentMonitoringJob`
9775 9776 9777 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9775 def model_deployment_monitoring_job @model_deployment_monitoring_job end |
#name ⇒ String
Identifier. The resource name of the Endpoint.
Corresponds to the JSON property name
9780 9781 9782 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9780 def name @name end |
#network ⇒ String
Optional. The full name of the Google Compute Engine network to which the
Endpoint should be peered. Private services access must already be configured
for the network. If left unspecified, the Endpoint is not peered with any
network. Only one of the fields, network or enable_private_service_connect,
can be set. Format: projects/project/global/networks/network. Where
projectis a project number, as in `12345`, andnetwork`is network name.
Corresponds to the JSON propertynetwork`
9792 9793 9794 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9792 def network @network end |
#predict_request_response_logging_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictRequestResponseLoggingConfig
Configuration for logging request-response to a BigQuery table.
Corresponds to the JSON property predictRequestResponseLoggingConfig
9797 9798 9799 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9797 def predict_request_response_logging_config @predict_request_response_logging_config end |
#private_service_connect_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig
Represents configuration for private service connect.
Corresponds to the JSON property privateServiceConnectConfig
9802 9803 9804 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9802 def private_service_connect_config @private_service_connect_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
9807 9808 9809 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9807 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
9813 9814 9815 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9813 def satisfies_pzs @satisfies_pzs end |
#traffic_split ⇒ Hash<String,Fixnum>
A map from a DeployedModel's ID to the percentage of this Endpoint's traffic
that should be forwarded to that DeployedModel. If a DeployedModel's ID is not
listed in this map, then it receives no traffic. The traffic percentage values
must add up to 100, or map must be empty if the Endpoint is to not accept any
traffic at a moment.
Corresponds to the JSON property trafficSplit
9823 9824 9825 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9823 def traffic_split @traffic_split end |
#update_time ⇒ String
Output only. Timestamp when this Endpoint was last updated.
Corresponds to the JSON property updateTime
9828 9829 9830 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9828 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9835 9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 9849 9850 9851 9852 9853 9854 9855 9856 9857 9858 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9835 def update!(**args) @client_connection_config = args[:client_connection_config] if args.key?(:client_connection_config) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_endpoint_dns = args[:dedicated_endpoint_dns] if args.key?(:dedicated_endpoint_dns) @dedicated_endpoint_enabled = args[:dedicated_endpoint_enabled] if args.key?(:dedicated_endpoint_enabled) @deployed_models = args[:deployed_models] if args.key?(:deployed_models) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @gdc_config = args[:gdc_config] if args.key?(:gdc_config) @gen_ai_advanced_features_config = args[:gen_ai_advanced_features_config] if args.key?(:gen_ai_advanced_features_config) @labels = args[:labels] if args.key?(:labels) @model_deployment_monitoring_job = args[:model_deployment_monitoring_job] if args.key?(:model_deployment_monitoring_job) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @predict_request_response_logging_config = args[:predict_request_response_logging_config] if args.key?(:predict_request_response_logging_config) @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @traffic_split = args[:traffic_split] if args.key?(:traffic_split) @update_time = args[:update_time] if args.key?(:update_time) end |