Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EnterpriseWebSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Tool to search public web data, powered by Vertex AI Search and Sec4 compliance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EnterpriseWebSearch

Returns a new instance of GoogleCloudAiplatformV1beta1EnterpriseWebSearch.



9944
9945
9946
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocking_confidenceString

Optional. Sites with confidence level chosen & above this value will be blocked from the search results. Corresponds to the JSON property blockingConfidence

Returns:

  • (String)


9936
9937
9938
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9936

def blocking_confidence
  @blocking_confidence
end

#exclude_domainsArray<String>

Optional. List of domains to be excluded from the search results. The default limit is 2000 domains. Corresponds to the JSON property excludeDomains

Returns:

  • (Array<String>)


9942
9943
9944
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9942

def exclude_domains
  @exclude_domains
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9949
9950
9951
9952
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9949

def update!(**args)
  @blocking_confidence = args[:blocking_confidence] if args.key?(:blocking_confidence)
  @exclude_domains = args[:exclude_domains] if args.key?(:exclude_domains)
end