Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EnterpriseWebSearch
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EnterpriseWebSearch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Tool to search public web data, powered by Vertex AI Search and Sec4 compliance.
Instance Attribute Summary collapse
-
#blocking_confidence ⇒ String
Optional.
-
#exclude_domains ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EnterpriseWebSearch
constructor
A new instance of GoogleCloudAiplatformV1beta1EnterpriseWebSearch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EnterpriseWebSearch
Returns a new instance of GoogleCloudAiplatformV1beta1EnterpriseWebSearch.
9878 9879 9880 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9878 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocking_confidence ⇒ String
Optional. Sites with confidence level chosen & above this value will be
blocked from the search results.
Corresponds to the JSON property blockingConfidence
9870 9871 9872 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9870 def blocking_confidence @blocking_confidence end |
#exclude_domains ⇒ Array<String>
Optional. List of domains to be excluded from the search results. The default
limit is 2000 domains.
Corresponds to the JSON property excludeDomains
9876 9877 9878 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9876 def exclude_domains @exclude_domains end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9883 9884 9885 9886 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 9883 def update!(**args) @blocking_confidence = args[:blocking_confidence] if args.key?(:blocking_confidence) @exclude_domains = args[:exclude_domains] if args.key?(:exclude_domains) end |