Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Model error analysis for each annotation.
Instance Attribute Summary collapse
-
#attributed_items ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotationAttributedItem>
Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type.
-
#outlier_score ⇒ Float
The outlier score of this annotated item.
-
#outlier_threshold ⇒ Float
The threshold used to determine if this annotation is an outlier or not.
-
#query_type ⇒ String
The query type used for finding the attributed items.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation
constructor
A new instance of GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation
Returns a new instance of GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation.
16372 16373 16374 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16372 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributed_items ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotationAttributedItem>
Attributed items for a given annotation, typically representing neighbors from
the training sets constrained by the query type.
Corresponds to the JSON property attributedItems
16354 16355 16356 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16354 def attributed_items @attributed_items end |
#outlier_score ⇒ Float
The outlier score of this annotated item. Usually defined as the min of all
distances from attributed items.
Corresponds to the JSON property outlierScore
16360 16361 16362 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16360 def outlier_score @outlier_score end |
#outlier_threshold ⇒ Float
The threshold used to determine if this annotation is an outlier or not.
Corresponds to the JSON property outlierThreshold
16365 16366 16367 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16365 def outlier_threshold @outlier_threshold end |
#query_type ⇒ String
The query type used for finding the attributed items.
Corresponds to the JSON property queryType
16370 16371 16372 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16370 def query_type @query_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16377 16378 16379 16380 16381 16382 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16377 def update!(**args) @attributed_items = args[:attributed_items] if args.key?(:attributed_items) @outlier_score = args[:outlier_score] if args.key?(:outlier_score) @outlier_threshold = args[:outlier_threshold] if args.key?(:outlier_threshold) @query_type = args[:query_type] if args.key?(:query_type) end |