Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Model error analysis for each annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation

Returns a new instance of GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation.



10064
10065
10066
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributed_itemsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotationAttributedItem>

Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type. Corresponds to the JSON property attributedItems



10046
10047
10048
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10046

def attributed_items
  @attributed_items
end

#outlier_scoreFloat

The outlier score of this annotated item. Usually defined as the min of all distances from attributed items. Corresponds to the JSON property outlierScore

Returns:

  • (Float)


10052
10053
10054
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10052

def outlier_score
  @outlier_score
end

#outlier_thresholdFloat

The threshold used to determine if this annotation is an outlier or not. Corresponds to the JSON property outlierThreshold

Returns:

  • (Float)


10057
10058
10059
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10057

def outlier_threshold
  @outlier_threshold
end

#query_typeString

The query type used for finding the attributed items. Corresponds to the JSON property queryType

Returns:

  • (String)


10062
10063
10064
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10062

def query_type
  @query_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10069
10070
10071
10072
10073
10074
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10069

def update!(**args)
  @attributed_items = args[:attributed_items] if args.key?(:attributed_items)
  @outlier_score = args[:outlier_score] if args.key?(:outlier_score)
  @outlier_threshold = args[:outlier_threshold] if args.key?(:outlier_threshold)
  @query_type = args[:query_type] if args.key?(:query_type)
end