Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateDatasetResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The results from an evaluation run performed by the EvaluationService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluateDatasetResponse

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluateDatasetResponse.



10228
10229
10230
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_outputGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AggregationOutput

The aggregation result for the entire dataset and all metrics. Corresponds to the JSON property aggregationOutput



10221
10222
10223
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10221

def aggregation_output
  @aggregation_output
end

#output_infoGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OutputInfo

Describes the info for output of EvaluationService. Corresponds to the JSON property outputInfo



10226
10227
10228
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10226

def output_info
  @output_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10233
10234
10235
10236
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10233

def update!(**args)
  @aggregation_output = args[:aggregation_output] if args.key?(:aggregation_output)
  @output_info = args[:output_info] if args.key?(:output_info)
end