Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateDatasetResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateDatasetResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The results from an evaluation run performed by the EvaluationService.
Instance Attribute Summary collapse
-
#aggregation_output ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AggregationOutput
The aggregation result for the entire dataset and all metrics.
-
#output_info ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OutputInfo
Describes the info for output of EvaluationService.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluateDatasetResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluateDatasetResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluateDatasetResponse
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluateDatasetResponse.
10162 10163 10164 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation_output ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AggregationOutput
The aggregation result for the entire dataset and all metrics.
Corresponds to the JSON property aggregationOutput
10155 10156 10157 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10155 def aggregation_output @aggregation_output end |
#output_info ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OutputInfo
Describes the info for output of EvaluationService.
Corresponds to the JSON property outputInfo
10160 10161 10162 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10160 def output_info @output_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10167 10168 10169 10170 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10167 def update!(**args) @aggregation_output = args[:aggregation_output] if args.key?(:aggregation_output) @output_info = args[:output_info] if args.key?(:output_info) end |