Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateDatasetRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Evaluate Dataset Run Result for Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluateDatasetRun

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluateDatasetRun.



16814
16815
16816
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16814

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

Output only. The checkpoint id used in the evaluation run. Only populated when evaluating checkpoints. Corresponds to the JSON property checkpointId

Returns:

  • (String)


16786
16787
16788
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16786

def checkpoint_id
  @checkpoint_id
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



16796
16797
16798
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16796

def error
  @error
end

#evaluate_dataset_responseGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateDatasetResponse

The results from an evaluation run performed by the EvaluationService. Corresponds to the JSON property evaluateDatasetResponse



16801
16802
16803
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16801

def evaluate_dataset_response
  @evaluate_dataset_response
end

#evaluation_runString

Output only. The resource name of the evaluation run. Format: projects/ project/locations/location/evaluationRuns/evaluation_run_id`. Corresponds to the JSON propertyevaluationRun`

Returns:

  • (String)


16807
16808
16809
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16807

def evaluation_run
  @evaluation_run
end

#operation_nameString

Output only. Deprecated: The updated architecture uses evaluation_run instead. Corresponds to the JSON property operationName

Returns:

  • (String)


16812
16813
16814
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16812

def operation_name
  @operation_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16819
16820
16821
16822
16823
16824
16825
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16819

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @error = args[:error] if args.key?(:error)
  @evaluate_dataset_response = args[:evaluate_dataset_response] if args.key?(:evaluate_dataset_response)
  @evaluation_run = args[:evaluation_run] if args.key?(:evaluation_run)
  @operation_name = args[:operation_name] if args.key?(:operation_name)
end