Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for EvaluationService.EvaluateInstances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluateInstancesResponse

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluateInstancesResponse.



18156
18157
18158
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bleu_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BleuResults

Results for bleu metric. Corresponds to the JSON property bleuResults



17991
17992
17993
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17991

def bleu_results
  @bleu_results
end

#coherence_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CoherenceResult

Spec for coherence result. Corresponds to the JSON property coherenceResult



17996
17997
17998
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17996

def coherence_result
  @coherence_result
end

#comet_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CometResult

Spec for Comet result - calculates the comet score for the given instance using the version specified in the spec. Corresponds to the JSON property cometResult



18002
18003
18004
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18002

def comet_result
  @comet_result
end

#exact_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExactMatchResults

Results for exact match metric. Corresponds to the JSON property exactMatchResults



18007
18008
18009
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18007

def exact_match_results
  @exact_match_results
end

#fluency_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FluencyResult

Spec for fluency result. Corresponds to the JSON property fluencyResult



18012
18013
18014
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18012

def fluency_result
  @fluency_result
end

#fulfillment_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FulfillmentResult

Spec for fulfillment result. Corresponds to the JSON property fulfillmentResult



18017
18018
18019
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18017

def fulfillment_result
  @fulfillment_result
end

#groundedness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundednessResult

Spec for groundedness result. Corresponds to the JSON property groundednessResult



18022
18023
18024
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18022

def groundedness_result
  @groundedness_result
end

#metric_resultsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricResult>

Metric results for each instance. The order of the metric results is guaranteed to be the same as the order of the instances in the request. Corresponds to the JSON property metricResults



18028
18029
18030
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18028

def metric_results
  @metric_results
end

#metricx_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricxResult

Spec for MetricX result - calculates the MetricX score for the given instance using the version specified in the spec. Corresponds to the JSON property metricxResult



18034
18035
18036
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18034

def metricx_result
  @metricx_result
end

#pairwise_metric_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseMetricResult

Spec for pairwise metric result. Corresponds to the JSON property pairwiseMetricResult



18039
18040
18041
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18039

def pairwise_metric_result
  @pairwise_metric_result
end

#pairwise_question_answering_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseQuestionAnsweringQualityResult

Spec for pairwise question answering quality result. Corresponds to the JSON property pairwiseQuestionAnsweringQualityResult



18044
18045
18046
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18044

def pairwise_question_answering_quality_result
  @pairwise_question_answering_quality_result
end

#pairwise_summarization_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseSummarizationQualityResult

Spec for pairwise summarization quality result. Corresponds to the JSON property pairwiseSummarizationQualityResult



18049
18050
18051
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18049

def pairwise_summarization_quality_result
  @pairwise_summarization_quality_result
end

#pointwise_metric_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PointwiseMetricResult

Spec for pointwise metric result. Corresponds to the JSON property pointwiseMetricResult



18054
18055
18056
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18054

def pointwise_metric_result
  @pointwise_metric_result
end

#question_answering_correctness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringCorrectnessResult

Spec for question answering correctness result. Corresponds to the JSON property questionAnsweringCorrectnessResult



18059
18060
18061
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18059

def question_answering_correctness_result
  @question_answering_correctness_result
end

#question_answering_helpfulness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringHelpfulnessResult

Spec for question answering helpfulness result. Corresponds to the JSON property questionAnsweringHelpfulnessResult



18064
18065
18066
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18064

def question_answering_helpfulness_result
  @question_answering_helpfulness_result
end

#question_answering_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringQualityResult

Spec for question answering quality result. Corresponds to the JSON property questionAnsweringQualityResult



18069
18070
18071
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18069

def question_answering_quality_result
  @question_answering_quality_result
end

#question_answering_relevance_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringRelevanceResult

Spec for question answering relevance result. Corresponds to the JSON property questionAnsweringRelevanceResult



18074
18075
18076
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18074

def question_answering_relevance_result
  @question_answering_relevance_result
end

#rouge_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RougeResults

Results for rouge metric. Corresponds to the JSON property rougeResults



18079
18080
18081
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18079

def rouge_results
  @rouge_results
end

#rubric_based_instruction_following_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricBasedInstructionFollowingResult

Result for RubricBasedInstructionFollowing metric. Corresponds to the JSON property rubricBasedInstructionFollowingResult



18084
18085
18086
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18084

def rubric_based_instruction_following_result
  @rubric_based_instruction_following_result
end

#safety_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetyResult

Spec for safety result. Corresponds to the JSON property safetyResult



18089
18090
18091
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18089

def safety_result
  @safety_result
end

#summarization_helpfulness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationHelpfulnessResult

Spec for summarization helpfulness result. Corresponds to the JSON property summarizationHelpfulnessResult



18094
18095
18096
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18094

def summarization_helpfulness_result
  @summarization_helpfulness_result
end

#summarization_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationQualityResult

Spec for summarization quality result. Corresponds to the JSON property summarizationQualityResult



18099
18100
18101
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18099

def summarization_quality_result
  @summarization_quality_result
end

#summarization_verbosity_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationVerbosityResult

Spec for summarization verbosity result. Corresponds to the JSON property summarizationVerbosityResult



18104
18105
18106
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18104

def summarization_verbosity_result
  @summarization_verbosity_result
end

#tool_call_valid_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolCallValidResults

Results for tool call valid metric. Corresponds to the JSON property toolCallValidResults



18109
18110
18111
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18109

def tool_call_valid_results
  @tool_call_valid_results
end

#tool_name_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolNameMatchResults

Results for tool name match metric. Corresponds to the JSON property toolNameMatchResults



18114
18115
18116
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18114

def tool_name_match_results
  @tool_name_match_results
end

#tool_parameter_key_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParameterKeyMatchResults

Results for tool parameter key match metric. Corresponds to the JSON property toolParameterKeyMatchResults



18119
18120
18121
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18119

def tool_parameter_key_match_results
  @tool_parameter_key_match_results
end

#tool_parameter_kv_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParameterKvMatchResults

Results for tool parameter key value match metric. Corresponds to the JSON property toolParameterKvMatchResults



18124
18125
18126
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18124

def tool_parameter_kv_match_results
  @tool_parameter_kv_match_results
end

#trajectory_any_order_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchResults

Results for TrajectoryAnyOrderMatch metric. Corresponds to the JSON property trajectoryAnyOrderMatchResults



18129
18130
18131
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18129

def trajectory_any_order_match_results
  @trajectory_any_order_match_results
end

#trajectory_exact_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryExactMatchResults

Results for TrajectoryExactMatch metric. Corresponds to the JSON property trajectoryExactMatchResults



18134
18135
18136
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18134

def trajectory_exact_match_results
  @trajectory_exact_match_results
end

#trajectory_in_order_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchResults

Results for TrajectoryInOrderMatch metric. Corresponds to the JSON property trajectoryInOrderMatchResults



18139
18140
18141
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18139

def trajectory_in_order_match_results
  @trajectory_in_order_match_results
end

#trajectory_precision_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryPrecisionResults

Results for TrajectoryPrecision metric. Corresponds to the JSON property trajectoryPrecisionResults



18144
18145
18146
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18144

def trajectory_precision_results
  @trajectory_precision_results
end

#trajectory_recall_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryRecallResults

Results for TrajectoryRecall metric. Corresponds to the JSON property trajectoryRecallResults



18149
18150
18151
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18149

def trajectory_recall_results
  @trajectory_recall_results
end

#trajectory_single_tool_use_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectorySingleToolUseResults

Results for TrajectorySingleToolUse metric. Corresponds to the JSON property trajectorySingleToolUseResults



18154
18155
18156
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18154

def trajectory_single_tool_use_results
  @trajectory_single_tool_use_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18161
18162
18163
18164
18165
18166
18167
18168
18169
18170
18171
18172
18173
18174
18175
18176
18177
18178
18179
18180
18181
18182
18183
18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18161

def update!(**args)
  @bleu_results = args[:bleu_results] if args.key?(:bleu_results)
  @coherence_result = args[:coherence_result] if args.key?(:coherence_result)
  @comet_result = args[:comet_result] if args.key?(:comet_result)
  @exact_match_results = args[:exact_match_results] if args.key?(:exact_match_results)
  @fluency_result = args[:fluency_result] if args.key?(:fluency_result)
  @fulfillment_result = args[:fulfillment_result] if args.key?(:fulfillment_result)
  @groundedness_result = args[:groundedness_result] if args.key?(:groundedness_result)
  @metric_results = args[:metric_results] if args.key?(:metric_results)
  @metricx_result = args[:metricx_result] if args.key?(:metricx_result)
  @pairwise_metric_result = args[:pairwise_metric_result] if args.key?(:pairwise_metric_result)
  @pairwise_question_answering_quality_result = args[:pairwise_question_answering_quality_result] if args.key?(:pairwise_question_answering_quality_result)
  @pairwise_summarization_quality_result = args[:pairwise_summarization_quality_result] if args.key?(:pairwise_summarization_quality_result)
  @pointwise_metric_result = args[:pointwise_metric_result] if args.key?(:pointwise_metric_result)
  @question_answering_correctness_result = args[:question_answering_correctness_result] if args.key?(:question_answering_correctness_result)
  @question_answering_helpfulness_result = args[:question_answering_helpfulness_result] if args.key?(:question_answering_helpfulness_result)
  @question_answering_quality_result = args[:question_answering_quality_result] if args.key?(:question_answering_quality_result)
  @question_answering_relevance_result = args[:question_answering_relevance_result] if args.key?(:question_answering_relevance_result)
  @rouge_results = args[:rouge_results] if args.key?(:rouge_results)
  @rubric_based_instruction_following_result = args[:rubric_based_instruction_following_result] if args.key?(:rubric_based_instruction_following_result)
  @safety_result = args[:safety_result] if args.key?(:safety_result)
  @summarization_helpfulness_result = args[:summarization_helpfulness_result] if args.key?(:summarization_helpfulness_result)
  @summarization_quality_result = args[:summarization_quality_result] if args.key?(:summarization_quality_result)
  @summarization_verbosity_result = args[:summarization_verbosity_result] if args.key?(:summarization_verbosity_result)
  @tool_call_valid_results = args[:tool_call_valid_results] if args.key?(:tool_call_valid_results)
  @tool_name_match_results = args[:tool_name_match_results] if args.key?(:tool_name_match_results)
  @tool_parameter_key_match_results = args[:tool_parameter_key_match_results] if args.key?(:tool_parameter_key_match_results)
  @tool_parameter_kv_match_results = args[:tool_parameter_kv_match_results] if args.key?(:tool_parameter_kv_match_results)
  @trajectory_any_order_match_results = args[:trajectory_any_order_match_results] if args.key?(:trajectory_any_order_match_results)
  @trajectory_exact_match_results = args[:trajectory_exact_match_results] if args.key?(:trajectory_exact_match_results)
  @trajectory_in_order_match_results = args[:trajectory_in_order_match_results] if args.key?(:trajectory_in_order_match_results)
  @trajectory_precision_results = args[:trajectory_precision_results] if args.key?(:trajectory_precision_results)
  @trajectory_recall_results = args[:trajectory_recall_results] if args.key?(:trajectory_recall_results)
  @trajectory_single_tool_use_results = args[:trajectory_single_tool_use_results] if args.key?(:trajectory_single_tool_use_results)
end