Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for EvaluationService.EvaluateInstances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluateInstancesResponse

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluateInstancesResponse.



17243
17244
17245
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bleu_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BleuResults

Results for bleu metric. Corresponds to the JSON property bleuResults



17078
17079
17080
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17078

def bleu_results
  @bleu_results
end

#coherence_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CoherenceResult

Spec for coherence result. Corresponds to the JSON property coherenceResult



17083
17084
17085
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17083

def coherence_result
  @coherence_result
end

#comet_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CometResult

Spec for Comet result - calculates the comet score for the given instance using the version specified in the spec. Corresponds to the JSON property cometResult



17089
17090
17091
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17089

def comet_result
  @comet_result
end

#exact_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExactMatchResults

Results for exact match metric. Corresponds to the JSON property exactMatchResults



17094
17095
17096
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17094

def exact_match_results
  @exact_match_results
end

#fluency_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FluencyResult

Spec for fluency result. Corresponds to the JSON property fluencyResult



17099
17100
17101
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17099

def fluency_result
  @fluency_result
end

#fulfillment_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FulfillmentResult

Spec for fulfillment result. Corresponds to the JSON property fulfillmentResult



17104
17105
17106
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17104

def fulfillment_result
  @fulfillment_result
end

#groundedness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundednessResult

Spec for groundedness result. Corresponds to the JSON property groundednessResult



17109
17110
17111
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17109

def groundedness_result
  @groundedness_result
end

#metric_resultsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricResult>

Metric results for each instance. The order of the metric results is guaranteed to be the same as the order of the instances in the request. Corresponds to the JSON property metricResults



17115
17116
17117
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17115

def metric_results
  @metric_results
end

#metricx_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricxResult

Spec for MetricX result - calculates the MetricX score for the given instance using the version specified in the spec. Corresponds to the JSON property metricxResult



17121
17122
17123
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17121

def metricx_result
  @metricx_result
end

#pairwise_metric_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseMetricResult

Spec for pairwise metric result. Corresponds to the JSON property pairwiseMetricResult



17126
17127
17128
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17126

def pairwise_metric_result
  @pairwise_metric_result
end

#pairwise_question_answering_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseQuestionAnsweringQualityResult

Spec for pairwise question answering quality result. Corresponds to the JSON property pairwiseQuestionAnsweringQualityResult



17131
17132
17133
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17131

def pairwise_question_answering_quality_result
  @pairwise_question_answering_quality_result
end

#pairwise_summarization_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseSummarizationQualityResult

Spec for pairwise summarization quality result. Corresponds to the JSON property pairwiseSummarizationQualityResult



17136
17137
17138
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17136

def pairwise_summarization_quality_result
  @pairwise_summarization_quality_result
end

#pointwise_metric_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PointwiseMetricResult

Spec for pointwise metric result. Corresponds to the JSON property pointwiseMetricResult



17141
17142
17143
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17141

def pointwise_metric_result
  @pointwise_metric_result
end

#question_answering_correctness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringCorrectnessResult

Spec for question answering correctness result. Corresponds to the JSON property questionAnsweringCorrectnessResult



17146
17147
17148
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17146

def question_answering_correctness_result
  @question_answering_correctness_result
end

#question_answering_helpfulness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringHelpfulnessResult

Spec for question answering helpfulness result. Corresponds to the JSON property questionAnsweringHelpfulnessResult



17151
17152
17153
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17151

def question_answering_helpfulness_result
  @question_answering_helpfulness_result
end

#question_answering_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringQualityResult

Spec for question answering quality result. Corresponds to the JSON property questionAnsweringQualityResult



17156
17157
17158
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17156

def question_answering_quality_result
  @question_answering_quality_result
end

#question_answering_relevance_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringRelevanceResult

Spec for question answering relevance result. Corresponds to the JSON property questionAnsweringRelevanceResult



17161
17162
17163
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17161

def question_answering_relevance_result
  @question_answering_relevance_result
end

#rouge_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RougeResults

Results for rouge metric. Corresponds to the JSON property rougeResults



17166
17167
17168
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17166

def rouge_results
  @rouge_results
end

#rubric_based_instruction_following_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricBasedInstructionFollowingResult

Result for RubricBasedInstructionFollowing metric. Corresponds to the JSON property rubricBasedInstructionFollowingResult



17171
17172
17173
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17171

def rubric_based_instruction_following_result
  @rubric_based_instruction_following_result
end

#safety_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetyResult

Spec for safety result. Corresponds to the JSON property safetyResult



17176
17177
17178
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17176

def safety_result
  @safety_result
end

#summarization_helpfulness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationHelpfulnessResult

Spec for summarization helpfulness result. Corresponds to the JSON property summarizationHelpfulnessResult



17181
17182
17183
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17181

def summarization_helpfulness_result
  @summarization_helpfulness_result
end

#summarization_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationQualityResult

Spec for summarization quality result. Corresponds to the JSON property summarizationQualityResult



17186
17187
17188
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17186

def summarization_quality_result
  @summarization_quality_result
end

#summarization_verbosity_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationVerbosityResult

Spec for summarization verbosity result. Corresponds to the JSON property summarizationVerbosityResult



17191
17192
17193
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17191

def summarization_verbosity_result
  @summarization_verbosity_result
end

#tool_call_valid_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolCallValidResults

Results for tool call valid metric. Corresponds to the JSON property toolCallValidResults



17196
17197
17198
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17196

def tool_call_valid_results
  @tool_call_valid_results
end

#tool_name_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolNameMatchResults

Results for tool name match metric. Corresponds to the JSON property toolNameMatchResults



17201
17202
17203
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17201

def tool_name_match_results
  @tool_name_match_results
end

#tool_parameter_key_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParameterKeyMatchResults

Results for tool parameter key match metric. Corresponds to the JSON property toolParameterKeyMatchResults



17206
17207
17208
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17206

def tool_parameter_key_match_results
  @tool_parameter_key_match_results
end

#tool_parameter_kv_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParameterKvMatchResults

Results for tool parameter key value match metric. Corresponds to the JSON property toolParameterKvMatchResults



17211
17212
17213
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17211

def tool_parameter_kv_match_results
  @tool_parameter_kv_match_results
end

#trajectory_any_order_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchResults

Results for TrajectoryAnyOrderMatch metric. Corresponds to the JSON property trajectoryAnyOrderMatchResults



17216
17217
17218
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17216

def trajectory_any_order_match_results
  @trajectory_any_order_match_results
end

#trajectory_exact_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryExactMatchResults

Results for TrajectoryExactMatch metric. Corresponds to the JSON property trajectoryExactMatchResults



17221
17222
17223
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17221

def trajectory_exact_match_results
  @trajectory_exact_match_results
end

#trajectory_in_order_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchResults

Results for TrajectoryInOrderMatch metric. Corresponds to the JSON property trajectoryInOrderMatchResults



17226
17227
17228
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17226

def trajectory_in_order_match_results
  @trajectory_in_order_match_results
end

#trajectory_precision_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryPrecisionResults

Results for TrajectoryPrecision metric. Corresponds to the JSON property trajectoryPrecisionResults



17231
17232
17233
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17231

def trajectory_precision_results
  @trajectory_precision_results
end

#trajectory_recall_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryRecallResults

Results for TrajectoryRecall metric. Corresponds to the JSON property trajectoryRecallResults



17236
17237
17238
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17236

def trajectory_recall_results
  @trajectory_recall_results
end

#trajectory_single_tool_use_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectorySingleToolUseResults

Results for TrajectorySingleToolUse metric. Corresponds to the JSON property trajectorySingleToolUseResults



17241
17242
17243
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17241

def trajectory_single_tool_use_results
  @trajectory_single_tool_use_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17248
17249
17250
17251
17252
17253
17254
17255
17256
17257
17258
17259
17260
17261
17262
17263
17264
17265
17266
17267
17268
17269
17270
17271
17272
17273
17274
17275
17276
17277
17278
17279
17280
17281
17282
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17248

def update!(**args)
  @bleu_results = args[:bleu_results] if args.key?(:bleu_results)
  @coherence_result = args[:coherence_result] if args.key?(:coherence_result)
  @comet_result = args[:comet_result] if args.key?(:comet_result)
  @exact_match_results = args[:exact_match_results] if args.key?(:exact_match_results)
  @fluency_result = args[:fluency_result] if args.key?(:fluency_result)
  @fulfillment_result = args[:fulfillment_result] if args.key?(:fulfillment_result)
  @groundedness_result = args[:groundedness_result] if args.key?(:groundedness_result)
  @metric_results = args[:metric_results] if args.key?(:metric_results)
  @metricx_result = args[:metricx_result] if args.key?(:metricx_result)
  @pairwise_metric_result = args[:pairwise_metric_result] if args.key?(:pairwise_metric_result)
  @pairwise_question_answering_quality_result = args[:pairwise_question_answering_quality_result] if args.key?(:pairwise_question_answering_quality_result)
  @pairwise_summarization_quality_result = args[:pairwise_summarization_quality_result] if args.key?(:pairwise_summarization_quality_result)
  @pointwise_metric_result = args[:pointwise_metric_result] if args.key?(:pointwise_metric_result)
  @question_answering_correctness_result = args[:question_answering_correctness_result] if args.key?(:question_answering_correctness_result)
  @question_answering_helpfulness_result = args[:question_answering_helpfulness_result] if args.key?(:question_answering_helpfulness_result)
  @question_answering_quality_result = args[:question_answering_quality_result] if args.key?(:question_answering_quality_result)
  @question_answering_relevance_result = args[:question_answering_relevance_result] if args.key?(:question_answering_relevance_result)
  @rouge_results = args[:rouge_results] if args.key?(:rouge_results)
  @rubric_based_instruction_following_result = args[:rubric_based_instruction_following_result] if args.key?(:rubric_based_instruction_following_result)
  @safety_result = args[:safety_result] if args.key?(:safety_result)
  @summarization_helpfulness_result = args[:summarization_helpfulness_result] if args.key?(:summarization_helpfulness_result)
  @summarization_quality_result = args[:summarization_quality_result] if args.key?(:summarization_quality_result)
  @summarization_verbosity_result = args[:summarization_verbosity_result] if args.key?(:summarization_verbosity_result)
  @tool_call_valid_results = args[:tool_call_valid_results] if args.key?(:tool_call_valid_results)
  @tool_name_match_results = args[:tool_name_match_results] if args.key?(:tool_name_match_results)
  @tool_parameter_key_match_results = args[:tool_parameter_key_match_results] if args.key?(:tool_parameter_key_match_results)
  @tool_parameter_kv_match_results = args[:tool_parameter_kv_match_results] if args.key?(:tool_parameter_kv_match_results)
  @trajectory_any_order_match_results = args[:trajectory_any_order_match_results] if args.key?(:trajectory_any_order_match_results)
  @trajectory_exact_match_results = args[:trajectory_exact_match_results] if args.key?(:trajectory_exact_match_results)
  @trajectory_in_order_match_results = args[:trajectory_in_order_match_results] if args.key?(:trajectory_in_order_match_results)
  @trajectory_precision_results = args[:trajectory_precision_results] if args.key?(:trajectory_precision_results)
  @trajectory_recall_results = args[:trajectory_recall_results] if args.key?(:trajectory_recall_results)
  @trajectory_single_tool_use_results = args[:trajectory_single_tool_use_results] if args.key?(:trajectory_single_tool_use_results)
end