Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for EvaluationService.EvaluateInstances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluateInstancesResponse

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluateInstancesResponse.



16946
16947
16948
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16946

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bleu_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BleuResults

Results for bleu metric. Corresponds to the JSON property bleuResults



16781
16782
16783
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16781

def bleu_results
  @bleu_results
end

#coherence_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CoherenceResult

Spec for coherence result. Corresponds to the JSON property coherenceResult



16786
16787
16788
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16786

def coherence_result
  @coherence_result
end

#comet_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CometResult

Spec for Comet result - calculates the comet score for the given instance using the version specified in the spec. Corresponds to the JSON property cometResult



16792
16793
16794
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16792

def comet_result
  @comet_result
end

#exact_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExactMatchResults

Results for exact match metric. Corresponds to the JSON property exactMatchResults



16797
16798
16799
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16797

def exact_match_results
  @exact_match_results
end

#fluency_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FluencyResult

Spec for fluency result. Corresponds to the JSON property fluencyResult



16802
16803
16804
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16802

def fluency_result
  @fluency_result
end

#fulfillment_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FulfillmentResult

Spec for fulfillment result. Corresponds to the JSON property fulfillmentResult



16807
16808
16809
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16807

def fulfillment_result
  @fulfillment_result
end

#groundedness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundednessResult

Spec for groundedness result. Corresponds to the JSON property groundednessResult



16812
16813
16814
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16812

def groundedness_result
  @groundedness_result
end

#metric_resultsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricResult>

Metric results for each instance. The order of the metric results is guaranteed to be the same as the order of the instances in the request. Corresponds to the JSON property metricResults



16818
16819
16820
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16818

def metric_results
  @metric_results
end

#metricx_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricxResult

Spec for MetricX result - calculates the MetricX score for the given instance using the version specified in the spec. Corresponds to the JSON property metricxResult



16824
16825
16826
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16824

def metricx_result
  @metricx_result
end

#pairwise_metric_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseMetricResult

Spec for pairwise metric result. Corresponds to the JSON property pairwiseMetricResult



16829
16830
16831
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16829

def pairwise_metric_result
  @pairwise_metric_result
end

#pairwise_question_answering_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseQuestionAnsweringQualityResult

Spec for pairwise question answering quality result. Corresponds to the JSON property pairwiseQuestionAnsweringQualityResult



16834
16835
16836
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16834

def pairwise_question_answering_quality_result
  @pairwise_question_answering_quality_result
end

#pairwise_summarization_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseSummarizationQualityResult

Spec for pairwise summarization quality result. Corresponds to the JSON property pairwiseSummarizationQualityResult



16839
16840
16841
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16839

def pairwise_summarization_quality_result
  @pairwise_summarization_quality_result
end

#pointwise_metric_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PointwiseMetricResult

Spec for pointwise metric result. Corresponds to the JSON property pointwiseMetricResult



16844
16845
16846
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16844

def pointwise_metric_result
  @pointwise_metric_result
end

#question_answering_correctness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringCorrectnessResult

Spec for question answering correctness result. Corresponds to the JSON property questionAnsweringCorrectnessResult



16849
16850
16851
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16849

def question_answering_correctness_result
  @question_answering_correctness_result
end

#question_answering_helpfulness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringHelpfulnessResult

Spec for question answering helpfulness result. Corresponds to the JSON property questionAnsweringHelpfulnessResult



16854
16855
16856
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16854

def question_answering_helpfulness_result
  @question_answering_helpfulness_result
end

#question_answering_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringQualityResult

Spec for question answering quality result. Corresponds to the JSON property questionAnsweringQualityResult



16859
16860
16861
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16859

def question_answering_quality_result
  @question_answering_quality_result
end

#question_answering_relevance_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringRelevanceResult

Spec for question answering relevance result. Corresponds to the JSON property questionAnsweringRelevanceResult



16864
16865
16866
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16864

def question_answering_relevance_result
  @question_answering_relevance_result
end

#rouge_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RougeResults

Results for rouge metric. Corresponds to the JSON property rougeResults



16869
16870
16871
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16869

def rouge_results
  @rouge_results
end

#rubric_based_instruction_following_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricBasedInstructionFollowingResult

Result for RubricBasedInstructionFollowing metric. Corresponds to the JSON property rubricBasedInstructionFollowingResult



16874
16875
16876
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16874

def rubric_based_instruction_following_result
  @rubric_based_instruction_following_result
end

#safety_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetyResult

Spec for safety result. Corresponds to the JSON property safetyResult



16879
16880
16881
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16879

def safety_result
  @safety_result
end

#summarization_helpfulness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationHelpfulnessResult

Spec for summarization helpfulness result. Corresponds to the JSON property summarizationHelpfulnessResult



16884
16885
16886
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16884

def summarization_helpfulness_result
  @summarization_helpfulness_result
end

#summarization_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationQualityResult

Spec for summarization quality result. Corresponds to the JSON property summarizationQualityResult



16889
16890
16891
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16889

def summarization_quality_result
  @summarization_quality_result
end

#summarization_verbosity_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationVerbosityResult

Spec for summarization verbosity result. Corresponds to the JSON property summarizationVerbosityResult



16894
16895
16896
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16894

def summarization_verbosity_result
  @summarization_verbosity_result
end

#tool_call_valid_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolCallValidResults

Results for tool call valid metric. Corresponds to the JSON property toolCallValidResults



16899
16900
16901
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16899

def tool_call_valid_results
  @tool_call_valid_results
end

#tool_name_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolNameMatchResults

Results for tool name match metric. Corresponds to the JSON property toolNameMatchResults



16904
16905
16906
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16904

def tool_name_match_results
  @tool_name_match_results
end

#tool_parameter_key_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParameterKeyMatchResults

Results for tool parameter key match metric. Corresponds to the JSON property toolParameterKeyMatchResults



16909
16910
16911
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16909

def tool_parameter_key_match_results
  @tool_parameter_key_match_results
end

#tool_parameter_kv_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParameterKvMatchResults

Results for tool parameter key value match metric. Corresponds to the JSON property toolParameterKvMatchResults



16914
16915
16916
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16914

def tool_parameter_kv_match_results
  @tool_parameter_kv_match_results
end

#trajectory_any_order_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchResults

Results for TrajectoryAnyOrderMatch metric. Corresponds to the JSON property trajectoryAnyOrderMatchResults



16919
16920
16921
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16919

def trajectory_any_order_match_results
  @trajectory_any_order_match_results
end

#trajectory_exact_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryExactMatchResults

Results for TrajectoryExactMatch metric. Corresponds to the JSON property trajectoryExactMatchResults



16924
16925
16926
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16924

def trajectory_exact_match_results
  @trajectory_exact_match_results
end

#trajectory_in_order_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchResults

Results for TrajectoryInOrderMatch metric. Corresponds to the JSON property trajectoryInOrderMatchResults



16929
16930
16931
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16929

def trajectory_in_order_match_results
  @trajectory_in_order_match_results
end

#trajectory_precision_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryPrecisionResults

Results for TrajectoryPrecision metric. Corresponds to the JSON property trajectoryPrecisionResults



16934
16935
16936
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16934

def trajectory_precision_results
  @trajectory_precision_results
end

#trajectory_recall_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryRecallResults

Results for TrajectoryRecall metric. Corresponds to the JSON property trajectoryRecallResults



16939
16940
16941
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16939

def trajectory_recall_results
  @trajectory_recall_results
end

#trajectory_single_tool_use_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectorySingleToolUseResults

Results for TrajectorySingleToolUse metric. Corresponds to the JSON property trajectorySingleToolUseResults



16944
16945
16946
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16944

def trajectory_single_tool_use_results
  @trajectory_single_tool_use_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16951
16952
16953
16954
16955
16956
16957
16958
16959
16960
16961
16962
16963
16964
16965
16966
16967
16968
16969
16970
16971
16972
16973
16974
16975
16976
16977
16978
16979
16980
16981
16982
16983
16984
16985
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16951

def update!(**args)
  @bleu_results = args[:bleu_results] if args.key?(:bleu_results)
  @coherence_result = args[:coherence_result] if args.key?(:coherence_result)
  @comet_result = args[:comet_result] if args.key?(:comet_result)
  @exact_match_results = args[:exact_match_results] if args.key?(:exact_match_results)
  @fluency_result = args[:fluency_result] if args.key?(:fluency_result)
  @fulfillment_result = args[:fulfillment_result] if args.key?(:fulfillment_result)
  @groundedness_result = args[:groundedness_result] if args.key?(:groundedness_result)
  @metric_results = args[:metric_results] if args.key?(:metric_results)
  @metricx_result = args[:metricx_result] if args.key?(:metricx_result)
  @pairwise_metric_result = args[:pairwise_metric_result] if args.key?(:pairwise_metric_result)
  @pairwise_question_answering_quality_result = args[:pairwise_question_answering_quality_result] if args.key?(:pairwise_question_answering_quality_result)
  @pairwise_summarization_quality_result = args[:pairwise_summarization_quality_result] if args.key?(:pairwise_summarization_quality_result)
  @pointwise_metric_result = args[:pointwise_metric_result] if args.key?(:pointwise_metric_result)
  @question_answering_correctness_result = args[:question_answering_correctness_result] if args.key?(:question_answering_correctness_result)
  @question_answering_helpfulness_result = args[:question_answering_helpfulness_result] if args.key?(:question_answering_helpfulness_result)
  @question_answering_quality_result = args[:question_answering_quality_result] if args.key?(:question_answering_quality_result)
  @question_answering_relevance_result = args[:question_answering_relevance_result] if args.key?(:question_answering_relevance_result)
  @rouge_results = args[:rouge_results] if args.key?(:rouge_results)
  @rubric_based_instruction_following_result = args[:rubric_based_instruction_following_result] if args.key?(:rubric_based_instruction_following_result)
  @safety_result = args[:safety_result] if args.key?(:safety_result)
  @summarization_helpfulness_result = args[:summarization_helpfulness_result] if args.key?(:summarization_helpfulness_result)
  @summarization_quality_result = args[:summarization_quality_result] if args.key?(:summarization_quality_result)
  @summarization_verbosity_result = args[:summarization_verbosity_result] if args.key?(:summarization_verbosity_result)
  @tool_call_valid_results = args[:tool_call_valid_results] if args.key?(:tool_call_valid_results)
  @tool_name_match_results = args[:tool_name_match_results] if args.key?(:tool_name_match_results)
  @tool_parameter_key_match_results = args[:tool_parameter_key_match_results] if args.key?(:tool_parameter_key_match_results)
  @tool_parameter_kv_match_results = args[:tool_parameter_kv_match_results] if args.key?(:tool_parameter_kv_match_results)
  @trajectory_any_order_match_results = args[:trajectory_any_order_match_results] if args.key?(:trajectory_any_order_match_results)
  @trajectory_exact_match_results = args[:trajectory_exact_match_results] if args.key?(:trajectory_exact_match_results)
  @trajectory_in_order_match_results = args[:trajectory_in_order_match_results] if args.key?(:trajectory_in_order_match_results)
  @trajectory_precision_results = args[:trajectory_precision_results] if args.key?(:trajectory_precision_results)
  @trajectory_recall_results = args[:trajectory_recall_results] if args.key?(:trajectory_recall_results)
  @trajectory_single_tool_use_results = args[:trajectory_single_tool_use_results] if args.key?(:trajectory_single_tool_use_results)
end