Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for EvaluationService.EvaluateInstances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluateInstancesResponse

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluateInstancesResponse.



10704
10705
10706
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bleu_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BleuResults

Results for bleu metric. Corresponds to the JSON property bleuResults



10539
10540
10541
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10539

def bleu_results
  @bleu_results
end

#coherence_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CoherenceResult

Spec for coherence result. Corresponds to the JSON property coherenceResult



10544
10545
10546
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10544

def coherence_result
  @coherence_result
end

#comet_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CometResult

Spec for Comet result - calculates the comet score for the given instance using the version specified in the spec. Corresponds to the JSON property cometResult



10550
10551
10552
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10550

def comet_result
  @comet_result
end

#exact_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExactMatchResults

Results for exact match metric. Corresponds to the JSON property exactMatchResults



10555
10556
10557
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10555

def exact_match_results
  @exact_match_results
end

#fluency_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FluencyResult

Spec for fluency result. Corresponds to the JSON property fluencyResult



10560
10561
10562
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10560

def fluency_result
  @fluency_result
end

#fulfillment_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FulfillmentResult

Spec for fulfillment result. Corresponds to the JSON property fulfillmentResult



10565
10566
10567
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10565

def fulfillment_result
  @fulfillment_result
end

#groundedness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundednessResult

Spec for groundedness result. Corresponds to the JSON property groundednessResult



10570
10571
10572
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10570

def groundedness_result
  @groundedness_result
end

#metric_resultsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricResult>

Metric results for each instance. The order of the metric results is guaranteed to be the same as the order of the instances in the request. Corresponds to the JSON property metricResults



10576
10577
10578
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10576

def metric_results
  @metric_results
end

#metricx_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricxResult

Spec for MetricX result - calculates the MetricX score for the given instance using the version specified in the spec. Corresponds to the JSON property metricxResult



10582
10583
10584
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10582

def metricx_result
  @metricx_result
end

#pairwise_metric_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseMetricResult

Spec for pairwise metric result. Corresponds to the JSON property pairwiseMetricResult



10587
10588
10589
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10587

def pairwise_metric_result
  @pairwise_metric_result
end

#pairwise_question_answering_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseQuestionAnsweringQualityResult

Spec for pairwise question answering quality result. Corresponds to the JSON property pairwiseQuestionAnsweringQualityResult



10592
10593
10594
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10592

def pairwise_question_answering_quality_result
  @pairwise_question_answering_quality_result
end

#pairwise_summarization_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseSummarizationQualityResult

Spec for pairwise summarization quality result. Corresponds to the JSON property pairwiseSummarizationQualityResult



10597
10598
10599
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10597

def pairwise_summarization_quality_result
  @pairwise_summarization_quality_result
end

#pointwise_metric_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PointwiseMetricResult

Spec for pointwise metric result. Corresponds to the JSON property pointwiseMetricResult



10602
10603
10604
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10602

def pointwise_metric_result
  @pointwise_metric_result
end

#question_answering_correctness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringCorrectnessResult

Spec for question answering correctness result. Corresponds to the JSON property questionAnsweringCorrectnessResult



10607
10608
10609
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10607

def question_answering_correctness_result
  @question_answering_correctness_result
end

#question_answering_helpfulness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringHelpfulnessResult

Spec for question answering helpfulness result. Corresponds to the JSON property questionAnsweringHelpfulnessResult



10612
10613
10614
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10612

def question_answering_helpfulness_result
  @question_answering_helpfulness_result
end

#question_answering_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringQualityResult

Spec for question answering quality result. Corresponds to the JSON property questionAnsweringQualityResult



10617
10618
10619
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10617

def question_answering_quality_result
  @question_answering_quality_result
end

#question_answering_relevance_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringRelevanceResult

Spec for question answering relevance result. Corresponds to the JSON property questionAnsweringRelevanceResult



10622
10623
10624
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10622

def question_answering_relevance_result
  @question_answering_relevance_result
end

#rouge_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RougeResults

Results for rouge metric. Corresponds to the JSON property rougeResults



10627
10628
10629
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10627

def rouge_results
  @rouge_results
end

#rubric_based_instruction_following_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricBasedInstructionFollowingResult

Result for RubricBasedInstructionFollowing metric. Corresponds to the JSON property rubricBasedInstructionFollowingResult



10632
10633
10634
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10632

def rubric_based_instruction_following_result
  @rubric_based_instruction_following_result
end

#safety_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetyResult

Spec for safety result. Corresponds to the JSON property safetyResult



10637
10638
10639
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10637

def safety_result
  @safety_result
end

#summarization_helpfulness_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationHelpfulnessResult

Spec for summarization helpfulness result. Corresponds to the JSON property summarizationHelpfulnessResult



10642
10643
10644
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10642

def summarization_helpfulness_result
  @summarization_helpfulness_result
end

#summarization_quality_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationQualityResult

Spec for summarization quality result. Corresponds to the JSON property summarizationQualityResult



10647
10648
10649
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10647

def summarization_quality_result
  @summarization_quality_result
end

#summarization_verbosity_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationVerbosityResult

Spec for summarization verbosity result. Corresponds to the JSON property summarizationVerbosityResult



10652
10653
10654
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10652

def summarization_verbosity_result
  @summarization_verbosity_result
end

#tool_call_valid_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolCallValidResults

Results for tool call valid metric. Corresponds to the JSON property toolCallValidResults



10657
10658
10659
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10657

def tool_call_valid_results
  @tool_call_valid_results
end

#tool_name_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolNameMatchResults

Results for tool name match metric. Corresponds to the JSON property toolNameMatchResults



10662
10663
10664
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10662

def tool_name_match_results
  @tool_name_match_results
end

#tool_parameter_key_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParameterKeyMatchResults

Results for tool parameter key match metric. Corresponds to the JSON property toolParameterKeyMatchResults



10667
10668
10669
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10667

def tool_parameter_key_match_results
  @tool_parameter_key_match_results
end

#tool_parameter_kv_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParameterKvMatchResults

Results for tool parameter key value match metric. Corresponds to the JSON property toolParameterKvMatchResults



10672
10673
10674
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10672

def tool_parameter_kv_match_results
  @tool_parameter_kv_match_results
end

#trajectory_any_order_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchResults

Results for TrajectoryAnyOrderMatch metric. Corresponds to the JSON property trajectoryAnyOrderMatchResults



10677
10678
10679
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10677

def trajectory_any_order_match_results
  @trajectory_any_order_match_results
end

#trajectory_exact_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryExactMatchResults

Results for TrajectoryExactMatch metric. Corresponds to the JSON property trajectoryExactMatchResults



10682
10683
10684
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10682

def trajectory_exact_match_results
  @trajectory_exact_match_results
end

#trajectory_in_order_match_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchResults

Results for TrajectoryInOrderMatch metric. Corresponds to the JSON property trajectoryInOrderMatchResults



10687
10688
10689
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10687

def trajectory_in_order_match_results
  @trajectory_in_order_match_results
end

#trajectory_precision_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryPrecisionResults

Results for TrajectoryPrecision metric. Corresponds to the JSON property trajectoryPrecisionResults



10692
10693
10694
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10692

def trajectory_precision_results
  @trajectory_precision_results
end

#trajectory_recall_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryRecallResults

Results for TrajectoryRecall metric. Corresponds to the JSON property trajectoryRecallResults



10697
10698
10699
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10697

def trajectory_recall_results
  @trajectory_recall_results
end

#trajectory_single_tool_use_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectorySingleToolUseResults

Results for TrajectorySingleToolUse metric. Corresponds to the JSON property trajectorySingleToolUseResults



10702
10703
10704
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10702

def trajectory_single_tool_use_results
  @trajectory_single_tool_use_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10709
10710
10711
10712
10713
10714
10715
10716
10717
10718
10719
10720
10721
10722
10723
10724
10725
10726
10727
10728
10729
10730
10731
10732
10733
10734
10735
10736
10737
10738
10739
10740
10741
10742
10743
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10709

def update!(**args)
  @bleu_results = args[:bleu_results] if args.key?(:bleu_results)
  @coherence_result = args[:coherence_result] if args.key?(:coherence_result)
  @comet_result = args[:comet_result] if args.key?(:comet_result)
  @exact_match_results = args[:exact_match_results] if args.key?(:exact_match_results)
  @fluency_result = args[:fluency_result] if args.key?(:fluency_result)
  @fulfillment_result = args[:fulfillment_result] if args.key?(:fulfillment_result)
  @groundedness_result = args[:groundedness_result] if args.key?(:groundedness_result)
  @metric_results = args[:metric_results] if args.key?(:metric_results)
  @metricx_result = args[:metricx_result] if args.key?(:metricx_result)
  @pairwise_metric_result = args[:pairwise_metric_result] if args.key?(:pairwise_metric_result)
  @pairwise_question_answering_quality_result = args[:pairwise_question_answering_quality_result] if args.key?(:pairwise_question_answering_quality_result)
  @pairwise_summarization_quality_result = args[:pairwise_summarization_quality_result] if args.key?(:pairwise_summarization_quality_result)
  @pointwise_metric_result = args[:pointwise_metric_result] if args.key?(:pointwise_metric_result)
  @question_answering_correctness_result = args[:question_answering_correctness_result] if args.key?(:question_answering_correctness_result)
  @question_answering_helpfulness_result = args[:question_answering_helpfulness_result] if args.key?(:question_answering_helpfulness_result)
  @question_answering_quality_result = args[:question_answering_quality_result] if args.key?(:question_answering_quality_result)
  @question_answering_relevance_result = args[:question_answering_relevance_result] if args.key?(:question_answering_relevance_result)
  @rouge_results = args[:rouge_results] if args.key?(:rouge_results)
  @rubric_based_instruction_following_result = args[:rubric_based_instruction_following_result] if args.key?(:rubric_based_instruction_following_result)
  @safety_result = args[:safety_result] if args.key?(:safety_result)
  @summarization_helpfulness_result = args[:summarization_helpfulness_result] if args.key?(:summarization_helpfulness_result)
  @summarization_quality_result = args[:summarization_quality_result] if args.key?(:summarization_quality_result)
  @summarization_verbosity_result = args[:summarization_verbosity_result] if args.key?(:summarization_verbosity_result)
  @tool_call_valid_results = args[:tool_call_valid_results] if args.key?(:tool_call_valid_results)
  @tool_name_match_results = args[:tool_name_match_results] if args.key?(:tool_name_match_results)
  @tool_parameter_key_match_results = args[:tool_parameter_key_match_results] if args.key?(:tool_parameter_key_match_results)
  @tool_parameter_kv_match_results = args[:tool_parameter_kv_match_results] if args.key?(:tool_parameter_kv_match_results)
  @trajectory_any_order_match_results = args[:trajectory_any_order_match_results] if args.key?(:trajectory_any_order_match_results)
  @trajectory_exact_match_results = args[:trajectory_exact_match_results] if args.key?(:trajectory_exact_match_results)
  @trajectory_in_order_match_results = args[:trajectory_in_order_match_results] if args.key?(:trajectory_in_order_match_results)
  @trajectory_precision_results = args[:trajectory_precision_results] if args.key?(:trajectory_precision_results)
  @trajectory_recall_results = args[:trajectory_recall_results] if args.key?(:trajectory_recall_results)
  @trajectory_single_tool_use_results = args[:trajectory_single_tool_use_results] if args.key?(:trajectory_single_tool_use_results)
end