Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateInstancesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateInstancesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for EvaluationService.EvaluateInstances.
Instance Attribute Summary collapse
-
#bleu_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BleuResults
Results for bleu metric.
-
#coherence_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CoherenceResult
Spec for coherence result.
-
#comet_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CometResult
Spec for Comet result - calculates the comet score for the given instance using the version specified in the spec.
-
#exact_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExactMatchResults
Results for exact match metric.
-
#fluency_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FluencyResult
Spec for fluency result.
-
#fulfillment_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FulfillmentResult
Spec for fulfillment result.
-
#groundedness_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundednessResult
Spec for groundedness result.
-
#metric_results ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricResult>
Metric results for each instance.
-
#metricx_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricxResult
Spec for MetricX result - calculates the MetricX score for the given instance using the version specified in the spec.
-
#pairwise_metric_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseMetricResult
Spec for pairwise metric result.
-
#pairwise_question_answering_quality_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseQuestionAnsweringQualityResult
Spec for pairwise question answering quality result.
-
#pairwise_summarization_quality_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseSummarizationQualityResult
Spec for pairwise summarization quality result.
-
#pointwise_metric_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PointwiseMetricResult
Spec for pointwise metric result.
-
#question_answering_correctness_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringCorrectnessResult
Spec for question answering correctness result.
-
#question_answering_helpfulness_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringHelpfulnessResult
Spec for question answering helpfulness result.
-
#question_answering_quality_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringQualityResult
Spec for question answering quality result.
-
#question_answering_relevance_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringRelevanceResult
Spec for question answering relevance result.
-
#rouge_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RougeResults
Results for rouge metric.
-
#rubric_based_instruction_following_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricBasedInstructionFollowingResult
Result for RubricBasedInstructionFollowing metric.
-
#safety_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetyResult
Spec for safety result.
-
#summarization_helpfulness_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationHelpfulnessResult
Spec for summarization helpfulness result.
-
#summarization_quality_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationQualityResult
Spec for summarization quality result.
-
#summarization_verbosity_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationVerbosityResult
Spec for summarization verbosity result.
-
#tool_call_valid_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolCallValidResults
Results for tool call valid metric.
-
#tool_name_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolNameMatchResults
Results for tool name match metric.
-
#tool_parameter_key_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParameterKeyMatchResults
Results for tool parameter key match metric.
-
#tool_parameter_kv_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParameterKvMatchResults
Results for tool parameter key value match metric.
-
#trajectory_any_order_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchResults
Results for TrajectoryAnyOrderMatch metric.
-
#trajectory_exact_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryExactMatchResults
Results for TrajectoryExactMatch metric.
-
#trajectory_in_order_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchResults
Results for TrajectoryInOrderMatch metric.
-
#trajectory_precision_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryPrecisionResults
Results for TrajectoryPrecision metric.
-
#trajectory_recall_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryRecallResults
Results for TrajectoryRecall metric.
-
#trajectory_single_tool_use_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectorySingleToolUseResults
Results for TrajectorySingleToolUse metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluateInstancesResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluateInstancesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluateInstancesResponse
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluateInstancesResponse.
10638 10639 10640 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10638 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bleu_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BleuResults
Results for bleu metric.
Corresponds to the JSON property bleuResults
10473 10474 10475 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10473 def bleu_results @bleu_results end |
#coherence_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CoherenceResult
Spec for coherence result.
Corresponds to the JSON property coherenceResult
10478 10479 10480 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10478 def coherence_result @coherence_result end |
#comet_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CometResult
Spec for Comet result - calculates the comet score for the given instance
using the version specified in the spec.
Corresponds to the JSON property cometResult
10484 10485 10486 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10484 def comet_result @comet_result end |
#exact_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExactMatchResults
Results for exact match metric.
Corresponds to the JSON property exactMatchResults
10489 10490 10491 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10489 def exact_match_results @exact_match_results end |
#fluency_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FluencyResult
Spec for fluency result.
Corresponds to the JSON property fluencyResult
10494 10495 10496 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10494 def fluency_result @fluency_result end |
#fulfillment_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FulfillmentResult
Spec for fulfillment result.
Corresponds to the JSON property fulfillmentResult
10499 10500 10501 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10499 def fulfillment_result @fulfillment_result end |
#groundedness_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundednessResult
Spec for groundedness result.
Corresponds to the JSON property groundednessResult
10504 10505 10506 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10504 def groundedness_result @groundedness_result end |
#metric_results ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricResult>
Metric results for each instance. The order of the metric results is
guaranteed to be the same as the order of the instances in the request.
Corresponds to the JSON property metricResults
10510 10511 10512 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10510 def metric_results @metric_results end |
#metricx_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricxResult
Spec for MetricX result - calculates the MetricX score for the given instance
using the version specified in the spec.
Corresponds to the JSON property metricxResult
10516 10517 10518 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10516 def metricx_result @metricx_result end |
#pairwise_metric_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseMetricResult
Spec for pairwise metric result.
Corresponds to the JSON property pairwiseMetricResult
10521 10522 10523 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10521 def pairwise_metric_result @pairwise_metric_result end |
#pairwise_question_answering_quality_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseQuestionAnsweringQualityResult
Spec for pairwise question answering quality result.
Corresponds to the JSON property pairwiseQuestionAnsweringQualityResult
10526 10527 10528 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10526 def pairwise_question_answering_quality_result @pairwise_question_answering_quality_result end |
#pairwise_summarization_quality_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseSummarizationQualityResult
Spec for pairwise summarization quality result.
Corresponds to the JSON property pairwiseSummarizationQualityResult
10531 10532 10533 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10531 def pairwise_summarization_quality_result @pairwise_summarization_quality_result end |
#pointwise_metric_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PointwiseMetricResult
Spec for pointwise metric result.
Corresponds to the JSON property pointwiseMetricResult
10536 10537 10538 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10536 def pointwise_metric_result @pointwise_metric_result end |
#question_answering_correctness_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringCorrectnessResult
Spec for question answering correctness result.
Corresponds to the JSON property questionAnsweringCorrectnessResult
10541 10542 10543 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10541 def question_answering_correctness_result @question_answering_correctness_result end |
#question_answering_helpfulness_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringHelpfulnessResult
Spec for question answering helpfulness result.
Corresponds to the JSON property questionAnsweringHelpfulnessResult
10546 10547 10548 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10546 def question_answering_helpfulness_result @question_answering_helpfulness_result end |
#question_answering_quality_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringQualityResult
Spec for question answering quality result.
Corresponds to the JSON property questionAnsweringQualityResult
10551 10552 10553 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10551 def question_answering_quality_result @question_answering_quality_result end |
#question_answering_relevance_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QuestionAnsweringRelevanceResult
Spec for question answering relevance result.
Corresponds to the JSON property questionAnsweringRelevanceResult
10556 10557 10558 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10556 def question_answering_relevance_result @question_answering_relevance_result end |
#rouge_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RougeResults
Results for rouge metric.
Corresponds to the JSON property rougeResults
10561 10562 10563 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10561 def rouge_results @rouge_results end |
#rubric_based_instruction_following_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricBasedInstructionFollowingResult
Result for RubricBasedInstructionFollowing metric.
Corresponds to the JSON property rubricBasedInstructionFollowingResult
10566 10567 10568 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10566 def rubric_based_instruction_following_result @rubric_based_instruction_following_result end |
#safety_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetyResult
Spec for safety result.
Corresponds to the JSON property safetyResult
10571 10572 10573 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10571 def safety_result @safety_result end |
#summarization_helpfulness_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationHelpfulnessResult
Spec for summarization helpfulness result.
Corresponds to the JSON property summarizationHelpfulnessResult
10576 10577 10578 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10576 def summarization_helpfulness_result @summarization_helpfulness_result end |
#summarization_quality_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationQualityResult
Spec for summarization quality result.
Corresponds to the JSON property summarizationQualityResult
10581 10582 10583 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10581 def summarization_quality_result @summarization_quality_result end |
#summarization_verbosity_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummarizationVerbosityResult
Spec for summarization verbosity result.
Corresponds to the JSON property summarizationVerbosityResult
10586 10587 10588 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10586 def summarization_verbosity_result @summarization_verbosity_result end |
#tool_call_valid_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolCallValidResults
Results for tool call valid metric.
Corresponds to the JSON property toolCallValidResults
10591 10592 10593 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10591 def tool_call_valid_results @tool_call_valid_results end |
#tool_name_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolNameMatchResults
Results for tool name match metric.
Corresponds to the JSON property toolNameMatchResults
10596 10597 10598 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10596 def tool_name_match_results @tool_name_match_results end |
#tool_parameter_key_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParameterKeyMatchResults
Results for tool parameter key match metric.
Corresponds to the JSON property toolParameterKeyMatchResults
10601 10602 10603 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10601 def tool_parameter_key_match_results @tool_parameter_key_match_results end |
#tool_parameter_kv_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParameterKvMatchResults
Results for tool parameter key value match metric.
Corresponds to the JSON property toolParameterKvMatchResults
10606 10607 10608 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10606 def tool_parameter_kv_match_results @tool_parameter_kv_match_results end |
#trajectory_any_order_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchResults
Results for TrajectoryAnyOrderMatch metric.
Corresponds to the JSON property trajectoryAnyOrderMatchResults
10611 10612 10613 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10611 def trajectory_any_order_match_results @trajectory_any_order_match_results end |
#trajectory_exact_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryExactMatchResults
Results for TrajectoryExactMatch metric.
Corresponds to the JSON property trajectoryExactMatchResults
10616 10617 10618 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10616 def trajectory_exact_match_results @trajectory_exact_match_results end |
#trajectory_in_order_match_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchResults
Results for TrajectoryInOrderMatch metric.
Corresponds to the JSON property trajectoryInOrderMatchResults
10621 10622 10623 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10621 def trajectory_in_order_match_results @trajectory_in_order_match_results end |
#trajectory_precision_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryPrecisionResults
Results for TrajectoryPrecision metric.
Corresponds to the JSON property trajectoryPrecisionResults
10626 10627 10628 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10626 def trajectory_precision_results @trajectory_precision_results end |
#trajectory_recall_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryRecallResults
Results for TrajectoryRecall metric.
Corresponds to the JSON property trajectoryRecallResults
10631 10632 10633 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10631 def trajectory_recall_results @trajectory_recall_results end |
#trajectory_single_tool_use_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectorySingleToolUseResults
Results for TrajectorySingleToolUse metric.
Corresponds to the JSON property trajectorySingleToolUseResults
10636 10637 10638 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10636 def trajectory_single_tool_use_results @trajectory_single_tool_use_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10643 10644 10645 10646 10647 10648 10649 10650 10651 10652 10653 10654 10655 10656 10657 10658 10659 10660 10661 10662 10663 10664 10665 10666 10667 10668 10669 10670 10671 10672 10673 10674 10675 10676 10677 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10643 def update!(**args) @bleu_results = args[:bleu_results] if args.key?(:bleu_results) @coherence_result = args[:coherence_result] if args.key?(:coherence_result) @comet_result = args[:comet_result] if args.key?(:comet_result) @exact_match_results = args[:exact_match_results] if args.key?(:exact_match_results) @fluency_result = args[:fluency_result] if args.key?(:fluency_result) @fulfillment_result = args[:fulfillment_result] if args.key?(:fulfillment_result) @groundedness_result = args[:groundedness_result] if args.key?(:groundedness_result) @metric_results = args[:metric_results] if args.key?(:metric_results) @metricx_result = args[:metricx_result] if args.key?(:metricx_result) @pairwise_metric_result = args[:pairwise_metric_result] if args.key?(:pairwise_metric_result) @pairwise_question_answering_quality_result = args[:pairwise_question_answering_quality_result] if args.key?(:pairwise_question_answering_quality_result) @pairwise_summarization_quality_result = args[:pairwise_summarization_quality_result] if args.key?(:pairwise_summarization_quality_result) @pointwise_metric_result = args[:pointwise_metric_result] if args.key?(:pointwise_metric_result) @question_answering_correctness_result = args[:question_answering_correctness_result] if args.key?(:question_answering_correctness_result) @question_answering_helpfulness_result = args[:question_answering_helpfulness_result] if args.key?(:question_answering_helpfulness_result) @question_answering_quality_result = args[:question_answering_quality_result] if args.key?(:question_answering_quality_result) @question_answering_relevance_result = args[:question_answering_relevance_result] if args.key?(:question_answering_relevance_result) @rouge_results = args[:rouge_results] if args.key?(:rouge_results) @rubric_based_instruction_following_result = args[:rubric_based_instruction_following_result] if args.key?(:rubric_based_instruction_following_result) @safety_result = args[:safety_result] if args.key?(:safety_result) @summarization_helpfulness_result = args[:summarization_helpfulness_result] if args.key?(:summarization_helpfulness_result) @summarization_quality_result = args[:summarization_quality_result] if args.key?(:summarization_quality_result) @summarization_verbosity_result = args[:summarization_verbosity_result] if args.key?(:summarization_verbosity_result) @tool_call_valid_results = args[:tool_call_valid_results] if args.key?(:tool_call_valid_results) @tool_name_match_results = args[:tool_name_match_results] if args.key?(:tool_name_match_results) @tool_parameter_key_match_results = args[:tool_parameter_key_match_results] if args.key?(:tool_parameter_key_match_results) @tool_parameter_kv_match_results = args[:tool_parameter_kv_match_results] if args.key?(:tool_parameter_kv_match_results) @trajectory_any_order_match_results = args[:trajectory_any_order_match_results] if args.key?(:trajectory_any_order_match_results) @trajectory_exact_match_results = args[:trajectory_exact_match_results] if args.key?(:trajectory_exact_match_results) @trajectory_in_order_match_results = args[:trajectory_in_order_match_results] if args.key?(:trajectory_in_order_match_results) @trajectory_precision_results = args[:trajectory_precision_results] if args.key?(:trajectory_precision_results) @trajectory_recall_results = args[:trajectory_recall_results] if args.key?(:trajectory_recall_results) @trajectory_single_tool_use_results = args[:trajectory_single_tool_use_results] if args.key?(:trajectory_single_tool_use_results) end |