Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluatedAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluatedAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
True positive, false positive, or false negative. EvaluatedAnnotation is only
available under ModelEvaluationSlice with slice of annotationSpec dimension.
Instance Attribute Summary collapse
-
#data_item_payload ⇒ Object
Output only.
-
#error_analysis_annotations ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation>
Annotations of model error analysis results.
-
#evaluated_data_item_view_id ⇒ String
Output only.
-
#explanations ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluatedAnnotationExplanation>
Explanations of predictions.
-
#ground_truths ⇒ Array<Object>
Output only.
-
#predictions ⇒ Array<Object>
Output only.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluatedAnnotation
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluatedAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluatedAnnotation
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluatedAnnotation.
10741 10742 10743 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10741 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_item_payload ⇒ Object
Output only. The data item payload that the Model predicted this
EvaluatedAnnotation on.
Corresponds to the JSON property dataItemPayload
10689 10690 10691 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10689 def data_item_payload @data_item_payload end |
#error_analysis_annotations ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ErrorAnalysisAnnotation>
Annotations of model error analysis results.
Corresponds to the JSON property errorAnalysisAnnotations
10694 10695 10696 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10694 def error_analysis_annotations @error_analysis_annotations end |
#evaluated_data_item_view_id ⇒ String
Output only. ID of the EvaluatedDataItemView under the same ancestor
ModelEvaluation. The EvaluatedDataItemView consists of all ground truths and
predictions on data_item_payload.
Corresponds to the JSON property evaluatedDataItemViewId
10701 10702 10703 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10701 def evaluated_data_item_view_id @evaluated_data_item_view_id end |
#explanations ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluatedAnnotationExplanation>
Explanations of predictions. Each element of the explanations indicates the
explanation for one explanation Method. The attributions list in the
EvaluatedAnnotationExplanation.explanation object corresponds to the
predictions list. For example, the second element in the attributions list
explains the second element in the predictions list.
Corresponds to the JSON property explanations
10710 10711 10712 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10710 def explanations @explanations end |
#ground_truths ⇒ Array<Object>
Output only. The ground truth Annotations, i.e. the Annotations that exist in
the test data the Model is evaluated on. For true positive, there is one and
only one ground truth annotation, which matches the only prediction in
predictions. For false positive, there are zero or more ground truth
annotations that are similar to the only prediction in predictions, but not
enough for a match. For false negative, there is one and only one ground truth
annotation, which doesn't match any predictions created by the model. The
schema of the ground truth is stored in ModelEvaluation.annotation_schema_uri
Corresponds to the JSON property groundTruths
10722 10723 10724 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10722 def ground_truths @ground_truths end |
#predictions ⇒ Array<Object>
Output only. The model predicted annotations. For true positive, there is one
and only one prediction, which matches the only one ground truth annotation in
ground_truths. For false positive, there is one and only one prediction, which
doesn't match any ground truth annotation of the corresponding
data_item_view_id. For false negative, there are zero or more predictions
which are similar to the only ground truth annotation in ground_truths but not
enough for a match. The schema of the prediction is stored in ModelEvaluation.
annotation_schema_uri
Corresponds to the JSON property predictions
10734 10735 10736 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10734 def predictions @predictions end |
#type ⇒ String
Output only. Type of the EvaluatedAnnotation.
Corresponds to the JSON property type
10739 10740 10741 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10739 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10746 10747 10748 10749 10750 10751 10752 10753 10754 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 10746 def update!(**args) @data_item_payload = args[:data_item_payload] if args.key?(:data_item_payload) @error_analysis_annotations = args[:error_analysis_annotations] if args.key?(:error_analysis_annotations) @evaluated_data_item_view_id = args[:evaluated_data_item_view_id] if args.key?(:evaluated_data_item_view_id) @explanations = args[:explanations] if args.key?(:explanations) @ground_truths = args[:ground_truths] if args.key?(:ground_truths) @predictions = args[:predictions] if args.key?(:predictions) @type = args[:type] if args.key?(:type) end |