Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstance
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations
Instance Attribute Summary collapse
-
#agent_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData
Deprecated: Use
agent_eval_datainstead. -
#agent_eval_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData
Represents data specific to multi-turn agent evaluations.
-
#interactions_data_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInteractionsDataSource
Source for populating
AgentDatafrom an Interactions API interaction. -
#other_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceMapInstance
Instance data specified as a map.
-
#prompt ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#reference ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#response ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#rubric_groups ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGroup>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstance
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstance
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationInstance.
18837 18838 18839 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData
Deprecated: Use agent_eval_data instead. Contains data specific to agent
evaluations.
Corresponds to the JSON property agentData
18798 18799 18800 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18798 def agent_data @agent_data end |
#agent_eval_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData
Represents data specific to multi-turn agent evaluations.
Corresponds to the JSON property agentEvalData
18803 18804 18805 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18803 def agent_eval_data @agent_eval_data end |
#interactions_data_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInteractionsDataSource
Source for populating AgentData from an Interactions API interaction.
Corresponds to the JSON property interactionsDataSource
18808 18809 18810 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18808 def interactions_data_source @interactions_data_source end |
#other_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceMapInstance
Instance data specified as a map.
Corresponds to the JSON property otherData
18813 18814 18815 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18813 def other_data @other_data end |
#prompt ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property prompt
18818 18819 18820 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18818 def prompt @prompt end |
#reference ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property reference
18823 18824 18825 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18823 def reference @reference end |
#response ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property response
18828 18829 18830 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18828 def response @response end |
#rubric_groups ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGroup>
Optional. Named groups of rubrics associated with the prompt. This is used for
rubric-based evaluations where rubrics can be referenced by a key. The key
could represent versions, associated metrics, etc.
Corresponds to the JSON property rubricGroups
18835 18836 18837 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18835 def rubric_groups @rubric_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18842 18843 18844 18845 18846 18847 18848 18849 18850 18851 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18842 def update!(**args) @agent_data = args[:agent_data] if args.key?(:agent_data) @agent_eval_data = args[:agent_eval_data] if args.key?(:agent_eval_data) @interactions_data_source = args[:interactions_data_source] if args.key?(:interactions_data_source) @other_data = args[:other_data] if args.key?(:other_data) @prompt = args[:prompt] if args.key?(:prompt) @reference = args[:reference] if args.key?(:reference) @response = args[:response] if args.key?(:response) @rubric_groups = args[:rubric_groups] if args.key?(:rubric_groups) end |