Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstance

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationInstance.



18417
18418
18419
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData

Deprecated: Use agent_eval_data instead. Contains data specific to agent evaluations. Corresponds to the JSON property agentData



18383
18384
18385
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18383

def agent_data
  @agent_data
end

#agent_eval_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData

Represents data specific to multi-turn agent evaluations. Corresponds to the JSON property agentEvalData



18388
18389
18390
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18388

def agent_eval_data
  @agent_eval_data
end

#other_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceMapInstance

Instance data specified as a map. Corresponds to the JSON property otherData



18393
18394
18395
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18393

def other_data
  @other_data
end

#promptGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property prompt



18398
18399
18400
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18398

def prompt
  @prompt
end

#referenceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property reference



18403
18404
18405
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18403

def reference
  @reference
end

#responseGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property response



18408
18409
18410
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18408

def response
  @response
end

#rubric_groupsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGroup>

Optional. Named groups of rubrics associated with the prompt. This is used for rubric-based evaluations where rubrics can be referenced by a key. The key could represent versions, associated metrics, etc. Corresponds to the JSON property rubricGroups



18415
18416
18417
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18415

def rubric_groups
  @rubric_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18422
18423
18424
18425
18426
18427
18428
18429
18430
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18422

def update!(**args)
  @agent_data = args[:agent_data] if args.key?(:agent_data)
  @agent_eval_data = args[:agent_eval_data] if args.key?(:agent_eval_data)
  @other_data = args[:other_data] if args.key?(:other_data)
  @prompt = args[:prompt] if args.key?(:prompt)
  @reference = args[:reference] if args.key?(:reference)
  @response = args[:response] if args.key?(:response)
  @rubric_groups = args[:rubric_groups] if args.key?(:rubric_groups)
end