Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstance

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationInstance.



17029
17030
17031
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData

Deprecated: Use agent_eval_data instead. Contains data specific to agent evaluations. Corresponds to the JSON property agentData



16995
16996
16997
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16995

def agent_data
  @agent_data
end

#agent_eval_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData

Represents data specific to multi-turn agent evaluations. Corresponds to the JSON property agentEvalData



17000
17001
17002
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17000

def agent_eval_data
  @agent_eval_data
end

#other_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceMapInstance

Instance data specified as a map. Corresponds to the JSON property otherData



17005
17006
17007
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17005

def other_data
  @other_data
end

#promptGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property prompt



17010
17011
17012
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17010

def prompt
  @prompt
end

#referenceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property reference



17015
17016
17017
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17015

def reference
  @reference
end

#responseGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property response



17020
17021
17022
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17020

def response
  @response
end

#rubric_groupsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGroup>

Optional. Named groups of rubrics associated with the prompt. This is used for rubric-based evaluations where rubrics can be referenced by a key. The key could represent versions, associated metrics, etc. Corresponds to the JSON property rubricGroups



17027
17028
17029
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17027

def rubric_groups
  @rubric_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17034
17035
17036
17037
17038
17039
17040
17041
17042
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17034

def update!(**args)
  @agent_data = args[:agent_data] if args.key?(:agent_data)
  @agent_eval_data = args[:agent_eval_data] if args.key?(:agent_eval_data)
  @other_data = args[:other_data] if args.key?(:other_data)
  @prompt = args[:prompt] if args.key?(:prompt)
  @reference = args[:reference] if args.key?(:reference)
  @response = args[:response] if args.key?(:response)
  @rubric_groups = args[:rubric_groups] if args.key?(:rubric_groups)
end