Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstance
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations
Instance Attribute Summary collapse
-
#agent_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData
Deprecated: Use
agent_eval_datainstead. -
#agent_eval_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData
Represents data specific to multi-turn agent evaluations.
-
#other_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceMapInstance
Instance data specified as a map.
-
#prompt ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#reference ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#response ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#rubric_groups ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGroup>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstance
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstance
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationInstance.
15750 15751 15752 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData
Deprecated: Use agent_eval_data instead. Contains data specific to agent
evaluations.
Corresponds to the JSON property agentData
15716 15717 15718 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15716 def agent_data @agent_data end |
#agent_eval_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData
Represents data specific to multi-turn agent evaluations.
Corresponds to the JSON property agentEvalData
15721 15722 15723 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15721 def agent_eval_data @agent_eval_data end |
#other_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceMapInstance
Instance data specified as a map.
Corresponds to the JSON property otherData
15726 15727 15728 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15726 def other_data @other_data end |
#prompt ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property prompt
15731 15732 15733 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15731 def prompt @prompt end |
#reference ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property reference
15736 15737 15738 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15736 def reference @reference end |
#response ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property response
15741 15742 15743 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15741 def response @response end |
#rubric_groups ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGroup>
Optional. Named groups of rubrics associated with the prompt. This is used for
rubric-based evaluations where rubrics can be referenced by a key. The key
could represent versions, associated metrics, etc.
Corresponds to the JSON property rubricGroups
15748 15749 15750 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15748 def rubric_groups @rubric_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15755 15756 15757 15758 15759 15760 15761 15762 15763 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15755 def update!(**args) @agent_data = args[:agent_data] if args.key?(:agent_data) @agent_eval_data = args[:agent_eval_data] if args.key?(:agent_eval_data) @other_data = args[:other_data] if args.key?(:other_data) @prompt = args[:prompt] if args.key?(:prompt) @reference = args[:reference] if args.key?(:reference) @response = args[:response] if args.key?(:response) @rubric_groups = args[:rubric_groups] if args.key?(:rubric_groups) end |