Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Deprecated: Use google.cloud.aiplatform.master.AgentConfig in
agent_eval_data instead. Configuration for an Agent.
Instance Attribute Summary collapse
-
#agent_id ⇒ String
Optional.
-
#agent_type ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#developer_instruction ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#sub_agents ⇒ Array<String>
Optional.
-
#tools ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfigTools
Represents a list of tools for an agent.
-
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig.
18901 18902 18903 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
Optional. Unique identifier of the agent. This ID is used to refer to this
agent, e.g., in AgentEvent.author, or in the sub_agents field. It must be
unique within the agents map.
Corresponds to the JSON property agentId
18864 18865 18866 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18864 def agent_id @agent_id end |
#agent_type ⇒ String
Optional. The type or class of the agent (e.g., "LlmAgent", "RouterAgent", "
ToolUseAgent"). Useful for the autorater to understand the expected behavior
of the agent.
Corresponds to the JSON property agentType
18871 18872 18873 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18871 def agent_type @agent_type end |
#description ⇒ String
Optional. A high-level description of the agent's role and responsibilities.
Critical for evaluating if the agent is routing tasks correctly.
Corresponds to the JSON property description
18877 18878 18879 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18877 def description @description end |
#developer_instruction ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property developerInstruction
18882 18883 18884 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18882 def developer_instruction @developer_instruction end |
#sub_agents ⇒ Array<String>
Optional. The list of valid agent IDs (names) that this agent can delegate to.
This defines the directed edges in the agent system graph topology.
Corresponds to the JSON property subAgents
18888 18889 18890 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18888 def sub_agents @sub_agents end |
#tools ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfigTools
Represents a list of tools for an agent.
Corresponds to the JSON property tools
18893 18894 18895 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18893 def tools @tools end |
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such
as name, description, parameters and required parameters.
Corresponds to the JSON property toolsText
18899 18900 18901 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18899 def tools_text @tools_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18906 18907 18908 18909 18910 18911 18912 18913 18914 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18906 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @agent_type = args[:agent_type] if args.key?(:agent_type) @description = args[:description] if args.key?(:description) @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction) @sub_agents = args[:sub_agents] if args.key?(:sub_agents) @tools = args[:tools] if args.key?(:tools) @tools_text = args[:tools_text] if args.key?(:tools_text) end |