Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Deprecated: Use google.cloud.aiplatform.master.AgentConfig in agent_eval_data instead. Configuration for an Agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig.



15813
15814
15815
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15813

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

Optional. Unique identifier of the agent. This ID is used to refer to this agent, e.g., in AgentEvent.author, or in the sub_agents field. It must be unique within the agents map. Corresponds to the JSON property agentId

Returns:

  • (String)


15776
15777
15778
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15776

def agent_id
  @agent_id
end

#agent_typeString

Optional. The type or class of the agent (e.g., "LlmAgent", "RouterAgent", " ToolUseAgent"). Useful for the autorater to understand the expected behavior of the agent. Corresponds to the JSON property agentType

Returns:

  • (String)


15783
15784
15785
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15783

def agent_type
  @agent_type
end

#descriptionString

Optional. A high-level description of the agent's role and responsibilities. Critical for evaluating if the agent is routing tasks correctly. Corresponds to the JSON property description

Returns:

  • (String)


15789
15790
15791
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15789

def description
  @description
end

#developer_instructionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property developerInstruction



15794
15795
15796
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15794

def developer_instruction
  @developer_instruction
end

#sub_agentsArray<String>

Optional. The list of valid agent IDs (names) that this agent can delegate to. This defines the directed edges in the agent system graph topology. Corresponds to the JSON property subAgents

Returns:

  • (Array<String>)


15800
15801
15802
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15800

def sub_agents
  @sub_agents
end

#toolsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfigTools

Represents a list of tools for an agent. Corresponds to the JSON property tools



15805
15806
15807
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15805

def tools
  @tools
end

#tools_textString

A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters. Corresponds to the JSON property toolsText

Returns:

  • (String)


15811
15812
15813
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15811

def tools_text
  @tools_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15818
15819
15820
15821
15822
15823
15824
15825
15826
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15818

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @agent_type = args[:agent_type] if args.key?(:agent_type)
  @description = args[:description] if args.key?(:description)
  @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction)
  @sub_agents = args[:sub_agents] if args.key?(:sub_agents)
  @tools = args[:tools] if args.key?(:tools)
  @tools_text = args[:tools_text] if args.key?(:tools_text)
end