Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Deprecated: Use agent_eval_data instead. Contains data specific to agent evaluations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData.



17173
17174
17175
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig

Deprecated: Use google.cloud.aiplatform.master.AgentConfig in agent_eval_data instead. Configuration for an Agent. Corresponds to the JSON property agentConfig



17136
17137
17138
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17136

def agent_config
  @agent_config
end

#agentsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig>

Optional. The static Agent Configuration. This map defines the graph structure of the agent system. Key: agent_id (matches the author field in events). Value: The static configuration of the agent (tools, instructions, sub-agents). Corresponds to the JSON property agents



17143
17144
17145
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17143

def agents
  @agents
end

#developer_instructionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property developerInstruction



17148
17149
17150
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17148

def developer_instruction
  @developer_instruction
end

#eventsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataEvents

Represents a list of events for an agent. Corresponds to the JSON property events



17153
17154
17155
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17153

def events
  @events
end

#toolsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataTools

Deprecated: Use agent_eval_data instead. Represents a list of tools for an agent. Corresponds to the JSON property tools



17159
17160
17161
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17159

def tools
  @tools
end

#tools_textString

A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters. Corresponds to the JSON property toolsText

Returns:

  • (String)


17165
17166
17167
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17165

def tools_text
  @tools_text
end

#turnsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataConversationTurn>

Optional. The chronological list of conversation turns. Each turn represents a logical execution cycle (e.g., User Input -> Agent Response). Corresponds to the JSON property turns



17171
17172
17173
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17171

def turns
  @turns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17178
17179
17180
17181
17182
17183
17184
17185
17186
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17178

def update!(**args)
  @agent_config = args[:agent_config] if args.key?(:agent_config)
  @agents = args[:agents] if args.key?(:agents)
  @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction)
  @events = args[:events] if args.key?(:events)
  @tools = args[:tools] if args.key?(:tools)
  @tools_text = args[:tools_text] if args.key?(:tools_text)
  @turns = args[:turns] if args.key?(:turns)
end