Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Deprecated: Use agent_eval_data instead. Contains data specific to agent
evaluations.
Instance Attribute Summary collapse
-
#agent_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig
Deprecated: Use
google.cloud.aiplatform.master.AgentConfiginagent_eval_datainstead. -
#agents ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig>
Optional.
-
#developer_instruction ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#events ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataEvents
Represents a list of events for an agent.
-
#tools ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataTools
Deprecated: Use
agent_eval_datainstead. -
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters.
-
#turns ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataConversationTurn>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentData.
15894 15895 15896 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15894 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig
Deprecated: Use google.cloud.aiplatform.master.AgentConfig in
agent_eval_data instead. Configuration for an Agent.
Corresponds to the JSON property agentConfig
15857 15858 15859 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15857 def agent_config @agent_config end |
#agents ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig>
Optional. The static Agent Configuration. This map defines the graph structure
of the agent system. Key: agent_id (matches the author field in events).
Value: The static configuration of the agent (tools, instructions, sub-agents).
Corresponds to the JSON property agents
15864 15865 15866 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15864 def agents @agents end |
#developer_instruction ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property developerInstruction
15869 15870 15871 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15869 def developer_instruction @developer_instruction end |
#events ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataEvents
Represents a list of events for an agent.
Corresponds to the JSON property events
15874 15875 15876 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15874 def events @events end |
#tools ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataTools
Deprecated: Use agent_eval_data instead. Represents a list of tools for an
agent.
Corresponds to the JSON property tools
15880 15881 15882 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15880 def tools @tools end |
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such
as name, description, parameters and required parameters.
Corresponds to the JSON property toolsText
15886 15887 15888 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15886 def tools_text @tools_text end |
#turns ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataConversationTurn>
Optional. The chronological list of conversation turns. Each turn represents a
logical execution cycle (e.g., User Input -> Agent Response).
Corresponds to the JSON property turns
15892 15893 15894 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15892 def turns @turns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15899 15900 15901 15902 15903 15904 15905 15906 15907 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15899 def update!(**args) @agent_config = args[:agent_config] if args.key?(:agent_config) @agents = args[:agents] if args.key?(:agents) @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction) @events = args[:events] if args.key?(:events) @tools = args[:tools] if args.key?(:tools) @tools_text = args[:tools_text] if args.key?(:tools_text) @turns = args[:turns] if args.key?(:turns) end |