Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataAgentEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataAgentEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A single event in the execution trace.
Instance Attribute Summary collapse
-
#active_tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional.
-
#author ⇒ String
Required.
-
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message.
-
#event_time ⇒ String
Optional.
-
#state_delta ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataAgentEvent
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataAgentEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataAgentEvent
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataAgentEvent.
11092 11093 11094 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11092 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional. The list of tools that were active/available to the agent at the
time of this event. This overrides the AgentConfig.tools if set.
Corresponds to the JSON property activeTools
11067 11068 11069 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11067 def active_tools @active_tools end |
#author ⇒ String
Required. The ID of the agent or entity that generated this event.
Corresponds to the JSON property author
11072 11073 11074 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11072 def @author end |
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
11079 11080 11081 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11079 def content @content end |
#event_time ⇒ String
Optional. The timestamp when the event occurred.
Corresponds to the JSON property eventTime
11084 11085 11086 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11084 def event_time @event_time end |
#state_delta ⇒ Hash<String,Object>
Optional. The change in the session state caused by this event. This is a key-
value map of fields that were modified or added by the event.
Corresponds to the JSON property stateDelta
11090 11091 11092 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11090 def state_delta @state_delta end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11097 11098 11099 11100 11101 11102 11103 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11097 def update!(**args) @active_tools = args[:active_tools] if args.key?(:active_tools) @author = args[:author] if args.key?(:author) @content = args[:content] if args.key?(:content) @event_time = args[:event_time] if args.key?(:event_time) @state_delta = args[:state_delta] if args.key?(:state_delta) end |