Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataConversationTurn
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataConversationTurn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a single turn/invocation in the conversation.
Instance Attribute Summary collapse
-
#events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataAgentEvent>
Optional.
-
#turn_id ⇒ String
Optional.
-
#turn_index ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataConversationTurn
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataConversationTurn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataConversationTurn
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataConversationTurn.
11126 11127 11128 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentDataAgentEvent>
Optional. The list of events that occurred during this turn.
Corresponds to the JSON property events
11113 11114 11115 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11113 def events @events end |
#turn_id ⇒ String
Optional. A unique identifier for the turn. Useful for referencing specific
turns across systems.
Corresponds to the JSON property turnId
11119 11120 11121 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11119 def turn_id @turn_id end |
#turn_index ⇒ Fixnum
Required. The 0-based index of the turn in the conversation sequence.
Corresponds to the JSON property turnIndex
11124 11125 11126 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11124 def turn_index @turn_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11131 11132 11133 11134 11135 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11131 def update!(**args) @events = args[:events] if args.key?(:events) @turn_id = args[:turn_id] if args.key?(:turn_id) @turn_index = args[:turn_index] if args.key?(:turn_index) end |