Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

EvaluationItem is a single evaluation request or result. The content of an EvaluationItem is immutable - it cannot be updated once created. EvaluationItems can be deleted when no longer needed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationItem

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationItem.



18826
18827
18828
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18826

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this item was created. Corresponds to the JSON property createTime

Returns:

  • (String)


18767
18768
18769
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18767

def create_time
  @create_time
end

#display_nameString

Required. The display name of the EvaluationItem. Corresponds to the JSON property displayName

Returns:

  • (String)


18772
18773
18774
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18772

def display_name
  @display_name
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



18782
18783
18784
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18782

def error
  @error
end

#evaluation_item_typeString

Required. The type of the EvaluationItem. Corresponds to the JSON property evaluationItemType

Returns:

  • (String)


18787
18788
18789
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18787

def evaluation_item_type
  @evaluation_item_type
end

#evaluation_requestGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRequest

A single evaluation request supporting input for both single-turn model generation and multi-turn agent execution traces. Valid input modes: 1. Inference Mode: prompt is set (containing text or AgentData context). 2. Offline Eval Mode: prompt is unset, and candidate_responses contains agent_data (the completed execution trace). Validation Rule: Either prompt must be set, OR at least one of the candidate_responses must contain agent_data. Corresponds to the JSON property evaluationRequest



18798
18799
18800
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18798

def evaluation_request
  @evaluation_request
end

#evaluation_responseGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationResult

Evaluation result. Corresponds to the JSON property evaluationResponse



18803
18804
18805
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18803

def evaluation_response
  @evaluation_response
end

#gcs_uriString

The Cloud Storage object where the request or response is stored. Corresponds to the JSON property gcsUri

Returns:

  • (String)


18808
18809
18810
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18808

def gcs_uri
  @gcs_uri
end

#labelsHash<String,String>

Optional. Labels for the EvaluationItem. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


18813
18814
18815
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18813

def labels
  @labels
end

#metadataObject

Optional. Metadata for the EvaluationItem. Corresponds to the JSON property metadata

Returns:

  • (Object)


18818
18819
18820
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18818

def 
  @metadata
end

#nameString

Identifier. The resource name of the EvaluationItem. Format: projects/ project/locations/location/evaluationItems/evaluation_item` Corresponds to the JSON propertyname`

Returns:

  • (String)


18824
18825
18826
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18824

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18831

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
  @evaluation_item_type = args[:evaluation_item_type] if args.key?(:evaluation_item_type)
  @evaluation_request = args[:evaluation_request] if args.key?(:evaluation_request)
  @evaluation_response = args[:evaluation_response] if args.key?(:evaluation_response)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end