Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

EvaluationItem is a single evaluation request or result. The content of an EvaluationItem is immutable - it cannot be updated once created. EvaluationItems can be deleted when no longer needed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationItem

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationItem.



16159
16160
16161
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16159

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this item was created. Corresponds to the JSON property createTime

Returns:

  • (String)


16100
16101
16102
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16100

def create_time
  @create_time
end

#display_nameString

Required. The display name of the EvaluationItem. Corresponds to the JSON property displayName

Returns:

  • (String)


16105
16106
16107
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16105

def display_name
  @display_name
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



16115
16116
16117
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16115

def error
  @error
end

#evaluation_item_typeString

Required. The type of the EvaluationItem. Corresponds to the JSON property evaluationItemType

Returns:

  • (String)


16120
16121
16122
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16120

def evaluation_item_type
  @evaluation_item_type
end

#evaluation_requestGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRequest

A single evaluation request supporting input for both single-turn model generation and multi-turn agent execution traces. Valid input modes: 1. Inference Mode: prompt is set (containing text or AgentData context). 2. Offline Eval Mode: prompt is unset, and candidate_responses contains agent_data (the completed execution trace). Validation Rule: Either prompt must be set, OR at least one of the candidate_responses must contain agent_data. Corresponds to the JSON property evaluationRequest



16131
16132
16133
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16131

def evaluation_request
  @evaluation_request
end

#evaluation_responseGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationResult

Evaluation result. Corresponds to the JSON property evaluationResponse



16136
16137
16138
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16136

def evaluation_response
  @evaluation_response
end

#gcs_uriString

The Cloud Storage object where the request or response is stored. Corresponds to the JSON property gcsUri

Returns:

  • (String)


16141
16142
16143
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16141

def gcs_uri
  @gcs_uri
end

#labelsHash<String,String>

Optional. Labels for the EvaluationItem. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


16146
16147
16148
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16146

def labels
  @labels
end

#metadataObject

Optional. Metadata for the EvaluationItem. Corresponds to the JSON property metadata

Returns:

  • (Object)


16151
16152
16153
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16151

def 
  @metadata
end

#nameString

Identifier. The resource name of the EvaluationItem. Format: projects/ project/locations/location/evaluationItems/evaluation_item` Corresponds to the JSON propertyname`

Returns:

  • (String)


16157
16158
16159
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16157

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16164
16165
16166
16167
16168
16169
16170
16171
16172
16173
16174
16175
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16164

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
  @evaluation_item_type = args[:evaluation_item_type] if args.key?(:evaluation_item_type)
  @evaluation_request = args[:evaluation_request] if args.key?(:evaluation_request)
  @evaluation_response = args[:evaluation_response] if args.key?(:evaluation_response)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end