Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

EvaluationMetric is a resource that represents a reusable metric configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationMetric

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationMetric.



19344
19345
19346
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the EvaluationMetric was created. Corresponds to the JSON property createTime

Returns:

  • (String)


19300
19301
19302
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19300

def create_time
  @create_time
end

#descriptionString

Optional. A description of the EvaluationMetric. Corresponds to the JSON property description

Returns:

  • (String)


19305
19306
19307
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19305

def description
  @description
end

#display_nameString

Required. The user-friendly display name for the EvaluationMetric. Corresponds to the JSON property displayName

Returns:

  • (String)


19310
19311
19312
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19310

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



19316
19317
19318
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19316

def encryption_spec
  @encryption_spec
end

#gcs_uriString

Optional. The Google Cloud Storage URI that stores the metric specification.. Corresponds to the JSON property gcsUri

Returns:

  • (String)


19321
19322
19323
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19321

def gcs_uri
  @gcs_uri
end

#labelsHash<String,String>

Optional. Labels for the evaluation metric. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


19326
19327
19328
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19326

def labels
  @labels
end

#metricGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Metric

The metric used for running evaluations. Corresponds to the JSON property metric



19331
19332
19333
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19331

def metric
  @metric
end

#nameString

Identifier. The resource name of the EvaluationMetric. Format: projects/ project/locations/location/evaluationMetrics/evaluation_metric` Corresponds to the JSON propertyname`

Returns:

  • (String)


19337
19338
19339
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19337

def name
  @name
end

#update_timeString

Output only. The time when the EvaluationMetric was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


19342
19343
19344
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19342

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19349
19350
19351
19352
19353
19354
19355
19356
19357
19358
19359
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19349

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @labels = args[:labels] if args.key?(:labels)
  @metric = args[:metric] if args.key?(:metric)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end