Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationMetric
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
EvaluationMetric is a resource that represents a reusable metric configuration.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#gcs_uri ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#metric ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Metric
The metric used for running evaluations.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationMetric
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationMetric
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationMetric.
18896 18897 18898 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18896 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the EvaluationMetric was created.
Corresponds to the JSON property createTime
18852 18853 18854 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18852 def create_time @create_time end |
#description ⇒ String
Optional. A description of the EvaluationMetric.
Corresponds to the JSON property description
18857 18858 18859 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18857 def description @description end |
#display_name ⇒ String
Required. The user-friendly display name for the EvaluationMetric.
Corresponds to the JSON property displayName
18862 18863 18864 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18862 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
18868 18869 18870 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18868 def encryption_spec @encryption_spec end |
#gcs_uri ⇒ String
Optional. The Google Cloud Storage URI that stores the metric specification..
Corresponds to the JSON property gcsUri
18873 18874 18875 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18873 def gcs_uri @gcs_uri end |
#labels ⇒ Hash<String,String>
Optional. Labels for the evaluation metric.
Corresponds to the JSON property labels
18878 18879 18880 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18878 def labels @labels end |
#metric ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Metric
The metric used for running evaluations.
Corresponds to the JSON property metric
18883 18884 18885 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18883 def metric @metric end |
#name ⇒ String
Identifier. The resource name of the EvaluationMetric. Format: projects/
project/locations/location/evaluationMetrics/evaluation_metric`
Corresponds to the JSON propertyname`
18889 18890 18891 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18889 def name @name end |
#update_time ⇒ String
Output only. The time when the EvaluationMetric was last updated.
Corresponds to the JSON property updateTime
18894 18895 18896 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18894 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18901 18902 18903 18904 18905 18906 18907 18908 18909 18910 18911 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18901 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @labels = args[:labels] if args.key?(:labels) @metric = args[:metric] if args.key?(:metric) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |