Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

EvaluationMetric is a resource that represents a reusable metric configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationMetric

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationMetric.



17983
17984
17985
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the EvaluationMetric was created. Corresponds to the JSON property createTime

Returns:

  • (String)


17939
17940
17941
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17939

def create_time
  @create_time
end

#descriptionString

Optional. A description of the EvaluationMetric. Corresponds to the JSON property description

Returns:

  • (String)


17944
17945
17946
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17944

def description
  @description
end

#display_nameString

Required. The user-friendly display name for the EvaluationMetric. Corresponds to the JSON property displayName

Returns:

  • (String)


17949
17950
17951
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17949

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



17955
17956
17957
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17955

def encryption_spec
  @encryption_spec
end

#gcs_uriString

Optional. The Google Cloud Storage URI that stores the metric specification.. Corresponds to the JSON property gcsUri

Returns:

  • (String)


17960
17961
17962
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17960

def gcs_uri
  @gcs_uri
end

#labelsHash<String,String>

Optional. Labels for the evaluation metric. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


17965
17966
17967
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17965

def labels
  @labels
end

#metricGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Metric

The metric used for running evaluations. Corresponds to the JSON property metric



17970
17971
17972
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17970

def metric
  @metric
end

#nameString

Identifier. The resource name of the EvaluationMetric. Format: projects/ project/locations/location/evaluationMetrics/evaluation_metric` Corresponds to the JSON propertyname`

Returns:

  • (String)


17976
17977
17978
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17976

def name
  @name
end

#update_timeString

Output only. The time when the EvaluationMetric was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


17981
17982
17983
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17981

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17988
17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17988

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @labels = args[:labels] if args.key?(:labels)
  @metric = args[:metric] if args.key?(:metric)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end