Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPrompt
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPrompt
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Prompt to be evaluated. This can represent a single-turn prompt or a multi- turn conversation for agent evaluations.
Instance Attribute Summary collapse
-
#agent_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData
Represents data specific to multi-turn agent evaluations.
-
#prompt_template_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPromptPromptTemplateData
Message to hold a prompt template and the values to populate the template.
-
#text ⇒ String
Text prompt.
-
#user_scenario ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPromptUserScenario
User scenario to help simulate multi-turn agent running results.
-
#value ⇒ Object
Fields and values that can be used to populate the prompt template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationPrompt
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationPrompt.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationPrompt
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationPrompt.
11536 11537 11538 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11536 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentData
Represents data specific to multi-turn agent evaluations.
Corresponds to the JSON property agentData
11514 11515 11516 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11514 def agent_data @agent_data end |
#prompt_template_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPromptPromptTemplateData
Message to hold a prompt template and the values to populate the template.
Corresponds to the JSON property promptTemplateData
11519 11520 11521 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11519 def prompt_template_data @prompt_template_data end |
#text ⇒ String
Text prompt.
Corresponds to the JSON property text
11524 11525 11526 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11524 def text @text end |
#user_scenario ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPromptUserScenario
User scenario to help simulate multi-turn agent running results.
Corresponds to the JSON property userScenario
11529 11530 11531 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11529 def user_scenario @user_scenario end |
#value ⇒ Object
Fields and values that can be used to populate the prompt template.
Corresponds to the JSON property value
11534 11535 11536 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11534 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11541 11542 11543 11544 11545 11546 11547 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11541 def update!(**args) @agent_data = args[:agent_data] if args.key?(:agent_data) @prompt_template_data = args[:prompt_template_data] if args.key?(:prompt_template_data) @text = args[:text] if args.key?(:text) @user_scenario = args[:user_scenario] if args.key?(:user_scenario) @value = args[:value] if args.key?(:value) end |