Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPromptUserScenario
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPromptUserScenario
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
User scenario to help simulate multi-turn agent running results.
Instance Attribute Summary collapse
-
#conversation_plan ⇒ String
Required.
-
#starting_prompt ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationPromptUserScenario
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationPromptUserScenario.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationPromptUserScenario
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationPromptUserScenario.
11585 11586 11587 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11585 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_plan ⇒ String
Required. The plan for the conversation, used to drive the multi-turn agent
run and generate the simulated agent evaluation dataset.
Corresponds to the JSON property conversationPlan
11577 11578 11579 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11577 def conversation_plan @conversation_plan end |
#starting_prompt ⇒ String
Required. The prompt that starts the conversation between the simulated user
and the agent under test.
Corresponds to the JSON property startingPrompt
11583 11584 11585 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11583 def starting_prompt @starting_prompt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11590 11591 11592 11593 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11590 def update!(**args) @conversation_plan = args[:conversation_plan] if args.key?(:conversation_plan) @starting_prompt = args[:starting_prompt] if args.key?(:starting_prompt) end |