Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A single evaluation request supporting input for both single-turn model generation and multi-turn agent execution traces. Valid input modes: 1. Inference Mode: prompt is set (containing text or AgentData context). 2. Offline Eval Mode: prompt is unset, and candidate_responses contains agent_data (the completed execution trace). Validation Rule: Either prompt must be set, OR at least one of the candidate_responses must contain agent_data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRequest

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRequest.



11629
11630
11631
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidate_responsesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse>

Optional. Responses from model under test and other baseline models for comparison. Corresponds to the JSON property candidateResponses



11610
11611
11612
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11610

def candidate_responses
  @candidate_responses
end

#golden_responseGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CandidateResponse

Responses from model or agent. Corresponds to the JSON property goldenResponse



11615
11616
11617
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11615

def golden_response
  @golden_response
end

#promptGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationPrompt

Prompt to be evaluated. This can represent a single-turn prompt or a multi- turn conversation for agent evaluations. Corresponds to the JSON property prompt



11621
11622
11623
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11621

def prompt
  @prompt
end

#rubricsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGroup>

Optional. Named groups of rubrics associated with this prompt. The key is a user-defined name for the rubric group. Corresponds to the JSON property rubrics



11627
11628
11629
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11627

def rubrics
  @rubrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11634
11635
11636
11637
11638
11639
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11634

def update!(**args)
  @candidate_responses = args[:candidate_responses] if args.key?(:candidate_responses)
  @golden_response = args[:golden_response] if args.key?(:golden_response)
  @prompt = args[:prompt] if args.key?(:prompt)
  @rubrics = args[:rubrics] if args.key?(:rubrics)
end