Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationResults

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The results of the evaluation run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationResults

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationResults.



17783
17784
17785
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17783

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#evaluation_setString

The evaluation set where item level results are stored. Corresponds to the JSON property evaluationSet

Returns:

  • (String)


17770
17771
17772
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17770

def evaluation_set
  @evaluation_set
end

#loss_analysis_resultsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossAnalysisResult>

Output only. The results of the auto-loss analysis performed on the eval set associated with the run. Corresponds to the JSON property lossAnalysisResults



17776
17777
17778
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17776

def loss_analysis_results
  @loss_analysis_results
end

#summary_metricsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummaryMetrics

The summary metrics for the evaluation run. Corresponds to the JSON property summaryMetrics



17781
17782
17783
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17781

def summary_metrics
  @summary_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17788
17789
17790
17791
17792
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17788

def update!(**args)
  @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set)
  @loss_analysis_results = args[:loss_analysis_results] if args.key?(:loss_analysis_results)
  @summary_metrics = args[:summary_metrics] if args.key?(:summary_metrics)
end