Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationResults

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The results of the evaluation run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationResults

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationResults.



11653
11654
11655
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#evaluation_setString

The evaluation set where item level results are stored. Corresponds to the JSON property evaluationSet

Returns:

  • (String)


11640
11641
11642
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11640

def evaluation_set
  @evaluation_set
end

#loss_analysis_resultsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossAnalysisResult>

Output only. The results of the auto-loss analysis performed on the eval set associated with the run. Corresponds to the JSON property lossAnalysisResults



11646
11647
11648
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11646

def loss_analysis_results
  @loss_analysis_results
end

#summary_metricsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SummaryMetrics

The summary metrics for the evaluation run. Corresponds to the JSON property summaryMetrics



11651
11652
11653
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11651

def summary_metrics
  @summary_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11658
11659
11660
11661
11662
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11658

def update!(**args)
  @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set)
  @loss_analysis_results = args[:loss_analysis_results] if args.key?(:loss_analysis_results)
  @summary_metrics = args[:summary_metrics] if args.key?(:summary_metrics)
end