Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRubricConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for a rubric group to be generated/saved for evaluation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRubricConfig

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRubricConfig.



19673
19674
19675
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19673

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#predefined_rubric_generation_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricPredefinedMetricSpec

Specification for a pre-defined metric. Corresponds to the JSON property predefinedRubricGenerationSpec



19656
19657
19658
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19656

def predefined_rubric_generation_spec
  @predefined_rubric_generation_spec
end

#rubric_generation_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricGenerationSpec

Specification for how rubrics should be generated. Corresponds to the JSON property rubricGenerationSpec



19661
19662
19663
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19661

def rubric_generation_spec
  @rubric_generation_spec
end

#rubric_group_keyString

Required. The key used to save the generated rubrics. If a generation spec is provided, this key will be used for the name of the generated rubric group. Otherwise, this key will be used to look up the existing rubric group on the evaluation item. Note that if a rubric group key is specified on both a rubric config and an evaluation metric, the key from the metric will be used to select the rubrics for evaluation. Corresponds to the JSON property rubricGroupKey

Returns:

  • (String)


19671
19672
19673
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19671

def rubric_group_key
  @rubric_group_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19678
19679
19680
19681
19682
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19678

def update!(**args)
  @predefined_rubric_generation_spec = args[:predefined_rubric_generation_spec] if args.key?(:predefined_rubric_generation_spec)
  @rubric_generation_spec = args[:rubric_generation_spec] if args.key?(:rubric_generation_spec)
  @rubric_group_key = args[:rubric_group_key] if args.key?(:rubric_group_key)
end