Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRubricConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for a rubric group to be generated/saved for evaluation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRubricConfig

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRubricConfig.



19214
19215
19216
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19214

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#predefined_rubric_generation_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricPredefinedMetricSpec

Specification for a pre-defined metric. Corresponds to the JSON property predefinedRubricGenerationSpec



19197
19198
19199
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19197

def predefined_rubric_generation_spec
  @predefined_rubric_generation_spec
end

#rubric_generation_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricGenerationSpec

Specification for how rubrics should be generated. Corresponds to the JSON property rubricGenerationSpec



19202
19203
19204
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19202

def rubric_generation_spec
  @rubric_generation_spec
end

#rubric_group_keyString

Required. The key used to save the generated rubrics. If a generation spec is provided, this key will be used for the name of the generated rubric group. Otherwise, this key will be used to look up the existing rubric group on the evaluation item. Note that if a rubric group key is specified on both a rubric config and an evaluation metric, the key from the metric will be used to select the rubrics for evaluation. Corresponds to the JSON property rubricGroupKey

Returns:

  • (String)


19212
19213
19214
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19212

def rubric_group_key
  @rubric_group_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19219
19220
19221
19222
19223
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19219

def update!(**args)
  @predefined_rubric_generation_spec = args[:predefined_rubric_generation_spec] if args.key?(:predefined_rubric_generation_spec)
  @rubric_generation_spec = args[:rubric_generation_spec] if args.key?(:rubric_generation_spec)
  @rubric_group_key = args[:rubric_group_key] if args.key?(:rubric_group_key)
end