Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

EvaluationRun is a resource that represents a single evaluation run, which includes a set of prompts, model responses, evaluation configuration and the resulting metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRun

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRun.



19774
19775
19776
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19774

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completion_timeString

Output only. Time when the evaluation run was completed. Corresponds to the JSON property completionTime

Returns:

  • (String)


19694
19695
19696
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19694

def completion_time
  @completion_time
end

#create_timeString

Output only. Time when the evaluation run was created. Corresponds to the JSON property createTime

Returns:

  • (String)


19699
19700
19701
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19699

def create_time
  @create_time
end

#data_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunDataSource

The data source for the evaluation run. Corresponds to the JSON property dataSource



19704
19705
19706
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19704

def data_source
  @data_source
end

#display_nameString

Required. The display name of the Evaluation Run. Corresponds to the JSON property displayName

Returns:

  • (String)


19709
19710
19711
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19709

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



19715
19716
19717
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19715

def encryption_spec
  @encryption_spec
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



19725
19726
19727
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19725

def error
  @error
end

#evaluation_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfig

The Evalution configuration used for the evaluation run. Corresponds to the JSON property evaluationConfig



19730
19731
19732
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19730

def evaluation_config
  @evaluation_config
end

#evaluation_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationResults

The results of the evaluation run. Corresponds to the JSON property evaluationResults



19735
19736
19737
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19735

def evaluation_results
  @evaluation_results
end

#evaluation_set_snapshotString

Output only. The specific evaluation set of the evaluation run. For runs with an evaluation set input, this will be that same set. For runs with BigQuery input, it's the sampled BigQuery dataset. Corresponds to the JSON property evaluationSetSnapshot

Returns:

  • (String)


19742
19743
19744
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19742

def evaluation_set_snapshot
  @evaluation_set_snapshot
end

#inference_configsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig>

Optional. The candidate to inference config map for the evaluation run. The candidate can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property inferenceConfigs



19749
19750
19751
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19749

def inference_configs
  @inference_configs
end

#labelsHash<String,String>

Optional. Labels for the evaluation run. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


19754
19755
19756
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19754

def labels
  @labels
end

#metadataObject

Optional. Metadata about the evaluation run, can be used by the caller to store additional tracking information about the evaluation run. Corresponds to the JSON property metadata

Returns:

  • (Object)


19760
19761
19762
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19760

def 
  @metadata
end

#nameString

Identifier. The resource name of the EvaluationRun. This is a unique identifier. Format: projects/project/locations/location/evaluationRuns/ evaluation_run` Corresponds to the JSON propertyname`

Returns:

  • (String)


19767
19768
19769
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19767

def name
  @name
end

#stateString

Output only. The state of the evaluation run. Corresponds to the JSON property state

Returns:

  • (String)


19772
19773
19774
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19772

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19779
19780
19781
19782
19783
19784
19785
19786
19787
19788
19789
19790
19791
19792
19793
19794
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19779

def update!(**args)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @error = args[:error] if args.key?(:error)
  @evaluation_config = args[:evaluation_config] if args.key?(:evaluation_config)
  @evaluation_results = args[:evaluation_results] if args.key?(:evaluation_results)
  @evaluation_set_snapshot = args[:evaluation_set_snapshot] if args.key?(:evaluation_set_snapshot)
  @inference_configs = args[:inference_configs] if args.key?(:inference_configs)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end