Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

EvaluationRun is a resource that represents a single evaluation run, which includes a set of prompts, model responses, evaluation configuration and the resulting metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRun

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRun.



16635
16636
16637
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16635

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completion_timeString

Output only. Time when the evaluation run was completed. Corresponds to the JSON property completionTime

Returns:

  • (String)


16561
16562
16563
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16561

def completion_time
  @completion_time
end

#create_timeString

Output only. Time when the evaluation run was created. Corresponds to the JSON property createTime

Returns:

  • (String)


16566
16567
16568
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16566

def create_time
  @create_time
end

#data_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunDataSource

The data source for the evaluation run. Corresponds to the JSON property dataSource



16571
16572
16573
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16571

def data_source
  @data_source
end

#display_nameString

Required. The display name of the Evaluation Run. Corresponds to the JSON property displayName

Returns:

  • (String)


16576
16577
16578
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16576

def display_name
  @display_name
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



16586
16587
16588
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16586

def error
  @error
end

#evaluation_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfig

The Evalution configuration used for the evaluation run. Corresponds to the JSON property evaluationConfig



16591
16592
16593
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16591

def evaluation_config
  @evaluation_config
end

#evaluation_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationResults

The results of the evaluation run. Corresponds to the JSON property evaluationResults



16596
16597
16598
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16596

def evaluation_results
  @evaluation_results
end

#evaluation_set_snapshotString

Output only. The specific evaluation set of the evaluation run. For runs with an evaluation set input, this will be that same set. For runs with BigQuery input, it's the sampled BigQuery dataset. Corresponds to the JSON property evaluationSetSnapshot

Returns:

  • (String)


16603
16604
16605
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16603

def evaluation_set_snapshot
  @evaluation_set_snapshot
end

#inference_configsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig>

Optional. The candidate to inference config map for the evaluation run. The candidate can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property inferenceConfigs



16610
16611
16612
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16610

def inference_configs
  @inference_configs
end

#labelsHash<String,String>

Optional. Labels for the evaluation run. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


16615
16616
16617
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16615

def labels
  @labels
end

#metadataObject

Optional. Metadata about the evaluation run, can be used by the caller to store additional tracking information about the evaluation run. Corresponds to the JSON property metadata

Returns:

  • (Object)


16621
16622
16623
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16621

def 
  @metadata
end

#nameString

Identifier. The resource name of the EvaluationRun. This is a unique identifier. Format: projects/project/locations/location/evaluationRuns/ evaluation_run` Corresponds to the JSON propertyname`

Returns:

  • (String)


16628
16629
16630
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16628

def name
  @name
end

#stateString

Output only. The state of the evaluation run. Corresponds to the JSON property state

Returns:

  • (String)


16633
16634
16635
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16633

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16640
16641
16642
16643
16644
16645
16646
16647
16648
16649
16650
16651
16652
16653
16654
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16640

def update!(**args)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
  @evaluation_config = args[:evaluation_config] if args.key?(:evaluation_config)
  @evaluation_results = args[:evaluation_results] if args.key?(:evaluation_results)
  @evaluation_set_snapshot = args[:evaluation_set_snapshot] if args.key?(:evaluation_set_snapshot)
  @inference_configs = args[:inference_configs] if args.key?(:inference_configs)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end