Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRun
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
EvaluationRun is a resource that represents a single evaluation run, which includes a set of prompts, model responses, evaluation configuration and the resulting metrics.
Instance Attribute Summary collapse
-
#completion_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#data_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunDataSource
The data source for the evaluation run.
-
#display_name ⇒ String
Required.
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#evaluation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfig
The Evalution configuration used for the evaluation run.
-
#evaluation_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationResults
The results of the evaluation run.
-
#evaluation_set_snapshot ⇒ String
Output only.
-
#inference_configs ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#metadata ⇒ Object
Optional.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRun
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRun
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRun.
11850 11851 11852 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11850 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completion_time ⇒ String
Output only. Time when the evaluation run was completed.
Corresponds to the JSON property completionTime
11776 11777 11778 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11776 def completion_time @completion_time end |
#create_time ⇒ String
Output only. Time when the evaluation run was created.
Corresponds to the JSON property createTime
11781 11782 11783 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11781 def create_time @create_time end |
#data_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunDataSource
The data source for the evaluation run.
Corresponds to the JSON property dataSource
11786 11787 11788 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11786 def data_source @data_source end |
#display_name ⇒ String
Required. The display name of the Evaluation Run.
Corresponds to the JSON property displayName
11791 11792 11793 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11791 def display_name @display_name end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
11801 11802 11803 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11801 def error @error end |
#evaluation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfig
The Evalution configuration used for the evaluation run.
Corresponds to the JSON property evaluationConfig
11806 11807 11808 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11806 def evaluation_config @evaluation_config end |
#evaluation_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationResults
The results of the evaluation run.
Corresponds to the JSON property evaluationResults
11811 11812 11813 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11811 def evaluation_results @evaluation_results end |
#evaluation_set_snapshot ⇒ String
Output only. The specific evaluation set of the evaluation run. For runs with
an evaluation set input, this will be that same set. For runs with BigQuery
input, it's the sampled BigQuery dataset.
Corresponds to the JSON property evaluationSetSnapshot
11818 11819 11820 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11818 def evaluation_set_snapshot @evaluation_set_snapshot end |
#inference_configs ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig>
Optional. The candidate to inference config map for the evaluation run. The
candidate can be up to 128 characters long and can consist of any UTF-8
characters.
Corresponds to the JSON property inferenceConfigs
11825 11826 11827 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11825 def inference_configs @inference_configs end |
#labels ⇒ Hash<String,String>
Optional. Labels for the evaluation run.
Corresponds to the JSON property labels
11830 11831 11832 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11830 def labels @labels end |
#metadata ⇒ Object
Optional. Metadata about the evaluation run, can be used by the caller to
store additional tracking information about the evaluation run.
Corresponds to the JSON property metadata
11836 11837 11838 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11836 def @metadata end |
#name ⇒ String
Identifier. The resource name of the EvaluationRun. This is a unique
identifier. Format: projects/project/locations/location/evaluationRuns/
evaluation_run`
Corresponds to the JSON propertyname`
11843 11844 11845 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11843 def name @name end |
#state ⇒ String
Output only. The state of the evaluation run.
Corresponds to the JSON property state
11848 11849 11850 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11848 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11855 11856 11857 11858 11859 11860 11861 11862 11863 11864 11865 11866 11867 11868 11869 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11855 def update!(**args) @completion_time = args[:completion_time] if args.key?(:completion_time) @create_time = args[:create_time] if args.key?(:create_time) @data_source = args[:data_source] if args.key?(:data_source) @display_name = args[:display_name] if args.key?(:display_name) @error = args[:error] if args.key?(:error) @evaluation_config = args[:evaluation_config] if args.key?(:evaluation_config) @evaluation_results = args[:evaluation_results] if args.key?(:evaluation_results) @evaluation_set_snapshot = args[:evaluation_set_snapshot] if args.key?(:evaluation_set_snapshot) @inference_configs = args[:inference_configs] if args.key?(:inference_configs) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |