Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigAutoraterConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigAutoraterConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The autorater config used for the evaluation run.
Instance Attribute Summary collapse
-
#autorater_model ⇒ String
Optional.
-
#generation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation.
-
#sample_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigAutoraterConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigAutoraterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigAutoraterConfig
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigAutoraterConfig.
11919 11920 11921 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autorater_model ⇒ String
Optional. The fully qualified name of the publisher model or tuned autorater
endpoint to use. Publisher model format: projects/project/locations/
location/publishers/*/models/* Tuned model endpoint format: projects/
project/locations/location/endpoints/endpoint`
Corresponds to the JSON propertyautoraterModel`
11904 11905 11906 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11904 def autorater_model @autorater_model end |
#generation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation. This message contains all the parameters
that control how the model generates content. It allows you to influence the
randomness, length, and structure of the output.
Corresponds to the JSON property generationConfig
11911 11912 11913 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11911 def generation_config @generation_config end |
#sample_count ⇒ Fixnum
Optional. Number of samples for each instance in the dataset. If not specified,
the default is 4. Minimum value is 1, maximum value is 32.
Corresponds to the JSON property sampleCount
11917 11918 11919 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11917 def sample_count @sample_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11924 11925 11926 11927 11928 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11924 def update!(**args) @autorater_model = args[:autorater_model] if args.key?(:autorater_model) @generation_config = args[:generation_config] if args.key?(:generation_config) @sample_count = args[:sample_count] if args.key?(:sample_count) end |