Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigOutputConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigOutputConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The output config for the evaluation run.
Instance Attribute Summary collapse
-
#bigquery_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryDestination
The BigQuery location for the output content.
-
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigOutputConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigOutputConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigOutputConfig
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigOutputConfig.
12011 12012 12013 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryDestination
The BigQuery location for the output content.
Corresponds to the JSON property bigqueryDestination
12004 12005 12006 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12004 def bigquery_destination @bigquery_destination end |
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcsDestination
12009 12010 12011 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12009 def gcs_destination @gcs_destination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12016 12017 12018 12019 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12016 def update!(**args) @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) end |