Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Defines the configuration for a candidate model or agent being evaluated.
InferenceConfig encapsulates all the necessary information to invoke or
scrape the candidate during the evaluation run. This includes direct model
inference parameters, agent execution settings, and multi-turn scraping
configurations (such as user simulators). It serves as the primary
representation of the candidate across different stages of the evaluation
process.
Instance Attribute Summary collapse
-
#agent_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig
Configuration that describes an agent.
-
#agent_run_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigAgentRunConfig
Configuration for Agent Run.
-
#agents ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig>
Optional.
-
#generation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation.
-
#model ⇒ String
Optional.
-
#parallelism ⇒ Fixnum
Optional.
-
#prompt_template ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigPromptTemplate
Prompt template used for inference.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig.
20099 20100 20101 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20099 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig
Configuration that describes an agent.
Corresponds to the JSON property agentConfig
20056 20057 20058 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20056 def agent_config @agent_config end |
#agent_run_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigAgentRunConfig
Configuration for Agent Run.
Corresponds to the JSON property agentRunConfig
20061 20062 20063 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20061 def agent_run_config @agent_run_config end |
#agents ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig>
Optional. Contains the static configurations for each agent in the system. Key:
agent_id (matches the author field in events). Value: The static
configuration of the agent.
Corresponds to the JSON property agents
20068 20069 20070 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20068 def agents @agents end |
#generation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation. This message contains all the parameters
that control how the model generates content. It allows you to influence the
randomness, length, and structure of the output.
Corresponds to the JSON property generationConfig
20075 20076 20077 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20075 def generation_config @generation_config end |
#model ⇒ String
Optional. The fully qualified name of the publisher model or endpoint to use.
Anthropic and Llama third-party models are also supported through Model Garden.
Publisher model format: projects/project/locations/location/publishers/*/
models/* Third-party model formats: projects/project/locations/location/
publishers/anthropic/models/modelor `projects/`project`/locations/`
location`/publishers/llama/models/`model Endpoint format: projects/project
/locations/location/endpoints/endpoint`
Corresponds to the JSON propertymodel`
20086 20087 20088 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20086 def model @model end |
#parallelism ⇒ Fixnum
Optional. The parallelism of the evaluation run for the inference step. If not
specified, the default parallelism will be used.
Corresponds to the JSON property parallelism
20092 20093 20094 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20092 def parallelism @parallelism end |
#prompt_template ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigPromptTemplate
Prompt template used for inference.
Corresponds to the JSON property promptTemplate
20097 20098 20099 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20097 def prompt_template @prompt_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20104 20105 20106 20107 20108 20109 20110 20111 20112 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20104 def update!(**args) @agent_config = args[:agent_config] if args.key?(:agent_config) @agent_run_config = args[:agent_run_config] if args.key?(:agent_run_config) @agents = args[:agents] if args.key?(:agents) @generation_config = args[:generation_config] if args.key?(:generation_config) @model = args[:model] if args.key?(:model) @parallelism = args[:parallelism] if args.key?(:parallelism) @prompt_template = args[:prompt_template] if args.key?(:prompt_template) end |