Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Defines the configuration for a candidate model or agent being evaluated. InferenceConfig encapsulates all the necessary information to invoke or scrape the candidate during the evaluation run. This includes direct model inference parameters, agent execution settings, and multi-turn scraping configurations (such as user simulators). It serves as the primary representation of the candidate across different stages of the evaluation process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig.



20038
20039
20040
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig

Configuration that describes an agent. Corresponds to the JSON property agentConfig



19995
19996
19997
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19995

def agent_config
  @agent_config
end

#agent_run_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigAgentRunConfig

Configuration for Agent Run. Corresponds to the JSON property agentRunConfig



20000
20001
20002
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20000

def agent_run_config
  @agent_run_config
end

#agentsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig>

Optional. Contains the static configurations for each agent in the system. Key: agent_id (matches the author field in events). Value: The static configuration of the agent. Corresponds to the JSON property agents



20007
20008
20009
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20007

def agents
  @agents
end

#generation_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property generationConfig



20014
20015
20016
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20014

def generation_config
  @generation_config
end

#modelString

Optional. The fully qualified name of the publisher model or endpoint to use. Anthropic and Llama third-party models are also supported through Model Garden. Publisher model format: projects/project/locations/location/publishers/*/ models/* Third-party model formats: projects/project/locations/location/ publishers/anthropic/models/modelor `projects/`project`/locations/` location`/publishers/llama/models/`model Endpoint format: projects/project /locations/location/endpoints/endpoint` Corresponds to the JSON propertymodel`

Returns:

  • (String)


20025
20026
20027
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20025

def model
  @model
end

#parallelismFixnum

Optional. The parallelism of the evaluation run for the inference step. If not specified, the default parallelism will be used. Corresponds to the JSON property parallelism

Returns:

  • (Fixnum)


20031
20032
20033
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20031

def parallelism
  @parallelism
end

#prompt_templateGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigPromptTemplate

Prompt template used for inference. Corresponds to the JSON property promptTemplate



20036
20037
20038
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20036

def prompt_template
  @prompt_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20043
20044
20045
20046
20047
20048
20049
20050
20051
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20043

def update!(**args)
  @agent_config = args[:agent_config] if args.key?(:agent_config)
  @agent_run_config = args[:agent_run_config] if args.key?(:agent_run_config)
  @agents = args[:agents] if args.key?(:agents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @model = args[:model] if args.key?(:model)
  @parallelism = args[:parallelism] if args.key?(:parallelism)
  @prompt_template = args[:prompt_template] if args.key?(:prompt_template)
end