Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Defines the configuration for a candidate model or agent being evaluated. InferenceConfig encapsulates all the necessary information to invoke or scrape the candidate during the evaluation run. This includes direct model inference parameters, agent execution settings, and multi-turn scraping configurations (such as user simulators). It serves as the primary representation of the candidate across different stages of the evaluation process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig.



12101
12102
12103
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12101

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig

Configuration that describes an agent. Corresponds to the JSON property agentConfig



12063
12064
12065
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12063

def agent_config
  @agent_config
end

#agent_run_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigAgentRunConfig

Configuration for Agent Run. Corresponds to the JSON property agentRunConfig



12068
12069
12070
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12068

def agent_run_config
  @agent_run_config
end

#agentsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig>

Optional. Contains the static configurations for each agent in the system. Key: agent_id (matches the author field in events). Value: The static configuration of the agent. Corresponds to the JSON property agents



12075
12076
12077
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12075

def agents
  @agents
end

#generation_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property generationConfig



12082
12083
12084
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12082

def generation_config
  @generation_config
end

#modelString

Optional. The fully qualified name of the publisher model or endpoint to use. Anthropic and Llama third-party models are also supported through Model Garden. Publisher model format: projects/project/locations/location/publishers/*/ models/* Third-party model formats: projects/project/locations/location/ publishers/anthropic/models/modelor `projects/`project`/locations/` location`/publishers/llama/models/`model Endpoint format: projects/project /locations/location/endpoints/endpoint` Corresponds to the JSON propertymodel`

Returns:

  • (String)


12093
12094
12095
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12093

def model
  @model
end

#parallelismFixnum

Optional. The parallelism of the evaluation run for the inference step. If not specified, the default parallelism will be used. Corresponds to the JSON property parallelism

Returns:

  • (Fixnum)


12099
12100
12101
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12099

def parallelism
  @parallelism
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12106
12107
12108
12109
12110
12111
12112
12113
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12106

def update!(**args)
  @agent_config = args[:agent_config] if args.key?(:agent_config)
  @agent_run_config = args[:agent_run_config] if args.key?(:agent_run_config)
  @agents = args[:agents] if args.key?(:agents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @model = args[:model] if args.key?(:model)
  @parallelism = args[:parallelism] if args.key?(:parallelism)
end