Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Defines the configuration for a candidate model or agent being evaluated.
InferenceConfig encapsulates all the necessary information to invoke or
scrape the candidate during the evaluation run. This includes direct model
inference parameters, agent execution settings, and multi-turn scraping
configurations (such as user simulators). It serves as the primary
representation of the candidate across different stages of the evaluation
process.
Instance Attribute Summary collapse
-
#agent_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig
Configuration that describes an agent.
-
#agent_run_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigAgentRunConfig
Configuration for Agent Run.
-
#agents ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig>
Optional.
-
#generation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation.
-
#model ⇒ String
Optional.
-
#parallelism ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfig.
12035 12036 12037 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12035 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig
Configuration that describes an agent.
Corresponds to the JSON property agentConfig
11997 11998 11999 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 11997 def agent_config @agent_config end |
#agent_run_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigAgentRunConfig
Configuration for Agent Run.
Corresponds to the JSON property agentRunConfig
12002 12003 12004 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12002 def agent_run_config @agent_run_config end |
#agents ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig>
Optional. Contains the static configurations for each agent in the system. Key:
agent_id (matches the author field in events). Value: The static
configuration of the agent.
Corresponds to the JSON property agents
12009 12010 12011 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12009 def agents @agents end |
#generation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation. This message contains all the parameters
that control how the model generates content. It allows you to influence the
randomness, length, and structure of the output.
Corresponds to the JSON property generationConfig
12016 12017 12018 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12016 def generation_config @generation_config end |
#model ⇒ String
Optional. The fully qualified name of the publisher model or endpoint to use.
Anthropic and Llama third-party models are also supported through Model Garden.
Publisher model format: projects/project/locations/location/publishers/*/
models/* Third-party model formats: projects/project/locations/location/
publishers/anthropic/models/modelor `projects/`project`/locations/`
location`/publishers/llama/models/`model Endpoint format: projects/project
/locations/location/endpoints/endpoint`
Corresponds to the JSON propertymodel`
12027 12028 12029 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12027 def model @model end |
#parallelism ⇒ Fixnum
Optional. The parallelism of the evaluation run for the inference step. If not
specified, the default parallelism will be used.
Corresponds to the JSON property parallelism
12033 12034 12035 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12033 def parallelism @parallelism end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12040 12041 12042 12043 12044 12045 12046 12047 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12040 def update!(**args) @agent_config = args[:agent_config] if args.key?(:agent_config) @agent_run_config = args[:agent_run_config] if args.key?(:agent_run_config) @agents = args[:agents] if args.key?(:agents) @generation_config = args[:generation_config] if args.key?(:generation_config) @model = args[:model] if args.key?(:model) @parallelism = args[:parallelism] if args.key?(:parallelism) end |