Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Used for multi-turn agent scraping. Contains configuration for a user simulator that uses an LLM to generate messages on behalf of the user.
Instance Attribute Summary collapse
-
#max_turn ⇒ Fixnum
Maximum number of invocations allowed by the multi-turn agent scraping.
-
#model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation.
-
#model_name ⇒ String
The model name to use for multi-turn agent scraping to get next user message, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig.
18419 18420 18421 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18419 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_turn ⇒ Fixnum
Maximum number of invocations allowed by the multi-turn agent scraping. This
property allows us to stop a run-off conversation, where the agent and the
user simulator get into a never ending loop. The initial fixed prompt is also
counted as an invocation.
Corresponds to the JSON property maxTurn
18404 18405 18406 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18404 def max_turn @max_turn end |
#model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation. This message contains all the parameters
that control how the model generates content. It allows you to influence the
randomness, length, and structure of the output.
Corresponds to the JSON property modelConfig
18411 18412 18413 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18411 def model_config @model_config end |
#model_name ⇒ String
The model name to use for multi-turn agent scraping to get next user message,
e.g. "gemini-3-flash-preview".
Corresponds to the JSON property modelName
18417 18418 18419 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18417 def model_name @model_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18424 18425 18426 18427 18428 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18424 def update!(**args) @max_turn = args[:max_turn] if args.key?(:max_turn) @model_config = args[:model_config] if args.key?(:model_config) @model_name = args[:model_name] if args.key?(:model_name) end |