Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration that describes an agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig.



12204
12205
12206
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12204

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#developer_instructionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property developerInstruction



12197
12198
12199
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12197

def developer_instruction
  @developer_instruction
end

#toolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>

Optional. The tools available to the agent. Corresponds to the JSON property tools



12202
12203
12204
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12202

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12209
12210
12211
12212
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12209

def update!(**args)
  @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction)
  @tools = args[:tools] if args.key?(:tools)
end