Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration that describes an agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig

Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunInferenceConfigInferenceAgentConfig.



12138
12139
12140
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12138

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#developer_instructionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property developerInstruction



12131
12132
12133
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12131

def developer_instruction
  @developer_instruction
end

#toolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>

Optional. The tools available to the agent. Corresponds to the JSON property tools



12136
12137
12138
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12136

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12143
12144
12145
12146
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12143

def update!(**args)
  @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction)
  @tools = args[:tools] if args.key?(:tools)
end