Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetric
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The metric used for evaluation runs.
Instance Attribute Summary collapse
-
#computation_based_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricComputationBasedMetricSpec
Specification for a computation based metric.
-
#llm_based_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricLlmBasedMetricSpec
Specification for an LLM based metric.
-
#metric ⇒ String
Required.
-
#metric_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Metric
The metric used for running evaluations.
-
#metric_resource_name ⇒ String
Optional.
-
#predefined_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricPredefinedMetricSpec
Specification for a pre-defined metric.
-
#rubric_based_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricBasedMetricSpec
Specification for a metric that is based on rubrics.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunMetric
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationRunMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunMetric
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunMetric.
19759 19760 19761 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19759 def initialize(**args) update!(**args) end |
Instance Attribute Details
#computation_based_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricComputationBasedMetricSpec
Specification for a computation based metric.
Corresponds to the JSON property computationBasedMetricSpec
19727 19728 19729 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19727 def computation_based_metric_spec @computation_based_metric_spec end |
#llm_based_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricLlmBasedMetricSpec
Specification for an LLM based metric.
Corresponds to the JSON property llmBasedMetricSpec
19732 19733 19734 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19732 def llm_based_metric_spec @llm_based_metric_spec end |
#metric ⇒ String
Required. The name of the metric.
Corresponds to the JSON property metric
19737 19738 19739 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19737 def metric @metric end |
#metric_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Metric
The metric used for running evaluations.
Corresponds to the JSON property metricConfig
19742 19743 19744 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19742 def metric_config @metric_config end |
#metric_resource_name ⇒ String
Optional. The resource name of the metric definition.
Corresponds to the JSON property metricResourceName
19747 19748 19749 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19747 def metric_resource_name @metric_resource_name end |
#predefined_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricPredefinedMetricSpec
Specification for a pre-defined metric.
Corresponds to the JSON property predefinedMetricSpec
19752 19753 19754 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19752 def predefined_metric_spec @predefined_metric_spec end |
#rubric_based_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricBasedMetricSpec
Specification for a metric that is based on rubrics.
Corresponds to the JSON property rubricBasedMetricSpec
19757 19758 19759 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19757 def rubric_based_metric_spec @rubric_based_metric_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19764 19765 19766 19767 19768 19769 19770 19771 19772 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19764 def update!(**args) @computation_based_metric_spec = args[:computation_based_metric_spec] if args.key?(:computation_based_metric_spec) @llm_based_metric_spec = args[:llm_based_metric_spec] if args.key?(:llm_based_metric_spec) @metric = args[:metric] if args.key?(:metric) @metric_config = args[:metric_config] if args.key?(:metric_config) @metric_resource_name = args[:metric_resource_name] if args.key?(:metric_resource_name) @predefined_metric_spec = args[:predefined_metric_spec] if args.key?(:predefined_metric_spec) @rubric_based_metric_spec = args[:rubric_based_metric_spec] if args.key?(:rubric_based_metric_spec) end |