Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetric
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The metric used for evaluation runs.
Instance Attribute Summary collapse
-
#computation_based_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricComputationBasedMetricSpec
Specification for a computation based metric.
-
#llm_based_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricLlmBasedMetricSpec
Specification for an LLM based metric.
-
#metric ⇒ String
Required.
-
#metric_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Metric
The metric used for running evaluations.
-
#metric_resource_name ⇒ String
Optional.
-
#predefined_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricPredefinedMetricSpec
Specification for a pre-defined metric.
-
#rubric_based_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricBasedMetricSpec
Specification for a metric that is based on rubrics.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunMetric
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationRunMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunMetric
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunMetric.
17564 17565 17566 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17564 def initialize(**args) update!(**args) end |
Instance Attribute Details
#computation_based_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricComputationBasedMetricSpec
Specification for a computation based metric.
Corresponds to the JSON property computationBasedMetricSpec
17532 17533 17534 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17532 def computation_based_metric_spec @computation_based_metric_spec end |
#llm_based_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricLlmBasedMetricSpec
Specification for an LLM based metric.
Corresponds to the JSON property llmBasedMetricSpec
17537 17538 17539 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17537 def llm_based_metric_spec @llm_based_metric_spec end |
#metric ⇒ String
Required. The name of the metric.
Corresponds to the JSON property metric
17542 17543 17544 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17542 def metric @metric end |
#metric_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Metric
The metric used for running evaluations.
Corresponds to the JSON property metricConfig
17547 17548 17549 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17547 def metric_config @metric_config end |
#metric_resource_name ⇒ String
Optional. The resource name of the metric definition.
Corresponds to the JSON property metricResourceName
17552 17553 17554 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17552 def metric_resource_name @metric_resource_name end |
#predefined_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricPredefinedMetricSpec
Specification for a pre-defined metric.
Corresponds to the JSON property predefinedMetricSpec
17557 17558 17559 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17557 def predefined_metric_spec @predefined_metric_spec end |
#rubric_based_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricBasedMetricSpec
Specification for a metric that is based on rubrics.
Corresponds to the JSON property rubricBasedMetricSpec
17562 17563 17564 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17562 def rubric_based_metric_spec @rubric_based_metric_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17569 17570 17571 17572 17573 17574 17575 17576 17577 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17569 def update!(**args) @computation_based_metric_spec = args[:computation_based_metric_spec] if args.key?(:computation_based_metric_spec) @llm_based_metric_spec = args[:llm_based_metric_spec] if args.key?(:llm_based_metric_spec) @metric = args[:metric] if args.key?(:metric) @metric_config = args[:metric_config] if args.key?(:metric_config) @metric_resource_name = args[:metric_resource_name] if args.key?(:metric_resource_name) @predefined_metric_spec = args[:predefined_metric_spec] if args.key?(:predefined_metric_spec) @rubric_based_metric_spec = args[:rubric_based_metric_spec] if args.key?(:rubric_based_metric_spec) end |