Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricBasedMetricSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricBasedMetricSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Specification for a metric that is based on rubrics.
Instance Attribute Summary collapse
-
#inline_rubrics ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricBasedMetricSpecRepeatedRubrics
Defines a list of rubrics, used when providing rubrics inline.
-
#judge_autorater_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigAutoraterConfig
The autorater config used for the evaluation run.
-
#metric_prompt_template ⇒ String
Optional.
-
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricGenerationSpec
Specification for how rubrics should be generated.
-
#rubric_group_key ⇒ String
Use a pre-defined group of rubrics associated with the input content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricBasedMetricSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricBasedMetricSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricBasedMetricSpec
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricBasedMetricSpec.
12375 12376 12377 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12375 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inline_rubrics ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricBasedMetricSpecRepeatedRubrics
Defines a list of rubrics, used when providing rubrics inline.
Corresponds to the JSON property inlineRubrics
12351 12352 12353 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12351 def inline_rubrics @inline_rubrics end |
#judge_autorater_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunEvaluationConfigAutoraterConfig
The autorater config used for the evaluation run.
Corresponds to the JSON property judgeAutoraterConfig
12356 12357 12358 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12356 def judge_autorater_config @judge_autorater_config end |
#metric_prompt_template ⇒ String
Optional. Template for the prompt used by the judge model to evaluate against
rubrics.
Corresponds to the JSON property metricPromptTemplate
12362 12363 12364 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12362 def metric_prompt_template @metric_prompt_template end |
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationRunMetricRubricGenerationSpec
Specification for how rubrics should be generated.
Corresponds to the JSON property rubricGenerationSpec
12367 12368 12369 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12367 def rubric_generation_spec @rubric_generation_spec end |
#rubric_group_key ⇒ String
Use a pre-defined group of rubrics associated with the input content. This
refers to a key in the rubric_groups map of RubricEnhancedContents.
Corresponds to the JSON property rubricGroupKey
12373 12374 12375 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12373 def rubric_group_key @rubric_group_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12380 12381 12382 12383 12384 12385 12386 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12380 def update!(**args) @inline_rubrics = args[:inline_rubrics] if args.key?(:inline_rubrics) @judge_autorater_config = args[:judge_autorater_config] if args.key?(:judge_autorater_config) @metric_prompt_template = args[:metric_prompt_template] if args.key?(:metric_prompt_template) @rubric_generation_spec = args[:rubric_generation_spec] if args.key?(:rubric_generation_spec) @rubric_group_key = args[:rubric_group_key] if args.key?(:rubric_group_key) end |