Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationSet
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
EvaluationSet is a collection of related EvaluationItems that are evaluated together.
Instance Attribute Summary collapse
-
#agent_configs ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig>
Optional.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#evaluation_items ⇒ Array<String>
Required.
-
#metadata ⇒ Object
Optional.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationSet
constructor
A new instance of GoogleCloudAiplatformV1beta1EvaluationSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EvaluationSet
Returns a new instance of GoogleCloudAiplatformV1beta1EvaluationSet.
20514 20515 20516 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_configs ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig>
Optional. Static configurations for each agent associated with the items in
this set. Key: agent_id (matches the author field in events). Value: The
static configuration of the agent.
Corresponds to the JSON property agentConfigs
20475 20476 20477 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20475 def agent_configs @agent_configs end |
#create_time ⇒ String
Output only. Timestamp when this item was created.
Corresponds to the JSON property createTime
20480 20481 20482 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20480 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the EvaluationSet.
Corresponds to the JSON property displayName
20485 20486 20487 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20485 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
20491 20492 20493 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20491 def encryption_spec @encryption_spec end |
#evaluation_items ⇒ Array<String>
Required. The EvaluationItems that are part of this dataset.
Corresponds to the JSON property evaluationItems
20496 20497 20498 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20496 def evaluation_items @evaluation_items end |
#metadata ⇒ Object
Optional. Metadata for the EvaluationSet.
Corresponds to the JSON property metadata
20501 20502 20503 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20501 def @metadata end |
#name ⇒ String
Identifier. The resource name of the EvaluationSet. Format: projects/project
/locations/location/evaluationSets/evaluation_set`
Corresponds to the JSON propertyname`
20507 20508 20509 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20507 def name @name end |
#update_time ⇒ String
Output only. Timestamp when this item was last updated.
Corresponds to the JSON property updateTime
20512 20513 20514 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20512 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20519 20520 20521 20522 20523 20524 20525 20526 20527 20528 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20519 def update!(**args) @agent_configs = args[:agent_configs] if args.key?(:agent_configs) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @evaluation_items = args[:evaluation_items] if args.key?(:evaluation_items) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |