Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Event
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Event
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An edge describing the relationship between an Artifact and an Execution in a lineage graph.
Instance Attribute Summary collapse
-
#artifact ⇒ String
Required.
-
#event_time ⇒ String
Output only.
-
#execution ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to annotate Events.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Event
constructor
A new instance of GoogleCloudAiplatformV1beta1Event.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Event
Returns a new instance of GoogleCloudAiplatformV1beta1Event.
19174 19175 19176 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact ⇒ String
Required. The relative resource name of the Artifact in the Event.
Corresponds to the JSON property artifact
19146 19147 19148 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19146 def artifact @artifact end |
#event_time ⇒ String
Output only. Time the Event occurred.
Corresponds to the JSON property eventTime
19151 19152 19153 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19151 def event_time @event_time end |
#execution ⇒ String
Output only. The relative resource name of the Execution in the Event.
Corresponds to the JSON property execution
19156 19157 19158 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19156 def execution @execution end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to annotate Events. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Event (System labels are excluded). See https://goo.gl/
xmQnxf for more information and examples of labels. System reserved label keys
are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
19167 19168 19169 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19167 def labels @labels end |
#type ⇒ String
Required. The type of the Event.
Corresponds to the JSON property type
19172 19173 19174 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19172 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19179 19180 19181 19182 19183 19184 19185 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19179 def update!(**args) @artifact = args[:artifact] if args.key?(:artifact) @event_time = args[:event_time] if args.key?(:event_time) @execution = args[:execution] if args.key?(:execution) @labels = args[:labels] if args.key?(:labels) @type = args[:type] if args.key?(:type) end |