Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Event
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Event
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An edge describing the relationship between an Artifact and an Execution in a lineage graph.
Instance Attribute Summary collapse
-
#artifact ⇒ String
Required.
-
#event_time ⇒ String
Output only.
-
#execution ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to annotate Events.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Event
constructor
A new instance of GoogleCloudAiplatformV1beta1Event.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Event
Returns a new instance of GoogleCloudAiplatformV1beta1Event.
18680 18681 18682 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18680 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact ⇒ String
Required. The relative resource name of the Artifact in the Event.
Corresponds to the JSON property artifact
18652 18653 18654 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18652 def artifact @artifact end |
#event_time ⇒ String
Output only. Time the Event occurred.
Corresponds to the JSON property eventTime
18657 18658 18659 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18657 def event_time @event_time end |
#execution ⇒ String
Output only. The relative resource name of the Execution in the Event.
Corresponds to the JSON property execution
18662 18663 18664 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18662 def execution @execution end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to annotate Events. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Event (System labels are excluded). See https://goo.gl/
xmQnxf for more information and examples of labels. System reserved label keys
are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
18673 18674 18675 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18673 def labels @labels end |
#type ⇒ String
Required. The type of the Event.
Corresponds to the JSON property type
18678 18679 18680 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18678 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18685 18686 18687 18688 18689 18690 18691 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18685 def update!(**args) @artifact = args[:artifact] if args.key?(:artifact) @event_time = args[:event_time] if args.key?(:event_time) @execution = args[:execution] if args.key?(:execution) @labels = args[:labels] if args.key?(:labels) @type = args[:type] if args.key?(:type) end |