Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Event

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An edge describing the relationship between an Artifact and an Execution in a lineage graph.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Event

Returns a new instance of GoogleCloudAiplatformV1beta1Event.



18858
18859
18860
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifactString

Required. The relative resource name of the Artifact in the Event. Corresponds to the JSON property artifact

Returns:

  • (String)


18830
18831
18832
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18830

def artifact
  @artifact
end

#event_timeString

Output only. Time the Event occurred. Corresponds to the JSON property eventTime

Returns:

  • (String)


18835
18836
18837
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18835

def event_time
  @event_time
end

#executionString

Output only. The relative resource name of the Execution in the Event. Corresponds to the JSON property execution

Returns:

  • (String)


18840
18841
18842
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18840

def execution
  @execution
end

#labelsHash<String,String>

The labels with user-defined metadata to annotate Events. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Event (System labels are excluded). See https://goo.gl/ xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


18851
18852
18853
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18851

def labels
  @labels
end

#typeString

Required. The type of the Event. Corresponds to the JSON property type

Returns:

  • (String)


18856
18857
18858
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18856

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18863
18864
18865
18866
18867
18868
18869
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18863

def update!(**args)
  @artifact = args[:artifact] if args.key?(:artifact)
  @event_time = args[:event_time] if args.key?(:event_time)
  @execution = args[:execution] if args.key?(:execution)
  @labels = args[:labels] if args.key?(:labels)
  @type = args[:type] if args.key?(:type)
end