Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Event

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An edge describing the relationship between an Artifact and an Execution in a lineage graph.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Event

Returns a new instance of GoogleCloudAiplatformV1beta1Event.



17401
17402
17403
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifactString

Required. The relative resource name of the Artifact in the Event. Corresponds to the JSON property artifact

Returns:

  • (String)


17373
17374
17375
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17373

def artifact
  @artifact
end

#event_timeString

Output only. Time the Event occurred. Corresponds to the JSON property eventTime

Returns:

  • (String)


17378
17379
17380
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17378

def event_time
  @event_time
end

#executionString

Output only. The relative resource name of the Execution in the Event. Corresponds to the JSON property execution

Returns:

  • (String)


17383
17384
17385
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17383

def execution
  @execution
end

#labelsHash<String,String>

The labels with user-defined metadata to annotate Events. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Event (System labels are excluded). See https://goo.gl/ xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


17394
17395
17396
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17394

def labels
  @labels
end

#typeString

Required. The type of the Event. Corresponds to the JSON property type

Returns:

  • (String)


17399
17400
17401
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17399

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17406
17407
17408
17409
17410
17411
17412
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17406

def update!(**args)
  @artifact = args[:artifact] if args.key?(:artifact)
  @event_time = args[:event_time] if args.key?(:event_time)
  @execution = args[:execution] if args.key?(:execution)
  @labels = args[:labels] if args.key?(:labels)
  @type = args[:type] if args.key?(:type)
end