Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EventActions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Actions are parts of events that are executed by the agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EventActions

Returns a new instance of GoogleCloudAiplatformV1beta1EventActions.



12670
12671
12672
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_deltaHash<String,Fixnum>

Optional. Indicates that the event is updating an artifact. key is the filename, value is the version. Corresponds to the JSON property artifactDelta

Returns:

  • (Hash<String,Fixnum>)


12637
12638
12639
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12637

def artifact_delta
  @artifact_delta
end

#escalateBoolean Also known as: escalate?

Optional. The agent is escalating to a higher level agent. Corresponds to the JSON property escalate

Returns:

  • (Boolean)


12642
12643
12644
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12642

def escalate
  @escalate
end

#requested_auth_configsHash<String,Object>

Optional. Will only be set by a tool response indicating tool request euc. Struct key is the function call id since one function call response (from model) could correspond to multiple function calls. Struct value is the required auth config, which can be another struct. Corresponds to the JSON property requestedAuthConfigs

Returns:

  • (Hash<String,Object>)


12651
12652
12653
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12651

def requested_auth_configs
  @requested_auth_configs
end

#skip_summarizationBoolean Also known as: skip_summarization?

Optional. If true, it won't call model to summarize function response. Only used for function_response event. Corresponds to the JSON property skipSummarization

Returns:

  • (Boolean)


12657
12658
12659
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12657

def skip_summarization
  @skip_summarization
end

#state_deltaHash<String,Object>

Optional. Indicates that the event is updating the state with the given delta. Corresponds to the JSON property stateDelta

Returns:

  • (Hash<String,Object>)


12663
12664
12665
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12663

def state_delta
  @state_delta
end

#transfer_agentString

Optional. If set, the event transfers to the specified agent. Corresponds to the JSON property transferAgent

Returns:

  • (String)


12668
12669
12670
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12668

def transfer_agent
  @transfer_agent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12675
12676
12677
12678
12679
12680
12681
12682
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12675

def update!(**args)
  @artifact_delta = args[:artifact_delta] if args.key?(:artifact_delta)
  @escalate = args[:escalate] if args.key?(:escalate)
  @requested_auth_configs = args[:requested_auth_configs] if args.key?(:requested_auth_configs)
  @skip_summarization = args[:skip_summarization] if args.key?(:skip_summarization)
  @state_delta = args[:state_delta] if args.key?(:state_delta)
  @transfer_agent = args[:transfer_agent] if args.key?(:transfer_agent)
end