Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EventActions
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EventActions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Actions are parts of events that are executed by the agent.
Instance Attribute Summary collapse
-
#artifact_delta ⇒ Hash<String,Fixnum>
Optional.
-
#escalate ⇒ Boolean
(also: #escalate?)
Optional.
-
#requested_auth_configs ⇒ Hash<String,Object>
Optional.
-
#skip_summarization ⇒ Boolean
(also: #skip_summarization?)
Optional.
-
#state_delta ⇒ Hash<String,Object>
Optional.
-
#transfer_agent ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EventActions
constructor
A new instance of GoogleCloudAiplatformV1beta1EventActions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EventActions
Returns a new instance of GoogleCloudAiplatformV1beta1EventActions.
12604 12605 12606 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12604 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_delta ⇒ Hash<String,Fixnum>
Optional. Indicates that the event is updating an artifact. key is the
filename, value is the version.
Corresponds to the JSON property artifactDelta
12571 12572 12573 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12571 def artifact_delta @artifact_delta end |
#escalate ⇒ Boolean Also known as: escalate?
Optional. The agent is escalating to a higher level agent.
Corresponds to the JSON property escalate
12576 12577 12578 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12576 def escalate @escalate end |
#requested_auth_configs ⇒ Hash<String,Object>
Optional. Will only be set by a tool response indicating tool request euc.
Struct key is the function call id since one function call response (from
model) could correspond to multiple function calls. Struct value is the
required auth config, which can be another struct.
Corresponds to the JSON property requestedAuthConfigs
12585 12586 12587 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12585 def requested_auth_configs @requested_auth_configs end |
#skip_summarization ⇒ Boolean Also known as: skip_summarization?
Optional. If true, it won't call model to summarize function response. Only
used for function_response event.
Corresponds to the JSON property skipSummarization
12591 12592 12593 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12591 def skip_summarization @skip_summarization end |
#state_delta ⇒ Hash<String,Object>
Optional. Indicates that the event is updating the state with the given delta.
Corresponds to the JSON property stateDelta
12597 12598 12599 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12597 def state_delta @state_delta end |
#transfer_agent ⇒ String
Optional. If set, the event transfers to the specified agent.
Corresponds to the JSON property transferAgent
12602 12603 12604 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12602 def transfer_agent @transfer_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12609 12610 12611 12612 12613 12614 12615 12616 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12609 def update!(**args) @artifact_delta = args[:artifact_delta] if args.key?(:artifact_delta) @escalate = args[:escalate] if args.key?(:escalate) @requested_auth_configs = args[:requested_auth_configs] if args.key?(:requested_auth_configs) @skip_summarization = args[:skip_summarization] if args.key?(:skip_summarization) @state_delta = args[:state_delta] if args.key?(:state_delta) @transfer_agent = args[:transfer_agent] if args.key?(:transfer_agent) end |