Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EventMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Metadata relating to a LLM response event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EventMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1EventMetadata.



18812
18813
18814
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18812

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#branchString

Optional. The branch of the event. The format is like agent_1.agent_2.agent_3, where agent_1 is the parent of agent_2, and agent_2 is the parent of agent_3. Branch is used when multiple child agents shouldn't see their siblings' conversation history. Corresponds to the JSON property branch

Returns:

  • (String)


18760
18761
18762
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18760

def branch
  @branch
end

#custom_metadataHash<String,Object>

The custom metadata of the LlmResponse. Corresponds to the JSON property customMetadata

Returns:

  • (Hash<String,Object>)


18765
18766
18767
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18765

def 
  @custom_metadata
end

#grounding_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingMetadata

Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources. Corresponds to the JSON property groundingMetadata



18772
18773
18774
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18772

def 
  @grounding_metadata
end

#input_transcriptionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Transcription

Audio transcription in Server Content. Corresponds to the JSON property inputTranscription



18777
18778
18779
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18777

def input_transcription
  @input_transcription
end

#interruptedBoolean Also known as: interrupted?

Optional. Flag indicating that LLM was interrupted when generating the content. Usually it's due to user interruption during a bidi streaming. Corresponds to the JSON property interrupted

Returns:

  • (Boolean)


18783
18784
18785
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18783

def interrupted
  @interrupted
end

#long_running_tool_idsArray<String>

Optional. Set of ids of the long running function calls. Agent client will know from this field about which function call is long running. Only valid for function call event. Corresponds to the JSON property longRunningToolIds

Returns:

  • (Array<String>)


18791
18792
18793
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18791

def long_running_tool_ids
  @long_running_tool_ids
end

#output_transcriptionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Transcription

Audio transcription in Server Content. Corresponds to the JSON property outputTranscription



18796
18797
18798
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18796

def output_transcription
  @output_transcription
end

#partialBoolean Also known as: partial?

Optional. Indicates whether the text content is part of a unfinished text stream. Only used for streaming mode and when the content is plain text. Corresponds to the JSON property partial

Returns:

  • (Boolean)


18802
18803
18804
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18802

def partial
  @partial
end

#turn_completeBoolean Also known as: turn_complete?

Optional. Indicates whether the response from the model is complete. Only used for streaming mode. Corresponds to the JSON property turnComplete

Returns:

  • (Boolean)


18809
18810
18811
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18809

def turn_complete
  @turn_complete
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18817
18818
18819
18820
18821
18822
18823
18824
18825
18826
18827
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18817

def update!(**args)
  @branch = args[:branch] if args.key?(:branch)
  @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata)
  @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata)
  @input_transcription = args[:input_transcription] if args.key?(:input_transcription)
  @interrupted = args[:interrupted] if args.key?(:interrupted)
  @long_running_tool_ids = args[:long_running_tool_ids] if args.key?(:long_running_tool_ids)
  @output_transcription = args[:output_transcription] if args.key?(:output_transcription)
  @partial = args[:partial] if args.key?(:partial)
  @turn_complete = args[:turn_complete] if args.key?(:turn_complete)
end