Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EventMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EventMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Metadata relating to a LLM response event.
Instance Attribute Summary collapse
-
#branch ⇒ String
Optional.
-
#custom_metadata ⇒ Hash<String,Object>
The custom metadata of the LlmResponse.
-
#grounding_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingMetadata
Information about the sources that support the content of a response.
-
#input_transcription ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Transcription
Audio transcription in Server Content.
-
#interrupted ⇒ Boolean
(also: #interrupted?)
Optional.
-
#long_running_tool_ids ⇒ Array<String>
Optional.
-
#output_transcription ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Transcription
Audio transcription in Server Content.
-
#partial ⇒ Boolean
(also: #partial?)
Optional.
-
#turn_complete ⇒ Boolean
(also: #turn_complete?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EventMetadata
constructor
A new instance of GoogleCloudAiplatformV1beta1EventMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1EventMetadata
Returns a new instance of GoogleCloudAiplatformV1beta1EventMetadata.
12747 12748 12749 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#branch ⇒ String
Optional. The branch of the event. The format is like agent_1.agent_2.agent_3,
where agent_1 is the parent of agent_2, and agent_2 is the parent of agent_3.
Branch is used when multiple child agents shouldn't see their siblings'
conversation history.
Corresponds to the JSON property branch
12695 12696 12697 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12695 def branch @branch end |
#custom_metadata ⇒ Hash<String,Object>
The custom metadata of the LlmResponse.
Corresponds to the JSON property customMetadata
12700 12701 12702 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12700 def @custom_metadata end |
#grounding_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingMetadata
Information about the sources that support the content of a response. When
grounding is enabled, the model returns citations for claims in the response.
This object contains the retrieved sources.
Corresponds to the JSON property groundingMetadata
12707 12708 12709 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12707 def @grounding_metadata end |
#input_transcription ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Transcription
Audio transcription in Server Content.
Corresponds to the JSON property inputTranscription
12712 12713 12714 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12712 def input_transcription @input_transcription end |
#interrupted ⇒ Boolean Also known as: interrupted?
Optional. Flag indicating that LLM was interrupted when generating the content.
Usually it's due to user interruption during a bidi streaming.
Corresponds to the JSON property interrupted
12718 12719 12720 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12718 def interrupted @interrupted end |
#long_running_tool_ids ⇒ Array<String>
Optional. Set of ids of the long running function calls. Agent client will
know from this field about which function call is long running. Only valid for
function call event.
Corresponds to the JSON property longRunningToolIds
12726 12727 12728 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12726 def long_running_tool_ids @long_running_tool_ids end |
#output_transcription ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Transcription
Audio transcription in Server Content.
Corresponds to the JSON property outputTranscription
12731 12732 12733 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12731 def output_transcription @output_transcription end |
#partial ⇒ Boolean Also known as: partial?
Optional. Indicates whether the text content is part of a unfinished text
stream. Only used for streaming mode and when the content is plain text.
Corresponds to the JSON property partial
12737 12738 12739 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12737 def partial @partial end |
#turn_complete ⇒ Boolean Also known as: turn_complete?
Optional. Indicates whether the response from the model is complete. Only used
for streaming mode.
Corresponds to the JSON property turnComplete
12744 12745 12746 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12744 def turn_complete @turn_complete end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12752 12753 12754 12755 12756 12757 12758 12759 12760 12761 12762 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12752 def update!(**args) @branch = args[:branch] if args.key?(:branch) @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata) @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata) @input_transcription = args[:input_transcription] if args.key?(:input_transcription) @interrupted = args[:interrupted] if args.key?(:interrupted) @long_running_tool_ids = args[:long_running_tool_ids] if args.key?(:long_running_tool_ids) @output_transcription = args[:output_transcription] if args.key?(:output_transcription) @partial = args[:partial] if args.key?(:partial) @turn_complete = args[:turn_complete] if args.key?(:turn_complete) end |