Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Example

Returns a new instance of GoogleCloudAiplatformV1beta1Example.



12894
12895
12896
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Example was created. Corresponds to the JSON property createTime

Returns:

  • (String)


12875
12876
12877
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12875

def create_time
  @create_time
end

#display_nameString

Optional. The display name for Example. Corresponds to the JSON property displayName

Returns:

  • (String)


12880
12881
12882
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12880

def display_name
  @display_name
end

#example_idString

Optional. Immutable. Unique identifier of an example. If not specified when upserting new examples, the example_id will be generated. Corresponds to the JSON property exampleId

Returns:

  • (String)


12886
12887
12888
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12886

def example_id
  @example_id
end

#stored_contents_exampleGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExample

A ContentsExample to be used with GenerateContent alongside information required for storage and retrieval with Example Store. Corresponds to the JSON property storedContentsExample



12892
12893
12894
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12892

def stored_contents_example
  @stored_contents_example
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12899
12900
12901
12902
12903
12904
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12899

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @example_id = args[:example_id] if args.key?(:example_id)
  @stored_contents_example = args[:stored_contents_example] if args.key?(:stored_contents_example)
end