Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Example

Returns a new instance of GoogleCloudAiplatformV1beta1Example.



12828
12829
12830
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12828

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Example was created. Corresponds to the JSON property createTime

Returns:

  • (String)


12809
12810
12811
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12809

def create_time
  @create_time
end

#display_nameString

Optional. The display name for Example. Corresponds to the JSON property displayName

Returns:

  • (String)


12814
12815
12816
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12814

def display_name
  @display_name
end

#example_idString

Optional. Immutable. Unique identifier of an example. If not specified when upserting new examples, the example_id will be generated. Corresponds to the JSON property exampleId

Returns:

  • (String)


12820
12821
12822
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12820

def example_id
  @example_id
end

#stored_contents_exampleGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExample

A ContentsExample to be used with GenerateContent alongside information required for storage and retrieval with Example Store. Corresponds to the JSON property storedContentsExample



12826
12827
12828
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12826

def stored_contents_example
  @stored_contents_example
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12833
12834
12835
12836
12837
12838
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12833

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @example_id = args[:example_id] if args.key?(:example_id)
  @stored_contents_example = args[:stored_contents_example] if args.key?(:stored_contents_example)
end