Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Examples

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Example-based explainability that returns the nearest neighbors from the provided dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Examples

Returns a new instance of GoogleCloudAiplatformV1beta1Examples.



13010
13011
13012
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#example_gcs_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesExampleGcsSource

The Cloud Storage input instances. Corresponds to the JSON property exampleGcsSource



12985
12986
12987
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12985

def example_gcs_source
  @example_gcs_source
end

#gcs_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



12990
12991
12992
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12990

def gcs_source
  @gcs_source
end

#nearest_neighbor_search_configObject

The full configuration for the generated index, the semantics are the same as metadata and should match NearestNeighborSearchConfig. Corresponds to the JSON property nearestNeighborSearchConfig

Returns:

  • (Object)


12998
12999
13000
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 12998

def nearest_neighbor_search_config
  @nearest_neighbor_search_config
end

#neighbor_countFixnum

The number of neighbors to return when querying for examples. Corresponds to the JSON property neighborCount

Returns:

  • (Fixnum)


13003
13004
13005
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13003

def neighbor_count
  @neighbor_count
end

#presetsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Presets

Preset configuration for example-based explanations Corresponds to the JSON property presets



13008
13009
13010
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13008

def presets
  @presets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13015
13016
13017
13018
13019
13020
13021
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13015

def update!(**args)
  @example_gcs_source = args[:example_gcs_source] if args.key?(:example_gcs_source)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @nearest_neighbor_search_config = args[:nearest_neighbor_search_config] if args.key?(:nearest_neighbor_search_config)
  @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count)
  @presets = args[:presets] if args.key?(:presets)
end