Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesOverride
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Overrides for example-based explanations.
Instance Attribute Summary collapse
-
#crowding_count ⇒ Fixnum
The number of neighbors to return that have the same crowding tag.
-
#data_format ⇒ String
The format of the data being provided with each call.
-
#neighbor_count ⇒ Fixnum
The number of neighbors to return.
-
#restrictions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesRestrictionsNamespace>
Restrict the resulting nearest neighbors to respect these constraints.
-
#return_embeddings ⇒ Boolean
(also: #return_embeddings?)
If true, return the embeddings instead of neighbors.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExamplesOverride
constructor
A new instance of GoogleCloudAiplatformV1beta1ExamplesOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExamplesOverride
Returns a new instance of GoogleCloudAiplatformV1beta1ExamplesOverride.
19171 19172 19173 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19171 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crowding_count ⇒ Fixnum
The number of neighbors to return that have the same crowding tag.
Corresponds to the JSON property crowdingCount
19148 19149 19150 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19148 def crowding_count @crowding_count end |
#data_format ⇒ String
The format of the data being provided with each call.
Corresponds to the JSON property dataFormat
19153 19154 19155 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19153 def data_format @data_format end |
#neighbor_count ⇒ Fixnum
The number of neighbors to return.
Corresponds to the JSON property neighborCount
19158 19159 19160 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19158 def neighbor_count @neighbor_count end |
#restrictions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesRestrictionsNamespace>
Restrict the resulting nearest neighbors to respect these constraints.
Corresponds to the JSON property restrictions
19163 19164 19165 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19163 def restrictions @restrictions end |
#return_embeddings ⇒ Boolean Also known as: return_embeddings?
If true, return the embeddings instead of neighbors.
Corresponds to the JSON property returnEmbeddings
19168 19169 19170 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19168 def @return_embeddings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19176 19177 19178 19179 19180 19181 19182 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19176 def update!(**args) @crowding_count = args[:crowding_count] if args.key?(:crowding_count) @data_format = args[:data_format] if args.key?(:data_format) @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count) @restrictions = args[:restrictions] if args.key?(:restrictions) @return_embeddings = args[:return_embeddings] if args.key?(:return_embeddings) end |