Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesOverride
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Overrides for example-based explanations.
Instance Attribute Summary collapse
-
#crowding_count ⇒ Fixnum
The number of neighbors to return that have the same crowding tag.
-
#data_format ⇒ String
The format of the data being provided with each call.
-
#neighbor_count ⇒ Fixnum
The number of neighbors to return.
-
#restrictions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesRestrictionsNamespace>
Restrict the resulting nearest neighbors to respect these constraints.
-
#return_embeddings ⇒ Boolean
(also: #return_embeddings?)
If true, return the embeddings instead of neighbors.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExamplesOverride
constructor
A new instance of GoogleCloudAiplatformV1beta1ExamplesOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExamplesOverride
Returns a new instance of GoogleCloudAiplatformV1beta1ExamplesOverride.
19349 19350 19351 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19349 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crowding_count ⇒ Fixnum
The number of neighbors to return that have the same crowding tag.
Corresponds to the JSON property crowdingCount
19326 19327 19328 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19326 def crowding_count @crowding_count end |
#data_format ⇒ String
The format of the data being provided with each call.
Corresponds to the JSON property dataFormat
19331 19332 19333 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19331 def data_format @data_format end |
#neighbor_count ⇒ Fixnum
The number of neighbors to return.
Corresponds to the JSON property neighborCount
19336 19337 19338 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19336 def neighbor_count @neighbor_count end |
#restrictions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesRestrictionsNamespace>
Restrict the resulting nearest neighbors to respect these constraints.
Corresponds to the JSON property restrictions
19341 19342 19343 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19341 def restrictions @restrictions end |
#return_embeddings ⇒ Boolean Also known as: return_embeddings?
If true, return the embeddings instead of neighbors.
Corresponds to the JSON property returnEmbeddings
19346 19347 19348 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19346 def @return_embeddings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19354 19355 19356 19357 19358 19359 19360 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19354 def update!(**args) @crowding_count = args[:crowding_count] if args.key?(:crowding_count) @data_format = args[:data_format] if args.key?(:data_format) @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count) @restrictions = args[:restrictions] if args.key?(:restrictions) @return_embeddings = args[:return_embeddings] if args.key?(:return_embeddings) end |