Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExecutableCode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the CodeExecution tool, in which the code will be automatically executed, and a corresponding CodeExecutionResult will also be generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecutableCode

Returns a new instance of GoogleCloudAiplatformV1beta1ExecutableCode.



20653
20654
20655
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Required. The code to be executed. Corresponds to the JSON property code

Returns:

  • (String)


20640
20641
20642
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20640

def code
  @code
end

#idString

Optional. Unique identifier of the ExecutableCode part. The server returns the CodeExecutionResult with the matching id. Corresponds to the JSON property id

Returns:

  • (String)


20646
20647
20648
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20646

def id
  @id
end

#languageString

Required. Programming language of the code. Corresponds to the JSON property language

Returns:

  • (String)


20651
20652
20653
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20651

def language
  @language
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20658
20659
20660
20661
20662
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20658

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @id = args[:id] if args.key?(:id)
  @language = args[:language] if args.key?(:language)
end