Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExecutableCode
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExecutableCode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Code generated by the model that is meant to be executed, and the result
returned to the model. Generated when using the CodeExecution tool, in which
the code will be automatically executed, and a corresponding
CodeExecutionResult will also be generated.
Instance Attribute Summary collapse
-
#code ⇒ String
Required.
-
#language ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecutableCode
constructor
A new instance of GoogleCloudAiplatformV1beta1ExecutableCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecutableCode
Returns a new instance of GoogleCloudAiplatformV1beta1ExecutableCode.
19411 19412 19413 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19411 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Required. The code to be executed.
Corresponds to the JSON property code
19404 19405 19406 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19404 def code @code end |
#language ⇒ String
Required. Programming language of the code.
Corresponds to the JSON property language
19409 19410 19411 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19409 def language @language end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19416 19417 19418 19419 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19416 def update!(**args) @code = args[:code] if args.key?(:code) @language = args[:language] if args.key?(:language) end |