Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExecutableCode
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExecutableCode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Code generated by the model that is meant to be executed, and the result
returned to the model. Generated when using the CodeExecution tool, in which
the code will be automatically executed, and a corresponding
CodeExecutionResult will also be generated.
Instance Attribute Summary collapse
-
#code ⇒ String
Required.
-
#language ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecutableCode
constructor
A new instance of GoogleCloudAiplatformV1beta1ExecutableCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecutableCode
Returns a new instance of GoogleCloudAiplatformV1beta1ExecutableCode.
18445 18446 18447 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18445 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Required. The code to be executed.
Corresponds to the JSON property code
18438 18439 18440 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18438 def code @code end |
#language ⇒ String
Required. Programming language of the code.
Corresponds to the JSON property language
18443 18444 18445 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18443 def language @language end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18450 18451 18452 18453 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18450 def update!(**args) @code = args[:code] if args.key?(:code) @language = args[:language] if args.key?(:language) end |