Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExecutableCode
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExecutableCode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Code generated by the model that is meant to be executed, and the result
returned to the model. Generated when using the CodeExecution tool, in which
the code will be automatically executed, and a corresponding
CodeExecutionResult will also be generated.
Instance Attribute Summary collapse
-
#code ⇒ String
Required.
-
#language ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecutableCode
constructor
A new instance of GoogleCloudAiplatformV1beta1ExecutableCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecutableCode
Returns a new instance of GoogleCloudAiplatformV1beta1ExecutableCode.
17954 17955 17956 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17954 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Required. The code to be executed.
Corresponds to the JSON property code
17947 17948 17949 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17947 def code @code end |
#language ⇒ String
Required. Programming language of the code.
Corresponds to the JSON property language
17952 17953 17954 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17952 def language @language end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17959 17960 17961 17962 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17959 def update!(**args) @code = args[:code] if args.key?(:code) @language = args[:language] if args.key?(:language) end |