Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Execution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Execution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Instance of a general execution.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the Execution Corresponds to the JSON property
description. -
#display_name ⇒ String
User provided display name of the Execution.
-
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Executions.
-
#metadata ⇒ Hash<String,Object>
Properties of the Execution.
-
#name ⇒ String
Output only.
-
#schema_title ⇒ String
The title of the schema describing the metadata.
-
#schema_version ⇒ String
The version of the schema in
schema_titleto use. -
#state ⇒ String
The state of this Execution.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Execution
constructor
A new instance of GoogleCloudAiplatformV1beta1Execution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Execution
Returns a new instance of GoogleCloudAiplatformV1beta1Execution.
18662 18663 18664 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18662 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Execution was created.
Corresponds to the JSON property createTime
18594 18595 18596 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18594 def create_time @create_time end |
#description ⇒ String
Description of the Execution
Corresponds to the JSON property description
18599 18600 18601 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18599 def description @description end |
#display_name ⇒ String
User provided display name of the Execution. May be up to 128 Unicode
characters.
Corresponds to the JSON property displayName
18605 18606 18607 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18605 def display_name @display_name end |
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
18611 18612 18613 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18611 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Executions. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Execution (System labels are excluded).
Corresponds to the JSON property labels
18620 18621 18622 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18620 def labels @labels end |
#metadata ⇒ Hash<String,Object>
Properties of the Execution. Top level metadata keys' heading and trailing
spaces will be trimmed. The size of this field should not exceed 200KB.
Corresponds to the JSON property metadata
18626 18627 18628 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18626 def @metadata end |
#name ⇒ String
Output only. The resource name of the Execution.
Corresponds to the JSON property name
18631 18632 18633 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18631 def name @name end |
#schema_title ⇒ String
The title of the schema describing the metadata. Schema title and version is
expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaTitle
18639 18640 18641 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18639 def schema_title @schema_title end |
#schema_version ⇒ String
The version of the schema in schema_title to use. Schema title and version
is expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaVersion
18647 18648 18649 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18647 def schema_version @schema_version end |
#state ⇒ String
The state of this Execution. This is a property of the Execution, and does not
imply or capture any ongoing process. This property is managed by clients (
such as Vertex AI Pipelines) and the system does not prescribe or check the
validity of state transitions.
Corresponds to the JSON property state
18655 18656 18657 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18655 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this Execution was last updated.
Corresponds to the JSON property updateTime
18660 18661 18662 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18660 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18667 18668 18669 18670 18671 18672 18673 18674 18675 18676 18677 18678 18679 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18667 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @schema_title = args[:schema_title] if args.key?(:schema_title) @schema_version = args[:schema_version] if args.key?(:schema_version) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |