Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Execution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Instance of a general execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Execution

Returns a new instance of GoogleCloudAiplatformV1beta1Execution.



13385
13386
13387
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13385

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Execution was created. Corresponds to the JSON property createTime

Returns:

  • (String)


13317
13318
13319
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13317

def create_time
  @create_time
end

#descriptionString

Description of the Execution Corresponds to the JSON property description

Returns:

  • (String)


13322
13323
13324
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13322

def description
  @description
end

#display_nameString

User provided display name of the Execution. May be up to 128 Unicode characters. Corresponds to the JSON property displayName

Returns:

  • (String)


13328
13329
13330
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13328

def display_name
  @display_name
end

#etagString

An eTag used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


13334
13335
13336
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13334

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Executions. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Execution (System labels are excluded). Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


13343
13344
13345
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13343

def labels
  @labels
end

#metadataHash<String,Object>

Properties of the Execution. Top level metadata keys' heading and trailing spaces will be trimmed. The size of this field should not exceed 200KB. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


13349
13350
13351
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13349

def 
  @metadata
end

#nameString

Output only. The resource name of the Execution. Corresponds to the JSON property name

Returns:

  • (String)


13354
13355
13356
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13354

def name
  @name
end

#schema_titleString

The title of the schema describing the metadata. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store. Corresponds to the JSON property schemaTitle

Returns:

  • (String)


13362
13363
13364
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13362

def schema_title
  @schema_title
end

#schema_versionString

The version of the schema in schema_title to use. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store. Corresponds to the JSON property schemaVersion

Returns:

  • (String)


13370
13371
13372
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13370

def schema_version
  @schema_version
end

#stateString

The state of this Execution. This is a property of the Execution, and does not imply or capture any ongoing process. This property is managed by clients ( such as Vertex AI Pipelines) and the system does not prescribe or check the validity of state transitions. Corresponds to the JSON property state

Returns:

  • (String)


13378
13379
13380
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13378

def state
  @state
end

#update_timeString

Output only. Timestamp when this Execution was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


13383
13384
13385
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13383

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13390
13391
13392
13393
13394
13395
13396
13397
13398
13399
13400
13401
13402
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13390

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @schema_title = args[:schema_title] if args.key?(:schema_title)
  @schema_version = args[:schema_version] if args.key?(:schema_version)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end