Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplainRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for PredictionService.Explain.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplainRequest

Returns a new instance of GoogleCloudAiplatformV1beta1ExplainRequest.



19689
19690
19691
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19689

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#concurrent_explanation_spec_overrideHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpecOverride>

Optional. This field is the same as the one above, but supports multiple explanations to occur in parallel. The key can be any string. Each override will be run against the model, then its explanations will be grouped together. Note - these explanations are run In Addition to the default Explanation in the deployed model. Corresponds to the JSON property concurrentExplanationSpecOverride



19659
19660
19661
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19659

def concurrent_explanation_spec_override
  @concurrent_explanation_spec_override
end

#deployed_model_idString

If specified, this ExplainRequest will be served by the chosen DeployedModel, overriding Endpoint.traffic_split. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


19665
19666
19667
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19665

def deployed_model_id
  @deployed_model_id
end

#explanation_spec_overrideGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpecOverride

The ExplanationSpec entries that can be overridden at online explanation time. Corresponds to the JSON property explanationSpecOverride



19670
19671
19672
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19670

def explanation_spec_override
  @explanation_spec_override
end

#instancesArray<Object>

Required. The instances that are the input to the explanation call. A DeployedModel may have an upper limit on the number of instances it supports per request, and when it is exceeded the explanation call errors in case of AutoML Models, or, in case of customer created Models, the behaviour is as documented by that Model. The schema of any single instance may be specified via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri. Corresponds to the JSON property instances

Returns:

  • (Array<Object>)


19680
19681
19682
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19680

def instances
  @instances
end

#parametersObject

The parameters that govern the prediction. The schema of the parameters may be specified via Endpoint's DeployedModels' Model's PredictSchemata's parameters_schema_uri. Corresponds to the JSON property parameters

Returns:

  • (Object)


19687
19688
19689
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19687

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19694
19695
19696
19697
19698
19699
19700
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19694

def update!(**args)
  @concurrent_explanation_spec_override = args[:concurrent_explanation_spec_override] if args.key?(:concurrent_explanation_spec_override)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @explanation_spec_override = args[:explanation_spec_override] if args.key?(:explanation_spec_override)
  @instances = args[:instances] if args.key?(:instances)
  @parameters = args[:parameters] if args.key?(:parameters)
end