Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplainRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplainRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for PredictionService.Explain.
Instance Attribute Summary collapse
-
#concurrent_explanation_spec_override ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpecOverride>
Optional.
-
#deployed_model_id ⇒ String
If specified, this ExplainRequest will be served by the chosen DeployedModel, overriding Endpoint.traffic_split.
-
#explanation_spec_override ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpecOverride
The ExplanationSpec entries that can be overridden at online explanation time.
-
#instances ⇒ Array<Object>
Required.
-
#parameters ⇒ Object
The parameters that govern the prediction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplainRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1ExplainRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplainRequest
Returns a new instance of GoogleCloudAiplatformV1beta1ExplainRequest.
13380 13381 13382 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13380 def initialize(**args) update!(**args) end |
Instance Attribute Details
#concurrent_explanation_spec_override ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpecOverride>
Optional. This field is the same as the one above, but supports multiple
explanations to occur in parallel. The key can be any string. Each override
will be run against the model, then its explanations will be grouped together.
Note - these explanations are run In Addition to the default Explanation
in the deployed model.
Corresponds to the JSON property concurrentExplanationSpecOverride
13350 13351 13352 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13350 def concurrent_explanation_spec_override @concurrent_explanation_spec_override end |
#deployed_model_id ⇒ String
If specified, this ExplainRequest will be served by the chosen DeployedModel,
overriding Endpoint.traffic_split.
Corresponds to the JSON property deployedModelId
13356 13357 13358 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13356 def deployed_model_id @deployed_model_id end |
#explanation_spec_override ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpecOverride
The ExplanationSpec entries that can be overridden at online explanation time.
Corresponds to the JSON property explanationSpecOverride
13361 13362 13363 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13361 def explanation_spec_override @explanation_spec_override end |
#instances ⇒ Array<Object>
Required. The instances that are the input to the explanation call. A
DeployedModel may have an upper limit on the number of instances it supports
per request, and when it is exceeded the explanation call errors in case of
AutoML Models, or, in case of customer created Models, the behaviour is as
documented by that Model. The schema of any single instance may be specified
via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri.
Corresponds to the JSON property instances
13371 13372 13373 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13371 def instances @instances end |
#parameters ⇒ Object
The parameters that govern the prediction. The schema of the parameters may be
specified via Endpoint's DeployedModels' Model's PredictSchemata's
parameters_schema_uri.
Corresponds to the JSON property parameters
13378 13379 13380 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13378 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13385 13386 13387 13388 13389 13390 13391 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13385 def update!(**args) @concurrent_explanation_spec_override = args[:concurrent_explanation_spec_override] if args.key?(:concurrent_explanation_spec_override) @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id) @explanation_spec_override = args[:explanation_spec_override] if args.key?(:explanation_spec_override) @instances = args[:instances] if args.key?(:instances) @parameters = args[:parameters] if args.key?(:parameters) end |