Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Metadata describing the Model's input and output for explanation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplanationMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1ExplanationMetadata.



18881
18882
18883
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18881

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feature_attributions_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing the format of the feature attributions. The schema is defined as an OpenAPI 3.0.2 Schema Object. AutoML tabular Models always have this field populated by Vertex AI. Note: The URI given on output may be different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access. Corresponds to the JSON property featureAttributionsSchemaUri

Returns:

  • (String)


18854
18855
18856
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18854

def feature_attributions_schema_uri
  @feature_attributions_schema_uri
end

#inputsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataInputMetadata>

Required. Map from feature names to feature input metadata. Keys are the name of the features. Values are the specification of the feature. An empty InputMetadata is valid. It describes a text feature which has the name specified as the key in ExplanationMetadata.inputs. The baseline of the empty feature is chosen by Vertex AI. For Vertex AI-provided Tensorflow images, the key can be any friendly name of the feature. Once specified, featureAttributions are keyed by this key (if not grouped with another feature) . For custom images, the key must match with the key in instance. Corresponds to the JSON property inputs



18866
18867
18868
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18866

def inputs
  @inputs
end

#latent_space_sourceString

Name of the source to generate embeddings for example based explanations. Corresponds to the JSON property latentSpaceSource

Returns:

  • (String)


18871
18872
18873
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18871

def latent_space_source
  @latent_space_source
end

#outputsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataOutputMetadata>

Required. Map from output names to output metadata. For Vertex AI-provided Tensorflow images, keys can be any user defined string that consists of any UTF-8 characters. For custom images, keys are the name of the output field in the prediction to be explained. Currently only one key is allowed. Corresponds to the JSON property outputs



18879
18880
18881
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18879

def outputs
  @outputs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18886
18887
18888
18889
18890
18891
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18886

def update!(**args)
  @feature_attributions_schema_uri = args[:feature_attributions_schema_uri] if args.key?(:feature_attributions_schema_uri)
  @inputs = args[:inputs] if args.key?(:inputs)
  @latent_space_source = args[:latent_space_source] if args.key?(:latent_space_source)
  @outputs = args[:outputs] if args.key?(:outputs)
end