Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataInputMetadataVisualization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Visualization configurations for image explanation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplanationMetadataInputMetadataVisualization

Returns a new instance of GoogleCloudAiplatformV1beta1ExplanationMetadataInputMetadataVisualization.



21316
21317
21318
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clip_percent_lowerboundFloat

Excludes attributions below the specified percentile, from the highlighted areas. Defaults to 62. Corresponds to the JSON property clipPercentLowerbound

Returns:

  • (Float)


21277
21278
21279
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21277

def clip_percent_lowerbound
  @clip_percent_lowerbound
end

#clip_percent_upperboundFloat

Excludes attributions above the specified percentile from the highlighted areas. Using the clip_percent_upperbound and clip_percent_lowerbound together can be useful for filtering out noise and making it easier to see areas of strong attribution. Defaults to 99.9. Corresponds to the JSON property clipPercentUpperbound

Returns:

  • (Float)


21285
21286
21287
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21285

def clip_percent_upperbound
  @clip_percent_upperbound
end

#color_mapString

The color scheme used for the highlighted areas. Defaults to PINK_GREEN for Integrated Gradients attribution, which shows positive attributions in green and negative in pink. Defaults to VIRIDIS for XRAI attribution, which highlights the most influential regions in yellow and the least influential in blue. Corresponds to the JSON property colorMap

Returns:

  • (String)


21294
21295
21296
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21294

def color_map
  @color_map
end

#overlay_typeString

How the original image is displayed in the visualization. Adjusting the overlay can help increase visual clarity if the original image makes it difficult to view the visualization. Defaults to NONE. Corresponds to the JSON property overlayType

Returns:

  • (String)


21301
21302
21303
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21301

def overlay_type
  @overlay_type
end

#polarityString

Whether to only highlight pixels with positive contributions, negative or both. Defaults to POSITIVE. Corresponds to the JSON property polarity

Returns:

  • (String)


21307
21308
21309
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21307

def polarity
  @polarity
end

#typeString

Type of the image visualization. Only applicable to Integrated Gradients attribution. OUTLINES shows regions of attribution, while PIXELS shows per- pixel attribution. Defaults to OUTLINES. Corresponds to the JSON property type

Returns:

  • (String)


21314
21315
21316
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21314

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21321
21322
21323
21324
21325
21326
21327
21328
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21321

def update!(**args)
  @clip_percent_lowerbound = args[:clip_percent_lowerbound] if args.key?(:clip_percent_lowerbound)
  @clip_percent_upperbound = args[:clip_percent_upperbound] if args.key?(:clip_percent_upperbound)
  @color_map = args[:color_map] if args.key?(:color_map)
  @overlay_type = args[:overlay_type] if args.key?(:overlay_type)
  @polarity = args[:polarity] if args.key?(:polarity)
  @type = args[:type] if args.key?(:type)
end