Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataOverride
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The ExplanationMetadata entries that can be overridden at online explanation time.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplanationMetadataOverride
constructor
A new instance of GoogleCloudAiplatformV1beta1ExplanationMetadataOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplanationMetadataOverride
Returns a new instance of GoogleCloudAiplatformV1beta1ExplanationMetadataOverride.
20143 20144 20145 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataOverrideInputMetadataOverride>
Required. Overrides the input metadata of the features. The key is the name of
the feature to be overridden. The keys specified here must exist in the input
metadata to be overridden. If a feature is not specified here, the
corresponding feature's input metadata is not overridden.
Corresponds to the JSON property inputs
20141 20142 20143 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20141 def inputs @inputs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20148 20149 20150 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20148 def update!(**args) @inputs = args[:inputs] if args.key?(:inputs) end |