Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The ExplanationMetadata entries that can be overridden at online explanation time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplanationMetadataOverride

Returns a new instance of GoogleCloudAiplatformV1beta1ExplanationMetadataOverride.



18686
18687
18688
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inputsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataOverrideInputMetadataOverride>

Required. Overrides the input metadata of the features. The key is the name of the feature to be overridden. The keys specified here must exist in the input metadata to be overridden. If a feature is not specified here, the corresponding feature's input metadata is not overridden. Corresponds to the JSON property inputs



18684
18685
18686
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18684

def inputs
  @inputs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18691
18692
18693
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18691

def update!(**args)
  @inputs = args[:inputs] if args.key?(:inputs)
end