Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataOverride
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The ExplanationMetadata entries that can be overridden at online explanation time.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplanationMetadataOverride
constructor
A new instance of GoogleCloudAiplatformV1beta1ExplanationMetadataOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplanationMetadataOverride
Returns a new instance of GoogleCloudAiplatformV1beta1ExplanationMetadataOverride.
13900 13901 13902 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13900 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataOverrideInputMetadataOverride>
Required. Overrides the input metadata of the features. The key is the name of
the feature to be overridden. The keys specified here must exist in the input
metadata to be overridden. If a feature is not specified here, the
corresponding feature's input metadata is not overridden.
Corresponds to the JSON property inputs
13898 13899 13900 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13898 def inputs @inputs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13905 13906 13907 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 13905 def update!(**args) @inputs = args[:inputs] if args.key?(:inputs) end |