Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpecOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The ExplanationSpec entries that can be overridden at online explanation time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplanationSpecOverride

Returns a new instance of GoogleCloudAiplatformV1beta1ExplanationSpecOverride.



21527
21528
21529
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21527

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#examples_overrideGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesOverride

Overrides for example-based explanations. Corresponds to the JSON property examplesOverride



21514
21515
21516
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21514

def examples_override
  @examples_override
end

#metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataOverride

The ExplanationMetadata entries that can be overridden at online explanation time. Corresponds to the JSON property metadata



21520
21521
21522
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21520

def 
  @metadata
end

#parametersGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationParameters

Parameters to configure explaining for Model's predictions. Corresponds to the JSON property parameters



21525
21526
21527
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21525

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21532
21533
21534
21535
21536
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21532

def update!(**args)
  @examples_override = args[:examples_override] if args.key?(:examples_override)
  @metadata = args[:metadata] if args.key?(:metadata)
  @parameters = args[:parameters] if args.key?(:parameters)
end