Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpecOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The ExplanationSpec entries that can be overridden at online explanation time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplanationSpecOverride

Returns a new instance of GoogleCloudAiplatformV1beta1ExplanationSpecOverride.



20600
20601
20602
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20600

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#examples_overrideGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesOverride

Overrides for example-based explanations. Corresponds to the JSON property examplesOverride



20587
20588
20589
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20587

def examples_override
  @examples_override
end

#metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataOverride

The ExplanationMetadata entries that can be overridden at online explanation time. Corresponds to the JSON property metadata



20593
20594
20595
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20593

def 
  @metadata
end

#parametersGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationParameters

Parameters to configure explaining for Model's predictions. Corresponds to the JSON property parameters



20598
20599
20600
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20598

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20605
20606
20607
20608
20609
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20605

def update!(**args)
  @examples_override = args[:examples_override] if args.key?(:examples_override)
  @metadata = args[:metadata] if args.key?(:metadata)
  @parameters = args[:parameters] if args.key?(:parameters)
end