Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpecOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The ExplanationSpec entries that can be overridden at online explanation time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExplanationSpecOverride

Returns a new instance of GoogleCloudAiplatformV1beta1ExplanationSpecOverride.



20284
20285
20286
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#examples_overrideGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesOverride

Overrides for example-based explanations. Corresponds to the JSON property examplesOverride



20271
20272
20273
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20271

def examples_override
  @examples_override
end

#metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationMetadataOverride

The ExplanationMetadata entries that can be overridden at online explanation time. Corresponds to the JSON property metadata



20277
20278
20279
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20277

def 
  @metadata
end

#parametersGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationParameters

Parameters to configure explaining for Model's predictions. Corresponds to the JSON property parameters



20282
20283
20284
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20282

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20289
20290
20291
20292
20293
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20289

def update!(**args)
  @examples_override = args[:examples_override] if args.key?(:examples_override)
  @metadata = args[:metadata] if args.key?(:metadata)
  @parameters = args[:parameters] if args.key?(:parameters)
end