Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportDataConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Describes what part of the Dataset is to be exported, the destination of the export and how to export.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportDataConfig

Returns a new instance of GoogleCloudAiplatformV1beta1ExportDataConfig.



20145
20146
20147
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotations_filterString

An expression for filtering what part of the Dataset is to be exported. Only Annotations that match this filter will be exported. The filter syntax is the same as in ListAnnotations. Corresponds to the JSON property annotationsFilter

Returns:

  • (String)


20128
20129
20130
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20128

def annotations_filter
  @annotations_filter
end

#fraction_splitGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFractionSplit

Assigns the input data to training, validation, and test sets as per the given fractions. Any of training_fraction, validation_fraction and test_fraction may optionally be provided, they must sum to up to 1. If the provided ones sum to less than 1, the remainder is assigned to sets as decided by Vertex AI. If none of the fractions are set, by default roughly 80% of data is used for training, 10% for validation, and 10% for test. Corresponds to the JSON property fractionSplit



20138
20139
20140
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20138

def fraction_split
  @fraction_split
end

#gcs_destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcsDestination



20143
20144
20145
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20143

def gcs_destination
  @gcs_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20150
20151
20152
20153
20154
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20150

def update!(**args)
  @annotations_filter = args[:annotations_filter] if args.key?(:annotations_filter)
  @fraction_split = args[:fraction_split] if args.key?(:fraction_split)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
end