Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportDataConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportDataConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Describes what part of the Dataset is to be exported, the destination of the export and how to export.
Instance Attribute Summary collapse
-
#annotations_filter ⇒ String
An expression for filtering what part of the Dataset is to be exported.
-
#fraction_split ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFractionSplit
Assigns the input data to training, validation, and test sets as per the given fractions.
-
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportDataConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1ExportDataConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportDataConfig
Returns a new instance of GoogleCloudAiplatformV1beta1ExportDataConfig.
18866 18867 18868 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18866 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations_filter ⇒ String
An expression for filtering what part of the Dataset is to be exported. Only
Annotations that match this filter will be exported. The filter syntax is the
same as in ListAnnotations.
Corresponds to the JSON property annotationsFilter
18849 18850 18851 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18849 def annotations_filter @annotations_filter end |
#fraction_split ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFractionSplit
Assigns the input data to training, validation, and test sets as per the given
fractions. Any of training_fraction, validation_fraction and
test_fraction may optionally be provided, they must sum to up to 1. If the
provided ones sum to less than 1, the remainder is assigned to sets as decided
by Vertex AI. If none of the fractions are set, by default roughly 80% of data
is used for training, 10% for validation, and 10% for test.
Corresponds to the JSON property fractionSplit
18859 18860 18861 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18859 def fraction_split @fraction_split end |
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcsDestination
18864 18865 18866 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18864 def gcs_destination @gcs_destination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18871 18872 18873 18874 18875 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18871 def update!(**args) @annotations_filter = args[:annotations_filter] if args.key?(:annotations_filter) @fraction_split = args[:fraction_split] if args.key?(:fraction_split) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) end |