Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportDataResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportDataResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for DatasetService.ExportData.
Instance Attribute Summary collapse
-
#exported_files ⇒ Array<String>
All of the files that are exported in this export operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportDataResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ExportDataResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportDataResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ExportDataResponse.
19426 19427 19428 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19426 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exported_files ⇒ Array<String>
All of the files that are exported in this export operation. For custom code
training export, only three (training, validation and test) Cloud Storage
paths in wildcard format are populated (for example, gs://.../training-*).
Corresponds to the JSON property exportedFiles
19424 19425 19426 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19424 def exported_files @exported_files end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19431 19432 19433 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19431 def update!(**args) @exported_files = args[:exported_files] if args.key?(:exported_files) end |