Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for FeaturestoreService.ExportFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest.



19486
19487
19488
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureValueDestination

A destination location for Feature values and format. Corresponds to the JSON property destination



19462
19463
19464
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19462

def destination
  @destination
end

#feature_selectorGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelector

Selector for Features of an EntityType. Corresponds to the JSON property featureSelector



19467
19468
19469
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19467

def feature_selector
  @feature_selector
end

#full_exportGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestFullExport

Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time]. Corresponds to the JSON property fullExport



19473
19474
19475
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19473

def full_export
  @full_export
end

#settingsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DestinationFeatureSetting>

Per-Feature export settings. Corresponds to the JSON property settings



19478
19479
19480
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19478

def settings
  @settings
end

#snapshot_exportGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestSnapshotExport

Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time]. Corresponds to the JSON property snapshotExport



19484
19485
19486
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19484

def snapshot_export
  @snapshot_export
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19491
19492
19493
19494
19495
19496
19497
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19491

def update!(**args)
  @destination = args[:destination] if args.key?(:destination)
  @feature_selector = args[:feature_selector] if args.key?(:feature_selector)
  @full_export = args[:full_export] if args.key?(:full_export)
  @settings = args[:settings] if args.key?(:settings)
  @snapshot_export = args[:snapshot_export] if args.key?(:snapshot_export)
end