Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for FeaturestoreService.ExportFeatureValues.
Instance Attribute Summary collapse
-
#destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureValueDestination
A destination location for Feature values and format.
-
#feature_selector ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelector
Selector for Features of an EntityType.
-
#full_export ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestFullExport
Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time].
-
#settings ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DestinationFeatureSetting>
Per-Feature export settings.
-
#snapshot_export ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestSnapshotExport
Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time].
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest
Returns a new instance of GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest.
18995 18996 18997 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureValueDestination
A destination location for Feature values and format.
Corresponds to the JSON property destination
18971 18972 18973 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18971 def destination @destination end |
#feature_selector ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelector
Selector for Features of an EntityType.
Corresponds to the JSON property featureSelector
18976 18977 18978 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18976 def feature_selector @feature_selector end |
#full_export ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestFullExport
Describes exporting all historical Feature values of all entities of the
EntityType between [start_time, end_time].
Corresponds to the JSON property fullExport
18982 18983 18984 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18982 def full_export @full_export end |
#settings ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DestinationFeatureSetting>
Per-Feature export settings.
Corresponds to the JSON property settings
18987 18988 18989 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18987 def settings @settings end |
#snapshot_export ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestSnapshotExport
Describes exporting the latest Feature values of all entities of the
EntityType between [start_time, snapshot_time].
Corresponds to the JSON property snapshotExport
18993 18994 18995 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18993 def snapshot_export @snapshot_export end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19000 19001 19002 19003 19004 19005 19006 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19000 def update!(**args) @destination = args[:destination] if args.key?(:destination) @feature_selector = args[:feature_selector] if args.key?(:feature_selector) @full_export = args[:full_export] if args.key?(:full_export) @settings = args[:settings] if args.key?(:settings) @snapshot_export = args[:snapshot_export] if args.key?(:snapshot_export) end |