Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for FeaturestoreService.ExportFeatureValues.
Instance Attribute Summary collapse
-
#destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureValueDestination
A destination location for Feature values and format.
-
#feature_selector ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelector
Selector for Features of an EntityType.
-
#full_export ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestFullExport
Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time].
-
#settings ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DestinationFeatureSetting>
Per-Feature export settings.
-
#snapshot_export ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestSnapshotExport
Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time].
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest
Returns a new instance of GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest.
14209 14210 14211 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14209 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureValueDestination
A destination location for Feature values and format.
Corresponds to the JSON property destination
14185 14186 14187 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14185 def destination @destination end |
#feature_selector ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelector
Selector for Features of an EntityType.
Corresponds to the JSON property featureSelector
14190 14191 14192 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14190 def feature_selector @feature_selector end |
#full_export ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestFullExport
Describes exporting all historical Feature values of all entities of the
EntityType between [start_time, end_time].
Corresponds to the JSON property fullExport
14196 14197 14198 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14196 def full_export @full_export end |
#settings ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DestinationFeatureSetting>
Per-Feature export settings.
Corresponds to the JSON property settings
14201 14202 14203 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14201 def settings @settings end |
#snapshot_export ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestSnapshotExport
Describes exporting the latest Feature values of all entities of the
EntityType between [start_time, snapshot_time].
Corresponds to the JSON property snapshotExport
14207 14208 14209 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14207 def snapshot_export @snapshot_export end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14214 14215 14216 14217 14218 14219 14220 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14214 def update!(**args) @destination = args[:destination] if args.key?(:destination) @feature_selector = args[:feature_selector] if args.key?(:feature_selector) @full_export = args[:full_export] if args.key?(:full_export) @settings = args[:settings] if args.key?(:settings) @snapshot_export = args[:snapshot_export] if args.key?(:snapshot_export) end |