Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for FeaturestoreService.ExportFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1ExportFeatureValuesRequest.



14143
14144
14145
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14143

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureValueDestination

A destination location for Feature values and format. Corresponds to the JSON property destination



14119
14120
14121
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14119

def destination
  @destination
end

#feature_selectorGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelector

Selector for Features of an EntityType. Corresponds to the JSON property featureSelector



14124
14125
14126
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14124

def feature_selector
  @feature_selector
end

#full_exportGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestFullExport

Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time]. Corresponds to the JSON property fullExport



14130
14131
14132
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14130

def full_export
  @full_export
end

#settingsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DestinationFeatureSetting>

Per-Feature export settings. Corresponds to the JSON property settings



14135
14136
14137
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14135

def settings
  @settings
end

#snapshot_exportGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestSnapshotExport

Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time]. Corresponds to the JSON property snapshotExport



14141
14142
14143
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14141

def snapshot_export
  @snapshot_export
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14148
14149
14150
14151
14152
14153
14154
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14148

def update!(**args)
  @destination = args[:destination] if args.key?(:destination)
  @feature_selector = args[:feature_selector] if args.key?(:feature_selector)
  @full_export = args[:full_export] if args.key?(:full_export)
  @settings = args[:settings] if args.key?(:settings)
  @snapshot_export = args[:snapshot_export] if args.key?(:snapshot_export)
end