Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestSnapshotExport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestSnapshotExport

Returns a new instance of GoogleCloudAiplatformV1beta1ExportFeatureValuesRequestSnapshotExport.



14204
14205
14206
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14204

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#snapshot_timeString

Exports Feature values as of this timestamp. If not set, retrieve values as of now. Timestamp, if present, must not have higher than millisecond precision. Corresponds to the JSON property snapshotTime

Returns:

  • (String)


14195
14196
14197
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14195

def snapshot_time
  @snapshot_time
end

#start_timeString

Excludes Feature values with feature generation timestamp before this timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp, if present, must not have higher than millisecond precision. Corresponds to the JSON property startTime

Returns:

  • (String)


14202
14203
14204
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14202

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14209
14210
14211
14212
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14209

def update!(**args)
  @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end