Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportModelRequestOutputConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportModelRequestOutputConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Output configuration for the Model export.
Instance Attribute Summary collapse
-
#artifact_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#export_format_id ⇒ String
The ID of the format in which the Model must be exported.
-
#image_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContainerRegistryDestination
The Container Registry location for the container image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportModelRequestOutputConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1ExportModelRequestOutputConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportModelRequestOutputConfig
Returns a new instance of GoogleCloudAiplatformV1beta1ExportModelRequestOutputConfig.
21911 21912 21913 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21911 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property artifactDestination
21897 21898 21899 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21897 def artifact_destination @artifact_destination end |
#export_format_id ⇒ String
The ID of the format in which the Model must be exported. Each Model lists the
export formats it supports. If no value is provided here, then the first from
the list of the Model's supported formats is used by default.
Corresponds to the JSON property exportFormatId
21904 21905 21906 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21904 def export_format_id @export_format_id end |
#image_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContainerRegistryDestination
The Container Registry location for the container image.
Corresponds to the JSON property imageDestination
21909 21910 21911 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21909 def image_destination @image_destination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21916 21917 21918 21919 21920 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21916 def update!(**args) @artifact_destination = args[:artifact_destination] if args.key?(:artifact_destination) @export_format_id = args[:export_format_id] if args.key?(:export_format_id) @image_destination = args[:image_destination] if args.key?(:image_destination) end |