Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportModelRequestOutputConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Output configuration for the Model export.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportModelRequestOutputConfig

Returns a new instance of GoogleCloudAiplatformV1beta1ExportModelRequestOutputConfig.



19702
19703
19704
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property artifactDestination



19688
19689
19690
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19688

def artifact_destination
  @artifact_destination
end

#export_format_idString

The ID of the format in which the Model must be exported. Each Model lists the export formats it supports. If no value is provided here, then the first from the list of the Model's supported formats is used by default. Corresponds to the JSON property exportFormatId

Returns:

  • (String)


19695
19696
19697
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19695

def export_format_id
  @export_format_id
end

#image_destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContainerRegistryDestination

The Container Registry location for the container image. Corresponds to the JSON property imageDestination



19700
19701
19702
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19700

def image_destination
  @image_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19707
19708
19709
19710
19711
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19707

def update!(**args)
  @artifact_destination = args[:artifact_destination] if args.key?(:artifact_destination)
  @export_format_id = args[:export_format_id] if args.key?(:export_format_id)
  @image_destination = args[:image_destination] if args.key?(:image_destination)
end