Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportModelRequestOutputConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Output configuration for the Model export.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportModelRequestOutputConfig

Returns a new instance of GoogleCloudAiplatformV1beta1ExportModelRequestOutputConfig.



19211
19212
19213
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property artifactDestination



19197
19198
19199
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19197

def artifact_destination
  @artifact_destination
end

#export_format_idString

The ID of the format in which the Model must be exported. Each Model lists the export formats it supports. If no value is provided here, then the first from the list of the Model's supported formats is used by default. Corresponds to the JSON property exportFormatId

Returns:

  • (String)


19204
19205
19206
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19204

def export_format_id
  @export_format_id
end

#image_destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContainerRegistryDestination

The Container Registry location for the container image. Corresponds to the JSON property imageDestination



19209
19210
19211
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19209

def image_destination
  @image_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19216
19217
19218
19219
19220
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19216

def update!(**args)
  @artifact_destination = args[:artifact_destination] if args.key?(:artifact_destination)
  @export_format_id = args[:export_format_id] if args.key?(:export_format_id)
  @image_destination = args[:image_destination] if args.key?(:image_destination)
end