Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportTensorboardTimeSeriesDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExportTensorboardTimeSeriesDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for TensorboardService.ExportTensorboardTimeSeriesData.
Instance Attribute Summary collapse
-
#filter ⇒ String
Exports the TensorboardTimeSeries' data that match the filter expression.
-
#order_by ⇒ String
Field to use to sort the TensorboardTimeSeries' data.
-
#page_size ⇒ Fixnum
The maximum number of data points to return per page.
-
#page_token ⇒ String
A page token, received from a previous ExportTensorboardTimeSeriesData call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportTensorboardTimeSeriesDataRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1ExportTensorboardTimeSeriesDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExportTensorboardTimeSeriesDataRequest
Returns a new instance of GoogleCloudAiplatformV1beta1ExportTensorboardTimeSeriesDataRequest.
20787 20788 20789 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Exports the TensorboardTimeSeries' data that match the filter expression.
Corresponds to the JSON property filter
20764 20765 20766 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20764 def filter @filter end |
#order_by ⇒ String
Field to use to sort the TensorboardTimeSeries' data. By default,
TensorboardTimeSeries' data is returned in a pseudo random order.
Corresponds to the JSON property orderBy
20770 20771 20772 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20770 def order_by @order_by end |
#page_size ⇒ Fixnum
The maximum number of data points to return per page. The default page_size is
- Values must be between 1 and 10000. Values above 10000 are coerced to
10000.
Corresponds to the JSON property
pageSize
20777 20778 20779 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20777 def page_size @page_size end |
#page_token ⇒ String
A page token, received from a previous ExportTensorboardTimeSeriesData call.
Provide this to retrieve the subsequent page. When paginating, all other
parameters provided to ExportTensorboardTimeSeriesData must match the call
that provided the page token.
Corresponds to the JSON property pageToken
20785 20786 20787 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20785 def page_token @page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20792 20793 20794 20795 20796 20797 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20792 def update!(**args) @filter = args[:filter] if args.key?(:filter) @order_by = args[:order_by] if args.key?(:order_by) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) end |