Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Extension
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Extension
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Extensions are tools for large language models to access external data, run computations, etc.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#etag ⇒ String
Optional.
-
#extension_operations ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionOperation>
Output only.
-
#manifest ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionManifest
Manifest spec of an Extension needed for runtime execution.
-
#name ⇒ String
Identifier.
-
#private_service_connect_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionPrivateServiceConnectConfig
PrivateExtensionConfig configuration for the extension.
-
#runtime_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RuntimeConfig
Runtime configuration to run the extension.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#tool_use_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExample>
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Extension
constructor
A new instance of GoogleCloudAiplatformV1beta1Extension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Extension
Returns a new instance of GoogleCloudAiplatformV1beta1Extension.
22665 22666 22667 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22665 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Extension was created.
Corresponds to the JSON property createTime
22599 22600 22601 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22599 def create_time @create_time end |
#description ⇒ String
Optional. The description of the Extension.
Corresponds to the JSON property description
22604 22605 22606 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22604 def description @description end |
#display_name ⇒ String
Required. The display name of the Extension. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
22610 22611 22612 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22610 def display_name @display_name end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
22616 22617 22618 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22616 def etag @etag end |
#extension_operations ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionOperation>
Output only. Supported operations.
Corresponds to the JSON property extensionOperations
22621 22622 22623 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22621 def extension_operations @extension_operations end |
#manifest ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionManifest
Manifest spec of an Extension needed for runtime execution.
Corresponds to the JSON property manifest
22626 22627 22628 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22626 def manifest @manifest end |
#name ⇒ String
Identifier. The resource name of the Extension.
Corresponds to the JSON property name
22631 22632 22633 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22631 def name @name end |
#private_service_connect_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionPrivateServiceConnectConfig
PrivateExtensionConfig configuration for the extension.
Corresponds to the JSON property privateServiceConnectConfig
22636 22637 22638 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22636 def private_service_connect_config @private_service_connect_config end |
#runtime_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RuntimeConfig
Runtime configuration to run the extension.
Corresponds to the JSON property runtimeConfig
22641 22642 22643 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22641 def runtime_config @runtime_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
22646 22647 22648 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22646 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
22652 22653 22654 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22652 def satisfies_pzs @satisfies_pzs end |
#tool_use_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExample>
Optional. Examples to illustrate the usage of the extension as a tool.
Corresponds to the JSON property toolUseExamples
22658 22659 22660 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22658 def tool_use_examples @tool_use_examples end |
#update_time ⇒ String
Output only. Timestamp when this Extension was most recently updated.
Corresponds to the JSON property updateTime
22663 22664 22665 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22663 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22670 22671 22672 22673 22674 22675 22676 22677 22678 22679 22680 22681 22682 22683 22684 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22670 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @extension_operations = args[:extension_operations] if args.key?(:extension_operations) @manifest = args[:manifest] if args.key?(:manifest) @name = args[:name] if args.key?(:name) @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config) @runtime_config = args[:runtime_config] if args.key?(:runtime_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @tool_use_examples = args[:tool_use_examples] if args.key?(:tool_use_examples) @update_time = args[:update_time] if args.key?(:update_time) end |