Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Extension

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Extensions are tools for large language models to access external data, run computations, etc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Extension

Returns a new instance of GoogleCloudAiplatformV1beta1Extension.



19486
19487
19488
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Extension was created. Corresponds to the JSON property createTime

Returns:

  • (String)


19420
19421
19422
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19420

def create_time
  @create_time
end

#descriptionString

Optional. The description of the Extension. Corresponds to the JSON property description

Returns:

  • (String)


19425
19426
19427
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19425

def description
  @description
end

#display_nameString

Required. The display name of the Extension. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


19431
19432
19433
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19431

def display_name
  @display_name
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


19437
19438
19439
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19437

def etag
  @etag
end

#extension_operationsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionOperation>

Output only. Supported operations. Corresponds to the JSON property extensionOperations



19442
19443
19444
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19442

def extension_operations
  @extension_operations
end

#manifestGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionManifest

Manifest spec of an Extension needed for runtime execution. Corresponds to the JSON property manifest



19447
19448
19449
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19447

def manifest
  @manifest
end

#nameString

Identifier. The resource name of the Extension. Corresponds to the JSON property name

Returns:

  • (String)


19452
19453
19454
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19452

def name
  @name
end

#private_service_connect_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionPrivateServiceConnectConfig

PrivateExtensionConfig configuration for the extension. Corresponds to the JSON property privateServiceConnectConfig



19457
19458
19459
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19457

def private_service_connect_config
  @private_service_connect_config
end

#runtime_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RuntimeConfig

Runtime configuration to run the extension. Corresponds to the JSON property runtimeConfig



19462
19463
19464
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19462

def runtime_config
  @runtime_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


19467
19468
19469
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19467

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


19473
19474
19475
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19473

def satisfies_pzs
  @satisfies_pzs
end

#tool_use_examplesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExample>

Optional. Examples to illustrate the usage of the extension as a tool. Corresponds to the JSON property toolUseExamples



19479
19480
19481
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19479

def tool_use_examples
  @tool_use_examples
end

#update_timeString

Output only. Timestamp when this Extension was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


19484
19485
19486
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19484

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19491
19492
19493
19494
19495
19496
19497
19498
19499
19500
19501
19502
19503
19504
19505
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19491

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @extension_operations = args[:extension_operations] if args.key?(:extension_operations)
  @manifest = args[:manifest] if args.key?(:manifest)
  @name = args[:name] if args.key?(:name)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
  @runtime_config = args[:runtime_config] if args.key?(:runtime_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @tool_use_examples = args[:tool_use_examples] if args.key?(:tool_use_examples)
  @update_time = args[:update_time] if args.key?(:update_time)
end