Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionManifest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Manifest spec of an Extension needed for runtime execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExtensionManifest

Returns a new instance of GoogleCloudAiplatformV1beta1ExtensionManifest.



22715
22716
22717
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22715

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionManifestApiSpec

The API specification shown to the LLM. Corresponds to the JSON property apiSpec



22694
22695
22696
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22694

def api_spec
  @api_spec
end

#auth_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AuthConfig

Auth configuration to run the extension. Corresponds to the JSON property authConfig



22699
22700
22701
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22699

def auth_config
  @auth_config
end

#descriptionString

Required. The natural language description shown to the LLM. It should describe the usage of the extension, and is essential for the LLM to perform reasoning. e.g., if the extension is a data store, you can let the LLM know what data it contains. Corresponds to the JSON property description

Returns:

  • (String)


22707
22708
22709
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22707

def description
  @description
end

#nameString

Required. Extension name shown to the LLM. The name can be up to 128 characters long. Corresponds to the JSON property name

Returns:

  • (String)


22713
22714
22715
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22713

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22720
22721
22722
22723
22724
22725
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22720

def update!(**args)
  @api_spec = args[:api_spec] if args.key?(:api_spec)
  @auth_config = args[:auth_config] if args.key?(:auth_config)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
end