Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionManifest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionManifest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Manifest spec of an Extension needed for runtime execution.
Instance Attribute Summary collapse
-
#api_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionManifestApiSpec
The API specification shown to the LLM.
-
#auth_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AuthConfig
Auth configuration to run the extension.
-
#description ⇒ String
Required.
-
#name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExtensionManifest
constructor
A new instance of GoogleCloudAiplatformV1beta1ExtensionManifest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExtensionManifest
Returns a new instance of GoogleCloudAiplatformV1beta1ExtensionManifest.
22242 22243 22244 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22242 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionManifestApiSpec
The API specification shown to the LLM.
Corresponds to the JSON property apiSpec
22221 22222 22223 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22221 def api_spec @api_spec end |
#auth_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AuthConfig
Auth configuration to run the extension.
Corresponds to the JSON property authConfig
22226 22227 22228 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22226 def auth_config @auth_config end |
#description ⇒ String
Required. The natural language description shown to the LLM. It should
describe the usage of the extension, and is essential for the LLM to perform
reasoning. e.g., if the extension is a data store, you can let the LLM know
what data it contains.
Corresponds to the JSON property description
22234 22235 22236 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22234 def description @description end |
#name ⇒ String
Required. Extension name shown to the LLM. The name can be up to 128
characters long.
Corresponds to the JSON property name
22240 22241 22242 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22240 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22247 22248 22249 22250 22251 22252 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22247 def update!(**args) @api_spec = args[:api_spec] if args.key?(:api_spec) @auth_config = args[:auth_config] if args.key?(:auth_config) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) end |