Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Operation of an extension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExtensionOperation

Returns a new instance of GoogleCloudAiplatformV1beta1ExtensionOperation.



21374
21375
21376
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#function_declarationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionDeclaration

Structured representation of a function declaration as defined by the OpenAPI 3.0 specification. Included in this declaration are the function name, description, parameters and response type. This FunctionDeclaration is a representation of a block of code that can be used as a Tool by the model and executed by the client. Corresponds to the JSON property functionDeclaration



21364
21365
21366
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21364

def function_declaration
  @function_declaration
end

#operation_idString

Operation ID that uniquely identifies the operations among the extension. See: "Operation Object" in https://swagger.io/specification/. This field is parsed from the OpenAPI spec. For HTTP extensions, if it does not exist in the spec, we will generate one from the HTTP method and path. Corresponds to the JSON property operationId

Returns:

  • (String)


21372
21373
21374
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21372

def operation_id
  @operation_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21379
21380
21381
21382
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21379

def update!(**args)
  @function_declaration = args[:function_declaration] if args.key?(:function_declaration)
  @operation_id = args[:operation_id] if args.key?(:operation_id)
end