Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionOperation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExtensionOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Operation of an extension.
Instance Attribute Summary collapse
-
#function_declaration ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionDeclaration
Structured representation of a function declaration as defined by the OpenAPI 3.0 specification.
-
#operation_id ⇒ String
Operation ID that uniquely identifies the operations among the extension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExtensionOperation
constructor
A new instance of GoogleCloudAiplatformV1beta1ExtensionOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExtensionOperation
Returns a new instance of GoogleCloudAiplatformV1beta1ExtensionOperation.
21058 21059 21060 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21058 def initialize(**args) update!(**args) end |
Instance Attribute Details
#function_declaration ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionDeclaration
Structured representation of a function declaration as defined by the OpenAPI
3.0 specification. Included in this
declaration are the function name, description, parameters and response type.
This FunctionDeclaration is a representation of a block of code that can be
used as a Tool by the model and executed by the client.
Corresponds to the JSON property functionDeclaration
21048 21049 21050 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21048 def function_declaration @function_declaration end |
#operation_id ⇒ String
Operation ID that uniquely identifies the operations among the extension. See:
"Operation Object" in https://swagger.io/specification/. This field is parsed
from the OpenAPI spec. For HTTP extensions, if it does not exist in the spec,
we will generate one from the HTTP method and path.
Corresponds to the JSON property operationId
21056 21057 21058 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21056 def operation_id @operation_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21063 21064 21065 21066 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21063 def update!(**args) @function_declaration = args[:function_declaration] if args.key?(:function_declaration) @operation_id = args[:operation_id] if args.key?(:operation_id) end |