Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExternalApi

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Retrieve from data source powered by external API for grounding. The external API is not owned by Google, but need to follow the pre-defined API spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExternalApi

Returns a new instance of GoogleCloudAiplatformV1beta1ExternalApi.



22847
22848
22849
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_authGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ApiAuth

The generic reusable api auth config. Deprecated. Please use AuthConfig ( google/cloud/aiplatform/master/auth.proto) instead. Corresponds to the JSON property apiAuth



22818
22819
22820
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22818

def api_auth
  @api_auth
end

#api_specString

The API spec that the external API implements. Corresponds to the JSON property apiSpec

Returns:

  • (String)


22823
22824
22825
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22823

def api_spec
  @api_spec
end

#auth_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AuthConfig

Auth configuration to run the extension. Corresponds to the JSON property authConfig



22828
22829
22830
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22828

def auth_config
  @auth_config
end

#elastic_search_paramsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExternalApiElasticSearchParams

The search parameters to use for the ELASTIC_SEARCH spec. Corresponds to the JSON property elasticSearchParams



22833
22834
22835
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22833

def elastic_search_params
  @elastic_search_params
end

#endpointString

The endpoint of the external API. The system will call the API at this endpoint to retrieve the data for grounding. Example: https://acme.com:443/ search Corresponds to the JSON property endpoint

Returns:

  • (String)


22840
22841
22842
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22840

def endpoint
  @endpoint
end

#simple_search_paramsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExternalApiSimpleSearchParams

The search parameters to use for SIMPLE_SEARCH spec. Corresponds to the JSON property simpleSearchParams



22845
22846
22847
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22845

def simple_search_params
  @simple_search_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22852
22853
22854
22855
22856
22857
22858
22859
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22852

def update!(**args)
  @api_auth = args[:api_auth] if args.key?(:api_auth)
  @api_spec = args[:api_spec] if args.key?(:api_spec)
  @auth_config = args[:auth_config] if args.key?(:auth_config)
  @elastic_search_params = args[:elastic_search_params] if args.key?(:elastic_search_params)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @simple_search_params = args[:simple_search_params] if args.key?(:simple_search_params)
end