Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExternalApi

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Retrieve from data source powered by external API for grounding. The external API is not owned by Google, but need to follow the pre-defined API spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExternalApi

Returns a new instance of GoogleCloudAiplatformV1beta1ExternalApi.



22374
22375
22376
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_authGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ApiAuth

The generic reusable api auth config. Deprecated. Please use AuthConfig ( google/cloud/aiplatform/master/auth.proto) instead. Corresponds to the JSON property apiAuth



22345
22346
22347
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22345

def api_auth
  @api_auth
end

#api_specString

The API spec that the external API implements. Corresponds to the JSON property apiSpec

Returns:

  • (String)


22350
22351
22352
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22350

def api_spec
  @api_spec
end

#auth_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AuthConfig

Auth configuration to run the extension. Corresponds to the JSON property authConfig



22355
22356
22357
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22355

def auth_config
  @auth_config
end

#elastic_search_paramsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExternalApiElasticSearchParams

The search parameters to use for the ELASTIC_SEARCH spec. Corresponds to the JSON property elasticSearchParams



22360
22361
22362
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22360

def elastic_search_params
  @elastic_search_params
end

#endpointString

The endpoint of the external API. The system will call the API at this endpoint to retrieve the data for grounding. Example: https://acme.com:443/ search Corresponds to the JSON property endpoint

Returns:

  • (String)


22367
22368
22369
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22367

def endpoint
  @endpoint
end

#simple_search_paramsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExternalApiSimpleSearchParams

The search parameters to use for SIMPLE_SEARCH spec. Corresponds to the JSON property simpleSearchParams



22372
22373
22374
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22372

def simple_search_params
  @simple_search_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22379
22380
22381
22382
22383
22384
22385
22386
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22379

def update!(**args)
  @api_auth = args[:api_auth] if args.key?(:api_auth)
  @api_spec = args[:api_spec] if args.key?(:api_spec)
  @auth_config = args[:auth_config] if args.key?(:auth_config)
  @elastic_search_params = args[:elastic_search_params] if args.key?(:elastic_search_params)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @simple_search_params = args[:simple_search_params] if args.key?(:simple_search_params)
end