Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExternalApi

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Retrieve from data source powered by external API for grounding. The external API is not owned by Google, but need to follow the pre-defined API spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExternalApi

Returns a new instance of GoogleCloudAiplatformV1beta1ExternalApi.



19668
19669
19670
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_authGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ApiAuth

The generic reusable api auth config. Deprecated. Please use AuthConfig ( google/cloud/aiplatform/master/auth.proto) instead. Corresponds to the JSON property apiAuth



19639
19640
19641
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19639

def api_auth
  @api_auth
end

#api_specString

The API spec that the external API implements. Corresponds to the JSON property apiSpec

Returns:

  • (String)


19644
19645
19646
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19644

def api_spec
  @api_spec
end

#auth_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AuthConfig

Auth configuration to run the extension. Corresponds to the JSON property authConfig



19649
19650
19651
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19649

def auth_config
  @auth_config
end

#elastic_search_paramsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExternalApiElasticSearchParams

The search parameters to use for the ELASTIC_SEARCH spec. Corresponds to the JSON property elasticSearchParams



19654
19655
19656
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19654

def elastic_search_params
  @elastic_search_params
end

#endpointString

The endpoint of the external API. The system will call the API at this endpoint to retrieve the data for grounding. Example: https://acme.com:443/ search Corresponds to the JSON property endpoint

Returns:

  • (String)


19661
19662
19663
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19661

def endpoint
  @endpoint
end

#simple_search_paramsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExternalApiSimpleSearchParams

The search parameters to use for SIMPLE_SEARCH spec. Corresponds to the JSON property simpleSearchParams



19666
19667
19668
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19666

def simple_search_params
  @simple_search_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19673
19674
19675
19676
19677
19678
19679
19680
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19673

def update!(**args)
  @api_auth = args[:api_auth] if args.key?(:api_auth)
  @api_spec = args[:api_spec] if args.key?(:api_spec)
  @auth_config = args[:auth_config] if args.key?(:auth_config)
  @elastic_search_params = args[:elastic_search_params] if args.key?(:elastic_search_params)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @simple_search_params = args[:simple_search_params] if args.key?(:simple_search_params)
end