Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Fact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The fact used in grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Fact

Returns a new instance of GoogleCloudAiplatformV1beta1Fact.



22480
22481
22482
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunkGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk

A RagChunk includes the content of a chunk of a RagFile, and associated metadata. Corresponds to the JSON property chunk



22442
22443
22444
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22442

def chunk
  @chunk
end

#queryString

Query that is used to retrieve this fact. Corresponds to the JSON property query

Returns:

  • (String)


22447
22448
22449
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22447

def query
  @query
end

#scoreFloat

If present, according to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the fact and its range depends on the metric type. For example, if the metric type is COSINE_DISTANCE, it represents the distance between the query and the fact. The larger the distance, the less relevant the fact is to the query. The range is [0, 2], while 0 means the most relevant and 2 means the least relevant. Corresponds to the JSON property score

Returns:

  • (Float)


22458
22459
22460
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22458

def score
  @score
end

#summaryString

If present, the summary/snippet of the fact. Corresponds to the JSON property summary

Returns:

  • (String)


22463
22464
22465
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22463

def summary
  @summary
end

#titleString

If present, it refers to the title of this fact. Corresponds to the JSON property title

Returns:

  • (String)


22468
22469
22470
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22468

def title
  @title
end

#uriString

If present, this uri links to the source of the fact. Corresponds to the JSON property uri

Returns:

  • (String)


22473
22474
22475
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22473

def uri
  @uri
end

#vector_distanceFloat

If present, the distance between the query vector and this fact vector. Corresponds to the JSON property vectorDistance

Returns:

  • (Float)


22478
22479
22480
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22478

def vector_distance
  @vector_distance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22485
22486
22487
22488
22489
22490
22491
22492
22493
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22485

def update!(**args)
  @chunk = args[:chunk] if args.key?(:chunk)
  @query = args[:query] if args.key?(:query)
  @score = args[:score] if args.key?(:score)
  @summary = args[:summary] if args.key?(:summary)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
  @vector_distance = args[:vector_distance] if args.key?(:vector_distance)
end