Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Fact
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Fact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The fact used in grounding.
Instance Attribute Summary collapse
-
#chunk ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
-
#query ⇒ String
Query that is used to retrieve this fact.
-
#score ⇒ Float
If present, according to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the fact and its range depends on the metric type.
-
#summary ⇒ String
If present, the summary/snippet of the fact.
-
#title ⇒ String
If present, it refers to the title of this fact.
-
#uri ⇒ String
If present, this uri links to the source of the fact.
-
#vector_distance ⇒ Float
If present, the distance between the query vector and this fact vector.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Fact
constructor
A new instance of GoogleCloudAiplatformV1beta1Fact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Fact
Returns a new instance of GoogleCloudAiplatformV1beta1Fact.
21059 21060 21061 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21059 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated
metadata.
Corresponds to the JSON property chunk
21021 21022 21023 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21021 def chunk @chunk end |
#query ⇒ String
Query that is used to retrieve this fact.
Corresponds to the JSON property query
21026 21027 21028 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21026 def query @query end |
#score ⇒ Float
If present, according to the underlying Vector DB and the selected metric type,
the score can be either the distance or the similarity between the query and
the fact and its range depends on the metric type. For example, if the metric
type is COSINE_DISTANCE, it represents the distance between the query and the
fact. The larger the distance, the less relevant the fact is to the query. The
range is [0, 2], while 0 means the most relevant and 2 means the least
relevant.
Corresponds to the JSON property score
21037 21038 21039 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21037 def score @score end |
#summary ⇒ String
If present, the summary/snippet of the fact.
Corresponds to the JSON property summary
21042 21043 21044 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21042 def summary @summary end |
#title ⇒ String
If present, it refers to the title of this fact.
Corresponds to the JSON property title
21047 21048 21049 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21047 def title @title end |
#uri ⇒ String
If present, this uri links to the source of the fact.
Corresponds to the JSON property uri
21052 21053 21054 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21052 def uri @uri end |
#vector_distance ⇒ Float
If present, the distance between the query vector and this fact vector.
Corresponds to the JSON property vectorDistance
21057 21058 21059 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21057 def vector_distance @vector_distance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21064 21065 21066 21067 21068 21069 21070 21071 21072 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21064 def update!(**args) @chunk = args[:chunk] if args.key?(:chunk) @query = args[:query] if args.key?(:query) @score = args[:score] if args.key?(:score) @summary = args[:summary] if args.key?(:summary) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) @vector_distance = args[:vector_distance] if args.key?(:vector_distance) end |