Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FailedRubric
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FailedRubric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a specific failed rubric and the associated analysis.
Instance Attribute Summary collapse
-
#classification_rationale ⇒ String
The rationale provided by the Loss Analysis Classifier for why this failure maps to this specific Loss Cluster.
-
#rubric_id ⇒ String
The unique ID of the rubric (if available from the metric source).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FailedRubric
constructor
A new instance of GoogleCloudAiplatformV1beta1FailedRubric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FailedRubric
Returns a new instance of GoogleCloudAiplatformV1beta1FailedRubric.
22986 22987 22988 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22986 def initialize(**args) update!(**args) end |
Instance Attribute Details
#classification_rationale ⇒ String
The rationale provided by the Loss Analysis Classifier for why this failure
maps to this specific Loss Cluster. e.g., "The agent claimed an action without
a tool call, matching 'Hallucination of Action'."
Corresponds to the JSON property classificationRationale
22978 22979 22980 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22978 def classification_rationale @classification_rationale end |
#rubric_id ⇒ String
The unique ID of the rubric (if available from the metric source). Clients use
this ID to query the corresponding rubric verdict.
Corresponds to the JSON property rubricId
22984 22985 22986 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22984 def rubric_id @rubric_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22991 22992 22993 22994 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22991 def update!(**args) @classification_rationale = args[:classification_rationale] if args.key?(:classification_rationale) @rubric_id = args[:rubric_id] if args.key?(:rubric_id) end |