Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FailedRubric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a specific failed rubric and the associated analysis.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FailedRubric

Returns a new instance of GoogleCloudAiplatformV1beta1FailedRubric.



14955
14956
14957
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14955

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classification_rationaleString

The rationale provided by the Loss Analysis Classifier for why this failure maps to this specific Loss Cluster. e.g., "The agent claimed an action without a tool call, matching 'Hallucination of Action'." Corresponds to the JSON property classificationRationale

Returns:

  • (String)


14947
14948
14949
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14947

def classification_rationale
  @classification_rationale
end

#rubric_idString

The unique ID of the rubric (if available from the metric source). Clients use this ID to query the corresponding rubric verdict. Corresponds to the JSON property rubricId

Returns:

  • (String)


14953
14954
14955
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14953

def rubric_id
  @rubric_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14960
14961
14962
14963
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14960

def update!(**args)
  @classification_rationale = args[:classification_rationale] if args.key?(:classification_rationale)
  @rubric_id = args[:rubric_id] if args.key?(:rubric_id)
end