Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Feature
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Feature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Feature Metadata information. For example, color is a feature that describes an apple.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the Feature.
-
#disable_monitoring ⇒ Boolean
(also: #disable_monitoring?)
Optional.
-
#etag ⇒ String
Used to perform a consistent read-modify-write updates.
-
#feature_stats_and_anomaly ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly>
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#monitoring_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfig
Configuration of how features in Featurestore are monitored.
-
#monitoring_stats ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAnomaly>
Output only.
-
#monitoring_stats_anomalies ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitoringStatsAnomaly>
Output only.
-
#name ⇒ String
Immutable.
-
#point_of_contact ⇒ String
Entity responsible for maintaining this feature.
-
#update_time ⇒ String
Output only.
-
#value_type ⇒ String
Immutable.
-
#version_column_name ⇒ String
Only applicable for Vertex AI Feature Store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Feature
constructor
A new instance of GoogleCloudAiplatformV1beta1Feature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Feature
Returns a new instance of GoogleCloudAiplatformV1beta1Feature.
15089 15090 15091 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15089 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Only applicable for Vertex AI Feature Store (Legacy). Timestamp
when this EntityType was created.
Corresponds to the JSON property createTime
14995 14996 14997 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 14995 def create_time @create_time end |
#description ⇒ String
Description of the Feature.
Corresponds to the JSON property description
15000 15001 15002 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15000 def description @description end |
#disable_monitoring ⇒ Boolean Also known as: disable_monitoring?
Optional. Only applicable for Vertex AI Feature Store (Legacy). If not set,
use the monitoring_config defined for the EntityType this Feature belongs to.
Only Features with type (Feature.ValueType) BOOL, STRING, DOUBLE or INT64 can
enable monitoring. If set to true, all types of data monitoring are disabled
despite the config on EntityType.
Corresponds to the JSON property disableMonitoring
15009 15010 15011 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15009 def disable_monitoring @disable_monitoring end |
#etag ⇒ String
Used to perform a consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
15016 15017 15018 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15016 def etag @etag end |
#feature_stats_and_anomaly ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly>
Output only. Only applicable for Vertex AI Feature Store. The list of
historical stats and anomalies.
Corresponds to the JSON property featureStatsAndAnomaly
15022 15023 15024 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15022 def feature_stats_and_anomaly @feature_stats_and_anomaly end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your Features.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information on and examples of labels. No more than 64 user labels can be
associated with one Feature (System labels are excluded)." System reserved
label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
15033 15034 15035 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15033 def labels @labels end |
#monitoring_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfig
Configuration of how features in Featurestore are monitored.
Corresponds to the JSON property monitoringConfig
15038 15039 15040 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15038 def monitoring_config @monitoring_config end |
#monitoring_stats ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAnomaly>
Output only. Only applicable for Vertex AI Feature Store (Legacy). A list of
historical SnapshotAnalysis stats requested by user, sorted by
FeatureStatsAnomaly.start_time descending.
Corresponds to the JSON property monitoringStats
15045 15046 15047 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15045 def monitoring_stats @monitoring_stats end |
#monitoring_stats_anomalies ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitoringStatsAnomaly>
Output only. Only applicable for Vertex AI Feature Store (Legacy). The list of
historical stats and anomalies with specified objectives.
Corresponds to the JSON property monitoringStatsAnomalies
15051 15052 15053 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15051 def monitoring_stats_anomalies @monitoring_stats_anomalies end |
#name ⇒ String
Immutable. Name of the Feature. Format: projects/project/locations/
location/featurestores/featurestore/entityTypes/entity_type/features/
feature`projects/`project`/locations/`location`/featureGroups/`
feature_group`/features/`feature The last part feature is assigned by the
client. The feature can be up to 64 characters long and can consist only of
ASCII Latin letters A-Z and a-z, underscore(_), and ASCII digits 0-9 starting
with a letter. The value will be unique given an entity type.
Corresponds to the JSON property name
15062 15063 15064 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15062 def name @name end |
#point_of_contact ⇒ String
Entity responsible for maintaining this feature. Can be comma separated list
of email addresses or URIs.
Corresponds to the JSON property pointOfContact
15068 15069 15070 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15068 def point_of_contact @point_of_contact end |
#update_time ⇒ String
Output only. Only applicable for Vertex AI Feature Store (Legacy). Timestamp
when this EntityType was most recently updated.
Corresponds to the JSON property updateTime
15074 15075 15076 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15074 def update_time @update_time end |
#value_type ⇒ String
Immutable. Only applicable for Vertex AI Feature Store (Legacy). Type of
Feature value.
Corresponds to the JSON property valueType
15080 15081 15082 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15080 def value_type @value_type end |
#version_column_name ⇒ String
Only applicable for Vertex AI Feature Store. The name of the BigQuery Table/
View column hosting data for this version. If no value is provided, will use
feature_id.
Corresponds to the JSON property versionColumnName
15087 15088 15089 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15087 def version_column_name @version_column_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15094 15095 15096 15097 15098 15099 15100 15101 15102 15103 15104 15105 15106 15107 15108 15109 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15094 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @disable_monitoring = args[:disable_monitoring] if args.key?(:disable_monitoring) @etag = args[:etag] if args.key?(:etag) @feature_stats_and_anomaly = args[:feature_stats_and_anomaly] if args.key?(:feature_stats_and_anomaly) @labels = args[:labels] if args.key?(:labels) @monitoring_config = args[:monitoring_config] if args.key?(:monitoring_config) @monitoring_stats = args[:monitoring_stats] if args.key?(:monitoring_stats) @monitoring_stats_anomalies = args[:monitoring_stats_anomalies] if args.key?(:monitoring_stats_anomalies) @name = args[:name] if args.key?(:name) @point_of_contact = args[:point_of_contact] if args.key?(:point_of_contact) @update_time = args[:update_time] if args.key?(:update_time) @value_type = args[:value_type] if args.key?(:value_type) @version_column_name = args[:version_column_name] if args.key?(:version_column_name) end |