Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Vertex AI Feature Group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureGroup

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureGroup.



21806
21807
21808
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21806

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_queryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureGroupBigQuery

Input source type for BigQuery Tables and Views. Corresponds to the JSON property bigQuery



21750
21751
21752
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21750

def big_query
  @big_query
end

#create_timeString

Output only. Timestamp when this FeatureGroup was created. Corresponds to the JSON property createTime

Returns:

  • (String)


21755
21756
21757
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21755

def create_time
  @create_time
end

#descriptionString

Optional. Description of the FeatureGroup. Corresponds to the JSON property description

Returns:

  • (String)


21760
21761
21762
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21760

def description
  @description
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


21766
21767
21768
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21766

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your FeatureGroup. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one FeatureGroup(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


21777
21778
21779
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21777

def labels
  @labels
end

#nameString

Identifier. Name of the FeatureGroup. Format: projects/project/locations/ location/featureGroups/featureGroup` Corresponds to the JSON propertyname`

Returns:

  • (String)


21783
21784
21785
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21783

def name
  @name
end

#service_account_emailString

Output only. A Service Account unique to this FeatureGroup. The role bigquery. dataViewer should be granted to this service account to allow Vertex AI Feature Store to access source data while running jobs under this FeatureGroup. Corresponds to the JSON property serviceAccountEmail

Returns:

  • (String)


21790
21791
21792
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21790

def 
  @service_account_email
end

#service_agent_typeString

Optional. Service agent type used during jobs under a FeatureGroup. By default, the Vertex AI Service Agent is used. When using an IAM Policy to isolate this FeatureGroup within a project, a separate service account should be provisioned by setting this field to SERVICE_AGENT_TYPE_FEATURE_GROUP. This will generate a separate service account to access the BigQuery source table. Corresponds to the JSON property serviceAgentType

Returns:

  • (String)


21799
21800
21801
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21799

def service_agent_type
  @service_agent_type
end

#update_timeString

Output only. Timestamp when this FeatureGroup was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


21804
21805
21806
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21804

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21811
21812
21813
21814
21815
21816
21817
21818
21819
21820
21821
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21811

def update!(**args)
  @big_query = args[:big_query] if args.key?(:big_query)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service_account_email = args[:service_account_email] if args.key?(:service_account_email)
  @service_agent_type = args[:service_agent_type] if args.key?(:service_agent_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end