Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Vertex AI Feature Group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureGroup

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureGroup.



21490
21491
21492
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21490

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_queryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureGroupBigQuery

Input source type for BigQuery Tables and Views. Corresponds to the JSON property bigQuery



21434
21435
21436
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21434

def big_query
  @big_query
end

#create_timeString

Output only. Timestamp when this FeatureGroup was created. Corresponds to the JSON property createTime

Returns:

  • (String)


21439
21440
21441
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21439

def create_time
  @create_time
end

#descriptionString

Optional. Description of the FeatureGroup. Corresponds to the JSON property description

Returns:

  • (String)


21444
21445
21446
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21444

def description
  @description
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


21450
21451
21452
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21450

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your FeatureGroup. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one FeatureGroup(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


21461
21462
21463
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21461

def labels
  @labels
end

#nameString

Identifier. Name of the FeatureGroup. Format: projects/project/locations/ location/featureGroups/featureGroup` Corresponds to the JSON propertyname`

Returns:

  • (String)


21467
21468
21469
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21467

def name
  @name
end

#service_account_emailString

Output only. A Service Account unique to this FeatureGroup. The role bigquery. dataViewer should be granted to this service account to allow Vertex AI Feature Store to access source data while running jobs under this FeatureGroup. Corresponds to the JSON property serviceAccountEmail

Returns:

  • (String)


21474
21475
21476
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21474

def 
  @service_account_email
end

#service_agent_typeString

Optional. Service agent type used during jobs under a FeatureGroup. By default, the Vertex AI Service Agent is used. When using an IAM Policy to isolate this FeatureGroup within a project, a separate service account should be provisioned by setting this field to SERVICE_AGENT_TYPE_FEATURE_GROUP. This will generate a separate service account to access the BigQuery source table. Corresponds to the JSON property serviceAgentType

Returns:

  • (String)


21483
21484
21485
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21483

def service_agent_type
  @service_agent_type
end

#update_timeString

Output only. Timestamp when this FeatureGroup was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


21488
21489
21490
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21488

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21495
21496
21497
21498
21499
21500
21501
21502
21503
21504
21505
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21495

def update!(**args)
  @big_query = args[:big_query] if args.key?(:big_query)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service_account_email = args[:service_account_email] if args.key?(:service_account_email)
  @service_agent_type = args[:service_agent_type] if args.key?(:service_agent_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end