Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitor
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Vertex AI Feature Monitor.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#feature_selection_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelectionConfig
Feature selection configuration for the FeatureMonitor.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#schedule_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ScheduleConfig
Schedule configuration for the FeatureMonitor.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureMonitor
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureMonitor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureMonitor
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureMonitor.
23416 23417 23418 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this FeatureMonitor was created.
Corresponds to the JSON property createTime
23370 23371 23372 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23370 def create_time @create_time end |
#description ⇒ String
Optional. Description of the FeatureMonitor.
Corresponds to the JSON property description
23375 23376 23377 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23375 def description @description end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
23381 23382 23383 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23381 def etag @etag end |
#feature_selection_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelectionConfig
Feature selection configuration for the FeatureMonitor.
Corresponds to the JSON property featureSelectionConfig
23386 23387 23388 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23386 def feature_selection_config @feature_selection_config end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your
FeatureMonitor. Label keys and values can be no longer than 64 characters (
Unicode codepoints), can only contain lowercase letters, numeric characters,
underscores and dashes. International characters are allowed. See https://goo.
gl/xmQnxf for more information on and examples of labels. No more than 64 user
labels can be associated with one FeatureMonitor(System labels are excluded)."
System reserved label keys are prefixed with "aiplatform.googleapis.com/" and
are immutable.
Corresponds to the JSON property labels
23398 23399 23400 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23398 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureMonitor. Format: projects/project/locations/
location/featureGroups/featureGroup/featureMonitors/featureMonitor`
Corresponds to the JSON propertyname`
23404 23405 23406 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23404 def name @name end |
#schedule_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ScheduleConfig
Schedule configuration for the FeatureMonitor.
Corresponds to the JSON property scheduleConfig
23409 23410 23411 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23409 def schedule_config @schedule_config end |
#update_time ⇒ String
Output only. Timestamp when this FeatureMonitor was last updated.
Corresponds to the JSON property updateTime
23414 23415 23416 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23414 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23421 23422 23423 23424 23425 23426 23427 23428 23429 23430 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23421 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @feature_selection_config = args[:feature_selection_config] if args.key?(:feature_selection_config) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @schedule_config = args[:schedule_config] if args.key?(:schedule_config) @update_time = args[:update_time] if args.key?(:update_time) end |