Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Vertex AI Feature Monitor.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureMonitor

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureMonitor.



21955
21956
21957
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21955

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this FeatureMonitor was created. Corresponds to the JSON property createTime

Returns:

  • (String)


21909
21910
21911
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21909

def create_time
  @create_time
end

#descriptionString

Optional. Description of the FeatureMonitor. Corresponds to the JSON property description

Returns:

  • (String)


21914
21915
21916
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21914

def description
  @description
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


21920
21921
21922
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21920

def etag
  @etag
end

#feature_selection_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelectionConfig

Feature selection configuration for the FeatureMonitor. Corresponds to the JSON property featureSelectionConfig



21925
21926
21927
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21925

def feature_selection_config
  @feature_selection_config
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your FeatureMonitor. Label keys and values can be no longer than 64 characters ( Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo. gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one FeatureMonitor(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


21937
21938
21939
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21937

def labels
  @labels
end

#nameString

Identifier. Name of the FeatureMonitor. Format: projects/project/locations/ location/featureGroups/featureGroup/featureMonitors/featureMonitor` Corresponds to the JSON propertyname`

Returns:

  • (String)


21943
21944
21945
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21943

def name
  @name
end

#schedule_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ScheduleConfig

Schedule configuration for the FeatureMonitor. Corresponds to the JSON property scheduleConfig



21948
21949
21950
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21948

def schedule_config
  @schedule_config
end

#update_timeString

Output only. Timestamp when this FeatureMonitor was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


21953
21954
21955
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21953

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21960
21961
21962
21963
21964
21965
21966
21967
21968
21969
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21960

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @feature_selection_config = args[:feature_selection_config] if args.key?(:feature_selection_config)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @schedule_config = args[:schedule_config] if args.key?(:schedule_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end