Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitor
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Vertex AI Feature Monitor.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#feature_selection_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelectionConfig
Feature selection configuration for the FeatureMonitor.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#schedule_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ScheduleConfig
Schedule configuration for the FeatureMonitor.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureMonitor
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureMonitor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureMonitor
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureMonitor.
15390 15391 15392 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15390 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this FeatureMonitor was created.
Corresponds to the JSON property createTime
15344 15345 15346 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15344 def create_time @create_time end |
#description ⇒ String
Optional. Description of the FeatureMonitor.
Corresponds to the JSON property description
15349 15350 15351 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15349 def description @description end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
15355 15356 15357 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15355 def etag @etag end |
#feature_selection_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelectionConfig
Feature selection configuration for the FeatureMonitor.
Corresponds to the JSON property featureSelectionConfig
15360 15361 15362 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15360 def feature_selection_config @feature_selection_config end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your
FeatureMonitor. Label keys and values can be no longer than 64 characters (
Unicode codepoints), can only contain lowercase letters, numeric characters,
underscores and dashes. International characters are allowed. See https://goo.
gl/xmQnxf for more information on and examples of labels. No more than 64 user
labels can be associated with one FeatureMonitor(System labels are excluded)."
System reserved label keys are prefixed with "aiplatform.googleapis.com/" and
are immutable.
Corresponds to the JSON property labels
15372 15373 15374 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15372 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureMonitor. Format: projects/project/locations/
location/featureGroups/featureGroup/featureMonitors/featureMonitor`
Corresponds to the JSON propertyname`
15378 15379 15380 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15378 def name @name end |
#schedule_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ScheduleConfig
Schedule configuration for the FeatureMonitor.
Corresponds to the JSON property scheduleConfig
15383 15384 15385 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15383 def schedule_config @schedule_config end |
#update_time ⇒ String
Output only. Timestamp when this FeatureMonitor was last updated.
Corresponds to the JSON property updateTime
15388 15389 15390 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15388 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15395 15396 15397 15398 15399 15400 15401 15402 15403 15404 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15395 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @feature_selection_config = args[:feature_selection_config] if args.key?(:feature_selection_config) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @schedule_config = args[:schedule_config] if args.key?(:schedule_config) @update_time = args[:update_time] if args.key?(:update_time) end |