Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitorJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitorJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Vertex AI Feature Monitor Job.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#drift_base_feature_monitor_job_id ⇒ Fixnum
Output only.
-
#drift_base_snapshot_time ⇒ String
Output only.
-
#feature_selection_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelectionConfig
Feature selection configuration for the FeatureMonitor.
-
#final_status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#job_summary ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitorJobJobSummary
Summary from the FeatureMonitorJob.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#trigger_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureMonitorJob
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureMonitorJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureMonitorJob
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureMonitorJob.
23503 23504 23505 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23503 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this FeatureMonitorJob was created. Creation of a
FeatureMonitorJob means that the job is pending / waiting for sufficient
resources but may not have started running yet.
Corresponds to the JSON property createTime
23442 23443 23444 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23442 def create_time @create_time end |
#description ⇒ String
Optional. Description of the FeatureMonitor.
Corresponds to the JSON property description
23447 23448 23449 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23447 def description @description end |
#drift_base_feature_monitor_job_id ⇒ Fixnum
Output only. FeatureMonitorJob ID comparing to which the drift is calculated.
Corresponds to the JSON property driftBaseFeatureMonitorJobId
23452 23453 23454 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23452 def drift_base_feature_monitor_job_id @drift_base_feature_monitor_job_id end |
#drift_base_snapshot_time ⇒ String
Output only. Data snapshot time comparing to which the drift is calculated.
Corresponds to the JSON property driftBaseSnapshotTime
23457 23458 23459 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23457 def drift_base_snapshot_time @drift_base_snapshot_time end |
#feature_selection_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelectionConfig
Feature selection configuration for the FeatureMonitor.
Corresponds to the JSON property featureSelectionConfig
23462 23463 23464 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23462 def feature_selection_config @feature_selection_config end |
#final_status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property finalStatus
23472 23473 23474 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23472 def final_status @final_status end |
#job_summary ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitorJobJobSummary
Summary from the FeatureMonitorJob.
Corresponds to the JSON property jobSummary
23477 23478 23479 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23477 def job_summary @job_summary end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your
FeatureMonitorJob. Label keys and values can be no longer than 64 characters (
Unicode codepoints), can only contain lowercase letters, numeric characters,
underscores and dashes. International characters are allowed. See https://goo.
gl/xmQnxf for more information on and examples of labels. No more than 64 user
labels can be associated with one FeatureMonitor(System labels are excluded)."
System reserved label keys are prefixed with "aiplatform.googleapis.com/" and
are immutable.
Corresponds to the JSON property labels
23489 23490 23491 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23489 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureMonitorJob. Format: projects/project/
locations/location/featureGroups/feature_group/featureMonitors/
feature_monitor/featureMonitorJobs/feature_monitor_job`.
Corresponds to the JSON propertyname`
23496 23497 23498 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23496 def name @name end |
#trigger_type ⇒ String
Output only. Trigger type of the Feature Monitor Job.
Corresponds to the JSON property triggerType
23501 23502 23503 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23501 def trigger_type @trigger_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23508 23509 23510 23511 23512 23513 23514 23515 23516 23517 23518 23519 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23508 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @drift_base_feature_monitor_job_id = args[:drift_base_feature_monitor_job_id] if args.key?(:drift_base_feature_monitor_job_id) @drift_base_snapshot_time = args[:drift_base_snapshot_time] if args.key?(:drift_base_snapshot_time) @feature_selection_config = args[:feature_selection_config] if args.key?(:feature_selection_config) @final_status = args[:final_status] if args.key?(:final_status) @job_summary = args[:job_summary] if args.key?(:job_summary) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @trigger_type = args[:trigger_type] if args.key?(:trigger_type) end |