Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitorJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Vertex AI Feature Monitor Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureMonitorJob

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureMonitorJob.



20263
20264
20265
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20263

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this FeatureMonitorJob was created. Creation of a FeatureMonitorJob means that the job is pending / waiting for sufficient resources but may not have started running yet. Corresponds to the JSON property createTime

Returns:

  • (String)


20202
20203
20204
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20202

def create_time
  @create_time
end

#descriptionString

Optional. Description of the FeatureMonitor. Corresponds to the JSON property description

Returns:

  • (String)


20207
20208
20209
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20207

def description
  @description
end

#drift_base_feature_monitor_job_idFixnum

Output only. FeatureMonitorJob ID comparing to which the drift is calculated. Corresponds to the JSON property driftBaseFeatureMonitorJobId

Returns:

  • (Fixnum)


20212
20213
20214
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20212

def drift_base_feature_monitor_job_id
  @drift_base_feature_monitor_job_id
end

#drift_base_snapshot_timeString

Output only. Data snapshot time comparing to which the drift is calculated. Corresponds to the JSON property driftBaseSnapshotTime

Returns:

  • (String)


20217
20218
20219
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20217

def drift_base_snapshot_time
  @drift_base_snapshot_time
end

#feature_selection_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelectionConfig

Feature selection configuration for the FeatureMonitor. Corresponds to the JSON property featureSelectionConfig



20222
20223
20224
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20222

def feature_selection_config
  @feature_selection_config
end

#final_statusGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property finalStatus



20232
20233
20234
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20232

def final_status
  @final_status
end

#job_summaryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitorJobJobSummary

Summary from the FeatureMonitorJob. Corresponds to the JSON property jobSummary



20237
20238
20239
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20237

def job_summary
  @job_summary
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your FeatureMonitorJob. Label keys and values can be no longer than 64 characters ( Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo. gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one FeatureMonitor(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


20249
20250
20251
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20249

def labels
  @labels
end

#nameString

Identifier. Name of the FeatureMonitorJob. Format: projects/project/ locations/location/featureGroups/feature_group/featureMonitors/ feature_monitor/featureMonitorJobs/feature_monitor_job`. Corresponds to the JSON propertyname`

Returns:

  • (String)


20256
20257
20258
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20256

def name
  @name
end

#trigger_typeString

Output only. Trigger type of the Feature Monitor Job. Corresponds to the JSON property triggerType

Returns:

  • (String)


20261
20262
20263
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20261

def trigger_type
  @trigger_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20268
20269
20270
20271
20272
20273
20274
20275
20276
20277
20278
20279
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20268

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @drift_base_feature_monitor_job_id = args[:drift_base_feature_monitor_job_id] if args.key?(:drift_base_feature_monitor_job_id)
  @drift_base_snapshot_time = args[:drift_base_snapshot_time] if args.key?(:drift_base_snapshot_time)
  @feature_selection_config = args[:feature_selection_config] if args.key?(:feature_selection_config)
  @final_status = args[:final_status] if args.key?(:final_status)
  @job_summary = args[:job_summary] if args.key?(:job_summary)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @trigger_type = args[:trigger_type] if args.key?(:trigger_type)
end