Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitorJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitorJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Vertex AI Feature Monitor Job.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#drift_base_feature_monitor_job_id ⇒ Fixnum
Output only.
-
#drift_base_snapshot_time ⇒ String
Output only.
-
#feature_selection_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelectionConfig
Feature selection configuration for the FeatureMonitor.
-
#final_status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#job_summary ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitorJobJobSummary
Summary from the FeatureMonitorJob.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#trigger_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureMonitorJob
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureMonitorJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureMonitorJob
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureMonitorJob.
15411 15412 15413 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15411 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this FeatureMonitorJob was created. Creation of a
FeatureMonitorJob means that the job is pending / waiting for sufficient
resources but may not have started running yet.
Corresponds to the JSON property createTime
15350 15351 15352 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15350 def create_time @create_time end |
#description ⇒ String
Optional. Description of the FeatureMonitor.
Corresponds to the JSON property description
15355 15356 15357 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15355 def description @description end |
#drift_base_feature_monitor_job_id ⇒ Fixnum
Output only. FeatureMonitorJob ID comparing to which the drift is calculated.
Corresponds to the JSON property driftBaseFeatureMonitorJobId
15360 15361 15362 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15360 def drift_base_feature_monitor_job_id @drift_base_feature_monitor_job_id end |
#drift_base_snapshot_time ⇒ String
Output only. Data snapshot time comparing to which the drift is calculated.
Corresponds to the JSON property driftBaseSnapshotTime
15365 15366 15367 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15365 def drift_base_snapshot_time @drift_base_snapshot_time end |
#feature_selection_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelectionConfig
Feature selection configuration for the FeatureMonitor.
Corresponds to the JSON property featureSelectionConfig
15370 15371 15372 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15370 def feature_selection_config @feature_selection_config end |
#final_status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property finalStatus
15380 15381 15382 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15380 def final_status @final_status end |
#job_summary ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitorJobJobSummary
Summary from the FeatureMonitorJob.
Corresponds to the JSON property jobSummary
15385 15386 15387 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15385 def job_summary @job_summary end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your
FeatureMonitorJob. Label keys and values can be no longer than 64 characters (
Unicode codepoints), can only contain lowercase letters, numeric characters,
underscores and dashes. International characters are allowed. See https://goo.
gl/xmQnxf for more information on and examples of labels. No more than 64 user
labels can be associated with one FeatureMonitor(System labels are excluded)."
System reserved label keys are prefixed with "aiplatform.googleapis.com/" and
are immutable.
Corresponds to the JSON property labels
15397 15398 15399 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15397 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureMonitorJob. Format: projects/project/
locations/location/featureGroups/feature_group/featureMonitors/
feature_monitor/featureMonitorJobs/feature_monitor_job`.
Corresponds to the JSON propertyname`
15404 15405 15406 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15404 def name @name end |
#trigger_type ⇒ String
Output only. Trigger type of the Feature Monitor Job.
Corresponds to the JSON property triggerType
15409 15410 15411 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15409 def trigger_type @trigger_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15416 15417 15418 15419 15420 15421 15422 15423 15424 15425 15426 15427 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15416 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @drift_base_feature_monitor_job_id = args[:drift_base_feature_monitor_job_id] if args.key?(:drift_base_feature_monitor_job_id) @drift_base_snapshot_time = args[:drift_base_snapshot_time] if args.key?(:drift_base_snapshot_time) @feature_selection_config = args[:feature_selection_config] if args.key?(:feature_selection_config) @final_status = args[:final_status] if args.key?(:final_status) @job_summary = args[:job_summary] if args.key?(:job_summary) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @trigger_type = args[:trigger_type] if args.key?(:trigger_type) end |