Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitoringStatsAnomaly
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitoringStatsAnomaly
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A list of historical SnapshotAnalysis or ImportFeaturesAnalysis stats requested by user, sorted by FeatureStatsAnomaly.start_time descending.
Instance Attribute Summary collapse
-
#feature_stats_anomaly ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAnomaly
Stats and Anomaly generated at specific timestamp for specific Feature.
-
#objective ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureMonitoringStatsAnomaly
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureMonitoringStatsAnomaly.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureMonitoringStatsAnomaly
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureMonitoringStatsAnomaly.
20826 20827 20828 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20826 def initialize(**args) update!(**args) end |
Instance Attribute Details
#feature_stats_anomaly ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAnomaly
Stats and Anomaly generated at specific timestamp for specific Feature. The
start_time and end_time are used to define the time range of the dataset that
current stats belongs to, e.g. prediction traffic is bucketed into prediction
datasets by time window. If the Dataset is not defined by time window,
start_time = end_time. Timestamp of the stats and anomalies always refers to
end_time. Raw stats and anomalies are stored in stats_uri or anomaly_uri in
the tensorflow defined protos. Field data_stats contains almost identical
information with the raw stats in Vertex AI defined proto, for UI to display.
Corresponds to the JSON property featureStatsAnomaly
20819 20820 20821 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20819 def feature_stats_anomaly @feature_stats_anomaly end |
#objective ⇒ String
Output only. The objective for each stats.
Corresponds to the JSON property objective
20824 20825 20826 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20824 def objective @objective end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20831 20832 20833 20834 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20831 def update!(**args) @feature_stats_anomaly = args[:feature_stats_anomaly] if args.key?(:feature_stats_anomaly) @objective = args[:objective] if args.key?(:objective) end |