Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureMonitoringStatsAnomaly

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A list of historical SnapshotAnalysis or ImportFeaturesAnalysis stats requested by user, sorted by FeatureStatsAnomaly.start_time descending.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureMonitoringStatsAnomaly

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureMonitoringStatsAnomaly.



20329
20330
20331
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20329

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feature_stats_anomalyGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAnomaly

Stats and Anomaly generated at specific timestamp for specific Feature. The start_time and end_time are used to define the time range of the dataset that current stats belongs to, e.g. prediction traffic is bucketed into prediction datasets by time window. If the Dataset is not defined by time window, start_time = end_time. Timestamp of the stats and anomalies always refers to end_time. Raw stats and anomalies are stored in stats_uri or anomaly_uri in the tensorflow defined protos. Field data_stats contains almost identical information with the raw stats in Vertex AI defined proto, for UI to display. Corresponds to the JSON property featureStatsAnomaly



20322
20323
20324
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20322

def feature_stats_anomaly
  @feature_stats_anomaly
end

#objectiveString

Output only. The objective for each stats. Corresponds to the JSON property objective

Returns:

  • (String)


20327
20328
20329
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20327

def objective
  @objective
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20334
20335
20336
20337
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20334

def update!(**args)
  @feature_stats_anomaly = args[:feature_stats_anomaly] if args.key?(:feature_stats_anomaly)
  @objective = args[:objective] if args.key?(:objective)
end