Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureNoiseSigma

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Noise sigma by features. Noise sigma represents the standard deviation of the gaussian kernel that will be used to add noise to interpolated inputs prior to computing gradients.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureNoiseSigma

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureNoiseSigma.



15565
15566
15567
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#noise_sigmaArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureNoiseSigmaNoiseSigmaForFeature>

Noise sigma per feature. No noise is added to features that are not set. Corresponds to the JSON property noiseSigma



15563
15564
15565
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15563

def noise_sigma
  @noise_sigma
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15570
15571
15572
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15570

def update!(**args)
  @noise_sigma = args[:noise_sigma] if args.key?(:noise_sigma)
end