Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureNoiseSigmaNoiseSigmaForFeature

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Noise sigma for a single feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureNoiseSigmaNoiseSigmaForFeature

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureNoiseSigmaNoiseSigmaForFeature.



15527
15528
15529
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15527

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the input feature for which noise sigma is provided. The features are defined in explanation metadata inputs. Corresponds to the JSON property name

Returns:

  • (String)


15517
15518
15519
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15517

def name
  @name
end

#sigmaFloat

This represents the standard deviation of the Gaussian kernel that will be used to add noise to the feature prior to computing gradients. Similar to noise_sigma but represents the noise added to the current feature. Defaults to 0.1. Corresponds to the JSON property sigma

Returns:

  • (Float)


15525
15526
15527
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15525

def sigma
  @sigma
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15532
15533
15534
15535
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15532

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @sigma = args[:sigma] if args.key?(:sigma)
end