Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Vertex AI Feature Online Store provides a centralized repository for serving ML features and embedding indexes at low latency. The Feature Online Store is a top-level container.
Instance Attribute Summary collapse
-
#bigtable ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable
Contains settings for the Cloud Bigtable instance that will be created to serve featureValues for all FeatureViews under this FeatureOnlineStore.
-
#create_time ⇒ String
Output only.
-
#dedicated_serving_endpoint ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint
The dedicated serving endpoint for this FeatureOnlineStore.
-
#embedding_management ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreEmbeddingManagement
Deprecated: This sub message is no longer needed anymore and embedding management is automatically enabled when specifying Optimized storage type.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#optimized ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreOptimized
Optimized storage type Corresponds to the JSON property
optimized. -
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStore
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStore
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStore.
23657 23658 23659 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigtable ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable
Contains settings for the Cloud Bigtable instance that will be created to
serve featureValues for all FeatureViews under this FeatureOnlineStore.
Corresponds to the JSON property bigtable
23579 23580 23581 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23579 def bigtable @bigtable end |
#create_time ⇒ String
Output only. Timestamp when this FeatureOnlineStore was created.
Corresponds to the JSON property createTime
23584 23585 23586 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23584 def create_time @create_time end |
#dedicated_serving_endpoint ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint
The dedicated serving endpoint for this FeatureOnlineStore. Only need to set
when you choose Optimized storage type. Public endpoint is provisioned by
default.
Corresponds to the JSON property dedicatedServingEndpoint
23591 23592 23593 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23591 def dedicated_serving_endpoint @dedicated_serving_endpoint end |
#embedding_management ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreEmbeddingManagement
Deprecated: This sub message is no longer needed anymore and embedding
management is automatically enabled when specifying Optimized storage type.
Contains settings for embedding management.
Corresponds to the JSON property embeddingManagement
23598 23599 23600 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23598 def @embedding_management end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
23604 23605 23606 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23604 def encryption_spec @encryption_spec end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
23610 23611 23612 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23610 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your
FeatureOnlineStore. Label keys and values can be no longer than 64 characters (
Unicode codepoints), can only contain lowercase letters, numeric characters,
underscores and dashes. International characters are allowed. See https://goo.
gl/xmQnxf for more information on and examples of labels. No more than 64 user
labels can be associated with one FeatureOnlineStore(System labels are
excluded)." System reserved label keys are prefixed with "aiplatform.
googleapis.com/" and are immutable.
Corresponds to the JSON property labels
23622 23623 23624 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23622 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureOnlineStore. Format: projects/project/
locations/location/featureOnlineStores/featureOnlineStore`
Corresponds to the JSON propertyname`
23628 23629 23630 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23628 def name @name end |
#optimized ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreOptimized
Optimized storage type
Corresponds to the JSON property optimized
23633 23634 23635 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23633 def optimized @optimized end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
23638 23639 23640 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23638 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
23644 23645 23646 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23644 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. State of the featureOnlineStore.
Corresponds to the JSON property state
23650 23651 23652 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23650 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this FeatureOnlineStore was last updated.
Corresponds to the JSON property updateTime
23655 23656 23657 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23655 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23662 23663 23664 23665 23666 23667 23668 23669 23670 23671 23672 23673 23674 23675 23676 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23662 def update!(**args) @bigtable = args[:bigtable] if args.key?(:bigtable) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_serving_endpoint = args[:dedicated_serving_endpoint] if args.key?(:dedicated_serving_endpoint) @embedding_management = args[:embedding_management] if args.key?(:embedding_management) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @optimized = args[:optimized] if args.key?(:optimized) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |