Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Vertex AI Feature Online Store provides a centralized repository for serving ML features and embedding indexes at low latency. The Feature Online Store is a top-level container.
Instance Attribute Summary collapse
-
#bigtable ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable
Contains settings for the Cloud Bigtable instance that will be created to serve featureValues for all FeatureViews under this FeatureOnlineStore.
-
#create_time ⇒ String
Output only.
-
#dedicated_serving_endpoint ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint
The dedicated serving endpoint for this FeatureOnlineStore.
-
#embedding_management ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreEmbeddingManagement
Deprecated: This sub message is no longer needed anymore and embedding management is automatically enabled when specifying Optimized storage type.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#optimized ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreOptimized
Optimized storage type Corresponds to the JSON property
optimized. -
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStore
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStore
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStore.
21763 21764 21765 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21763 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigtable ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable
Contains settings for the Cloud Bigtable instance that will be created to
serve featureValues for all FeatureViews under this FeatureOnlineStore.
Corresponds to the JSON property bigtable
21685 21686 21687 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21685 def bigtable @bigtable end |
#create_time ⇒ String
Output only. Timestamp when this FeatureOnlineStore was created.
Corresponds to the JSON property createTime
21690 21691 21692 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21690 def create_time @create_time end |
#dedicated_serving_endpoint ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint
The dedicated serving endpoint for this FeatureOnlineStore. Only need to set
when you choose Optimized storage type. Public endpoint is provisioned by
default.
Corresponds to the JSON property dedicatedServingEndpoint
21697 21698 21699 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21697 def dedicated_serving_endpoint @dedicated_serving_endpoint end |
#embedding_management ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreEmbeddingManagement
Deprecated: This sub message is no longer needed anymore and embedding
management is automatically enabled when specifying Optimized storage type.
Contains settings for embedding management.
Corresponds to the JSON property embeddingManagement
21704 21705 21706 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21704 def @embedding_management end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
21710 21711 21712 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21710 def encryption_spec @encryption_spec end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
21716 21717 21718 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21716 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your
FeatureOnlineStore. Label keys and values can be no longer than 64 characters (
Unicode codepoints), can only contain lowercase letters, numeric characters,
underscores and dashes. International characters are allowed. See https://goo.
gl/xmQnxf for more information on and examples of labels. No more than 64 user
labels can be associated with one FeatureOnlineStore(System labels are
excluded)." System reserved label keys are prefixed with "aiplatform.
googleapis.com/" and are immutable.
Corresponds to the JSON property labels
21728 21729 21730 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21728 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureOnlineStore. Format: projects/project/
locations/location/featureOnlineStores/featureOnlineStore`
Corresponds to the JSON propertyname`
21734 21735 21736 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21734 def name @name end |
#optimized ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreOptimized
Optimized storage type
Corresponds to the JSON property optimized
21739 21740 21741 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21739 def optimized @optimized end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
21744 21745 21746 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21744 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
21750 21751 21752 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21750 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. State of the featureOnlineStore.
Corresponds to the JSON property state
21756 21757 21758 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21756 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this FeatureOnlineStore was last updated.
Corresponds to the JSON property updateTime
21761 21762 21763 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21761 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21768 21769 21770 21771 21772 21773 21774 21775 21776 21777 21778 21779 21780 21781 21782 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21768 def update!(**args) @bigtable = args[:bigtable] if args.key?(:bigtable) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_serving_endpoint = args[:dedicated_serving_endpoint] if args.key?(:dedicated_serving_endpoint) @embedding_management = args[:embedding_management] if args.key?(:embedding_management) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @optimized = args[:optimized] if args.key?(:optimized) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |