Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable.



15742
15743
15744
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15742

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_scalingGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtableAutoScaling

Required. Autoscaling config applied to Bigtable Instance. Corresponds to the JSON property autoScaling



15721
15722
15723
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15721

def auto_scaling
  @auto_scaling
end

#bigtable_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtableBigtableMetadata

Metadata of the Bigtable instance. This is used by direct read access to the Bigtable in tenant project. Corresponds to the JSON property bigtableMetadata



15727
15728
15729
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15727

def 
  @bigtable_metadata
end

#enable_direct_bigtable_accessBoolean Also known as: enable_direct_bigtable_access?

Optional. It true, enable direct access to the Bigtable instance. Corresponds to the JSON property enableDirectBigtableAccess

Returns:

  • (Boolean)


15732
15733
15734
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15732

def enable_direct_bigtable_access
  @enable_direct_bigtable_access
end

#zoneString

Optional. The zone where the underlying Bigtable cluster for the primary Bigtable instance will be provisioned. Only the zone must be provided. For example, only "us-central1-a" should be provided. Corresponds to the JSON property zone

Returns:

  • (String)


15740
15741
15742
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15740

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15747
15748
15749
15750
15751
15752
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15747

def update!(**args)
  @auto_scaling = args[:auto_scaling] if args.key?(:auto_scaling)
  @bigtable_metadata = args[:bigtable_metadata] if args.key?(:bigtable_metadata)
  @enable_direct_bigtable_access = args[:enable_direct_bigtable_access] if args.key?(:enable_direct_bigtable_access)
  @zone = args[:zone] if args.key?(:zone)
end