Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#auto_scaling ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtableAutoScaling
Required.
-
#bigtable_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtableBigtableMetadata
Metadata of the Bigtable instance.
-
#enable_direct_bigtable_access ⇒ Boolean
(also: #enable_direct_bigtable_access?)
Optional.
-
#zone ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtable.
15676 15677 15678 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15676 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_scaling ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtableAutoScaling
Required. Autoscaling config applied to Bigtable Instance.
Corresponds to the JSON property autoScaling
15655 15656 15657 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15655 def auto_scaling @auto_scaling end |
#bigtable_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreBigtableBigtableMetadata
Metadata of the Bigtable instance. This is used by direct read access to the
Bigtable in tenant project.
Corresponds to the JSON property bigtableMetadata
15661 15662 15663 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15661 def @bigtable_metadata end |
#enable_direct_bigtable_access ⇒ Boolean Also known as: enable_direct_bigtable_access?
Optional. It true, enable direct access to the Bigtable instance.
Corresponds to the JSON property enableDirectBigtableAccess
15666 15667 15668 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15666 def enable_direct_bigtable_access @enable_direct_bigtable_access end |
#zone ⇒ String
Optional. The zone where the underlying Bigtable cluster for the primary
Bigtable instance will be provisioned. Only the zone must be provided. For
example, only "us-central1-a" should be provided.
Corresponds to the JSON property zone
15674 15675 15676 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15674 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15681 15682 15683 15684 15685 15686 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15681 def update!(**args) @auto_scaling = args[:auto_scaling] if args.key?(:auto_scaling) @bigtable_metadata = args[:bigtable_metadata] if args.key?(:bigtable_metadata) @enable_direct_bigtable_access = args[:enable_direct_bigtable_access] if args.key?(:enable_direct_bigtable_access) @zone = args[:zone] if args.key?(:zone) end |