Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The dedicated serving endpoint for this FeatureOnlineStore. Only need to set when you choose Optimized storage type. Public endpoint is provisioned by default.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint.



21131
21132
21133
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21131

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#private_service_connect_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig

Represents configuration for private service connect. Corresponds to the JSON property privateServiceConnectConfig



21117
21118
21119
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21117

def private_service_connect_config
  @private_service_connect_config
end

#public_endpoint_domain_nameString

Output only. This field will be populated with the domain name to use for this FeatureOnlineStore Corresponds to the JSON property publicEndpointDomainName

Returns:

  • (String)


21123
21124
21125
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21123

def public_endpoint_domain_name
  @public_endpoint_domain_name
end

#service_attachmentString

Output only. The name of the service attachment resource. Populated if private service connect is enabled and after FeatureViewSync is created. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


21129
21130
21131
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21129

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21136
21137
21138
21139
21140
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21136

def update!(**args)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
  @public_endpoint_domain_name = args[:public_endpoint_domain_name] if args.key?(:public_endpoint_domain_name)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end