Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The dedicated serving endpoint for this FeatureOnlineStore. Only need to set when you choose Optimized storage type. Public endpoint is provisioned by default.
Instance Attribute Summary collapse
-
#private_service_connect_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig
Represents configuration for private service connect.
-
#public_endpoint_domain_name ⇒ String
Output only.
-
#service_attachment ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStoreDedicatedServingEndpoint.
15848 15849 15850 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15848 def initialize(**args) update!(**args) end |
Instance Attribute Details
#private_service_connect_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig
Represents configuration for private service connect.
Corresponds to the JSON property privateServiceConnectConfig
15834 15835 15836 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15834 def private_service_connect_config @private_service_connect_config end |
#public_endpoint_domain_name ⇒ String
Output only. This field will be populated with the domain name to use for this
FeatureOnlineStore
Corresponds to the JSON property publicEndpointDomainName
15840 15841 15842 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15840 def public_endpoint_domain_name @public_endpoint_domain_name end |
#service_attachment ⇒ String
Output only. The name of the service attachment resource. Populated if private
service connect is enabled and after FeatureViewSync is created.
Corresponds to the JSON property serviceAttachment
15846 15847 15848 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15846 def @service_attachment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15853 15854 15855 15856 15857 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15853 def update!(**args) @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config) @public_endpoint_domain_name = args[:public_endpoint_domain_name] if args.key?(:public_endpoint_domain_name) @service_attachment = args[:service_attachment] if args.key?(:service_attachment) end |