Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureOnlineStoreEmbeddingManagement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Deprecated: This sub message is no longer needed anymore and embedding management is automatically enabled when specifying Optimized storage type. Contains settings for embedding management.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureOnlineStoreEmbeddingManagement

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureOnlineStoreEmbeddingManagement.



15874
15875
15876
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Optional. Immutable. Whether to enable embedding management in this FeatureOnlineStore. It's immutable after creation to ensure the FeatureOnlineStore availability. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


15871
15872
15873
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15871

def enabled
  @enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15879
15880
15881
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15879

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
end