Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureSelectionConfigFeatureConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Feature configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureSelectionConfigFeatureConfig

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureSelectionConfigFeatureConfig.



20720
20721
20722
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#drift_thresholdFloat

Optional. Drift threshold. If calculated difference with baseline data larger than threshold, it will be considered as the feature has drift. If not present, the threshold will be default to 0.3. Must be in range [0, 1). Corresponds to the JSON property driftThreshold

Returns:

  • (Float)


20712
20713
20714
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20712

def drift_threshold
  @drift_threshold
end

#feature_idString

Required. The ID of the feature resource. Final component of the Feature's resource name. Corresponds to the JSON property featureId

Returns:

  • (String)


20718
20719
20720
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20718

def feature_id
  @feature_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20725
20726
20727
20728
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20725

def update!(**args)
  @drift_threshold = args[:drift_threshold] if args.key?(:drift_threshold)
  @feature_id = args[:feature_id] if args.key?(:feature_id)
end