Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Stats and Anomaly generated by FeatureMonitorJobs. Anomaly only includes Drift.
Instance Attribute Summary collapse
-
#distribution_deviation ⇒ Float
Deviation from the current stats to baseline stats.
-
#drift_detected ⇒ Boolean
(also: #drift_detected?)
If set to true, indicates current stats is detected as and comparing with baseline stats.
-
#drift_detection_threshold ⇒ Float
This is the threshold used when detecting drifts, which is set in FeatureMonitor.FeatureSelectionConfig.FeatureConfig.drift_threshold Corresponds to the JSON property
driftDetectionThreshold. -
#feature_id ⇒ String
Feature Id.
-
#feature_monitor_id ⇒ String
The ID of the FeatureMonitor that this FeatureStatsAndAnomaly generated according to.
-
#feature_monitor_job_id ⇒ Fixnum
The ID of the FeatureMonitorJob that generated this FeatureStatsAndAnomaly.
-
#feature_stats ⇒ Object
Feature stats.
-
#stats_time ⇒ String
The timestamp we take snapshot for feature values to generate stats.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly.
22580 22581 22582 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22580 def initialize(**args) update!(**args) end |
Instance Attribute Details
#distribution_deviation ⇒ Float
Deviation from the current stats to baseline stats. 1. For categorical feature,
the distribution distance is calculated by L-inifinity norm. 2. For numerical
feature, the distribution distance is calculated by Jensen–Shannon divergence.
Corresponds to the JSON property distributionDeviation
22538 22539 22540 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22538 def distribution_deviation @distribution_deviation end |
#drift_detected ⇒ Boolean Also known as: drift_detected?
If set to true, indicates current stats is detected as and comparing with
baseline stats.
Corresponds to the JSON property driftDetected
22544 22545 22546 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22544 def drift_detected @drift_detected end |
#drift_detection_threshold ⇒ Float
This is the threshold used when detecting drifts, which is set in
FeatureMonitor.FeatureSelectionConfig.FeatureConfig.drift_threshold
Corresponds to the JSON property driftDetectionThreshold
22551 22552 22553 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22551 def drift_detection_threshold @drift_detection_threshold end |
#feature_id ⇒ String
Feature Id.
Corresponds to the JSON property featureId
22556 22557 22558 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22556 def feature_id @feature_id end |
#feature_monitor_id ⇒ String
The ID of the FeatureMonitor that this FeatureStatsAndAnomaly generated
according to.
Corresponds to the JSON property featureMonitorId
22562 22563 22564 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22562 def feature_monitor_id @feature_monitor_id end |
#feature_monitor_job_id ⇒ Fixnum
The ID of the FeatureMonitorJob that generated this FeatureStatsAndAnomaly.
Corresponds to the JSON property featureMonitorJobId
22567 22568 22569 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22567 def feature_monitor_job_id @feature_monitor_job_id end |
#feature_stats ⇒ Object
Feature stats. e.g. histogram buckets. In the format of tensorflow.metadata.v0.
DatasetFeatureStatistics.
Corresponds to the JSON property featureStats
22573 22574 22575 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22573 def feature_stats @feature_stats end |
#stats_time ⇒ String
The timestamp we take snapshot for feature values to generate stats.
Corresponds to the JSON property statsTime
22578 22579 22580 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22578 def stats_time @stats_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22585 22586 22587 22588 22589 22590 22591 22592 22593 22594 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22585 def update!(**args) @distribution_deviation = args[:distribution_deviation] if args.key?(:distribution_deviation) @drift_detected = args[:drift_detected] if args.key?(:drift_detected) @drift_detection_threshold = args[:drift_detection_threshold] if args.key?(:drift_detection_threshold) @feature_id = args[:feature_id] if args.key?(:feature_id) @feature_monitor_id = args[:feature_monitor_id] if args.key?(:feature_monitor_id) @feature_monitor_job_id = args[:feature_monitor_job_id] if args.key?(:feature_monitor_job_id) @feature_stats = args[:feature_stats] if args.key?(:feature_stats) @stats_time = args[:stats_time] if args.key?(:stats_time) end |