Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Stats and Anomaly generated by FeatureMonitorJobs. Anomaly only includes Drift.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly.



22264
22265
22266
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#distribution_deviationFloat

Deviation from the current stats to baseline stats. 1. For categorical feature, the distribution distance is calculated by L-inifinity norm. 2. For numerical feature, the distribution distance is calculated by Jensen–Shannon divergence. Corresponds to the JSON property distributionDeviation

Returns:

  • (Float)


22222
22223
22224
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22222

def distribution_deviation
  @distribution_deviation
end

#drift_detectedBoolean Also known as: drift_detected?

If set to true, indicates current stats is detected as and comparing with baseline stats. Corresponds to the JSON property driftDetected

Returns:

  • (Boolean)


22228
22229
22230
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22228

def drift_detected
  @drift_detected
end

#drift_detection_thresholdFloat

This is the threshold used when detecting drifts, which is set in FeatureMonitor.FeatureSelectionConfig.FeatureConfig.drift_threshold Corresponds to the JSON property driftDetectionThreshold

Returns:

  • (Float)


22235
22236
22237
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22235

def drift_detection_threshold
  @drift_detection_threshold
end

#feature_idString

Feature Id. Corresponds to the JSON property featureId

Returns:

  • (String)


22240
22241
22242
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22240

def feature_id
  @feature_id
end

#feature_monitor_idString

The ID of the FeatureMonitor that this FeatureStatsAndAnomaly generated according to. Corresponds to the JSON property featureMonitorId

Returns:

  • (String)


22246
22247
22248
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22246

def feature_monitor_id
  @feature_monitor_id
end

#feature_monitor_job_idFixnum

The ID of the FeatureMonitorJob that generated this FeatureStatsAndAnomaly. Corresponds to the JSON property featureMonitorJobId

Returns:

  • (Fixnum)


22251
22252
22253
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22251

def feature_monitor_job_id
  @feature_monitor_job_id
end

#feature_statsObject

Feature stats. e.g. histogram buckets. In the format of tensorflow.metadata.v0. DatasetFeatureStatistics. Corresponds to the JSON property featureStats

Returns:

  • (Object)


22257
22258
22259
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22257

def feature_stats
  @feature_stats
end

#stats_timeString

The timestamp we take snapshot for feature values to generate stats. Corresponds to the JSON property statsTime

Returns:

  • (String)


22262
22263
22264
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22262

def stats_time
  @stats_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22269
22270
22271
22272
22273
22274
22275
22276
22277
22278
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22269

def update!(**args)
  @distribution_deviation = args[:distribution_deviation] if args.key?(:distribution_deviation)
  @drift_detected = args[:drift_detected] if args.key?(:drift_detected)
  @drift_detection_threshold = args[:drift_detection_threshold] if args.key?(:drift_detection_threshold)
  @feature_id = args[:feature_id] if args.key?(:feature_id)
  @feature_monitor_id = args[:feature_monitor_id] if args.key?(:feature_monitor_id)
  @feature_monitor_job_id = args[:feature_monitor_job_id] if args.key?(:feature_monitor_job_id)
  @feature_stats = args[:feature_stats] if args.key?(:feature_stats)
  @stats_time = args[:stats_time] if args.key?(:stats_time)
end