Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Stats and Anomaly generated by FeatureMonitorJobs. Anomaly only includes Drift.
Instance Attribute Summary collapse
-
#distribution_deviation ⇒ Float
Deviation from the current stats to baseline stats.
-
#drift_detected ⇒ Boolean
(also: #drift_detected?)
If set to true, indicates current stats is detected as and comparing with baseline stats.
-
#drift_detection_threshold ⇒ Float
This is the threshold used when detecting drifts, which is set in FeatureMonitor.FeatureSelectionConfig.FeatureConfig.drift_threshold Corresponds to the JSON property
driftDetectionThreshold. -
#feature_id ⇒ String
Feature Id.
-
#feature_monitor_id ⇒ String
The ID of the FeatureMonitor that this FeatureStatsAndAnomaly generated according to.
-
#feature_monitor_job_id ⇒ Fixnum
The ID of the FeatureMonitorJob that generated this FeatureStatsAndAnomaly.
-
#feature_stats ⇒ Object
Feature stats.
-
#stats_time ⇒ String
The timestamp we take snapshot for feature values to generate stats.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly.
21298 21299 21300 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#distribution_deviation ⇒ Float
Deviation from the current stats to baseline stats. 1. For categorical feature,
the distribution distance is calculated by L-inifinity norm. 2. For numerical
feature, the distribution distance is calculated by Jensen–Shannon divergence.
Corresponds to the JSON property distributionDeviation
21256 21257 21258 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21256 def distribution_deviation @distribution_deviation end |
#drift_detected ⇒ Boolean Also known as: drift_detected?
If set to true, indicates current stats is detected as and comparing with
baseline stats.
Corresponds to the JSON property driftDetected
21262 21263 21264 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21262 def drift_detected @drift_detected end |
#drift_detection_threshold ⇒ Float
This is the threshold used when detecting drifts, which is set in
FeatureMonitor.FeatureSelectionConfig.FeatureConfig.drift_threshold
Corresponds to the JSON property driftDetectionThreshold
21269 21270 21271 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21269 def drift_detection_threshold @drift_detection_threshold end |
#feature_id ⇒ String
Feature Id.
Corresponds to the JSON property featureId
21274 21275 21276 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21274 def feature_id @feature_id end |
#feature_monitor_id ⇒ String
The ID of the FeatureMonitor that this FeatureStatsAndAnomaly generated
according to.
Corresponds to the JSON property featureMonitorId
21280 21281 21282 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21280 def feature_monitor_id @feature_monitor_id end |
#feature_monitor_job_id ⇒ Fixnum
The ID of the FeatureMonitorJob that generated this FeatureStatsAndAnomaly.
Corresponds to the JSON property featureMonitorJobId
21285 21286 21287 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21285 def feature_monitor_job_id @feature_monitor_job_id end |
#feature_stats ⇒ Object
Feature stats. e.g. histogram buckets. In the format of tensorflow.metadata.v0.
DatasetFeatureStatistics.
Corresponds to the JSON property featureStats
21291 21292 21293 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21291 def feature_stats @feature_stats end |
#stats_time ⇒ String
The timestamp we take snapshot for feature values to generate stats.
Corresponds to the JSON property statsTime
21296 21297 21298 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21296 def stats_time @stats_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21303 21304 21305 21306 21307 21308 21309 21310 21311 21312 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21303 def update!(**args) @distribution_deviation = args[:distribution_deviation] if args.key?(:distribution_deviation) @drift_detected = args[:drift_detected] if args.key?(:drift_detected) @drift_detection_threshold = args[:drift_detection_threshold] if args.key?(:drift_detection_threshold) @feature_id = args[:feature_id] if args.key?(:feature_id) @feature_monitor_id = args[:feature_monitor_id] if args.key?(:feature_monitor_id) @feature_monitor_job_id = args[:feature_monitor_job_id] if args.key?(:feature_monitor_job_id) @feature_stats = args[:feature_stats] if args.key?(:feature_stats) @stats_time = args[:stats_time] if args.key?(:stats_time) end |