Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Stats and Anomaly generated by FeatureMonitorJobs. Anomaly only includes Drift.
Instance Attribute Summary collapse
-
#distribution_deviation ⇒ Float
Deviation from the current stats to baseline stats.
-
#drift_detected ⇒ Boolean
(also: #drift_detected?)
If set to true, indicates current stats is detected as and comparing with baseline stats.
-
#drift_detection_threshold ⇒ Float
This is the threshold used when detecting drifts, which is set in FeatureMonitor.FeatureSelectionConfig.FeatureConfig.drift_threshold Corresponds to the JSON property
driftDetectionThreshold. -
#feature_id ⇒ String
Feature Id.
-
#feature_monitor_id ⇒ String
The ID of the FeatureMonitor that this FeatureStatsAndAnomaly generated according to.
-
#feature_monitor_job_id ⇒ Fixnum
The ID of the FeatureMonitorJob that generated this FeatureStatsAndAnomaly.
-
#feature_stats ⇒ Object
Feature stats.
-
#stats_time ⇒ String
The timestamp we take snapshot for feature values to generate stats.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly.
16015 16016 16017 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#distribution_deviation ⇒ Float
Deviation from the current stats to baseline stats. 1. For categorical feature,
the distribution distance is calculated by L-inifinity norm. 2. For numerical
feature, the distribution distance is calculated by Jensen–Shannon divergence.
Corresponds to the JSON property distributionDeviation
15973 15974 15975 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15973 def distribution_deviation @distribution_deviation end |
#drift_detected ⇒ Boolean Also known as: drift_detected?
If set to true, indicates current stats is detected as and comparing with
baseline stats.
Corresponds to the JSON property driftDetected
15979 15980 15981 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15979 def drift_detected @drift_detected end |
#drift_detection_threshold ⇒ Float
This is the threshold used when detecting drifts, which is set in
FeatureMonitor.FeatureSelectionConfig.FeatureConfig.drift_threshold
Corresponds to the JSON property driftDetectionThreshold
15986 15987 15988 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15986 def drift_detection_threshold @drift_detection_threshold end |
#feature_id ⇒ String
Feature Id.
Corresponds to the JSON property featureId
15991 15992 15993 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15991 def feature_id @feature_id end |
#feature_monitor_id ⇒ String
The ID of the FeatureMonitor that this FeatureStatsAndAnomaly generated
according to.
Corresponds to the JSON property featureMonitorId
15997 15998 15999 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15997 def feature_monitor_id @feature_monitor_id end |
#feature_monitor_job_id ⇒ Fixnum
The ID of the FeatureMonitorJob that generated this FeatureStatsAndAnomaly.
Corresponds to the JSON property featureMonitorJobId
16002 16003 16004 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16002 def feature_monitor_job_id @feature_monitor_job_id end |
#feature_stats ⇒ Object
Feature stats. e.g. histogram buckets. In the format of tensorflow.metadata.v0.
DatasetFeatureStatistics.
Corresponds to the JSON property featureStats
16008 16009 16010 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16008 def feature_stats @feature_stats end |
#stats_time ⇒ String
The timestamp we take snapshot for feature values to generate stats.
Corresponds to the JSON property statsTime
16013 16014 16015 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16013 def stats_time @stats_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16020 16021 16022 16023 16024 16025 16026 16027 16028 16029 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16020 def update!(**args) @distribution_deviation = args[:distribution_deviation] if args.key?(:distribution_deviation) @drift_detected = args[:drift_detected] if args.key?(:drift_detected) @drift_detection_threshold = args[:drift_detection_threshold] if args.key?(:drift_detection_threshold) @feature_id = args[:feature_id] if args.key?(:feature_id) @feature_monitor_id = args[:feature_monitor_id] if args.key?(:feature_monitor_id) @feature_monitor_job_id = args[:feature_monitor_job_id] if args.key?(:feature_monitor_job_id) @feature_stats = args[:feature_stats] if args.key?(:feature_stats) @stats_time = args[:stats_time] if args.key?(:stats_time) end |