Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Stats and Anomaly generated by FeatureMonitorJobs. Anomaly only includes Drift.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureStatsAndAnomaly.



15949
15950
15951
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15949

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#distribution_deviationFloat

Deviation from the current stats to baseline stats. 1. For categorical feature, the distribution distance is calculated by L-inifinity norm. 2. For numerical feature, the distribution distance is calculated by Jensen–Shannon divergence. Corresponds to the JSON property distributionDeviation

Returns:

  • (Float)


15907
15908
15909
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15907

def distribution_deviation
  @distribution_deviation
end

#drift_detectedBoolean Also known as: drift_detected?

If set to true, indicates current stats is detected as and comparing with baseline stats. Corresponds to the JSON property driftDetected

Returns:

  • (Boolean)


15913
15914
15915
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15913

def drift_detected
  @drift_detected
end

#drift_detection_thresholdFloat

This is the threshold used when detecting drifts, which is set in FeatureMonitor.FeatureSelectionConfig.FeatureConfig.drift_threshold Corresponds to the JSON property driftDetectionThreshold

Returns:

  • (Float)


15920
15921
15922
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15920

def drift_detection_threshold
  @drift_detection_threshold
end

#feature_idString

Feature Id. Corresponds to the JSON property featureId

Returns:

  • (String)


15925
15926
15927
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15925

def feature_id
  @feature_id
end

#feature_monitor_idString

The ID of the FeatureMonitor that this FeatureStatsAndAnomaly generated according to. Corresponds to the JSON property featureMonitorId

Returns:

  • (String)


15931
15932
15933
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15931

def feature_monitor_id
  @feature_monitor_id
end

#feature_monitor_job_idFixnum

The ID of the FeatureMonitorJob that generated this FeatureStatsAndAnomaly. Corresponds to the JSON property featureMonitorJobId

Returns:

  • (Fixnum)


15936
15937
15938
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15936

def feature_monitor_job_id
  @feature_monitor_job_id
end

#feature_statsObject

Feature stats. e.g. histogram buckets. In the format of tensorflow.metadata.v0. DatasetFeatureStatistics. Corresponds to the JSON property featureStats

Returns:

  • (Object)


15942
15943
15944
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15942

def feature_stats
  @feature_stats
end

#stats_timeString

The timestamp we take snapshot for feature values to generate stats. Corresponds to the JSON property statsTime

Returns:

  • (String)


15947
15948
15949
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15947

def stats_time
  @stats_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15954
15955
15956
15957
15958
15959
15960
15961
15962
15963
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 15954

def update!(**args)
  @distribution_deviation = args[:distribution_deviation] if args.key?(:distribution_deviation)
  @drift_detected = args[:drift_detected] if args.key?(:drift_detected)
  @drift_detection_threshold = args[:drift_detection_threshold] if args.key?(:drift_detection_threshold)
  @feature_id = args[:feature_id] if args.key?(:feature_id)
  @feature_monitor_id = args[:feature_monitor_id] if args.key?(:feature_monitor_id)
  @feature_monitor_job_id = args[:feature_monitor_job_id] if args.key?(:feature_monitor_job_id)
  @feature_stats = args[:feature_stats] if args.key?(:feature_stats)
  @stats_time = args[:stats_time] if args.key?(:stats_time)
end