Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAnomaly
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAnomaly
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Stats and Anomaly generated at specific timestamp for specific Feature. The start_time and end_time are used to define the time range of the dataset that current stats belongs to, e.g. prediction traffic is bucketed into prediction datasets by time window. If the Dataset is not defined by time window, start_time = end_time. Timestamp of the stats and anomalies always refers to end_time. Raw stats and anomalies are stored in stats_uri or anomaly_uri in the tensorflow defined protos. Field data_stats contains almost identical information with the raw stats in Vertex AI defined proto, for UI to display.
Instance Attribute Summary collapse
-
#anomaly_detection_threshold ⇒ Float
This is the threshold used when detecting anomalies.
-
#anomaly_uri ⇒ String
Path of the anomaly file for current feature values in Cloud Storage bucket.
-
#distribution_deviation ⇒ Float
Deviation from the current stats to baseline stats.
-
#end_time ⇒ String
The end timestamp of window where stats were generated.
-
#score ⇒ Float
Feature importance score, only populated when cross-feature monitoring is enabled.
-
#start_time ⇒ String
The start timestamp of window where stats were generated.
-
#stats_uri ⇒ String
Path of the stats file for current feature values in Cloud Storage bucket.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureStatsAnomaly
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureStatsAnomaly.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureStatsAnomaly
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureStatsAnomaly.
21382 21383 21384 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21382 def initialize(**args) update!(**args) end |
Instance Attribute Details
#anomaly_detection_threshold ⇒ Float
This is the threshold used when detecting anomalies. The threshold can be
changed by user, so this one might be different from ThresholdConfig.value.
Corresponds to the JSON property anomalyDetectionThreshold
21330 21331 21332 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21330 def anomaly_detection_threshold @anomaly_detection_threshold end |
#anomaly_uri ⇒ String
Path of the anomaly file for current feature values in Cloud Storage bucket.
Format: gs:////anomalies. Example: gs://monitoring_bucket/feature_name/
anomalies. Stats are stored as binary format with Protobuf message Anoamlies
are stored as binary format with Protobuf message tensorflow.metadata.v0.
AnomalyInfo.
Corresponds to the JSON property anomalyUri
21340 21341 21342 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21340 def anomaly_uri @anomaly_uri end |
#distribution_deviation ⇒ Float
Deviation from the current stats to baseline stats. 1. For categorical feature,
the distribution distance is calculated by L-inifinity norm. 2. For numerical
feature, the distribution distance is calculated by Jensen–Shannon divergence.
Corresponds to the JSON property distributionDeviation
21347 21348 21349 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21347 def distribution_deviation @distribution_deviation end |
#end_time ⇒ String
The end timestamp of window where stats were generated. For objectives where
time window doesn't make sense (e.g. Featurestore Snapshot Monitoring),
end_time indicates the timestamp of the data used to generate stats (e.g.
timestamp we take snapshots for feature values).
Corresponds to the JSON property endTime
21355 21356 21357 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21355 def end_time @end_time end |
#score ⇒ Float
Feature importance score, only populated when cross-feature monitoring is
enabled. For now only used to represent feature attribution score within range
[0, 1] for ModelDeploymentMonitoringObjectiveType.FEATURE_ATTRIBUTION_SKEW and
ModelDeploymentMonitoringObjectiveType.FEATURE_ATTRIBUTION_DRIFT.
Corresponds to the JSON property score
21363 21364 21365 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21363 def score @score end |
#start_time ⇒ String
The start timestamp of window where stats were generated. For objectives where
time window doesn't make sense (e.g. Featurestore Snapshot Monitoring),
start_time is only used to indicate the monitoring intervals, so it always
equals to (end_time - monitoring_interval).
Corresponds to the JSON property startTime
21371 21372 21373 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21371 def start_time @start_time end |
#stats_uri ⇒ String
Path of the stats file for current feature values in Cloud Storage bucket.
Format: gs:////stats. Example: gs://monitoring_bucket/feature_name/stats.
Stats are stored as binary format with Protobuf message tensorflow.metadata.
v0.FeatureNameStatistics.
Corresponds to the JSON property statsUri
21380 21381 21382 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21380 def stats_uri @stats_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21387 21388 21389 21390 21391 21392 21393 21394 21395 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21387 def update!(**args) @anomaly_detection_threshold = args[:anomaly_detection_threshold] if args.key?(:anomaly_detection_threshold) @anomaly_uri = args[:anomaly_uri] if args.key?(:anomaly_uri) @distribution_deviation = args[:distribution_deviation] if args.key?(:distribution_deviation) @end_time = args[:end_time] if args.key?(:end_time) @score = args[:score] if args.key?(:score) @start_time = args[:start_time] if args.key?(:start_time) @stats_uri = args[:stats_uri] if args.key?(:stats_uri) end |