Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureValueMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Metadata of feature value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureValueMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureValueMetadata.



22330
22331
22332
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generate_timeString

Feature generation timestamp. Typically, it is provided by user at feature ingestion time. If not, feature store will use the system timestamp when the data is ingested into feature store. Legacy Feature Store: For streaming ingestion, the time, aligned by days, must be no older than five years (1825 days) and no later than one year (366 days) in the future. Corresponds to the JSON property generateTime

Returns:

  • (String)


22328
22329
22330
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22328

def generate_time
  @generate_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22335
22336
22337
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22335

def update!(**args)
  @generate_time = args[:generate_time] if args.key?(:generate_time)
end