Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureView
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
FeatureView is representation of values that the FeatureOnlineStore will serve based on its syncConfig.
Instance Attribute Summary collapse
-
#big_query_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewBigQuerySource
Optional.
-
#bigtable_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewBigtableMetadata
Metadata for the Cloud Bigtable that supports directly interacting Bigtable instances.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#feature_registry_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySource
A Feature Registry source for features that need to be synced to Online Store.
-
#index_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewIndexConfig
Configuration for vector indexing.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#optimized_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account_email ⇒ String
Output only.
-
#service_agent_type ⇒ String
Optional.
-
#sync_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSyncConfig
Configuration for Sync.
-
#update_time ⇒ String
Output only.
-
#vector_search_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfig
Deprecated.
-
#vertex_rag_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVertexRagSource
A Vertex Rag source for features that need to be synced to Online Store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureView
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureView
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureView.
24344 24345 24346 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24344 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewBigQuerySource
Optional. Configures how data is supposed to be extracted from a BigQuery
source to be loaded onto the FeatureOnlineStore.
Corresponds to the JSON property bigQuerySource
24243 24244 24245 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24243 def big_query_source @big_query_source end |
#bigtable_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewBigtableMetadata
Metadata for the Cloud Bigtable that supports directly interacting Bigtable
instances.
Corresponds to the JSON property bigtableMetadata
24249 24250 24251 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24249 def @bigtable_metadata end |
#create_time ⇒ String
Output only. Timestamp when this FeatureView was created.
Corresponds to the JSON property createTime
24254 24255 24256 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24254 def create_time @create_time end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
24260 24261 24262 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24260 def etag @etag end |
#feature_registry_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySource
A Feature Registry source for features that need to be synced to Online Store.
Corresponds to the JSON property featureRegistrySource
24265 24266 24267 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24265 def feature_registry_source @feature_registry_source end |
#index_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewIndexConfig
Configuration for vector indexing.
Corresponds to the JSON property indexConfig
24270 24271 24272 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24270 def index_config @index_config end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your FeatureViews.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information on and examples of labels. No more than 64 user labels can be
associated with one FeatureOnlineStore(System labels are excluded)." System
reserved label keys are prefixed with "aiplatform.googleapis.com/" and are
immutable.
Corresponds to the JSON property labels
24282 24283 24284 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24282 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureView. Format: projects/project/locations/
location/featureOnlineStores/feature_online_store/featureViews/
feature_view`
Corresponds to the JSON propertyname`
24289 24290 24291 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24289 def name @name end |
#optimized_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
Corresponds to the JSON property optimizedConfig
24294 24295 24296 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24294 def optimized_config @optimized_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
24299 24300 24301 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24299 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
24305 24306 24307 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24305 def satisfies_pzs @satisfies_pzs end |
#service_account_email ⇒ String
Output only. A Service Account unique to this FeatureView. The role bigquery.
dataViewer should be granted to this service account to allow Vertex AI
Feature Store to sync data to the online store.
Corresponds to the JSON property serviceAccountEmail
24313 24314 24315 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24313 def service_account_email @service_account_email end |
#service_agent_type ⇒ String
Optional. Service agent type used during data sync. By default, the Vertex AI
Service Agent is used. When using an IAM Policy to isolate this FeatureView
within a project, a separate service account should be provisioned by setting
this field to SERVICE_AGENT_TYPE_FEATURE_VIEW. This will generate a separate
service account to access the BigQuery source table.
Corresponds to the JSON property serviceAgentType
24322 24323 24324 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24322 def service_agent_type @service_agent_type end |
#sync_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSyncConfig
Configuration for Sync. Only one option is set.
Corresponds to the JSON property syncConfig
24327 24328 24329 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24327 def sync_config @sync_config end |
#update_time ⇒ String
Output only. Timestamp when this FeatureView was last updated.
Corresponds to the JSON property updateTime
24332 24333 24334 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24332 def update_time @update_time end |
#vector_search_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfig
Deprecated. Use IndexConfig instead.
Corresponds to the JSON property vectorSearchConfig
24337 24338 24339 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24337 def vector_search_config @vector_search_config end |
#vertex_rag_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVertexRagSource
A Vertex Rag source for features that need to be synced to Online Store.
Corresponds to the JSON property vertexRagSource
24342 24343 24344 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24342 def vertex_rag_source @vertex_rag_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24349 24350 24351 24352 24353 24354 24355 24356 24357 24358 24359 24360 24361 24362 24363 24364 24365 24366 24367 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24349 def update!(**args) @big_query_source = args[:big_query_source] if args.key?(:big_query_source) @bigtable_metadata = args[:bigtable_metadata] if args.key?(:bigtable_metadata) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @feature_registry_source = args[:feature_registry_source] if args.key?(:feature_registry_source) @index_config = args[:index_config] if args.key?(:index_config) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @optimized_config = args[:optimized_config] if args.key?(:optimized_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account_email = args[:service_account_email] if args.key?(:service_account_email) @service_agent_type = args[:service_agent_type] if args.key?(:service_agent_type) @sync_config = args[:sync_config] if args.key?(:sync_config) @update_time = args[:update_time] if args.key?(:update_time) @vector_search_config = args[:vector_search_config] if args.key?(:vector_search_config) @vertex_rag_source = args[:vertex_rag_source] if args.key?(:vertex_rag_source) end |