Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureView
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
FeatureView is representation of values that the FeatureOnlineStore will serve based on its syncConfig.
Instance Attribute Summary collapse
-
#big_query_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewBigQuerySource
Optional.
-
#bigtable_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewBigtableMetadata
Metadata for the Cloud Bigtable that supports directly interacting Bigtable instances.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#feature_registry_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySource
A Feature Registry source for features that need to be synced to Online Store.
-
#index_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewIndexConfig
Configuration for vector indexing.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#optimized_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account_email ⇒ String
Output only.
-
#service_agent_type ⇒ String
Optional.
-
#sync_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSyncConfig
Configuration for Sync.
-
#update_time ⇒ String
Output only.
-
#vector_search_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfig
Deprecated.
-
#vertex_rag_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVertexRagSource
A Vertex Rag source for features that need to be synced to Online Store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureView
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureView
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureView.
23871 23872 23873 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewBigQuerySource
Optional. Configures how data is supposed to be extracted from a BigQuery
source to be loaded onto the FeatureOnlineStore.
Corresponds to the JSON property bigQuerySource
23770 23771 23772 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23770 def big_query_source @big_query_source end |
#bigtable_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewBigtableMetadata
Metadata for the Cloud Bigtable that supports directly interacting Bigtable
instances.
Corresponds to the JSON property bigtableMetadata
23776 23777 23778 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23776 def @bigtable_metadata end |
#create_time ⇒ String
Output only. Timestamp when this FeatureView was created.
Corresponds to the JSON property createTime
23781 23782 23783 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23781 def create_time @create_time end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
23787 23788 23789 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23787 def etag @etag end |
#feature_registry_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySource
A Feature Registry source for features that need to be synced to Online Store.
Corresponds to the JSON property featureRegistrySource
23792 23793 23794 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23792 def feature_registry_source @feature_registry_source end |
#index_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewIndexConfig
Configuration for vector indexing.
Corresponds to the JSON property indexConfig
23797 23798 23799 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23797 def index_config @index_config end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your FeatureViews.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information on and examples of labels. No more than 64 user labels can be
associated with one FeatureOnlineStore(System labels are excluded)." System
reserved label keys are prefixed with "aiplatform.googleapis.com/" and are
immutable.
Corresponds to the JSON property labels
23809 23810 23811 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23809 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureView. Format: projects/project/locations/
location/featureOnlineStores/feature_online_store/featureViews/
feature_view`
Corresponds to the JSON propertyname`
23816 23817 23818 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23816 def name @name end |
#optimized_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
Corresponds to the JSON property optimizedConfig
23821 23822 23823 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23821 def optimized_config @optimized_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
23826 23827 23828 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23826 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
23832 23833 23834 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23832 def satisfies_pzs @satisfies_pzs end |
#service_account_email ⇒ String
Output only. A Service Account unique to this FeatureView. The role bigquery.
dataViewer should be granted to this service account to allow Vertex AI
Feature Store to sync data to the online store.
Corresponds to the JSON property serviceAccountEmail
23840 23841 23842 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23840 def service_account_email @service_account_email end |
#service_agent_type ⇒ String
Optional. Service agent type used during data sync. By default, the Vertex AI
Service Agent is used. When using an IAM Policy to isolate this FeatureView
within a project, a separate service account should be provisioned by setting
this field to SERVICE_AGENT_TYPE_FEATURE_VIEW. This will generate a separate
service account to access the BigQuery source table.
Corresponds to the JSON property serviceAgentType
23849 23850 23851 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23849 def service_agent_type @service_agent_type end |
#sync_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSyncConfig
Configuration for Sync. Only one option is set.
Corresponds to the JSON property syncConfig
23854 23855 23856 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23854 def sync_config @sync_config end |
#update_time ⇒ String
Output only. Timestamp when this FeatureView was last updated.
Corresponds to the JSON property updateTime
23859 23860 23861 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23859 def update_time @update_time end |
#vector_search_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfig
Deprecated. Use IndexConfig instead.
Corresponds to the JSON property vectorSearchConfig
23864 23865 23866 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23864 def vector_search_config @vector_search_config end |
#vertex_rag_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVertexRagSource
A Vertex Rag source for features that need to be synced to Online Store.
Corresponds to the JSON property vertexRagSource
23869 23870 23871 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23869 def vertex_rag_source @vertex_rag_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23876 23877 23878 23879 23880 23881 23882 23883 23884 23885 23886 23887 23888 23889 23890 23891 23892 23893 23894 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23876 def update!(**args) @big_query_source = args[:big_query_source] if args.key?(:big_query_source) @bigtable_metadata = args[:bigtable_metadata] if args.key?(:bigtable_metadata) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @feature_registry_source = args[:feature_registry_source] if args.key?(:feature_registry_source) @index_config = args[:index_config] if args.key?(:index_config) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @optimized_config = args[:optimized_config] if args.key?(:optimized_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account_email = args[:service_account_email] if args.key?(:service_account_email) @service_agent_type = args[:service_agent_type] if args.key?(:service_agent_type) @sync_config = args[:sync_config] if args.key?(:sync_config) @update_time = args[:update_time] if args.key?(:update_time) @vector_search_config = args[:vector_search_config] if args.key?(:vector_search_config) @vertex_rag_source = args[:vertex_rag_source] if args.key?(:vertex_rag_source) end |