Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

FeatureView is representation of values that the FeatureOnlineStore will serve based on its syncConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureView

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureView.



22628
22629
22630
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_query_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewBigQuerySource

Optional. Configures how data is supposed to be extracted from a BigQuery source to be loaded onto the FeatureOnlineStore. Corresponds to the JSON property bigQuerySource



22527
22528
22529
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22527

def big_query_source
  @big_query_source
end

#bigtable_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewBigtableMetadata

Metadata for the Cloud Bigtable that supports directly interacting Bigtable instances. Corresponds to the JSON property bigtableMetadata



22533
22534
22535
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22533

def 
  @bigtable_metadata
end

#create_timeString

Output only. Timestamp when this FeatureView was created. Corresponds to the JSON property createTime

Returns:

  • (String)


22538
22539
22540
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22538

def create_time
  @create_time
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


22544
22545
22546
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22544

def etag
  @etag
end

#feature_registry_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySource

A Feature Registry source for features that need to be synced to Online Store. Corresponds to the JSON property featureRegistrySource



22549
22550
22551
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22549

def feature_registry_source
  @feature_registry_source
end

#index_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewIndexConfig

Configuration for vector indexing. Corresponds to the JSON property indexConfig



22554
22555
22556
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22554

def index_config
  @index_config
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your FeatureViews. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one FeatureOnlineStore(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


22566
22567
22568
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22566

def labels
  @labels
end

#nameString

Identifier. Name of the FeatureView. Format: projects/project/locations/ location/featureOnlineStores/feature_online_store/featureViews/ feature_view` Corresponds to the JSON propertyname`

Returns:

  • (String)


22573
22574
22575
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22573

def name
  @name
end

#optimized_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig

Configuration for FeatureViews created in Optimized FeatureOnlineStore. Corresponds to the JSON property optimizedConfig



22578
22579
22580
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22578

def optimized_config
  @optimized_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


22583
22584
22585
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22583

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


22589
22590
22591
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22589

def satisfies_pzs
  @satisfies_pzs
end

#service_account_emailString

Output only. A Service Account unique to this FeatureView. The role bigquery. dataViewer should be granted to this service account to allow Vertex AI Feature Store to sync data to the online store. Corresponds to the JSON property serviceAccountEmail

Returns:

  • (String)


22597
22598
22599
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22597

def 
  @service_account_email
end

#service_agent_typeString

Optional. Service agent type used during data sync. By default, the Vertex AI Service Agent is used. When using an IAM Policy to isolate this FeatureView within a project, a separate service account should be provisioned by setting this field to SERVICE_AGENT_TYPE_FEATURE_VIEW. This will generate a separate service account to access the BigQuery source table. Corresponds to the JSON property serviceAgentType

Returns:

  • (String)


22606
22607
22608
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22606

def service_agent_type
  @service_agent_type
end

#sync_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSyncConfig

Configuration for Sync. Only one option is set. Corresponds to the JSON property syncConfig



22611
22612
22613
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22611

def sync_config
  @sync_config
end

#update_timeString

Output only. Timestamp when this FeatureView was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


22616
22617
22618
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22616

def update_time
  @update_time
end

#vector_search_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVectorSearchConfig

Deprecated. Use IndexConfig instead. Corresponds to the JSON property vectorSearchConfig



22621
22622
22623
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22621

def vector_search_config
  @vector_search_config
end

#vertex_rag_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewVertexRagSource

A Vertex Rag source for features that need to be synced to Online Store. Corresponds to the JSON property vertexRagSource



22626
22627
22628
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22626

def vertex_rag_source
  @vertex_rag_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22633
22634
22635
22636
22637
22638
22639
22640
22641
22642
22643
22644
22645
22646
22647
22648
22649
22650
22651
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22633

def update!(**args)
  @big_query_source = args[:big_query_source] if args.key?(:big_query_source)
  @bigtable_metadata = args[:bigtable_metadata] if args.key?(:bigtable_metadata)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @feature_registry_source = args[:feature_registry_source] if args.key?(:feature_registry_source)
  @index_config = args[:index_config] if args.key?(:index_config)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @optimized_config = args[:optimized_config] if args.key?(:optimized_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @service_account_email = args[:service_account_email] if args.key?(:service_account_email)
  @service_agent_type = args[:service_agent_type] if args.key?(:service_agent_type)
  @sync_config = args[:sync_config] if args.key?(:sync_config)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vector_search_config = args[:vector_search_config] if args.key?(:vector_search_config)
  @vertex_rag_source = args[:vertex_rag_source] if args.key?(:vertex_rag_source)
end