Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewBigtableMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewBigtableMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Metadata for the Cloud Bigtable that supports directly interacting Bigtable instances.
Instance Attribute Summary collapse
-
#read_app_profile ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewBigtableMetadata
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureViewBigtableMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewBigtableMetadata
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureViewBigtableMetadata.
16375 16376 16377 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16375 def initialize(**args) update!(**args) end |
Instance Attribute Details
#read_app_profile ⇒ String
Output only. The Bigtable App Profile to use for reading from Bigtable.
Corresponds to the JSON property readAppProfile
16373 16374 16375 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16373 def read_app_profile @read_app_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16380 16381 16382 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16380 def update!(**args) @read_app_profile = args[:read_app_profile] if args.key?(:read_app_profile) end |