Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewDirectWriteRequestDataKeyAndFeatureValuesFeatureFeatureValueAndTimestamp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Feature value and timestamp.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewDirectWriteRequestDataKeyAndFeatureValuesFeatureFeatureValueAndTimestamp

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureViewDirectWriteRequestDataKeyAndFeatureValuesFeatureFeatureValueAndTimestamp.



16520
16521
16522
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16520

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#timestampString

The feature timestamp to store with this value. If not set, then the Feature Store server will generate a timestamp when it receives the write request. Corresponds to the JSON property timestamp

Returns:

  • (String)


16513
16514
16515
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16513

def timestamp
  @timestamp
end

#valueGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureValue

Value for a feature. Corresponds to the JSON property value



16518
16519
16520
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16518

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16525
16526
16527
16528
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16525

def update!(**args)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
  @value = args[:value] if args.key?(:value)
end