Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A Feature Registry source for features that need to be synced to Online Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySource

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySource.



21952
21953
21954
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21952

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feature_groupsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewFeatureRegistrySourceFeatureGroup>

Required. List of features that need to be synced to Online Store. Corresponds to the JSON property featureGroups



21945
21946
21947
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21945

def feature_groups
  @feature_groups
end

#project_numberFixnum

Optional. The project number of the parent project of the Feature Groups. Corresponds to the JSON property projectNumber

Returns:

  • (Fixnum)


21950
21951
21952
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21950

def project_number
  @project_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21957
21958
21959
21960
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21957

def update!(**args)
  @feature_groups = args[:feature_groups] if args.key?(:feature_groups)
  @project_number = args[:project_number] if args.key?(:project_number)
end