Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
Instance Attribute Summary collapse
-
#automatic_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AutomaticResources
A description of resources that to large degree are decided by Agent Platform, and require only a modest additional configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureViewOptimizedConfig.
22882 22883 22884 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22882 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automatic_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AutomaticResources
A description of resources that to large degree are decided by Agent Platform,
and require only a modest additional configuration. Each Model supporting
these resources documents its specific guidelines.
Corresponds to the JSON property automaticResources
22880 22881 22882 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22880 def automatic_resources @automatic_resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22887 22888 22889 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22887 def update!(**args) @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources) end |