Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSync

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

FeatureViewSync is a representation of sync operation which copies data from data source to Feature View in Online Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewSync

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureViewSync.



24368
24369
24370
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24368

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when this FeatureViewSync is created. Creation of a FeatureViewSync means that the job is pending / waiting for sufficient resources but may not have started the actual data transfer yet. Corresponds to the JSON property createTime

Returns:

  • (String)


24323
24324
24325
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24323

def create_time
  @create_time
end

#final_statusGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property finalStatus



24333
24334
24335
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24333

def final_status
  @final_status
end

#nameString

Identifier. Name of the FeatureViewSync. Format: projects/project/locations/ location/featureOnlineStores/feature_online_store/featureViews/ feature_view/featureViewSyncs/feature_view_sync` Corresponds to the JSON propertyname`

Returns:

  • (String)


24340
24341
24342
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24340

def name
  @name
end

#run_timeGoogle::Apis::AiplatformV1beta1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property runTime



24348
24349
24350
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24348

def run_time
  @run_time
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


24353
24354
24355
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24353

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


24359
24360
24361
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24359

def satisfies_pzs
  @satisfies_pzs
end

#sync_summaryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSyncSyncSummary

Summary from the Sync job. For continuous syncs, the summary is updated periodically. For batch syncs, it gets updated on completion of the sync. Corresponds to the JSON property syncSummary



24366
24367
24368
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24366

def sync_summary
  @sync_summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24373
24374
24375
24376
24377
24378
24379
24380
24381
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24373

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @final_status = args[:final_status] if args.key?(:final_status)
  @name = args[:name] if args.key?(:name)
  @run_time = args[:run_time] if args.key?(:run_time)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @sync_summary = args[:sync_summary] if args.key?(:sync_summary)
end