Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSync
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSync
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
FeatureViewSync is a representation of sync operation which copies data from data source to Feature View in Online Store.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#final_status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#name ⇒ String
Identifier.
-
#run_time ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#sync_summary ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSyncSyncSummary
Summary from the Sync job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewSync
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureViewSync.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewSync
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureViewSync.
23125 23126 23127 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23125 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when this FeatureViewSync is created. Creation of a
FeatureViewSync means that the job is pending / waiting for sufficient
resources but may not have started the actual data transfer yet.
Corresponds to the JSON property createTime
23080 23081 23082 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23080 def create_time @create_time end |
#final_status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property finalStatus
23090 23091 23092 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23090 def final_status @final_status end |
#name ⇒ String
Identifier. Name of the FeatureViewSync. Format: projects/project/locations/
location/featureOnlineStores/feature_online_store/featureViews/
feature_view/featureViewSyncs/feature_view_sync`
Corresponds to the JSON propertyname`
23097 23098 23099 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23097 def name @name end |
#run_time ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property runTime
23105 23106 23107 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23105 def run_time @run_time end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
23110 23111 23112 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23110 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
23116 23117 23118 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23116 def satisfies_pzs @satisfies_pzs end |
#sync_summary ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSyncSyncSummary
Summary from the Sync job. For continuous syncs, the summary is updated
periodically. For batch syncs, it gets updated on completion of the sync.
Corresponds to the JSON property syncSummary
23123 23124 23125 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23123 def sync_summary @sync_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23130 23131 23132 23133 23134 23135 23136 23137 23138 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23130 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @final_status = args[:final_status] if args.key?(:final_status) @name = args[:name] if args.key?(:name) @run_time = args[:run_time] if args.key?(:run_time) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @sync_summary = args[:sync_summary] if args.key?(:sync_summary) end |