Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSync

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

FeatureViewSync is a representation of sync operation which copies data from data source to Feature View in Online Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewSync

Returns a new instance of GoogleCloudAiplatformV1beta1FeatureViewSync.



16876
16877
16878
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16876

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when this FeatureViewSync is created. Creation of a FeatureViewSync means that the job is pending / waiting for sufficient resources but may not have started the actual data transfer yet. Corresponds to the JSON property createTime

Returns:

  • (String)


16831
16832
16833
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16831

def create_time
  @create_time
end

#final_statusGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property finalStatus



16841
16842
16843
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16841

def final_status
  @final_status
end

#nameString

Identifier. Name of the FeatureViewSync. Format: projects/project/locations/ location/featureOnlineStores/feature_online_store/featureViews/ feature_view/featureViewSyncs/feature_view_sync` Corresponds to the JSON propertyname`

Returns:

  • (String)


16848
16849
16850
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16848

def name
  @name
end

#run_timeGoogle::Apis::AiplatformV1beta1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property runTime



16856
16857
16858
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16856

def run_time
  @run_time
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


16861
16862
16863
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16861

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


16867
16868
16869
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16867

def satisfies_pzs
  @satisfies_pzs
end

#sync_summaryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSyncSyncSummary

Summary from the Sync job. For continuous syncs, the summary is updated periodically. For batch syncs, it gets updated on completion of the sync. Corresponds to the JSON property syncSummary



16874
16875
16876
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16874

def sync_summary
  @sync_summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16881
16882
16883
16884
16885
16886
16887
16888
16889
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 16881

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @final_status = args[:final_status] if args.key?(:final_status)
  @name = args[:name] if args.key?(:name)
  @run_time = args[:run_time] if args.key?(:run_time)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @sync_summary = args[:sync_summary] if args.key?(:sync_summary)
end