Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSyncSyncSummary
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewSyncSyncSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Summary from the Sync job. For continuous syncs, the summary is updated periodically. For batch syncs, it gets updated on completion of the sync.
Instance Attribute Summary collapse
-
#row_synced ⇒ Fixnum
Output only.
-
#system_watermark_time ⇒ String
Lower bound of the system time watermark for the sync job.
-
#total_slot ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewSyncSyncSummary
constructor
A new instance of GoogleCloudAiplatformV1beta1FeatureViewSyncSyncSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeatureViewSyncSyncSummary
Returns a new instance of GoogleCloudAiplatformV1beta1FeatureViewSyncSyncSummary.
23509 23510 23511 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23509 def initialize(**args) update!(**args) end |
Instance Attribute Details
#row_synced ⇒ Fixnum
Output only. Total number of rows synced.
Corresponds to the JSON property rowSynced
23496 23497 23498 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23496 def row_synced @row_synced end |
#system_watermark_time ⇒ String
Lower bound of the system time watermark for the sync job. This is only set
for continuously syncing feature views.
Corresponds to the JSON property systemWatermarkTime
23502 23503 23504 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23502 def system_watermark_time @system_watermark_time end |
#total_slot ⇒ Fixnum
Output only. BigQuery slot milliseconds consumed for the sync job.
Corresponds to the JSON property totalSlot
23507 23508 23509 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23507 def total_slot @total_slot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23514 23515 23516 23517 23518 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23514 def update!(**args) @row_synced = args[:row_synced] if args.key?(:row_synced) @system_watermark_time = args[:system_watermark_time] if args.key?(:system_watermark_time) @total_slot = args[:total_slot] if args.key?(:total_slot) end |