Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Featurestore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Vertex AI Feature Store provides a centralized repository for organizing, storing, and serving ML features. The Featurestore is a top-level container for your features and their values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Featurestore

Returns a new instance of GoogleCloudAiplatformV1beta1Featurestore.



17163
17164
17165
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Featurestore was created. Corresponds to the JSON property createTime

Returns:

  • (String)


17094
17095
17096
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17094

def create_time
  @create_time
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



17100
17101
17102
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17100

def encryption_spec
  @encryption_spec
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


17106
17107
17108
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17106

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your Featurestore. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one Featurestore(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


17117
17118
17119
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17117

def labels
  @labels
end

#nameString

Output only. Name of the Featurestore. Format: projects/project/locations/ location/featurestores/featurestore` Corresponds to the JSON propertyname`

Returns:

  • (String)


17123
17124
17125
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17123

def name
  @name
end

#online_serving_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeaturestoreOnlineServingConfig

OnlineServingConfig specifies the details for provisioning online serving resources. Corresponds to the JSON property onlineServingConfig



17129
17130
17131
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17129

def online_serving_config
  @online_serving_config
end

#online_storage_ttl_daysFixnum

Optional. TTL in days for feature values that will be stored in online serving storage. The Feature Store online storage periodically removes obsolete feature values older than online_storage_ttl_days since the feature generation time. Note that online_storage_ttl_days should be less than or equal to offline_storage_ttl_days for each EntityType under a featurestore. If not set, default to 4000 days Corresponds to the JSON property onlineStorageTtlDays

Returns:

  • (Fixnum)


17139
17140
17141
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17139

def online_storage_ttl_days
  @online_storage_ttl_days
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


17144
17145
17146
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17144

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


17150
17151
17152
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17150

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. State of the featurestore. Corresponds to the JSON property state

Returns:

  • (String)


17156
17157
17158
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17156

def state
  @state
end

#update_timeString

Output only. Timestamp when this Featurestore was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


17161
17162
17163
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17161

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17168
17169
17170
17171
17172
17173
17174
17175
17176
17177
17178
17179
17180
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17168

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @online_serving_config = args[:online_serving_config] if args.key?(:online_serving_config)
  @online_storage_ttl_days = args[:online_storage_ttl_days] if args.key?(:online_storage_ttl_days)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end