Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration of how features in Featurestore are monitored.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfig

Returns a new instance of GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfig.



23776
23777
23778
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23776

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categorical_threshold_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigThresholdConfig

The config for Featurestore Monitoring threshold. Corresponds to the JSON property categoricalThresholdConfig



23755
23756
23757
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23755

def categorical_threshold_config
  @categorical_threshold_config
end

#import_features_analysisGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigImportFeaturesAnalysis

Configuration of the Featurestore's ImportFeature Analysis Based Monitoring. This type of analysis generates statistics for values of each Feature imported by every ImportFeatureValues operation. Corresponds to the JSON property importFeaturesAnalysis



23762
23763
23764
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23762

def import_features_analysis
  @import_features_analysis
end

#numerical_threshold_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigThresholdConfig

The config for Featurestore Monitoring threshold. Corresponds to the JSON property numericalThresholdConfig



23767
23768
23769
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23767

def numerical_threshold_config
  @numerical_threshold_config
end

#snapshot_analysisGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeaturestoreMonitoringConfigSnapshotAnalysis

Configuration of the Featurestore's Snapshot Analysis Based Monitoring. This type of analysis generates statistics for each Feature based on a snapshot of the latest feature value of each entities every monitoring_interval. Corresponds to the JSON property snapshotAnalysis



23774
23775
23776
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23774

def snapshot_analysis
  @snapshot_analysis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23781
23782
23783
23784
23785
23786
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23781

def update!(**args)
  @categorical_threshold_config = args[:categorical_threshold_config] if args.key?(:categorical_threshold_config)
  @import_features_analysis = args[:import_features_analysis] if args.key?(:import_features_analysis)
  @numerical_threshold_config = args[:numerical_threshold_config] if args.key?(:numerical_threshold_config)
  @snapshot_analysis = args[:snapshot_analysis] if args.key?(:snapshot_analysis)
end