Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeaturestoreOnlineServingConfigScaling
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeaturestoreOnlineServingConfigScaling
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Online serving scaling configuration. If min_node_count and max_node_count are set to the same value, the cluster will be configured with the fixed number of node (no auto-scaling).
Instance Attribute Summary collapse
-
#cpu_utilization_target ⇒ Fixnum
Optional.
-
#max_node_count ⇒ Fixnum
The maximum number of nodes to scale up to.
-
#min_node_count ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeaturestoreOnlineServingConfigScaling
constructor
A new instance of GoogleCloudAiplatformV1beta1FeaturestoreOnlineServingConfigScaling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeaturestoreOnlineServingConfigScaling
Returns a new instance of GoogleCloudAiplatformV1beta1FeaturestoreOnlineServingConfigScaling.
22174 22175 22176 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpu_utilization_target ⇒ Fixnum
Optional. The cpu utilization that the Autoscaler should be trying to achieve.
This number is on a scale from 0 (no utilization) to 100 (total utilization),
and is limited between 10 and 80. When a cluster's CPU utilization exceeds the
target that you have set, Bigtable immediately adds nodes to the cluster. When
CPU utilization is substantially lower than the target, Bigtable removes nodes.
If not set or set to 0, default to 50.
Corresponds to the JSON property cpuUtilizationTarget
22160 22161 22162 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22160 def cpu_utilization_target @cpu_utilization_target end |
#max_node_count ⇒ Fixnum
The maximum number of nodes to scale up to. Must be greater than
min_node_count, and less than or equal to 10 times of 'min_node_count'.
Corresponds to the JSON property maxNodeCount
22166 22167 22168 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22166 def max_node_count @max_node_count end |
#min_node_count ⇒ Fixnum
Required. The minimum number of nodes to scale down to. Must be greater than
or equal to 1.
Corresponds to the JSON property minNodeCount
22172 22173 22174 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22172 def min_node_count @min_node_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22179 22180 22181 22182 22183 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22179 def update!(**args) @cpu_utilization_target = args[:cpu_utilization_target] if args.key?(:cpu_utilization_target) @max_node_count = args[:max_node_count] if args.key?(:max_node_count) @min_node_count = args[:min_node_count] if args.key?(:min_node_count) end |