Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeedbackContext
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeedbackContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Feedback context is a resource that represents additional information about the conversation where the feedback was given, such as the conversation history, system instructions, etc. If provided, feedback context allows to correlate the feedback with the conversation, even if the original session is deleted or not available.
Instance Attribute Summary collapse
-
#context_events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SessionEvent>
Optional.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeedbackContext
constructor
A new instance of GoogleCloudAiplatformV1beta1FeedbackContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeedbackContext
Returns a new instance of GoogleCloudAiplatformV1beta1FeedbackContext.
24912 24913 24914 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SessionEvent>
Optional. The session events from the originating session.
Corresponds to the JSON property contextEvents
24903 24904 24905 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24903 def context_events @context_events end |
#name ⇒ String
Identifier. The resource name. Assigned by the server on create. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
feedbackEntries/feedback_entry/feedbackContext
Corresponds to the JSON property name
24910 24911 24912 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24910 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24917 24918 24919 24920 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24917 def update!(**args) @context_events = args[:context_events] if args.key?(:context_events) @name = args[:name] if args.key?(:name) end |