Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeedbackEntry
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeedbackEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
FeedbackEntry is a resource that represents a user's feedback on a conversation with an agent.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_metadata ⇒ Hash<String,String>
Optional.
-
#event_id ⇒ String
Required.
-
#feedback_labels ⇒ Array<String>
Corresponds to the JSON property
feedbackLabels. -
#feedback_text ⇒ String
Optional.
-
#feedback_type ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#session_id ⇒ String
Required.
-
#source ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#user_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeedbackEntry
constructor
A new instance of GoogleCloudAiplatformV1beta1FeedbackEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeedbackEntry
Returns a new instance of GoogleCloudAiplatformV1beta1FeedbackEntry.
25462 25463 25464 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25462 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the entry was created.
Corresponds to the JSON property createTime
25404 25405 25406 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25404 def create_time @create_time end |
#custom_metadata ⇒ Hash<String,String>
Optional. Additional key-value metadata associated with the feedback.
Corresponds to the JSON property customMetadata
25409 25410 25411 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25409 def @custom_metadata end |
#event_id ⇒ String
Required. The ID of the event within the session that the feedback relates to.
Corresponds to the JSON property eventId
25414 25415 25416 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25414 def event_id @event_id end |
#feedback_labels ⇒ Array<String>
Corresponds to the JSON property feedbackLabels
25419 25420 25421 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25419 def feedback_labels @feedback_labels end |
#feedback_text ⇒ String
Optional. Qualitative free-form comments provided by the user.
Corresponds to the JSON property feedbackText
25424 25425 25426 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25424 def feedback_text @feedback_text end |
#feedback_type ⇒ String
Required. The coarse-grained type of feedback provided by the user. Must be
set to a value other than FEEDBACK_TYPE_UNSPECIFIED.
Corresponds to the JSON property feedbackType
25430 25431 25432 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25430 def feedback_type @feedback_type end |
#name ⇒ String
Identifier. The resource name. Assigned by the server on create. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
feedbackEntries/feedback_entry`
Corresponds to the JSON propertyname`
25437 25438 25439 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25437 def name @name end |
#session_id ⇒ String
Required. The ID of the session that the feedback relates to.
Corresponds to the JSON property sessionId
25442 25443 25444 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25442 def session_id @session_id end |
#source ⇒ String
Optional. The surface that the feedback originated from.
Corresponds to the JSON property source
25447 25448 25449 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25447 def source @source end |
#update_time ⇒ String
Output only. The time at which the entry was most recently updated.
Corresponds to the JSON property updateTime
25452 25453 25454 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25452 def update_time @update_time end |
#user_id ⇒ String
Optional. A caller-supplied identifier for the user who provided the feedback.
The semantics of this field (for example whether it is an opaque token, a
hashed value, or a user-visible identifier) are determined by the calling
application.
Corresponds to the JSON property userId
25460 25461 25462 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25460 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25467 25468 25469 25470 25471 25472 25473 25474 25475 25476 25477 25478 25479 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25467 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata) @event_id = args[:event_id] if args.key?(:event_id) @feedback_labels = args[:feedback_labels] if args.key?(:feedback_labels) @feedback_text = args[:feedback_text] if args.key?(:feedback_text) @feedback_type = args[:feedback_type] if args.key?(:feedback_type) @name = args[:name] if args.key?(:name) @session_id = args[:session_id] if args.key?(:session_id) @source = args[:source] if args.key?(:source) @update_time = args[:update_time] if args.key?(:update_time) @user_id = args[:user_id] if args.key?(:user_id) end |