Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeedbackEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

FeedbackEntry is a resource that represents a user's feedback on a conversation with an agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeedbackEntry

Returns a new instance of GoogleCloudAiplatformV1beta1FeedbackEntry.



24989
24990
24991
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the entry was created. Corresponds to the JSON property createTime

Returns:

  • (String)


24931
24932
24933
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24931

def create_time
  @create_time
end

#custom_metadataHash<String,String>

Optional. Additional key-value metadata associated with the feedback. Corresponds to the JSON property customMetadata

Returns:

  • (Hash<String,String>)


24936
24937
24938
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24936

def 
  @custom_metadata
end

#event_idString

Required. The ID of the event within the session that the feedback relates to. Corresponds to the JSON property eventId

Returns:

  • (String)


24941
24942
24943
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24941

def event_id
  @event_id
end

#feedback_labelsArray<String>

Corresponds to the JSON property feedbackLabels

Returns:

  • (Array<String>)


24946
24947
24948
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24946

def feedback_labels
  @feedback_labels
end

#feedback_textString

Optional. Qualitative free-form comments provided by the user. Corresponds to the JSON property feedbackText

Returns:

  • (String)


24951
24952
24953
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24951

def feedback_text
  @feedback_text
end

#feedback_typeString

Required. The coarse-grained type of feedback provided by the user. Must be set to a value other than FEEDBACK_TYPE_UNSPECIFIED. Corresponds to the JSON property feedbackType

Returns:

  • (String)


24957
24958
24959
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24957

def feedback_type
  @feedback_type
end

#nameString

Identifier. The resource name. Assigned by the server on create. Format: projects/project/locations/location/reasoningEngines/reasoning_engine/ feedbackEntries/feedback_entry` Corresponds to the JSON propertyname`

Returns:

  • (String)


24964
24965
24966
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24964

def name
  @name
end

#session_idString

Required. The ID of the session that the feedback relates to. Corresponds to the JSON property sessionId

Returns:

  • (String)


24969
24970
24971
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24969

def session_id
  @session_id
end

#sourceString

Optional. The surface that the feedback originated from. Corresponds to the JSON property source

Returns:

  • (String)


24974
24975
24976
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24974

def source
  @source
end

#update_timeString

Output only. The time at which the entry was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


24979
24980
24981
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24979

def update_time
  @update_time
end

#user_idString

Optional. A caller-supplied identifier for the user who provided the feedback. The semantics of this field (for example whether it is an opaque token, a hashed value, or a user-visible identifier) are determined by the calling application. Corresponds to the JSON property userId

Returns:

  • (String)


24987
24988
24989
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24987

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24994
24995
24996
24997
24998
24999
25000
25001
25002
25003
25004
25005
25006
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24994

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata)
  @event_id = args[:event_id] if args.key?(:event_id)
  @feedback_labels = args[:feedback_labels] if args.key?(:feedback_labels)
  @feedback_text = args[:feedback_text] if args.key?(:feedback_text)
  @feedback_type = args[:feedback_type] if args.key?(:feedback_type)
  @name = args[:name] if args.key?(:name)
  @session_id = args[:session_id] if args.key?(:session_id)
  @source = args[:source] if args.key?(:source)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_id = args[:user_id] if args.key?(:user_id)
end