Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeedbackEntry
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeedbackEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
FeedbackEntry is a resource that represents a user's feedback on a conversation with an agent.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_metadata ⇒ Hash<String,String>
Optional.
-
#event_id ⇒ String
Required.
-
#feedback_labels ⇒ Array<String>
Corresponds to the JSON property
feedbackLabels. -
#feedback_text ⇒ String
Optional.
-
#feedback_type ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#session_id ⇒ String
Required.
-
#source ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#user_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeedbackEntry
constructor
A new instance of GoogleCloudAiplatformV1beta1FeedbackEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FeedbackEntry
Returns a new instance of GoogleCloudAiplatformV1beta1FeedbackEntry.
24062 24063 24064 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24062 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the entry was created.
Corresponds to the JSON property createTime
24004 24005 24006 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24004 def create_time @create_time end |
#custom_metadata ⇒ Hash<String,String>
Optional. Additional key-value metadata associated with the feedback.
Corresponds to the JSON property customMetadata
24009 24010 24011 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24009 def @custom_metadata end |
#event_id ⇒ String
Required. The ID of the event within the session that the feedback relates to.
Corresponds to the JSON property eventId
24014 24015 24016 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24014 def event_id @event_id end |
#feedback_labels ⇒ Array<String>
Corresponds to the JSON property feedbackLabels
24019 24020 24021 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24019 def feedback_labels @feedback_labels end |
#feedback_text ⇒ String
Optional. Qualitative free-form comments provided by the user.
Corresponds to the JSON property feedbackText
24024 24025 24026 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24024 def feedback_text @feedback_text end |
#feedback_type ⇒ String
Required. The coarse-grained type of feedback provided by the user. Must be
set to a value other than FEEDBACK_TYPE_UNSPECIFIED.
Corresponds to the JSON property feedbackType
24030 24031 24032 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24030 def feedback_type @feedback_type end |
#name ⇒ String
Identifier. The resource name. Assigned by the server on create. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
feedbackEntries/feedback_entry`
Corresponds to the JSON propertyname`
24037 24038 24039 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24037 def name @name end |
#session_id ⇒ String
Required. The ID of the session that the feedback relates to.
Corresponds to the JSON property sessionId
24042 24043 24044 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24042 def session_id @session_id end |
#source ⇒ String
Optional. The surface that the feedback originated from.
Corresponds to the JSON property source
24047 24048 24049 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24047 def source @source end |
#update_time ⇒ String
Output only. The time at which the entry was most recently updated.
Corresponds to the JSON property updateTime
24052 24053 24054 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24052 def update_time @update_time end |
#user_id ⇒ String
Optional. A caller-supplied identifier for the user who provided the feedback.
The semantics of this field (for example whether it is an opaque token, a
hashed value, or a user-visible identifier) are determined by the calling
application.
Corresponds to the JSON property userId
24060 24061 24062 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24060 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24067 24068 24069 24070 24071 24072 24073 24074 24075 24076 24077 24078 24079 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24067 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata) @event_id = args[:event_id] if args.key?(:event_id) @feedback_labels = args[:feedback_labels] if args.key?(:feedback_labels) @feedback_text = args[:feedback_text] if args.key?(:feedback_text) @feedback_type = args[:feedback_type] if args.key?(:feedback_type) @name = args[:name] if args.key?(:name) @session_id = args[:session_id] if args.key?(:session_id) @source = args[:source] if args.key?(:source) @update_time = args[:update_time] if args.key?(:update_time) @user_id = args[:user_id] if args.key?(:user_id) end |