Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FetchExamplesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ExampleStoreService.FetchExamples.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FetchExamplesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1FetchExamplesRequest.



24111
24112
24113
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#example_idsArray<String>

Optional. Example IDs to fetch. If both metadata filters and Example IDs are specified, then both ID and metadata filtering will be applied. Corresponds to the JSON property exampleIds

Returns:

  • (Array<String>)


24090
24091
24092
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24090

def example_ids
  @example_ids
end

#page_sizeFixnum

Optional. The maximum number of examples to return. The service may return fewer than this value. If unspecified, at most 100 examples will be returned. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


24096
24097
24098
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24096

def page_size
  @page_size
end

#page_tokenString

Optional. The next_page_token value returned from a previous list ExampleStoreService.FetchExamplesResponse call. Corresponds to the JSON property pageToken

Returns:

  • (String)


24102
24103
24104
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24102

def page_token
  @page_token
end

#stored_contents_example_filterGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleFilter

The metadata filters that will be used to remove or fetch StoredContentsExamples. If a field is unspecified, then no filtering for that field will be applied. Corresponds to the JSON property storedContentsExampleFilter



24109
24110
24111
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24109

def stored_contents_example_filter
  @stored_contents_example_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24116
24117
24118
24119
24120
24121
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24116

def update!(**args)
  @example_ids = args[:example_ids] if args.key?(:example_ids)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @stored_contents_example_filter = args[:stored_contents_example_filter] if args.key?(:stored_contents_example_filter)
end