Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FetchExamplesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FetchExamplesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ExampleStoreService.FetchExamples.
Instance Attribute Summary collapse
-
#example_ids ⇒ Array<String>
Optional.
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#stored_contents_example_filter ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleFilter
The metadata filters that will be used to remove or fetch StoredContentsExamples.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FetchExamplesRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1FetchExamplesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FetchExamplesRequest
Returns a new instance of GoogleCloudAiplatformV1beta1FetchExamplesRequest.
22712 22713 22714 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#example_ids ⇒ Array<String>
Optional. Example IDs to fetch. If both metadata filters and Example IDs are
specified, then both ID and metadata filtering will be applied.
Corresponds to the JSON property exampleIds
22691 22692 22693 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22691 def example_ids @example_ids end |
#page_size ⇒ Fixnum
Optional. The maximum number of examples to return. The service may return
fewer than this value. If unspecified, at most 100 examples will be returned.
Corresponds to the JSON property pageSize
22697 22698 22699 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22697 def page_size @page_size end |
#page_token ⇒ String
Optional. The next_page_token value returned from a previous list
ExampleStoreService.FetchExamplesResponse call.
Corresponds to the JSON property pageToken
22703 22704 22705 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22703 def page_token @page_token end |
#stored_contents_example_filter ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleFilter
The metadata filters that will be used to remove or fetch
StoredContentsExamples. If a field is unspecified, then no filtering for that
field will be applied.
Corresponds to the JSON property storedContentsExampleFilter
22710 22711 22712 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22710 def stored_contents_example_filter @stored_contents_example_filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22717 22718 22719 22720 22721 22722 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22717 def update!(**args) @example_ids = args[:example_ids] if args.key?(:example_ids) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @stored_contents_example_filter = args[:stored_contents_example_filter] if args.key?(:stored_contents_example_filter) end |