Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FetchExamplesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ExampleStoreService.FetchExamples.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FetchExamplesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1FetchExamplesRequest.



17429
17430
17431
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#example_idsArray<String>

Optional. Example IDs to fetch. If both metadata filters and Example IDs are specified, then both ID and metadata filtering will be applied. Corresponds to the JSON property exampleIds

Returns:

  • (Array<String>)


17408
17409
17410
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17408

def example_ids
  @example_ids
end

#page_sizeFixnum

Optional. The maximum number of examples to return. The service may return fewer than this value. If unspecified, at most 100 examples will be returned. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


17414
17415
17416
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17414

def page_size
  @page_size
end

#page_tokenString

Optional. The next_page_token value returned from a previous list ExampleStoreService.FetchExamplesResponse call. Corresponds to the JSON property pageToken

Returns:

  • (String)


17420
17421
17422
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17420

def page_token
  @page_token
end

#stored_contents_example_filterGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleFilter

The metadata filters that will be used to remove or fetch StoredContentsExamples. If a field is unspecified, then no filtering for that field will be applied. Corresponds to the JSON property storedContentsExampleFilter



17427
17428
17429
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17427

def stored_contents_example_filter
  @stored_contents_example_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17434
17435
17436
17437
17438
17439
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17434

def update!(**args)
  @example_ids = args[:example_ids] if args.key?(:example_ids)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @stored_contents_example_filter = args[:stored_contents_example_filter] if args.key?(:stored_contents_example_filter)
end