Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FetchExamplesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FetchExamplesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for ExampleStoreService.FetchExamples.
Instance Attribute Summary collapse
-
#examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example>
The examples in the Example Store that satisfy the metadata filters.
-
#next_page_token ⇒ String
A token, which can be sent as FetchExamplesRequest.page_token to retrieve the next page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FetchExamplesResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1FetchExamplesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FetchExamplesResponse
Returns a new instance of GoogleCloudAiplatformV1beta1FetchExamplesResponse.
17391 17392 17393 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17391 def initialize(**args) update!(**args) end |
Instance Attribute Details
#examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example>
The examples in the Example Store that satisfy the metadata filters.
Corresponds to the JSON property examples
17383 17384 17385 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17383 def examples @examples end |
#next_page_token ⇒ String
A token, which can be sent as FetchExamplesRequest.page_token to retrieve the
next page. Absence of this field indicates there are no subsequent pages.
Corresponds to the JSON property nextPageToken
17389 17390 17391 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17389 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17396 17397 17398 17399 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17396 def update!(**args) @examples = args[:examples] if args.key?(:examples) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |