Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FetchFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for FeatureOnlineStoreService.FetchFeatureValues. All the features under the requested feature view will be returned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FetchFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1FetchFeatureValuesRequest.



24178
24179
24180
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_formatString

Optional. Response data format. If not set, FeatureViewDataFormat.KEY_VALUE will be used. Corresponds to the JSON property dataFormat

Returns:

  • (String)


24159
24160
24161
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24159

def data_format
  @data_format
end

#data_keyGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewDataKey

Lookup key for a feature view. Corresponds to the JSON property dataKey



24164
24165
24166
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24164

def data_key
  @data_key
end

#formatString

Specify response data format. If not set, KeyValue format will be used. Deprecated. Use FetchFeatureValuesRequest.data_format. Corresponds to the JSON property format

Returns:

  • (String)


24170
24171
24172
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24170

def format
  @format
end

#idString

Simple ID. The whole string will be used as is to identify Entity to fetch feature values for. Corresponds to the JSON property id

Returns:

  • (String)


24176
24177
24178
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24176

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24183
24184
24185
24186
24187
24188
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24183

def update!(**args)
  @data_format = args[:data_format] if args.key?(:data_format)
  @data_key = args[:data_key] if args.key?(:data_key)
  @format = args[:format] if args.key?(:format)
  @id = args[:id] if args.key?(:id)
end