Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FileData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

URI-based data. A FileData message contains a URI pointing to data of a specific media type. It is used to represent images, audio, and video stored in Google Cloud Storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FileData

Returns a new instance of GoogleCloudAiplatformV1beta1FileData.



17629
17630
17631
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of the file. Used to provide a label or filename to distinguish files. This field is only returned in PromptMessage for prompt management. It is used in the Gemini calls only when server side tools ( code_execution, google_search, and url_context) are enabled. Corresponds to the JSON property displayName

Returns:

  • (String)


17617
17618
17619
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17617

def display_name
  @display_name
end

#file_uriString

Required. The URI of the file in Google Cloud Storage. Corresponds to the JSON property fileUri

Returns:

  • (String)


17622
17623
17624
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17622

def file_uri
  @file_uri
end

#mime_typeString

Required. The IANA standard MIME type of the source data. Corresponds to the JSON property mimeType

Returns:

  • (String)


17627
17628
17629
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17627

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17634
17635
17636
17637
17638
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17634

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @file_uri = args[:file_uri] if args.key?(:file_uri)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end