Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FileData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

URI-based data. A FileData message contains a URI pointing to data of a specific media type. It is used to represent images, audio, and video stored in Google Cloud Storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FileData

Returns a new instance of GoogleCloudAiplatformV1beta1FileData.



17563
17564
17565
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17563

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of the file. Used to provide a label or filename to distinguish files. This field is only returned in PromptMessage for prompt management. It is used in the Gemini calls only when server side tools ( code_execution, google_search, and url_context) are enabled. Corresponds to the JSON property displayName

Returns:

  • (String)


17551
17552
17553
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17551

def display_name
  @display_name
end

#file_uriString

Required. The URI of the file in Google Cloud Storage. Corresponds to the JSON property fileUri

Returns:

  • (String)


17556
17557
17558
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17556

def file_uri
  @file_uri
end

#mime_typeString

Required. The IANA standard MIME type of the source data. Corresponds to the JSON property mimeType

Returns:

  • (String)


17561
17562
17563
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17561

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17568
17569
17570
17571
17572
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17568

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @file_uri = args[:file_uri] if args.key?(:file_uri)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end