Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FindNeighborsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The request message for MatchService.FindNeighbors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FindNeighborsRequest

Returns a new instance of GoogleCloudAiplatformV1beta1FindNeighborsRequest.



17740
17741
17742
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17740

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_index_idString

The ID of the DeployedIndex that will serve the request. This request is sent to a specific IndexEndpoint, as per the IndexEndpoint.network. That IndexEndpoint also has IndexEndpoint.deployed_indexes, and each such index has a DeployedIndex.id field. The value of the field below must equal one of the DeployedIndex.id fields of the IndexEndpoint that is being called for this request. Corresponds to the JSON property deployedIndexId

Returns:

  • (String)


17725
17726
17727
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17725

def deployed_index_id
  @deployed_index_id
end

#queriesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FindNeighborsRequestQuery>

The list of queries. Corresponds to the JSON property queries



17730
17731
17732
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17730

def queries
  @queries
end

#return_full_datapointBoolean Also known as: return_full_datapoint?

If set to true, the full datapoints (including all vector values and restricts) of the nearest neighbors are returned. Note that returning full datapoint will significantly increase the latency and cost of the query. Corresponds to the JSON property returnFullDatapoint

Returns:

  • (Boolean)


17737
17738
17739
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17737

def return_full_datapoint
  @return_full_datapoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17745
17746
17747
17748
17749
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17745

def update!(**args)
  @deployed_index_id = args[:deployed_index_id] if args.key?(:deployed_index_id)
  @queries = args[:queries] if args.key?(:queries)
  @return_full_datapoint = args[:return_full_datapoint] if args.key?(:return_full_datapoint)
end