Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FindNeighborsRequestQueryRrf

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Parameters for RRF algorithm that combines search results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FindNeighborsRequestQueryRrf

Returns a new instance of GoogleCloudAiplatformV1beta1FindNeighborsRequestQueryRrf.



17760
17761
17762
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17760

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alphaFloat

Required. Users can provide an alpha value to give more weight to dense vs sparse results. For example, if the alpha is 0, we only return sparse and if the alpha is 1, we only return dense. Corresponds to the JSON property alpha

Returns:

  • (Float)


17758
17759
17760
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17758

def alpha
  @alpha
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17765
17766
17767
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 17765

def update!(**args)
  @alpha = args[:alpha] if args.key?(:alpha)
end