Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FullFineTunedResources
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FullFineTunedResources
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Resources for an fft model.
Instance Attribute Summary collapse
-
#deployment_type ⇒ String
Required.
-
#model_inference_unit_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FullFineTunedResources
constructor
A new instance of GoogleCloudAiplatformV1beta1FullFineTunedResources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FullFineTunedResources
Returns a new instance of GoogleCloudAiplatformV1beta1FullFineTunedResources.
18117 18118 18119 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18117 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_type ⇒ String
Required. The kind of deployment.
Corresponds to the JSON property deploymentType
18104 18105 18106 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18104 def deployment_type @deployment_type end |
#model_inference_unit_count ⇒ Fixnum
Optional. The number of model inference units to use for this deployment. This
can only be specified for DEPLOYMENT_TYPE_PROD. The following table lists the
number of model inference units for different model types: * Gemini 2.5 Flash *
Foundation FMIU: 25 * Expansion FMIU: 4 * Gemini 2.5 Pro * Foundation FMIU:
32 * Expansion FMIU: 16 * Veo 3.0 (undistilled) * Foundation FMIU: 63 *
Expansion FMIU: 7 * Veo 3.0 (distilled) * Foundation FMIU: 30 * Expansion FMIU:
10
Corresponds to the JSON property modelInferenceUnitCount
18115 18116 18117 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18115 def model_inference_unit_count @model_inference_unit_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18122 18123 18124 18125 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18122 def update!(**args) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @model_inference_unit_count = args[:model_inference_unit_count] if args.key?(:model_inference_unit_count) end |