Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionCall

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A predicted FunctionCall returned from the model that contains a string representing the FunctionDeclaration.name and a structured JSON object containing the parameters and their values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionCall

Returns a new instance of GoogleCloudAiplatformV1beta1FunctionCall.



25874
25875
25876
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

Optional. The function parameters and values in JSON object format. See FunctionDeclaration.parameters for parameter details. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


25848
25849
25850
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25848

def args
  @args
end

#idString

Optional. The unique id of the function call. If populated, the client to execute the function_call and return the response with the matching id. Corresponds to the JSON property id

Returns:

  • (String)


25854
25855
25856
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25854

def id
  @id
end

#nameString

Optional. The name of the function to call. Matches FunctionDeclaration.name. Corresponds to the JSON property name

Returns:

  • (String)


25859
25860
25861
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25859

def name
  @name
end

#partial_argsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PartialArg>

Optional. The partial argument value of the function call. If provided, represents the arguments/fields that are streamed incrementally. Corresponds to the JSON property partialArgs



25865
25866
25867
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25865

def partial_args
  @partial_args
end

#will_continueBoolean Also known as: will_continue?

Optional. Whether this is the last part of the FunctionCall. If true, another partial message for the current FunctionCall is expected to follow. Corresponds to the JSON property willContinue

Returns:

  • (Boolean)


25871
25872
25873
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25871

def will_continue
  @will_continue
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25879
25880
25881
25882
25883
25884
25885
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25879

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @partial_args = args[:partial_args] if args.key?(:partial_args)
  @will_continue = args[:will_continue] if args.key?(:will_continue)
end