Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionCall

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A predicted FunctionCall returned from the model that contains a string representing the FunctionDeclaration.name and a structured JSON object containing the parameters and their values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionCall

Returns a new instance of GoogleCloudAiplatformV1beta1FunctionCall.



18199
18200
18201
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18199

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

Optional. The function parameters and values in JSON object format. See FunctionDeclaration.parameters for parameter details. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


18173
18174
18175
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18173

def args
  @args
end

#idString

Optional. The unique id of the function call. If populated, the client to execute the function_call and return the response with the matching id. Corresponds to the JSON property id

Returns:

  • (String)


18179
18180
18181
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18179

def id
  @id
end

#nameString

Optional. The name of the function to call. Matches FunctionDeclaration.name. Corresponds to the JSON property name

Returns:

  • (String)


18184
18185
18186
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18184

def name
  @name
end

#partial_argsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PartialArg>

Optional. The partial argument value of the function call. If provided, represents the arguments/fields that are streamed incrementally. Corresponds to the JSON property partialArgs



18190
18191
18192
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18190

def partial_args
  @partial_args
end

#will_continueBoolean Also known as: will_continue?

Optional. Whether this is the last part of the FunctionCall. If true, another partial message for the current FunctionCall is expected to follow. Corresponds to the JSON property willContinue

Returns:

  • (Boolean)


18196
18197
18198
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18196

def will_continue
  @will_continue
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18204
18205
18206
18207
18208
18209
18210
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18204

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @partial_args = args[:partial_args] if args.key?(:partial_args)
  @will_continue = args[:will_continue] if args.key?(:will_continue)
end