Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionCallingConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionCallingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Function calling config.
Instance Attribute Summary collapse
-
#allowed_function_names ⇒ Array<String>
Optional.
-
#mode ⇒ String
Optional.
-
#stream_function_call_arguments ⇒ Boolean
(also: #stream_function_call_arguments?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionCallingConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1FunctionCallingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionCallingConfig
Returns a new instance of GoogleCloudAiplatformV1beta1FunctionCallingConfig.
18237 18238 18239 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18237 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_function_names ⇒ Array<String>
Optional. Function names to call. Only set when the Mode is ANY. Function
names should match FunctionDeclaration.name. With mode set to ANY, model will
predict a function call from the set of function names provided.
Corresponds to the JSON property allowedFunctionNames
18222 18223 18224 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18222 def allowed_function_names @allowed_function_names end |
#mode ⇒ String
Optional. Function calling mode.
Corresponds to the JSON property mode
18227 18228 18229 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18227 def mode @mode end |
#stream_function_call_arguments ⇒ Boolean Also known as: stream_function_call_arguments?
Optional. When set to true, arguments of a single function call will be
streamed out in multiple parts/contents/responses. Partial parameter results
will be returned in the FunctionCall.partial_args field.
Corresponds to the JSON property streamFunctionCallArguments
18234 18235 18236 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18234 def stream_function_call_arguments @stream_function_call_arguments end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18242 18243 18244 18245 18246 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18242 def update!(**args) @allowed_function_names = args[:allowed_function_names] if args.key?(:allowed_function_names) @mode = args[:mode] if args.key?(:mode) @stream_function_call_arguments = args[:stream_function_call_arguments] if args.key?(:stream_function_call_arguments) end |