Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionDeclaration
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionDeclaration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Structured representation of a function declaration as defined by the OpenAPI
3.0 specification. Included in this
declaration are the function name, description, parameters and response type.
This FunctionDeclaration is a representation of a block of code that can be
used as a Tool by the model and executed by the client.
Instance Attribute Summary collapse
-
#behavior ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema
Defines the schema of input and output data.
-
#parameters_json_schema ⇒ Object
Optional.
-
#response ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema
Defines the schema of input and output data.
-
#response_json_schema ⇒ Object
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionDeclaration
constructor
A new instance of GoogleCloudAiplatformV1beta1FunctionDeclaration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionDeclaration
Returns a new instance of GoogleCloudAiplatformV1beta1FunctionDeclaration.
26515 26516 26517 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26515 def initialize(**args) update!(**args) end |
Instance Attribute Details
#behavior ⇒ String
Optional. Specifies the function Behavior. If not specified, the system keeps
the current function call behavior. This field is currently only supported by
the BidiGenerateContent method.
Corresponds to the JSON property behavior
26471 26472 26473 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26471 def behavior @behavior end |
#description ⇒ String
Optional. Description and purpose of the function. Model uses it to decide how
and whether to call the function.
Corresponds to the JSON property description
26477 26478 26479 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26477 def description @description end |
#name ⇒ String
Required. The name of the function to call. Must start with a letter or an
underscore. Must be a-z, A-Z, 0-9, or contain underscores, dots, colons and
dashes, with a maximum length of 128.
Corresponds to the JSON property name
26484 26485 26486 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26484 def name @name end |
#parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema
Defines the schema of input and output data. This is a subset of the OpenAPI
3.0 Schema Object.
Corresponds to the JSON property parameters
26490 26491 26492 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26490 def parameters @parameters end |
#parameters_json_schema ⇒ Object
Optional. Describes the parameters to the function in JSON Schema format. The
schema must describe an object where the properties are the parameters to the
function. For example: ` "type": "object", "properties": ` "name": ` "type"
: "string" `, "age": ` "type": "integer" ` `, "additionalProperties": false, "
required": ["name", "age"], "propertyOrdering": ["name", "age"] ` This
field is mutually exclusive with parameters.
Corresponds to the JSON property parametersJsonSchema
26500 26501 26502 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26500 def parameters_json_schema @parameters_json_schema end |
#response ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema
Defines the schema of input and output data. This is a subset of the OpenAPI
3.0 Schema Object.
Corresponds to the JSON property response
26506 26507 26508 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26506 def response @response end |
#response_json_schema ⇒ Object
Optional. Describes the output from this function in JSON Schema format. The
value specified by the schema is the response value of the function. This
field is mutually exclusive with response.
Corresponds to the JSON property responseJsonSchema
26513 26514 26515 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26513 def response_json_schema @response_json_schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26520 26521 26522 26523 26524 26525 26526 26527 26528 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26520 def update!(**args) @behavior = args[:behavior] if args.key?(:behavior) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) @parameters_json_schema = args[:parameters_json_schema] if args.key?(:parameters_json_schema) @response = args[:response] if args.key?(:response) @response_json_schema = args[:response_json_schema] if args.key?(:response_json_schema) end |