Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GatewayConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for a single gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GatewayConfig

Returns a new instance of GoogleCloudAiplatformV1beta1GatewayConfig.



25272
25273
25274
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25272

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_recordString

Output only. The fully qualified record name of the created A-record in Cloud DNS. Corresponds to the JSON property dnsRecord

Returns:

  • (String)


25234
25235
25236
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25234

def dns_record
  @dns_record
end

#dns_zone_nameString

Optional. FQDN of the private DNS zone to create DNS record set for PSC endpoint. Corresponds to the JSON property dnsZoneName

Returns:

  • (String)


25240
25241
25242
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25240

def dns_zone_name
  @dns_zone_name
end

#ip_addressString

Output only. The private IP address of the PSC endpoint. Corresponds to the JSON property ipAddress

Returns:

  • (String)


25245
25246
25247
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25245

def ip_address
  @ip_address
end

#networkString

Optional. The URI of the network resource where PSC-E will be provisioned. if not provided default network will be used. Format: projects/project/global/ networks/network Corresponds to the JSON property network

Returns:

  • (String)


25252
25253
25254
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25252

def network
  @network
end

#psc_endpointString

Output only. The self-link or name of the Private Service Connect endpoint forwarding rule. Corresponds to the JSON property pscEndpoint

Returns:

  • (String)


25258
25259
25260
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25258

def psc_endpoint
  @psc_endpoint
end

#stateString

Output only. The state of the Gateway configuration. Corresponds to the JSON property state

Returns:

  • (String)


25263
25264
25265
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25263

def state
  @state
end

#subnetworkString

Optional. The URI of the subnetwork resource where PSC-E will be provisioned. if not provided default subnet will be used from the same location Format: projects/project/regions/region/subnetworks/subnetwork Corresponds to the JSON property subnetwork

Returns:

  • (String)


25270
25271
25272
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25270

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25277
25278
25279
25280
25281
25282
25283
25284
25285
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25277

def update!(**args)
  @dns_record = args[:dns_record] if args.key?(:dns_record)
  @dns_zone_name = args[:dns_zone_name] if args.key?(:dns_zone_name)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @network = args[:network] if args.key?(:network)
  @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint)
  @state = args[:state] if args.key?(:state)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end