Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GatewayConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GatewayConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for a single gateway.
Instance Attribute Summary collapse
-
#dns_record ⇒ String
Output only.
-
#dns_zone_name ⇒ String
Optional.
-
#ip_address ⇒ String
Output only.
-
#network ⇒ String
Optional.
-
#psc_endpoint ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#subnetwork ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GatewayConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1GatewayConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GatewayConfig
Returns a new instance of GoogleCloudAiplatformV1beta1GatewayConfig.
24661 24662 24663 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24661 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dns_record ⇒ String
Output only. The fully qualified record name of the created A-record in Cloud
DNS.
Corresponds to the JSON property dnsRecord
24623 24624 24625 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24623 def dns_record @dns_record end |
#dns_zone_name ⇒ String
Optional. FQDN of the private DNS zone to create DNS record set for PSC
endpoint.
Corresponds to the JSON property dnsZoneName
24629 24630 24631 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24629 def dns_zone_name @dns_zone_name end |
#ip_address ⇒ String
Output only. The private IP address of the PSC endpoint.
Corresponds to the JSON property ipAddress
24634 24635 24636 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24634 def ip_address @ip_address end |
#network ⇒ String
Optional. The URI of the network resource where PSC-E will be provisioned. if
not provided default network will be used. Format: projects/project/global/
networks/network
Corresponds to the JSON property network
24641 24642 24643 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24641 def network @network end |
#psc_endpoint ⇒ String
Output only. The self-link or name of the Private Service Connect endpoint
forwarding rule.
Corresponds to the JSON property pscEndpoint
24647 24648 24649 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24647 def psc_endpoint @psc_endpoint end |
#state ⇒ String
Output only. The state of the Gateway configuration.
Corresponds to the JSON property state
24652 24653 24654 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24652 def state @state end |
#subnetwork ⇒ String
Optional. The URI of the subnetwork resource where PSC-E will be provisioned.
if not provided default subnet will be used from the same location Format:
projects/project/regions/region/subnetworks/subnetwork
Corresponds to the JSON property subnetwork
24659 24660 24661 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24659 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24666 24667 24668 24669 24670 24671 24672 24673 24674 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24666 def update!(**args) @dns_record = args[:dns_record] if args.key?(:dns_record) @dns_zone_name = args[:dns_zone_name] if args.key?(:dns_zone_name) @ip_address = args[:ip_address] if args.key?(:ip_address) @network = args[:network] if args.key?(:network) @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint) @state = args[:state] if args.key?(:state) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |