Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GatewayConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for a single gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GatewayConfig

Returns a new instance of GoogleCloudAiplatformV1beta1GatewayConfig.



24839
24840
24841
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24839

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_recordString

Output only. The fully qualified record name of the created A-record in Cloud DNS. Corresponds to the JSON property dnsRecord

Returns:

  • (String)


24801
24802
24803
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24801

def dns_record
  @dns_record
end

#dns_zone_nameString

Optional. FQDN of the private DNS zone to create DNS record set for PSC endpoint. Corresponds to the JSON property dnsZoneName

Returns:

  • (String)


24807
24808
24809
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24807

def dns_zone_name
  @dns_zone_name
end

#ip_addressString

Output only. The private IP address of the PSC endpoint. Corresponds to the JSON property ipAddress

Returns:

  • (String)


24812
24813
24814
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24812

def ip_address
  @ip_address
end

#networkString

Optional. The URI of the network resource where PSC-E will be provisioned. if not provided default network will be used. Format: projects/project/global/ networks/network Corresponds to the JSON property network

Returns:

  • (String)


24819
24820
24821
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24819

def network
  @network
end

#psc_endpointString

Output only. The self-link or name of the Private Service Connect endpoint forwarding rule. Corresponds to the JSON property pscEndpoint

Returns:

  • (String)


24825
24826
24827
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24825

def psc_endpoint
  @psc_endpoint
end

#stateString

Output only. The state of the Gateway configuration. Corresponds to the JSON property state

Returns:

  • (String)


24830
24831
24832
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24830

def state
  @state
end

#subnetworkString

Optional. The URI of the subnetwork resource where PSC-E will be provisioned. if not provided default subnet will be used from the same location Format: projects/project/regions/region/subnetworks/subnetwork Corresponds to the JSON property subnetwork

Returns:

  • (String)


24837
24838
24839
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24837

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24844
24845
24846
24847
24848
24849
24850
24851
24852
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24844

def update!(**args)
  @dns_record = args[:dns_record] if args.key?(:dns_record)
  @dns_zone_name = args[:dns_zone_name] if args.key?(:dns_zone_name)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @network = args[:network] if args.key?(:network)
  @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint)
  @state = args[:state] if args.key?(:state)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end