Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GatewayConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GatewayConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for a single gateway.
Instance Attribute Summary collapse
-
#dns_record ⇒ String
Output only.
-
#dns_zone_name ⇒ String
Optional.
-
#ip_address ⇒ String
Output only.
-
#network ⇒ String
Optional.
-
#psc_endpoint ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#subnetwork ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GatewayConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1GatewayConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GatewayConfig
Returns a new instance of GoogleCloudAiplatformV1beta1GatewayConfig.
23873 23874 23875 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23873 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dns_record ⇒ String
Output only. The fully qualified record name of the created A-record in Cloud
DNS.
Corresponds to the JSON property dnsRecord
23835 23836 23837 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23835 def dns_record @dns_record end |
#dns_zone_name ⇒ String
Optional. FQDN of the private DNS zone to create DNS record set for PSC
endpoint.
Corresponds to the JSON property dnsZoneName
23841 23842 23843 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23841 def dns_zone_name @dns_zone_name end |
#ip_address ⇒ String
Output only. The private IP address of the PSC endpoint.
Corresponds to the JSON property ipAddress
23846 23847 23848 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23846 def ip_address @ip_address end |
#network ⇒ String
Optional. The URI of the network resource where PSC-E will be provisioned. if
not provided default network will be used. Format: projects/project/global/
networks/network
Corresponds to the JSON property network
23853 23854 23855 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23853 def network @network end |
#psc_endpoint ⇒ String
Output only. The self-link or name of the Private Service Connect endpoint
forwarding rule.
Corresponds to the JSON property pscEndpoint
23859 23860 23861 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23859 def psc_endpoint @psc_endpoint end |
#state ⇒ String
Output only. The state of the Gateway configuration.
Corresponds to the JSON property state
23864 23865 23866 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23864 def state @state end |
#subnetwork ⇒ String
Optional. The URI of the subnetwork resource where PSC-E will be provisioned.
if not provided default subnet will be used from the same location Format:
projects/project/regions/region/subnetworks/subnetwork
Corresponds to the JSON property subnetwork
23871 23872 23873 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23871 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23878 23879 23880 23881 23882 23883 23884 23885 23886 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23878 def update!(**args) @dns_record = args[:dns_record] if args.key?(:dns_record) @dns_zone_name = args[:dns_zone_name] if args.key?(:dns_zone_name) @ip_address = args[:ip_address] if args.key?(:ip_address) @network = args[:network] if args.key?(:network) @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint) @state = args[:state] if args.key?(:state) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |