Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GeminiExample

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Format for Gemini examples used for Vertex Multimodal datasets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GeminiExample

Returns a new instance of GoogleCloudAiplatformV1beta1GeminiExample.



18609
18610
18611
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cached_contentString

Optional. The name of the cached content used as context to serve the prediction. Note: only used in explicit caching, where users can have control over caching (e.g. what content to cache) and enjoy guaranteed cost savings. Format: projects/project/locations/location/cachedContents/cachedContent Corresponds to the JSON property cachedContent

Returns:

  • (String)


18542
18543
18544
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18542

def cached_content
  @cached_content
end

#contentsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>

Required. The content of the current conversation with the model. For single- turn queries, this is a single instance. For multi-turn queries, this is a repeated field that contains conversation history + latest request. Corresponds to the JSON property contents



18549
18550
18551
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18549

def contents
  @contents
end

#generation_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property generationConfig



18556
18557
18558
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18556

def generation_config
  @generation_config
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata for the request. It is used for billing and reporting only. Label keys and values can be no longer than 63 characters (Unicode codepoints) and can only contain lowercase letters, numeric characters, underscores, and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


18565
18566
18567
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18565

def labels
  @labels
end

#modelString

Optional. The fully qualified name of the publisher model or tuned model endpoint to use. Publisher model format: projects/project/locations/ location/publishers/*/models/* Tuned model endpoint format: projects/ project/locations/location/endpoints/endpoint` Corresponds to the JSON propertymodel`

Returns:

  • (String)


18573
18574
18575
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18573

def model
  @model
end

#model_armor_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelArmorConfig

Configuration for Model Armor. Model Armor is a Google Cloud service that provides safety and security filtering for prompts and responses. It helps protect your AI applications from risks such as harmful content, sensitive data leakage, and prompt injection attacks. Corresponds to the JSON property modelArmorConfig



18581
18582
18583
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18581

def model_armor_config
  @model_armor_config
end

#safety_settingsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetySetting>

Optional. Per request settings for blocking unsafe content. Enforced on GenerateContentResponse.candidates. Corresponds to the JSON property safetySettings



18587
18588
18589
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18587

def safety_settings
  @safety_settings
end

#system_instructionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property systemInstruction



18594
18595
18596
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18594

def system_instruction
  @system_instruction
end

#tool_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolConfig

Tool config. This config is shared for all tools provided in the request. Corresponds to the JSON property toolConfig



18599
18600
18601
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18599

def tool_config
  @tool_config
end

#toolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>

Optional. A list of Tools the model may use to generate the next response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. Corresponds to the JSON property tools



18607
18608
18609
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18607

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18614
18615
18616
18617
18618
18619
18620
18621
18622
18623
18624
18625
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 18614

def update!(**args)
  @cached_content = args[:cached_content] if args.key?(:cached_content)
  @contents = args[:contents] if args.key?(:contents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @labels = args[:labels] if args.key?(:labels)
  @model = args[:model] if args.key?(:model)
  @model_armor_config = args[:model_armor_config] if args.key?(:model_armor_config)
  @safety_settings = args[:safety_settings] if args.key?(:safety_settings)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tool_config = args[:tool_config] if args.key?(:tool_config)
  @tools = args[:tools] if args.key?(:tools)
end