Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GeminiPreferenceExampleCompletion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Completion and its preference score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GeminiPreferenceExampleCompletion

Returns a new instance of GoogleCloudAiplatformV1beta1GeminiPreferenceExampleCompletion.



23529
23530
23531
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23529

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property completion



23522
23523
23524
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23522

def completion
  @completion
end

#scoreFloat

The score for the given completion. Corresponds to the JSON property score

Returns:

  • (Float)


23527
23528
23529
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23527

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23534
23535
23536
23537
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23534

def update!(**args)
  @completion = args[:completion] if args.key?(:completion)
  @score = args[:score] if args.key?(:score)
end