Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for NotebookInternalService.GenerateToken.
Instance Attribute Summary collapse
-
#access_token ⇒ String
Short-lived access token string which may be used to access Google APIs.
-
#expires_in ⇒ Fixnum
The time in seconds when the access token expires.
-
#scope ⇒ String
Space-separated list of scopes contained in the returned token.
-
#token_type ⇒ String
Type of the returned access token (e.g. "Bearer").
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse.
26576 26577 26578 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26576 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_token ⇒ String
Short-lived access token string which may be used to access Google APIs.
Corresponds to the JSON property accessToken
26556 26557 26558 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26556 def access_token @access_token end |
#expires_in ⇒ Fixnum
The time in seconds when the access token expires. Typically that's 3600.
Corresponds to the JSON property expiresIn
26561 26562 26563 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26561 def expires_in @expires_in end |
#scope ⇒ String
Space-separated list of scopes contained in the returned token. https://cloud.
google.com/docs/authentication/token-types#access-contents
Corresponds to the JSON property scope
26567 26568 26569 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26567 def scope @scope end |
#token_type ⇒ String
Type of the returned access token (e.g. "Bearer"). It specifies how the token
must be used. Bearer tokens may be used by any entity without proof of
identity.
Corresponds to the JSON property tokenType
26574 26575 26576 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26574 def token_type @token_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26581 26582 26583 26584 26585 26586 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26581 def update!(**args) @access_token = args[:access_token] if args.key?(:access_token) @expires_in = args[:expires_in] if args.key?(:expires_in) @scope = args[:scope] if args.key?(:scope) @token_type = args[:token_type] if args.key?(:token_type) end |