Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for NotebookInternalService.GenerateToken.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse

Returns a new instance of GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse.



25637
25638
25639
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25637

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_tokenString

Short-lived access token string which may be used to access Google APIs. Corresponds to the JSON property accessToken

Returns:

  • (String)


25617
25618
25619
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25617

def access_token
  @access_token
end

#expires_inFixnum

The time in seconds when the access token expires. Typically that's 3600. Corresponds to the JSON property expiresIn

Returns:

  • (Fixnum)


25622
25623
25624
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25622

def expires_in
  @expires_in
end

#scopeString

Space-separated list of scopes contained in the returned token. https://cloud. google.com/docs/authentication/token-types#access-contents Corresponds to the JSON property scope

Returns:

  • (String)


25628
25629
25630
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25628

def scope
  @scope
end

#token_typeString

Type of the returned access token (e.g. "Bearer"). It specifies how the token must be used. Bearer tokens may be used by any entity without proof of identity. Corresponds to the JSON property tokenType

Returns:

  • (String)


25635
25636
25637
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25635

def token_type
  @token_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25642
25643
25644
25645
25646
25647
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25642

def update!(**args)
  @access_token = args[:access_token] if args.key?(:access_token)
  @expires_in = args[:expires_in] if args.key?(:expires_in)
  @scope = args[:scope] if args.key?(:scope)
  @token_type = args[:token_type] if args.key?(:token_type)
end