Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for NotebookInternalService.GenerateToken.
Instance Attribute Summary collapse
-
#access_token ⇒ String
Short-lived access token string which may be used to access Google APIs.
-
#expires_in ⇒ Fixnum
The time in seconds when the access token expires.
-
#scope ⇒ String
Space-separated list of scopes contained in the returned token.
-
#token_type ⇒ String
Type of the returned access token (e.g. "Bearer").
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateAccessTokenResponse.
25026 25027 25028 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_token ⇒ String
Short-lived access token string which may be used to access Google APIs.
Corresponds to the JSON property accessToken
25006 25007 25008 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25006 def access_token @access_token end |
#expires_in ⇒ Fixnum
The time in seconds when the access token expires. Typically that's 3600.
Corresponds to the JSON property expiresIn
25011 25012 25013 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25011 def expires_in @expires_in end |
#scope ⇒ String
Space-separated list of scopes contained in the returned token. https://cloud.
google.com/docs/authentication/token-types#access-contents
Corresponds to the JSON property scope
25017 25018 25019 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25017 def scope @scope end |
#token_type ⇒ String
Type of the returned access token (e.g. "Bearer"). It specifies how the token
must be used. Bearer tokens may be used by any entity without proof of
identity.
Corresponds to the JSON property tokenType
25024 25025 25026 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25024 def token_type @token_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25031 25032 25033 25034 25035 25036 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25031 def update!(**args) @access_token = args[:access_token] if args.key?(:access_token) @expires_in = args[:expires_in] if args.key?(:expires_in) @scope = args[:scope] if args.key?(:scope) @token_type = args[:token_type] if args.key?(:token_type) end |