Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateContentRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateContentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for [PredictionService.GenerateContent].
Instance Attribute Summary collapse
-
#cached_content ⇒ String
Optional.
-
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Required.
-
#generation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation.
-
#labels ⇒ Hash<String,String>
Optional.
-
#model_armor_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelArmorConfig
Configuration for Model Armor.
-
#safety_settings ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetySetting>
Optional.
-
#system_instruction ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message.
-
#tool_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolConfig
Tool config.
-
#tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateContentRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateContentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateContentRequest
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateContentRequest.
25287 25288 25289 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25287 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cached_content ⇒ String
Optional. The name of the cached content used as context to serve the
prediction. Note: only used in explicit caching, where users can have control
over caching (e.g. what content to cache) and enjoy guaranteed cost savings.
Format: projects/project/locations/location/cachedContents/cachedContent
Corresponds to the JSON property cachedContent
25228 25229 25230 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25228 def cached_content @cached_content end |
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Required. The content of the current conversation with the model. For single-
turn queries, this is a single instance. For multi-turn queries, this is a
repeated field that contains conversation history + latest request.
Corresponds to the JSON property contents
25235 25236 25237 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25235 def contents @contents end |
#generation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation. This message contains all the parameters
that control how the model generates content. It allows you to influence the
randomness, length, and structure of the output.
Corresponds to the JSON property generationConfig
25242 25243 25244 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25242 def generation_config @generation_config end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata for the request. It is used
for billing and reporting only. Label keys and values can be no longer than 63
characters (Unicode codepoints) and can only contain lowercase letters,
numeric characters, underscores, and dashes. International characters are
allowed. Label values are optional. Label keys must start with a letter.
Corresponds to the JSON property labels
25251 25252 25253 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25251 def labels @labels end |
#model_armor_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelArmorConfig
Configuration for Model Armor. Model Armor is a Google Cloud service that
provides safety and security filtering for prompts and responses. It helps
protect your AI applications from risks such as harmful content, sensitive
data leakage, and prompt injection attacks.
Corresponds to the JSON property modelArmorConfig
25259 25260 25261 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25259 def model_armor_config @model_armor_config end |
#safety_settings ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetySetting>
Optional. Per request settings for blocking unsafe content. Enforced on
GenerateContentResponse.candidates.
Corresponds to the JSON property safetySettings
25265 25266 25267 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25265 def safety_settings @safety_settings end |
#system_instruction ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property systemInstruction
25272 25273 25274 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25272 def system_instruction @system_instruction end |
#tool_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolConfig
Tool config. This config is shared for all tools provided in the request.
Corresponds to the JSON property toolConfig
25277 25278 25279 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25277 def tool_config @tool_config end |
#tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>
Optional. A list of Tools the model may use to generate the next response. A
Tool is a piece of code that enables the system to interact with external
systems to perform an action, or set of actions, outside of knowledge and
scope of the model.
Corresponds to the JSON property tools
25285 25286 25287 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25285 def tools @tools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25292 25293 25294 25295 25296 25297 25298 25299 25300 25301 25302 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25292 def update!(**args) @cached_content = args[:cached_content] if args.key?(:cached_content) @contents = args[:contents] if args.key?(:contents) @generation_config = args[:generation_config] if args.key?(:generation_config) @labels = args[:labels] if args.key?(:labels) @model_armor_config = args[:model_armor_config] if args.key?(:model_armor_config) @safety_settings = args[:safety_settings] if args.key?(:safety_settings) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @tool_config = args[:tool_config] if args.key?(:tool_config) @tools = args[:tools] if args.key?(:tools) end |