Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateContentResponsePromptFeedback

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Content filter results for a prompt sent in the request. Note: This is sent only in the first stream chunk and only if no candidates were generated due to content violations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateContentResponsePromptFeedback

Returns a new instance of GoogleCloudAiplatformV1beta1GenerateContentResponsePromptFeedback.



19062
19063
19064
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#block_reasonString

Output only. The reason why the prompt was blocked. Corresponds to the JSON property blockReason

Returns:

  • (String)


19048
19049
19050
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19048

def block_reason
  @block_reason
end

#block_reason_messageString

Output only. A readable message that explains the reason why the prompt was blocked. Corresponds to the JSON property blockReasonMessage

Returns:

  • (String)


19054
19055
19056
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19054

def block_reason_message
  @block_reason_message
end

#safety_ratingsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetyRating>

Output only. A list of safety ratings for the prompt. There is one rating per category. Corresponds to the JSON property safetyRatings



19060
19061
19062
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19060

def safety_ratings
  @safety_ratings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19067
19068
19069
19070
19071
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19067

def update!(**args)
  @block_reason = args[:block_reason] if args.key?(:block_reason)
  @block_reason_message = args[:block_reason_message] if args.key?(:block_reason_message)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
end