Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateInstanceRubricsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateInstanceRubricsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for EvaluationService.GenerateInstanceRubrics.
Instance Attribute Summary collapse
-
#agent_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig
Deprecated: Use
google.cloud.aiplatform.master.AgentConfiginagent_eval_datainstead. -
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Required.
-
#location ⇒ String
Required.
-
#metric_resource_name ⇒ String
Optional.
-
#predefined_rubric_generation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredefinedMetricSpec
The spec for a pre-defined metric.
-
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGenerationSpec
Specification for how rubrics should be generated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateInstanceRubricsRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateInstanceRubricsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateInstanceRubricsRequest
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateInstanceRubricsRequest.
19245 19246 19247 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19245 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationInstanceDeprecatedAgentConfig
Deprecated: Use google.cloud.aiplatform.master.AgentConfig in
agent_eval_data instead. Configuration for an Agent.
Corresponds to the JSON property agentConfig
19211 19212 19213 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19211 def agent_config @agent_config end |
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Required. The prompt to generate rubrics from. For single-turn queries, this
is a single instance. For multi-turn queries, this is a repeated field that
contains conversation history + latest request.
Corresponds to the JSON property contents
19218 19219 19220 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19218 def contents @contents end |
#location ⇒ String
Required. The resource name of the Location to generate rubrics from. Format:
projects/project/locations/location`
Corresponds to the JSON propertylocation`
19224 19225 19226 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19224 def location @location end |
#metric_resource_name ⇒ String
Optional. The resource name of a registered metric. Rubric generation using
predefined metric spec or LLMBasedMetricSpec is supported. If this field is
set, the configuration provided in this field is used for rubric generation.
The predefined_rubric_generation_spec and rubric_generation_spec fields
will be ignored.
Corresponds to the JSON property metricResourceName
19233 19234 19235 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19233 def metric_resource_name @metric_resource_name end |
#predefined_rubric_generation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredefinedMetricSpec
The spec for a pre-defined metric.
Corresponds to the JSON property predefinedRubricGenerationSpec
19238 19239 19240 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19238 def predefined_rubric_generation_spec @predefined_rubric_generation_spec end |
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGenerationSpec
Specification for how rubrics should be generated.
Corresponds to the JSON property rubricGenerationSpec
19243 19244 19245 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19243 def rubric_generation_spec @rubric_generation_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19250 19251 19252 19253 19254 19255 19256 19257 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19250 def update!(**args) @agent_config = args[:agent_config] if args.key?(:agent_config) @contents = args[:contents] if args.key?(:contents) @location = args[:location] if args.key?(:location) @metric_resource_name = args[:metric_resource_name] if args.key?(:metric_resource_name) @predefined_rubric_generation_spec = args[:predefined_rubric_generation_spec] if args.key?(:predefined_rubric_generation_spec) @rubric_generation_spec = args[:rubric_generation_spec] if args.key?(:rubric_generation_spec) end |