Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateLossClustersRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateLossClustersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for EvaluationAnalyticsService.GenerateLossClusters.
Instance Attribute Summary collapse
-
#configs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossAnalysisConfig>
Required.
-
#evaluation_set ⇒ String
Reference to a persisted EvaluationSet.
-
#inline_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateLossClustersRequestEvaluationResultList
A wrapper to allow providing a list of items inline.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateLossClustersRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateLossClustersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateLossClustersRequest
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateLossClustersRequest.
26071 26072 26073 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26071 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossAnalysisConfig>
Required. Configuration for the analysis algorithm. Analysis for multiple
metrics and multiple candidates could be specified.
Corresponds to the JSON property configs
26058 26059 26060 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26058 def configs @configs end |
#evaluation_set ⇒ String
Reference to a persisted EvaluationSet. The service will read items from this
set.
Corresponds to the JSON property evaluationSet
26064 26065 26066 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26064 def evaluation_set @evaluation_set end |
#inline_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateLossClustersRequestEvaluationResultList
A wrapper to allow providing a list of items inline.
Corresponds to the JSON property inlineResults
26069 26070 26071 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26069 def inline_results @inline_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26076 26077 26078 26079 26080 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26076 def update!(**args) @configs = args[:configs] if args.key?(:configs) @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set) @inline_results = args[:inline_results] if args.key?(:inline_results) end |