Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateLossClustersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for EvaluationAnalyticsService.GenerateLossClusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateLossClustersRequest

Returns a new instance of GoogleCloudAiplatformV1beta1GenerateLossClustersRequest.



25460
25461
25462
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25460

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossAnalysisConfig>

Required. Configuration for the analysis algorithm. Analysis for multiple metrics and multiple candidates could be specified. Corresponds to the JSON property configs



25447
25448
25449
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25447

def configs
  @configs
end

#evaluation_setString

Reference to a persisted EvaluationSet. The service will read items from this set. Corresponds to the JSON property evaluationSet

Returns:

  • (String)


25453
25454
25455
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25453

def evaluation_set
  @evaluation_set
end

#inline_resultsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateLossClustersRequestEvaluationResultList

A wrapper to allow providing a list of items inline. Corresponds to the JSON property inlineResults



25458
25459
25460
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25458

def inline_results
  @inline_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25465
25466
25467
25468
25469
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25465

def update!(**args)
  @configs = args[:configs] if args.key?(:configs)
  @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set)
  @inline_results = args[:inline_results] if args.key?(:inline_results)
end