Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateLossClustersRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateLossClustersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for EvaluationAnalyticsService.GenerateLossClusters.
Instance Attribute Summary collapse
-
#configs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossAnalysisConfig>
Required.
-
#evaluation_set ⇒ String
Reference to a persisted EvaluationSet.
-
#inline_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateLossClustersRequestEvaluationResultList
A wrapper to allow providing a list of items inline.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateLossClustersRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateLossClustersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateLossClustersRequest
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateLossClustersRequest.
19319 19320 19321 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19319 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossAnalysisConfig>
Required. Configuration for the analysis algorithm. Analysis for multiple
metrics and multiple candidates could be specified.
Corresponds to the JSON property configs
19306 19307 19308 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19306 def configs @configs end |
#evaluation_set ⇒ String
Reference to a persisted EvaluationSet. The service will read items from this
set.
Corresponds to the JSON property evaluationSet
19312 19313 19314 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19312 def evaluation_set @evaluation_set end |
#inline_results ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateLossClustersRequestEvaluationResultList
A wrapper to allow providing a list of items inline.
Corresponds to the JSON property inlineResults
19317 19318 19319 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19317 def inline_results @inline_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19324 19325 19326 19327 19328 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19324 def update!(**args) @configs = args[:configs] if args.key?(:configs) @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set) @inline_results = args[:inline_results] if args.key?(:inline_results) end |