Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateLossClustersResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateLossClustersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for EvaluationAnalyticsService.GenerateLossClusters.
Instance Attribute Summary collapse
-
#analysis_time ⇒ String
The timestamp when this analysis was completed.
-
#results ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossAnalysisResult>
The analysis results, one per config provided in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateLossClustersResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateLossClustersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateLossClustersResponse
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateLossClustersResponse.
19298 19299 19300 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_time ⇒ String
The timestamp when this analysis was completed.
Corresponds to the JSON property analysisTime
19291 19292 19293 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19291 def analysis_time @analysis_time end |
#results ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossAnalysisResult>
The analysis results, one per config provided in the request.
Corresponds to the JSON property results
19296 19297 19298 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19296 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19303 19304 19305 19306 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19303 def update!(**args) @analysis_time = args[:analysis_time] if args.key?(:analysis_time) @results = args[:results] if args.key?(:results) end |