Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for MemoryBankService.GenerateMemories. Maximum size is 8 MB.
Instance Attribute Summary collapse
-
#allowed_topics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId>
Optional.
-
#direct_contents_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectContentsSource
Defines a direct source of content from which to generate the memories.
-
#direct_memories_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectMemoriesSource
Defines a direct source of memories that should be uploaded to Memory Bank with consolidation.
-
#disable_consolidation ⇒ Boolean
(also: #disable_consolidation?)
Optional.
-
#disable_memory_revisions ⇒ Boolean
(also: #disable_memory_revisions?)
Optional.
-
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>
Optional.
-
#metadata_merge_strategy ⇒ String
Optional.
-
#revision_expire_time ⇒ String
Optional.
-
#revision_labels ⇒ Hash<String,String>
Optional.
-
#revision_ttl ⇒ String
Optional.
-
#scope ⇒ Hash<String,String>
Optional.
-
#vertex_session_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestVertexSessionSource
Defines an Agent Engine Session from which to generate the memories.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateMemoriesRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateMemoriesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateMemoriesRequest
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateMemoriesRequest.
27706 27707 27708 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27706 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_topics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId>
Optional. Restricts memory generation to a subset of memory topics.
Corresponds to the JSON property allowedTopics
27634 27635 27636 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27634 def allowed_topics @allowed_topics end |
#direct_contents_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectContentsSource
Defines a direct source of content from which to generate the memories.
Corresponds to the JSON property directContentsSource
27639 27640 27641 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27639 def direct_contents_source @direct_contents_source end |
#direct_memories_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectMemoriesSource
Defines a direct source of memories that should be uploaded to Memory Bank
with consolidation.
Corresponds to the JSON property directMemoriesSource
27645 27646 27647 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27645 def direct_memories_source @direct_memories_source end |
#disable_consolidation ⇒ Boolean Also known as: disable_consolidation?
Optional. If true, generated memories will not be consolidated with existing
memories; all generated memories will be added as new memories regardless of
whether they are duplicates of or contradictory to existing memories. By
default, memory consolidation is enabled.
Corresponds to the JSON property disableConsolidation
27653 27654 27655 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27653 def disable_consolidation @disable_consolidation end |
#disable_memory_revisions ⇒ Boolean Also known as: disable_memory_revisions?
Optional. If true, no revisions will be created for this request.
Corresponds to the JSON property disableMemoryRevisions
27659 27660 27661 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27659 def disable_memory_revisions @disable_memory_revisions end |
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>
Optional. User-provided metadata for the generated memories. This is not
generated by Memory Bank.
Corresponds to the JSON property metadata
27666 27667 27668 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27666 def @metadata end |
#metadata_merge_strategy ⇒ String
Optional. The strategy to use when applying metadata to existing memories.
Corresponds to the JSON property metadataMergeStrategy
27671 27672 27673 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27671 def @metadata_merge_strategy end |
#revision_expire_time ⇒ String
Optional. Timestamp of when the revision is considered expired. If not set,
the memory revision will be kept until manually deleted.
Corresponds to the JSON property revisionExpireTime
27677 27678 27679 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27677 def revision_expire_time @revision_expire_time end |
#revision_labels ⇒ Hash<String,String>
Optional. Labels to be applied to the generated memory revisions. For example,
you can use this to label a revision with its data source.
Corresponds to the JSON property revisionLabels
27683 27684 27685 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27683 def revision_labels @revision_labels end |
#revision_ttl ⇒ String
Optional. The TTL for the revision. The expiration time is computed: now + TTL.
Corresponds to the JSON property revisionTtl
27688 27689 27690 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27688 def revision_ttl @revision_ttl end |
#scope ⇒ Hash<String,String>
Optional. The scope of the memories that should be generated. Memories will be
consolidated across memories with the same scope. Must be provided unless the
scope is defined in the source content. If scope is provided, it will
override the scope defined in the source content. Scope values cannot contain
the wildcard character '*'.
Corresponds to the JSON property scope
27697 27698 27699 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27697 def scope @scope end |
#vertex_session_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestVertexSessionSource
Defines an Agent Engine Session from which to generate the memories. If scope
is not provided, the scope will be extracted from the Session (i.e. "user_id"
: sesison.user_id).
Corresponds to the JSON property vertexSessionSource
27704 27705 27706 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27704 def vertex_session_source @vertex_session_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27711 27712 27713 27714 27715 27716 27717 27718 27719 27720 27721 27722 27723 27724 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27711 def update!(**args) @allowed_topics = args[:allowed_topics] if args.key?(:allowed_topics) @direct_contents_source = args[:direct_contents_source] if args.key?(:direct_contents_source) @direct_memories_source = args[:direct_memories_source] if args.key?(:direct_memories_source) @disable_consolidation = args[:disable_consolidation] if args.key?(:disable_consolidation) @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions) @metadata = args[:metadata] if args.key?(:metadata) @metadata_merge_strategy = args[:metadata_merge_strategy] if args.key?(:metadata_merge_strategy) @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time) @revision_labels = args[:revision_labels] if args.key?(:revision_labels) @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl) @scope = args[:scope] if args.key?(:scope) @vertex_session_source = args[:vertex_session_source] if args.key?(:vertex_session_source) end |