Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for MemoryBankService.GenerateMemories. Maximum size is 8 MB.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateMemoriesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1GenerateMemoriesRequest.



27145
27146
27147
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_topicsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId>

Optional. Restricts memory generation to a subset of memory topics. Corresponds to the JSON property allowedTopics



27073
27074
27075
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27073

def allowed_topics
  @allowed_topics
end

#direct_contents_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectContentsSource

Defines a direct source of content from which to generate the memories. Corresponds to the JSON property directContentsSource



27078
27079
27080
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27078

def direct_contents_source
  @direct_contents_source
end

#direct_memories_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectMemoriesSource

Defines a direct source of memories that should be uploaded to Memory Bank with consolidation. Corresponds to the JSON property directMemoriesSource



27084
27085
27086
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27084

def direct_memories_source
  @direct_memories_source
end

#disable_consolidationBoolean Also known as: disable_consolidation?

Optional. If true, generated memories will not be consolidated with existing memories; all generated memories will be added as new memories regardless of whether they are duplicates of or contradictory to existing memories. By default, memory consolidation is enabled. Corresponds to the JSON property disableConsolidation

Returns:

  • (Boolean)


27092
27093
27094
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27092

def disable_consolidation
  @disable_consolidation
end

#disable_memory_revisionsBoolean Also known as: disable_memory_revisions?

Optional. If true, no revisions will be created for this request. Corresponds to the JSON property disableMemoryRevisions

Returns:

  • (Boolean)


27098
27099
27100
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27098

def disable_memory_revisions
  @disable_memory_revisions
end

#metadataHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>

Optional. User-provided metadata for the generated memories. This is not generated by Memory Bank. Corresponds to the JSON property metadata



27105
27106
27107
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27105

def 
  @metadata
end

#metadata_merge_strategyString

Optional. The strategy to use when applying metadata to existing memories. Corresponds to the JSON property metadataMergeStrategy

Returns:

  • (String)


27110
27111
27112
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27110

def 
  @metadata_merge_strategy
end

#revision_expire_timeString

Optional. Timestamp of when the revision is considered expired. If not set, the memory revision will be kept until manually deleted. Corresponds to the JSON property revisionExpireTime

Returns:

  • (String)


27116
27117
27118
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27116

def revision_expire_time
  @revision_expire_time
end

#revision_labelsHash<String,String>

Optional. Labels to be applied to the generated memory revisions. For example, you can use this to label a revision with its data source. Corresponds to the JSON property revisionLabels

Returns:

  • (Hash<String,String>)


27122
27123
27124
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27122

def revision_labels
  @revision_labels
end

#revision_ttlString

Optional. The TTL for the revision. The expiration time is computed: now + TTL. Corresponds to the JSON property revisionTtl

Returns:

  • (String)


27127
27128
27129
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27127

def revision_ttl
  @revision_ttl
end

#scopeHash<String,String>

Optional. The scope of the memories that should be generated. Memories will be consolidated across memories with the same scope. Must be provided unless the scope is defined in the source content. If scope is provided, it will override the scope defined in the source content. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


27136
27137
27138
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27136

def scope
  @scope
end

#vertex_session_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestVertexSessionSource

Defines an Agent Engine Session from which to generate the memories. If scope is not provided, the scope will be extracted from the Session (i.e. "user_id" : sesison.user_id). Corresponds to the JSON property vertexSessionSource



27143
27144
27145
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27143

def vertex_session_source
  @vertex_session_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27150
27151
27152
27153
27154
27155
27156
27157
27158
27159
27160
27161
27162
27163
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27150

def update!(**args)
  @allowed_topics = args[:allowed_topics] if args.key?(:allowed_topics)
  @direct_contents_source = args[:direct_contents_source] if args.key?(:direct_contents_source)
  @direct_memories_source = args[:direct_memories_source] if args.key?(:direct_memories_source)
  @disable_consolidation = args[:disable_consolidation] if args.key?(:disable_consolidation)
  @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metadata_merge_strategy = args[:metadata_merge_strategy] if args.key?(:metadata_merge_strategy)
  @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time)
  @revision_labels = args[:revision_labels] if args.key?(:revision_labels)
  @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl)
  @scope = args[:scope] if args.key?(:scope)
  @vertex_session_source = args[:vertex_session_source] if args.key?(:vertex_session_source)
end