Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for MemoryBankService.GenerateMemories. Maximum size is 8 MB.
Instance Attribute Summary collapse
-
#allowed_topics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId>
Optional.
-
#direct_contents_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectContentsSource
Defines a direct source of content from which to generate the memories.
-
#direct_memories_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectMemoriesSource
Defines a direct source of memories that should be uploaded to Memory Bank with consolidation.
-
#disable_consolidation ⇒ Boolean
(also: #disable_consolidation?)
Optional.
-
#disable_memory_revisions ⇒ Boolean
(also: #disable_memory_revisions?)
Optional.
-
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>
Optional.
-
#metadata_merge_strategy ⇒ String
Optional.
-
#revision_expire_time ⇒ String
Optional.
-
#revision_labels ⇒ Hash<String,String>
Optional.
-
#revision_ttl ⇒ String
Optional.
-
#scope ⇒ Hash<String,String>
Optional.
-
#vertex_session_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestVertexSessionSource
Defines an Agent Engine Session from which to generate the memories.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateMemoriesRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateMemoriesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateMemoriesRequest
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateMemoriesRequest.
25595 25596 25597 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_topics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId>
Optional. Restricts memory generation to a subset of memory topics.
Corresponds to the JSON property allowedTopics
25523 25524 25525 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25523 def allowed_topics @allowed_topics end |
#direct_contents_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectContentsSource
Defines a direct source of content from which to generate the memories.
Corresponds to the JSON property directContentsSource
25528 25529 25530 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25528 def direct_contents_source @direct_contents_source end |
#direct_memories_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectMemoriesSource
Defines a direct source of memories that should be uploaded to Memory Bank
with consolidation.
Corresponds to the JSON property directMemoriesSource
25534 25535 25536 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25534 def direct_memories_source @direct_memories_source end |
#disable_consolidation ⇒ Boolean Also known as: disable_consolidation?
Optional. If true, generated memories will not be consolidated with existing
memories; all generated memories will be added as new memories regardless of
whether they are duplicates of or contradictory to existing memories. By
default, memory consolidation is enabled.
Corresponds to the JSON property disableConsolidation
25542 25543 25544 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25542 def disable_consolidation @disable_consolidation end |
#disable_memory_revisions ⇒ Boolean Also known as: disable_memory_revisions?
Optional. If true, no revisions will be created for this request.
Corresponds to the JSON property disableMemoryRevisions
25548 25549 25550 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25548 def disable_memory_revisions @disable_memory_revisions end |
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>
Optional. User-provided metadata for the generated memories. This is not
generated by Memory Bank.
Corresponds to the JSON property metadata
25555 25556 25557 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25555 def @metadata end |
#metadata_merge_strategy ⇒ String
Optional. The strategy to use when applying metadata to existing memories.
Corresponds to the JSON property metadataMergeStrategy
25560 25561 25562 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25560 def @metadata_merge_strategy end |
#revision_expire_time ⇒ String
Optional. Timestamp of when the revision is considered expired. If not set,
the memory revision will be kept until manually deleted.
Corresponds to the JSON property revisionExpireTime
25566 25567 25568 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25566 def revision_expire_time @revision_expire_time end |
#revision_labels ⇒ Hash<String,String>
Optional. Labels to be applied to the generated memory revisions. For example,
you can use this to label a revision with its data source.
Corresponds to the JSON property revisionLabels
25572 25573 25574 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25572 def revision_labels @revision_labels end |
#revision_ttl ⇒ String
Optional. The TTL for the revision. The expiration time is computed: now + TTL.
Corresponds to the JSON property revisionTtl
25577 25578 25579 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25577 def revision_ttl @revision_ttl end |
#scope ⇒ Hash<String,String>
Optional. The scope of the memories that should be generated. Memories will be
consolidated across memories with the same scope. Must be provided unless the
scope is defined in the source content. If scope is provided, it will
override the scope defined in the source content. Scope values cannot contain
the wildcard character '*'.
Corresponds to the JSON property scope
25586 25587 25588 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25586 def scope @scope end |
#vertex_session_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestVertexSessionSource
Defines an Agent Engine Session from which to generate the memories. If scope
is not provided, the scope will be extracted from the Session (i.e. "user_id"
: sesison.user_id).
Corresponds to the JSON property vertexSessionSource
25593 25594 25595 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25593 def vertex_session_source @vertex_session_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25600 25601 25602 25603 25604 25605 25606 25607 25608 25609 25610 25611 25612 25613 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25600 def update!(**args) @allowed_topics = args[:allowed_topics] if args.key?(:allowed_topics) @direct_contents_source = args[:direct_contents_source] if args.key?(:direct_contents_source) @direct_memories_source = args[:direct_memories_source] if args.key?(:direct_memories_source) @disable_consolidation = args[:disable_consolidation] if args.key?(:disable_consolidation) @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions) @metadata = args[:metadata] if args.key?(:metadata) @metadata_merge_strategy = args[:metadata_merge_strategy] if args.key?(:metadata_merge_strategy) @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time) @revision_labels = args[:revision_labels] if args.key?(:revision_labels) @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl) @scope = args[:scope] if args.key?(:scope) @vertex_session_source = args[:vertex_session_source] if args.key?(:vertex_session_source) end |