Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for MemoryBankService.GenerateMemories. Maximum size is 8 MB.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateMemoriesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1GenerateMemoriesRequest.



24248
24249
24250
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24248

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_topicsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId>

Optional. Restricts memory generation to a subset of memory topics. Corresponds to the JSON property allowedTopics



24176
24177
24178
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24176

def allowed_topics
  @allowed_topics
end

#direct_contents_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectContentsSource

Defines a direct source of content from which to generate the memories. Corresponds to the JSON property directContentsSource



24181
24182
24183
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24181

def direct_contents_source
  @direct_contents_source
end

#direct_memories_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestDirectMemoriesSource

Defines a direct source of memories that should be uploaded to Memory Bank with consolidation. Corresponds to the JSON property directMemoriesSource



24187
24188
24189
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24187

def direct_memories_source
  @direct_memories_source
end

#disable_consolidationBoolean Also known as: disable_consolidation?

Optional. If true, generated memories will not be consolidated with existing memories; all generated memories will be added as new memories regardless of whether they are duplicates of or contradictory to existing memories. By default, memory consolidation is enabled. Corresponds to the JSON property disableConsolidation

Returns:

  • (Boolean)


24195
24196
24197
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24195

def disable_consolidation
  @disable_consolidation
end

#disable_memory_revisionsBoolean Also known as: disable_memory_revisions?

Optional. If true, no revisions will be created for this request. Corresponds to the JSON property disableMemoryRevisions

Returns:

  • (Boolean)


24201
24202
24203
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24201

def disable_memory_revisions
  @disable_memory_revisions
end

#metadataHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>

Optional. User-provided metadata for the generated memories. This is not generated by Memory Bank. Corresponds to the JSON property metadata



24208
24209
24210
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24208

def 
  @metadata
end

#metadata_merge_strategyString

Optional. The strategy to use when applying metadata to existing memories. Corresponds to the JSON property metadataMergeStrategy

Returns:

  • (String)


24213
24214
24215
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24213

def 
  @metadata_merge_strategy
end

#revision_expire_timeString

Optional. Timestamp of when the revision is considered expired. If not set, the memory revision will be kept until manually deleted. Corresponds to the JSON property revisionExpireTime

Returns:

  • (String)


24219
24220
24221
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24219

def revision_expire_time
  @revision_expire_time
end

#revision_labelsHash<String,String>

Optional. Labels to be applied to the generated memory revisions. For example, you can use this to label a revision with its data source. Corresponds to the JSON property revisionLabels

Returns:

  • (Hash<String,String>)


24225
24226
24227
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24225

def revision_labels
  @revision_labels
end

#revision_ttlString

Optional. The TTL for the revision. The expiration time is computed: now + TTL. Corresponds to the JSON property revisionTtl

Returns:

  • (String)


24230
24231
24232
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24230

def revision_ttl
  @revision_ttl
end

#scopeHash<String,String>

Optional. The scope of the memories that should be generated. Memories will be consolidated across memories with the same scope. Must be provided unless the scope is defined in the source content. If scope is provided, it will override the scope defined in the source content. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


24239
24240
24241
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24239

def scope
  @scope
end

#vertex_session_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestVertexSessionSource

Defines an Agent Engine Session from which to generate the memories. If scope is not provided, the scope will be extracted from the Session (i.e. "user_id" : sesison.user_id). Corresponds to the JSON property vertexSessionSource



24246
24247
24248
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24246

def vertex_session_source
  @vertex_session_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24253

def update!(**args)
  @allowed_topics = args[:allowed_topics] if args.key?(:allowed_topics)
  @direct_contents_source = args[:direct_contents_source] if args.key?(:direct_contents_source)
  @direct_memories_source = args[:direct_memories_source] if args.key?(:direct_memories_source)
  @disable_consolidation = args[:disable_consolidation] if args.key?(:disable_consolidation)
  @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metadata_merge_strategy = args[:metadata_merge_strategy] if args.key?(:metadata_merge_strategy)
  @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time)
  @revision_labels = args[:revision_labels] if args.key?(:revision_labels)
  @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl)
  @scope = args[:scope] if args.key?(:scope)
  @vertex_session_source = args[:vertex_session_source] if args.key?(:vertex_session_source)
end