Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestVertexSessionSource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateMemoriesRequestVertexSessionSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Defines an Agent Engine Session from which to generate the memories. If scope
is not provided, the scope will be extracted from the Session (i.e. "user_id"
: sesison.user_id).
Instance Attribute Summary collapse
-
#end_time ⇒ String
Optional.
-
#session ⇒ String
Required.
-
#start_time ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateMemoriesRequestVertexSessionSource
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateMemoriesRequestVertexSessionSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateMemoriesRequestVertexSessionSource
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateMemoriesRequestVertexSessionSource.
25906 25907 25908 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Optional. End time (exclusive) of the time range. If not set, the end time is
unbounded.
Corresponds to the JSON property endTime
25890 25891 25892 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25890 def end_time @end_time end |
#session ⇒ String
Required. The resource name of the Session to generate memories for. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
sessions/session`
Corresponds to the JSON propertysession`
25897 25898 25899 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25897 def session @session end |
#start_time ⇒ String
Optional. Time range to define which session events should be used to generate
memories. Start time (inclusive) of the time range. If not set, the start time
is unbounded.
Corresponds to the JSON property startTime
25904 25905 25906 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25904 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25911 25912 25913 25914 25915 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25911 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @session = args[:session] if args.key?(:session) @start_time = args[:start_time] if args.key?(:start_time) end |