Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateSyntheticDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateSyntheticDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for DataFoundryService.GenerateSyntheticData. It contains the settings and information needed to generate synthetic data.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Required.
-
#examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SyntheticExample>
Optional.
-
#output_field_specs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OutputFieldSpec>
Required.
-
#task_description ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskDescriptionStrategy
Defines a generation strategy based on a general task description.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateSyntheticDataRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateSyntheticDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateSyntheticDataRequest
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateSyntheticDataRequest.
19629 19630 19631 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Required. The number of synthetic examples to generate. For this stateless API,
you can generate up to 50 examples in a single request.
Corresponds to the JSON property count
19608 19609 19610 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19608 def count @count end |
#examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SyntheticExample>
Optional. A list of few-shot examples that help the model understand the
desired style, tone, and format of the generated synthetic data. Providing
these few-shot examples can significantly improve the quality and relevance of
the output.
Corresponds to the JSON property examples
19616 19617 19618 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19616 def examples @examples end |
#output_field_specs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OutputFieldSpec>
Required. Defines the schema of each synthetic example to be generated,
defined by a list of fields.
Corresponds to the JSON property outputFieldSpecs
19622 19623 19624 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19622 def output_field_specs @output_field_specs end |
#task_description ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskDescriptionStrategy
Defines a generation strategy based on a general task description.
Corresponds to the JSON property taskDescription
19627 19628 19629 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19627 def task_description @task_description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19634 19635 19636 19637 19638 19639 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19634 def update!(**args) @count = args[:count] if args.key?(:count) @examples = args[:examples] if args.key?(:examples) @output_field_specs = args[:output_field_specs] if args.key?(:output_field_specs) @task_description = args[:task_description] if args.key?(:task_description) end |