Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateSyntheticDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for DataFoundryService.GenerateSyntheticData. It contains the settings and information needed to generate synthetic data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateSyntheticDataRequest

Returns a new instance of GoogleCloudAiplatformV1beta1GenerateSyntheticDataRequest.



19563
19564
19565
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19563

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Required. The number of synthetic examples to generate. For this stateless API, you can generate up to 50 examples in a single request. Corresponds to the JSON property count

Returns:

  • (Fixnum)


19542
19543
19544
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19542

def count
  @count
end

#examplesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SyntheticExample>

Optional. A list of few-shot examples that help the model understand the desired style, tone, and format of the generated synthetic data. Providing these few-shot examples can significantly improve the quality and relevance of the output. Corresponds to the JSON property examples



19550
19551
19552
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19550

def examples
  @examples
end

#output_field_specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OutputFieldSpec>

Required. Defines the schema of each synthetic example to be generated, defined by a list of fields. Corresponds to the JSON property outputFieldSpecs



19556
19557
19558
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19556

def output_field_specs
  @output_field_specs
end

#task_descriptionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskDescriptionStrategy

Defines a generation strategy based on a general task description. Corresponds to the JSON property taskDescription



19561
19562
19563
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19561

def task_description
  @task_description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19568
19569
19570
19571
19572
19573
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19568

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @examples = args[:examples] if args.key?(:examples)
  @output_field_specs = args[:output_field_specs] if args.key?(:output_field_specs)
  @task_description = args[:task_description] if args.key?(:task_description)
end