Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateSyntheticDataResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The response message for the GenerateSyntheticData method, containing the synthetic examples generated by the Gen AI evaluation service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateSyntheticDataResponse

Returns a new instance of GoogleCloudAiplatformV1beta1GenerateSyntheticDataResponse.



25006
25007
25008
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#synthetic_examplesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SyntheticExample>

A list of generated synthetic examples, each containing a complete synthetic data instance generated based on your request. Corresponds to the JSON property syntheticExamples



25004
25005
25006
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25004

def synthetic_examples
  @synthetic_examples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25011
25012
25013
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25011

def update!(**args)
  @synthetic_examples = args[:synthetic_examples] if args.key?(:synthetic_examples)
end