Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateSyntheticDataResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateSyntheticDataResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The response message for the GenerateSyntheticData method, containing the
synthetic examples generated by the Gen AI evaluation service.
Instance Attribute Summary collapse
-
#synthetic_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SyntheticExample>
A list of generated synthetic examples, each containing a complete synthetic data instance generated based on your request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateSyntheticDataResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateSyntheticDataResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateSyntheticDataResponse
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateSyntheticDataResponse.
19587 19588 19589 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19587 def initialize(**args) update!(**args) end |
Instance Attribute Details
#synthetic_examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SyntheticExample>
A list of generated synthetic examples, each containing a complete synthetic
data instance generated based on your request.
Corresponds to the JSON property syntheticExamples
19585 19586 19587 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19585 def synthetic_examples @synthetic_examples end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19592 19593 19594 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 19592 def update!(**args) @synthetic_examples = args[:synthetic_examples] if args.key?(:synthetic_examples) end |