Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateUserScenariosRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for DataFoundryService.GenerateUserScenarios.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateUserScenariosRequest

Returns a new instance of GoogleCloudAiplatformV1beta1GenerateUserScenariosRequest.



27891
27892
27893
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27891

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig>

Optional. A map containing the static configurations for each agent in the system. Key: agent_id (matches the author field in events). Value: The static configuration of the agent. Required unless gemini_agent_config is set, in which case the agents map and root_agent_id are derived from the referenced Gemini Agent. Corresponds to the JSON property agents



27860
27861
27862
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27860

def agents
  @agents
end

#allow_cross_region_modelBoolean Also known as: allow_cross_region_model?

Optional. Allows the scenario generation to use cross region models. When this flag is set, the service may route traffic to other regions if a model is unavailable in the current region (e.g., to a global endpoint). If a fully- qualified model endpoint resource name with a different region than the request location is provided elsewhere in the request, this flag must be set to true or the request will fail. Corresponds to the JSON property allowCrossRegionModel

Returns:

  • (Boolean)


27870
27871
27872
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27870

def allow_cross_region_model
  @allow_cross_region_model
end

#gemini_agent_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GeminiAgentConfig

Config for scraping a Gemini Agent (a Vertex AI Agent resource scraped via the Vertex Interactions API). Corresponds to the JSON property geminiAgentConfig



27877
27878
27879
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27877

def gemini_agent_config
  @gemini_agent_config
end

#root_agent_idString

Optional. The agent id to identify the root agent. Required unless gemini_agent_config is set, in which case it is derived from the referenced Gemini Agent. Corresponds to the JSON property rootAgentId

Returns:

  • (String)


27884
27885
27886
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27884

def root_agent_id
  @root_agent_id
end

#user_scenario_generation_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserScenarioGenerationConfig

User scenario generation configuration. Corresponds to the JSON property userScenarioGenerationConfig



27889
27890
27891
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27889

def user_scenario_generation_config
  @user_scenario_generation_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27896
27897
27898
27899
27900
27901
27902
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27896

def update!(**args)
  @agents = args[:agents] if args.key?(:agents)
  @allow_cross_region_model = args[:allow_cross_region_model] if args.key?(:allow_cross_region_model)
  @gemini_agent_config = args[:gemini_agent_config] if args.key?(:gemini_agent_config)
  @root_agent_id = args[:root_agent_id] if args.key?(:root_agent_id)
  @user_scenario_generation_config = args[:user_scenario_generation_config] if args.key?(:user_scenario_generation_config)
end