Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateUserScenariosRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerateUserScenariosRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for DataFoundryService.GenerateUserScenarios.
Instance Attribute Summary collapse
-
#agents ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig>
Optional.
-
#allow_cross_region_model ⇒ Boolean
(also: #allow_cross_region_model?)
Optional.
-
#root_agent_id ⇒ String
Optional.
-
#user_scenario_generation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserScenarioGenerationConfig
User scenario generation configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateUserScenariosRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateUserScenariosRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateUserScenariosRequest
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateUserScenariosRequest.
27390 27391 27392 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27390 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agents ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentConfig>
Optional. A map containing the static configurations for each agent in the
system. Key: agent_id (matches the author field in events). Value: The
static configuration of the agent. Required unless gemini_agent_config is
set, in which case the agents map and root_agent_id are derived from the
referenced Gemini Agent.
Corresponds to the JSON property agents
27365 27366 27367 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27365 def agents @agents end |
#allow_cross_region_model ⇒ Boolean Also known as: allow_cross_region_model?
Optional. Allows the scenario generation to use cross region models. When this
flag is set, the service may route traffic to other regions if a model is
unavailable in the current region (e.g., to a global endpoint). If a fully-
qualified model endpoint resource name with a different region than the
request location is provided elsewhere in the request, this flag must be set
to true or the request will fail.
Corresponds to the JSON property allowCrossRegionModel
27375 27376 27377 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27375 def allow_cross_region_model @allow_cross_region_model end |
#root_agent_id ⇒ String
Optional. The agent id to identify the root agent. Required unless
gemini_agent_config is set, in which case it is derived from the referenced
Gemini Agent.
Corresponds to the JSON property rootAgentId
27383 27384 27385 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27383 def root_agent_id @root_agent_id end |
#user_scenario_generation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserScenarioGenerationConfig
User scenario generation configuration.
Corresponds to the JSON property userScenarioGenerationConfig
27388 27389 27390 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27388 def user_scenario_generation_config @user_scenario_generation_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27395 27396 27397 27398 27399 27400 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27395 def update!(**args) @agents = args[:agents] if args.key?(:agents) @allow_cross_region_model = args[:allow_cross_region_model] if args.key?(:allow_cross_region_model) @root_agent_id = args[:root_agent_id] if args.key?(:root_agent_id) @user_scenario_generation_config = args[:user_scenario_generation_config] if args.key?(:user_scenario_generation_config) end |