Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The configuration for routing the request to a specific model. This can be used to control which model is used for the generation, either automatically or by specifying a model name.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig

Returns a new instance of GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig.



26201
26202
26203
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_modeGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode

The configuration for automated routing. When automated routing is specified, the routing will be determined by the pretrained routing model and customer provided model routing preference. Corresponds to the JSON property autoMode



26193
26194
26195
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26193

def auto_mode
  @auto_mode
end

#manual_modeGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigManualRoutingMode

The configuration for manual routing. When manual routing is specified, the model will be selected based on the model name provided. Corresponds to the JSON property manualMode



26199
26200
26201
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26199

def manual_mode
  @manual_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26206
26207
26208
26209
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26206

def update!(**args)
  @auto_mode = args[:auto_mode] if args.key?(:auto_mode)
  @manual_mode = args[:manual_mode] if args.key?(:manual_mode)
end