Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The configuration for routing the request to a specific model. This can be used to control which model is used for the generation, either automatically or by specifying a model name.
Instance Attribute Summary collapse
-
#auto_mode ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode
The configuration for automated routing.
-
#manual_mode ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigManualRoutingMode
The configuration for manual routing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig
Returns a new instance of GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig.
20051 20052 20053 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20051 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_mode ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode
The configuration for automated routing. When automated routing is specified,
the routing will be determined by the pretrained routing model and customer
provided model routing preference.
Corresponds to the JSON property autoMode
20043 20044 20045 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20043 def auto_mode @auto_mode end |
#manual_mode ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigManualRoutingMode
The configuration for manual routing. When manual routing is specified, the
model will be selected based on the model name provided.
Corresponds to the JSON property manualMode
20049 20050 20051 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20049 def manual_mode @manual_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20056 20057 20058 20059 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20056 def update!(**args) @auto_mode = args[:auto_mode] if args.key?(:auto_mode) @manual_mode = args[:manual_mode] if args.key?(:manual_mode) end |