Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The configuration for automated routing. When automated routing is specified, the routing will be determined by the pretrained routing model and customer provided model routing preference.
Instance Attribute Summary collapse
-
#model_routing_preference ⇒ String
The model routing preference.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode
Returns a new instance of GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode.
28285 28286 28287 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#model_routing_preference ⇒ String
The model routing preference.
Corresponds to the JSON property modelRoutingPreference
28283 28284 28285 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28283 def model_routing_preference @model_routing_preference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28290 28291 28292 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28290 def update!(**args) @model_routing_preference = args[:model_routing_preference] if args.key?(:model_routing_preference) end |