Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The configuration for automated routing. When automated routing is specified, the routing will be determined by the pretrained routing model and customer provided model routing preference.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode

Returns a new instance of GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode.



26838
26839
26840
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26838

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#model_routing_preferenceString

The model routing preference. Corresponds to the JSON property modelRoutingPreference

Returns:

  • (String)


26836
26837
26838
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26836

def model_routing_preference
  @model_routing_preference
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26843
26844
26845
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26843

def update!(**args)
  @model_routing_preference = args[:model_routing_preference] if args.key?(:model_routing_preference)
end