Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The configuration for automated routing. When automated routing is specified, the routing will be determined by the pretrained routing model and customer provided model routing preference.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode

Returns a new instance of GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode.



24867
24868
24869
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#model_routing_preferenceString

The model routing preference. Corresponds to the JSON property modelRoutingPreference

Returns:

  • (String)


24865
24866
24867
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24865

def model_routing_preference
  @model_routing_preference
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24872
24873
24874
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24872

def update!(**args)
  @model_routing_preference = args[:model_routing_preference] if args.key?(:model_routing_preference)
end