Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GoogleMaps

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Tool to retrieve public maps data for grounding, powered by Google.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GoogleMaps

Returns a new instance of GoogleCloudAiplatformV1beta1GoogleMaps.



28473
28474
28475
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_widgetBoolean Also known as: enable_widget?

Optional. Deprecated: The Google Maps contextual widget behavior in Grounding with Google Maps is being deprecated; this field is planned for removal and no longer has any effect once removed. If true, include the widget context token in the response. Corresponds to the JSON property enableWidget

Returns:

  • (Boolean)


28464
28465
28466
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28464

def enable_widget
  @enable_widget
end

#grounding_typesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GoogleMapsGroundingTypes

Defines the types of Google Maps grounding that can be enabled and their configurations. Corresponds to the JSON property groundingTypes



28471
28472
28473
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28471

def grounding_types
  @grounding_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28478
28479
28480
28481
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28478

def update!(**args)
  @enable_widget = args[:enable_widget] if args.key?(:enable_widget)
  @grounding_types = args[:grounding_types] if args.key?(:grounding_types)
end