Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GoogleMaps
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GoogleMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Tool to retrieve public maps data for grounding, powered by Google.
Instance Attribute Summary collapse
-
#enable_widget ⇒ Boolean
(also: #enable_widget?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GoogleMaps
constructor
A new instance of GoogleCloudAiplatformV1beta1GoogleMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GoogleMaps
Returns a new instance of GoogleCloudAiplatformV1beta1GoogleMaps.
20186 20187 20188 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20186 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_widget ⇒ Boolean Also known as: enable_widget?
Optional. If true, include the widget context token in the response.
Corresponds to the JSON property enableWidget
20183 20184 20185 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20183 def @enable_widget end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20191 20192 20193 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20191 def update!(**args) @enable_widget = args[:enable_widget] if args.key?(:enable_widget) end |