Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunk
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A piece of evidence that supports a claim made by the model. This is used to
show a citation for a claim made by the model. When grounding is enabled, the
model returns a GroundingChunk that contains a reference to the source of
the information.
Instance Attribute Summary collapse
-
#image ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkImage
An
Imagechunk is a piece of evidence that comes from an image search result. -
#maps ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMaps
A
Mapschunk is a piece of evidence that comes from Google Maps, containing information about places or routes. -
#retrieved_context ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext
Context retrieved from a data source to ground the model's response.
-
#web ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkWeb
A
Webchunk is a piece of evidence that comes from a web page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunk
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunk
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunk.
28693 28694 28695 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#image ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkImage
An Image chunk is a piece of evidence that comes from an image search result.
It contains the URI of the image search result and the URI of the image. This
is used to provide the user with a link to the source of the information.
Corresponds to the JSON property image
28670 28671 28672 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28670 def image @image end |
#maps ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMaps
A Maps chunk is a piece of evidence that comes from Google Maps, containing
information about places or routes. This is used to provide the user with rich,
location-based information.
Corresponds to the JSON property maps
28677 28678 28679 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28677 def maps @maps end |
#retrieved_context ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext
Context retrieved from a data source to ground the model's response. This is
used when a retrieval tool fetches information from a user-provided corpus or
a public dataset.
Corresponds to the JSON property retrievedContext
28684 28685 28686 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28684 def retrieved_context @retrieved_context end |
#web ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkWeb
A Web chunk is a piece of evidence that comes from a web page. It contains
the URI of the web page, the title of the page, and the domain of the page.
This is used to provide the user with a link to the source of the information.
Corresponds to the JSON property web
28691 28692 28693 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28691 def web @web end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28698 28699 28700 28701 28702 28703 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28698 def update!(**args) @image = args[:image] if args.key?(:image) @maps = args[:maps] if args.key?(:maps) @retrieved_context = args[:retrieved_context] if args.key?(:retrieved_context) @web = args[:web] if args.key?(:web) end |