Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A piece of evidence that supports a claim made by the model. This is used to show a citation for a claim made by the model. When grounding is enabled, the model returns a GroundingChunk that contains a reference to the source of the information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunk

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunk.



20417
20418
20419
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imageGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkImage

An Image chunk is a piece of evidence that comes from an image search result. It contains the URI of the image search result and the URI of the image. This is used to provide the user with a link to the source of the information. Corresponds to the JSON property image



20394
20395
20396
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20394

def image
  @image
end

#mapsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMaps

A Maps chunk is a piece of evidence that comes from Google Maps, containing information about places or routes. This is used to provide the user with rich, location-based information. Corresponds to the JSON property maps



20401
20402
20403
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20401

def maps
  @maps
end

#retrieved_contextGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext

Context retrieved from a data source to ground the model's response. This is used when a retrieval tool fetches information from a user-provided corpus or a public dataset. Corresponds to the JSON property retrievedContext



20408
20409
20410
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20408

def retrieved_context
  @retrieved_context
end

#webGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkWeb

A Web chunk is a piece of evidence that comes from a web page. It contains the URI of the web page, the title of the page, and the domain of the page. This is used to provide the user with a link to the source of the information. Corresponds to the JSON property web



20415
20416
20417
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20415

def web
  @web
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20422
20423
20424
20425
20426
20427
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20422

def update!(**args)
  @image = args[:image] if args.key?(:image)
  @maps = args[:maps] if args.key?(:maps)
  @retrieved_context = args[:retrieved_context] if args.key?(:retrieved_context)
  @web = args[:web] if args.key?(:web)
end