Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkImage
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An Image chunk is a piece of evidence that comes from an image search result.
It contains the URI of the image search result and the URI of the image. This
is used to provide the user with a link to the source of the information.
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain of the image search result page.
-
#image_uri ⇒ String
The URI of the image.
-
#source_uri ⇒ String
The URI of the image search result page.
-
#title ⇒ String
The title of the image search result page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkImage
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkImage
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkImage.
28798 28799 28800 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28798 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
The domain of the image search result page.
Corresponds to the JSON property domain
28781 28782 28783 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28781 def domain @domain end |
#image_uri ⇒ String
The URI of the image.
Corresponds to the JSON property imageUri
28786 28787 28788 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28786 def image_uri @image_uri end |
#source_uri ⇒ String
The URI of the image search result page.
Corresponds to the JSON property sourceUri
28791 28792 28793 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28791 def source_uri @source_uri end |
#title ⇒ String
The title of the image search result page.
Corresponds to the JSON property title
28796 28797 28798 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28796 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28803 28804 28805 28806 28807 28808 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28803 def update!(**args) @domain = args[:domain] if args.key?(:domain) @image_uri = args[:image_uri] if args.key?(:image_uri) @source_uri = args[:source_uri] if args.key?(:source_uri) @title = args[:title] if args.key?(:title) end |