Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkImage
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An Image chunk is a piece of evidence that comes from an image search result.
It contains the URI of the image search result and the URI of the image. This
is used to provide the user with a link to the source of the information.
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain of the image search result page.
-
#image_uri ⇒ String
The URI of the image.
-
#source_uri ⇒ String
The URI of the image search result page.
-
#title ⇒ String
The title of the image search result page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkImage
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkImage
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkImage.
28732 28733 28734 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28732 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
The domain of the image search result page.
Corresponds to the JSON property domain
28715 28716 28717 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28715 def domain @domain end |
#image_uri ⇒ String
The URI of the image.
Corresponds to the JSON property imageUri
28720 28721 28722 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28720 def image_uri @image_uri end |
#source_uri ⇒ String
The URI of the image search result page.
Corresponds to the JSON property sourceUri
28725 28726 28727 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28725 def source_uri @source_uri end |
#title ⇒ String
The title of the image search result page.
Corresponds to the JSON property title
28730 28731 28732 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28730 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28737 28738 28739 28740 28741 28742 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28737 def update!(**args) @domain = args[:domain] if args.key?(:domain) @image_uri = args[:image_uri] if args.key?(:image_uri) @source_uri = args[:source_uri] if args.key?(:source_uri) @title = args[:title] if args.key?(:title) end |