Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An Image chunk is a piece of evidence that comes from an image search result. It contains the URI of the image search result and the URI of the image. This is used to provide the user with a link to the source of the information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkImage

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkImage.



28230
28231
28232
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

The domain of the image search result page. Corresponds to the JSON property domain

Returns:

  • (String)


28213
28214
28215
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28213

def domain
  @domain
end

#image_uriString

The URI of the image. Corresponds to the JSON property imageUri

Returns:

  • (String)


28218
28219
28220
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28218

def image_uri
  @image_uri
end

#source_uriString

The URI of the image search result page. Corresponds to the JSON property sourceUri

Returns:

  • (String)


28223
28224
28225
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28223

def source_uri
  @source_uri
end

#titleString

The title of the image search result page. Corresponds to the JSON property title

Returns:

  • (String)


28228
28229
28230
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28228

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28235
28236
28237
28238
28239
28240
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28235

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @title = args[:title] if args.key?(:title)
end