Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An Image chunk is a piece of evidence that comes from an image search result. It contains the URI of the image search result and the URI of the image. This is used to provide the user with a link to the source of the information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkImage

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkImage.



26609
26610
26611
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

The domain of the image search result page. Corresponds to the JSON property domain

Returns:

  • (String)


26592
26593
26594
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26592

def domain
  @domain
end

#image_uriString

The URI of the image. Corresponds to the JSON property imageUri

Returns:

  • (String)


26597
26598
26599
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26597

def image_uri
  @image_uri
end

#source_uriString

The URI of the image search result page. Corresponds to the JSON property sourceUri

Returns:

  • (String)


26602
26603
26604
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26602

def source_uri
  @source_uri
end

#titleString

The title of the image search result page. Corresponds to the JSON property title

Returns:

  • (String)


26607
26608
26609
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26607

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26614
26615
26616
26617
26618
26619
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26614

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @title = args[:title] if args.key?(:title)
end