Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An Image chunk is a piece of evidence that comes from an image search result. It contains the URI of the image search result and the URI of the image. This is used to provide the user with a link to the source of the information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkImage

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkImage.



25250
25251
25252
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

The domain of the image search result page. Corresponds to the JSON property domain

Returns:

  • (String)


25233
25234
25235
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25233

def domain
  @domain
end

#image_uriString

The URI of the image. Corresponds to the JSON property imageUri

Returns:

  • (String)


25238
25239
25240
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25238

def image_uri
  @image_uri
end

#source_uriString

The URI of the image search result page. Corresponds to the JSON property sourceUri

Returns:

  • (String)


25243
25244
25245
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25243

def source_uri
  @source_uri
end

#titleString

The title of the image search result page. Corresponds to the JSON property title

Returns:

  • (String)


25248
25249
25250
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25248

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25255
25256
25257
25258
25259
25260
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25255

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @title = args[:title] if args.key?(:title)
end