Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMaps

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A Maps chunk is a piece of evidence that comes from Google Maps, containing information about places or routes. This is used to provide the user with rich, location-based information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMaps

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMaps.



27276
27277
27278
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27276

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#place_answer_sourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources

The sources that were used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as URIs to flag content. Corresponds to the JSON property placeAnswerSources



27248
27249
27250
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27248

def place_answer_sources
  @place_answer_sources
end

#place_idString

This Place's resource name, in places/place_id`format. This can be used to look up the place in the Google Maps API. Corresponds to the JSON propertyplaceId`

Returns:

  • (String)


27254
27255
27256
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27254

def place_id
  @place_id
end

#routeGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsRoute

Route information from Google Maps. Corresponds to the JSON property route



27259
27260
27261
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27259

def route
  @route
end

#textString

The text of the place answer. Corresponds to the JSON property text

Returns:

  • (String)


27264
27265
27266
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27264

def text
  @text
end

#titleString

The title of the place. Corresponds to the JSON property title

Returns:

  • (String)


27269
27270
27271
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27269

def title
  @title
end

#uriString

The URI of the place. Corresponds to the JSON property uri

Returns:

  • (String)


27274
27275
27276
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27274

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27281
27282
27283
27284
27285
27286
27287
27288
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27281

def update!(**args)
  @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources)
  @place_id = args[:place_id] if args.key?(:place_id)
  @route = args[:route] if args.key?(:route)
  @text = args[:text] if args.key?(:text)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end