Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMaps
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A Maps chunk is a piece of evidence that comes from Google Maps, containing
information about places or routes. This is used to provide the user with rich,
location-based information.
Instance Attribute Summary collapse
-
#place_answer_sources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer.
-
#place_id ⇒ String
This Place's resource name, in
places/place_id`` format. -
#route ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsRoute
Route information from Google Maps.
-
#text ⇒ String
The text of the place answer.
-
#title ⇒ String
The title of the place.
-
#uri ⇒ String
The URI of the place.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMaps
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMaps
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMaps.
26839 26840 26841 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#place_answer_sources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer. This includes review
snippets and photos that were used to generate the answer, as well as URIs to
flag content.
Corresponds to the JSON property placeAnswerSources
26811 26812 26813 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26811 def place_answer_sources @place_answer_sources end |
#place_id ⇒ String
This Place's resource name, in places/place_id`format. This can be used to
look up the place in the Google Maps API.
Corresponds to the JSON propertyplaceId`
26817 26818 26819 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26817 def place_id @place_id end |
#route ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsRoute
Route information from Google Maps.
Corresponds to the JSON property route
26822 26823 26824 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26822 def route @route end |
#text ⇒ String
The text of the place answer.
Corresponds to the JSON property text
26827 26828 26829 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26827 def text @text end |
#title ⇒ String
The title of the place.
Corresponds to the JSON property title
26832 26833 26834 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26832 def title @title end |
#uri ⇒ String
The URI of the place.
Corresponds to the JSON property uri
26837 26838 26839 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26837 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26844 26845 26846 26847 26848 26849 26850 26851 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26844 def update!(**args) @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources) @place_id = args[:place_id] if args.key?(:place_id) @route = args[:route] if args.key?(:route) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |