Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMaps
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A Maps chunk is a piece of evidence that comes from Google Maps, containing
information about places or routes. This is used to provide the user with rich,
location-based information.
Instance Attribute Summary collapse
-
#place_answer_sources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer.
-
#place_id ⇒ String
This Place's resource name, in
places/place_id`` format. -
#route ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsRoute
Route information from Google Maps.
-
#text ⇒ String
The text of the place answer.
-
#title ⇒ String
The title of the place.
-
#uri ⇒ String
The URI of the place.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMaps
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMaps
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMaps.
25302 25303 25304 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25302 def initialize(**args) update!(**args) end |
Instance Attribute Details
#place_answer_sources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer. This includes review
snippets and photos that were used to generate the answer, as well as URIs to
flag content.
Corresponds to the JSON property placeAnswerSources
25274 25275 25276 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25274 def place_answer_sources @place_answer_sources end |
#place_id ⇒ String
This Place's resource name, in places/place_id`format. This can be used to
look up the place in the Google Maps API.
Corresponds to the JSON propertyplaceId`
25280 25281 25282 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25280 def place_id @place_id end |
#route ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsRoute
Route information from Google Maps.
Corresponds to the JSON property route
25285 25286 25287 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25285 def route @route end |
#text ⇒ String
The text of the place answer.
Corresponds to the JSON property text
25290 25291 25292 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25290 def text @text end |
#title ⇒ String
The title of the place.
Corresponds to the JSON property title
25295 25296 25297 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25295 def title @title end |
#uri ⇒ String
The URI of the place.
Corresponds to the JSON property uri
25300 25301 25302 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25300 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25307 25308 25309 25310 25311 25312 25313 25314 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25307 def update!(**args) @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources) @place_id = args[:place_id] if args.key?(:place_id) @route = args[:route] if args.key?(:route) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |