Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMaps
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A Maps chunk is a piece of evidence that comes from Google Maps, containing
information about places or routes. This is used to provide the user with rich,
location-based information.
Instance Attribute Summary collapse
-
#place_answer_sources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer.
-
#place_id ⇒ String
This Place's resource name, in
places/place_id`` format. -
#route ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsRoute
Route information from Google Maps.
-
#text ⇒ String
The text of the place answer.
-
#title ⇒ String
The title of the place.
-
#uri ⇒ String
The URI of the place.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMaps
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMaps
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMaps.
20442 20443 20444 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20442 def initialize(**args) update!(**args) end |
Instance Attribute Details
#place_answer_sources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer. This includes review
snippets and photos that were used to generate the answer, as well as URIs to
flag content.
Corresponds to the JSON property placeAnswerSources
20414 20415 20416 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20414 def place_answer_sources @place_answer_sources end |
#place_id ⇒ String
This Place's resource name, in places/place_id`format. This can be used to
look up the place in the Google Maps API.
Corresponds to the JSON propertyplaceId`
20420 20421 20422 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20420 def place_id @place_id end |
#route ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsRoute
Route information from Google Maps.
Corresponds to the JSON property route
20425 20426 20427 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20425 def route @route end |
#text ⇒ String
The text of the place answer.
Corresponds to the JSON property text
20430 20431 20432 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20430 def text @text end |
#title ⇒ String
The title of the place.
Corresponds to the JSON property title
20435 20436 20437 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20435 def title @title end |
#uri ⇒ String
The URI of the place.
Corresponds to the JSON property uri
20440 20441 20442 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20440 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20447 20448 20449 20450 20451 20452 20453 20454 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20447 def update!(**args) @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources) @place_id = args[:place_id] if args.key?(:place_id) @route = args[:route] if args.key?(:route) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |