Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The sources that were used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as URIs to flag content.
Instance Attribute Summary collapse
-
#review_snippets ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet>
Snippets of reviews that were used to generate the answer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources.
28876 28877 28878 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28876 def initialize(**args) update!(**args) end |
Instance Attribute Details
#review_snippets ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet>
Snippets of reviews that were used to generate the answer.
Corresponds to the JSON property reviewSnippets
28874 28875 28876 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28874 def review_snippets @review_snippets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28881 28882 28883 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28881 def update!(**args) @review_snippets = args[:review_snippets] if args.key?(:review_snippets) end |