Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The sources that were used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as URIs to flag content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources.



25887
25888
25889
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#review_snippetsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet>

Snippets of reviews that were used to generate the answer. Corresponds to the JSON property reviewSnippets



25885
25886
25887
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25885

def review_snippets
  @review_snippets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25892
25893
25894
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25892

def update!(**args)
  @review_snippets = args[:review_snippets] if args.key?(:review_snippets)
end