Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A review snippet that is used to generate the answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.



26894
26895
26896
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_maps_uriString

A link to show the review on Google Maps. Corresponds to the JSON property googleMapsUri

Returns:

  • (String)


26882
26883
26884
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26882

def google_maps_uri
  @google_maps_uri
end

#review_idString

The ID of the review that is being referenced. Corresponds to the JSON property reviewId

Returns:

  • (String)


26887
26888
26889
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26887

def review_id
  @review_id
end

#titleString

The title of the review. Corresponds to the JSON property title

Returns:

  • (String)


26892
26893
26894
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26892

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26899
26900
26901
26902
26903
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26899

def update!(**args)
  @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri)
  @review_id = args[:review_id] if args.key?(:review_id)
  @title = args[:title] if args.key?(:title)
end