Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A review snippet that is used to generate the answer.
Instance Attribute Summary collapse
-
#google_maps_uri ⇒ String
A link to show the review on Google Maps.
-
#review_id ⇒ String
The ID of the review that is being referenced.
-
#title ⇒ String
The title of the review.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.
25357 25358 25359 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_maps_uri ⇒ String
A link to show the review on Google Maps.
Corresponds to the JSON property googleMapsUri
25345 25346 25347 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25345 def google_maps_uri @google_maps_uri end |
#review_id ⇒ String
The ID of the review that is being referenced.
Corresponds to the JSON property reviewId
25350 25351 25352 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25350 def review_id @review_id end |
#title ⇒ String
The title of the review.
Corresponds to the JSON property title
25355 25356 25357 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25355 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25362 25363 25364 25365 25366 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25362 def update!(**args) @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri) @review_id = args[:review_id] if args.key?(:review_id) @title = args[:title] if args.key?(:title) end |