Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A review snippet that is used to generate the answer.
Instance Attribute Summary collapse
-
#google_maps_uri ⇒ String
A link to show the review on Google Maps.
-
#review_id ⇒ String
The ID of the review that is being referenced.
-
#title ⇒ String
The title of the review.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.
20563 20564 20565 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20563 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_maps_uri ⇒ String
A link to show the review on Google Maps.
Corresponds to the JSON property googleMapsUri
20551 20552 20553 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20551 def google_maps_uri @google_maps_uri end |
#review_id ⇒ String
The ID of the review that is being referenced.
Corresponds to the JSON property reviewId
20556 20557 20558 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20556 def review_id @review_id end |
#title ⇒ String
The title of the review.
Corresponds to the JSON property title
20561 20562 20563 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20561 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20568 20569 20570 20571 20572 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20568 def update!(**args) @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri) @review_id = args[:review_id] if args.key?(:review_id) @title = args[:title] if args.key?(:title) end |