Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A review snippet that is used to generate the answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.



20497
20498
20499
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_maps_uriString

A link to show the review on Google Maps. Corresponds to the JSON property googleMapsUri

Returns:

  • (String)


20485
20486
20487
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20485

def google_maps_uri
  @google_maps_uri
end

#review_idString

The ID of the review that is being referenced. Corresponds to the JSON property reviewId

Returns:

  • (String)


20490
20491
20492
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20490

def review_id
  @review_id
end

#titleString

The title of the review. Corresponds to the JSON property title

Returns:

  • (String)


20495
20496
20497
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20495

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20502
20503
20504
20505
20506
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20502

def update!(**args)
  @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri)
  @review_id = args[:review_id] if args.key?(:review_id)
  @title = args[:title] if args.key?(:title)
end