Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Context retrieved from a data source to ground the model's response. This is used when a retrieval tool fetches information from a user-provided corpus or a public dataset.
Instance Attribute Summary collapse
-
#document_name ⇒ String
Output only.
-
#rag_chunk ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
-
#text ⇒ String
The content of the retrieved data source.
-
#title ⇒ String
The title of the retrieved data source.
-
#uri ⇒ String
The URI of the retrieved data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext.
25995 25996 25997 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_name ⇒ String
Output only. The full resource name of the referenced Vertex AI Search
document. This is used to identify the specific document that was retrieved.
The format is projects/project/locations/location/collections/collection
/dataStores/data_store/branches/branch/documents/document`.
Corresponds to the JSON propertydocumentName`
25972 25973 25974 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25972 def document_name @document_name end |
#rag_chunk ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated
metadata.
Corresponds to the JSON property ragChunk
25978 25979 25980 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25978 def rag_chunk @rag_chunk end |
#text ⇒ String
The content of the retrieved data source.
Corresponds to the JSON property text
25983 25984 25985 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25983 def text @text end |
#title ⇒ String
The title of the retrieved data source.
Corresponds to the JSON property title
25988 25989 25990 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25988 def title @title end |
#uri ⇒ String
The URI of the retrieved data source.
Corresponds to the JSON property uri
25993 25994 25995 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25993 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26000 26001 26002 26003 26004 26005 26006 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26000 def update!(**args) @document_name = args[:document_name] if args.key?(:document_name) @rag_chunk = args[:rag_chunk] if args.key?(:rag_chunk) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |