Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Context retrieved from a data source to ground the model's response. This is used when a retrieval tool fetches information from a user-provided corpus or a public dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext.



25436
25437
25438
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_nameString

Output only. The full resource name of the referenced Vertex AI Search document. This is used to identify the specific document that was retrieved. The format is projects/project/locations/location/collections/collection /dataStores/data_store/branches/branch/documents/document`. Corresponds to the JSON propertydocumentName`

Returns:

  • (String)


25413
25414
25415
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25413

def document_name
  @document_name
end

#rag_chunkGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk

A RagChunk includes the content of a chunk of a RagFile, and associated metadata. Corresponds to the JSON property ragChunk



25419
25420
25421
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25419

def rag_chunk
  @rag_chunk
end

#textString

The content of the retrieved data source. Corresponds to the JSON property text

Returns:

  • (String)


25424
25425
25426
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25424

def text
  @text
end

#titleString

The title of the retrieved data source. Corresponds to the JSON property title

Returns:

  • (String)


25429
25430
25431
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25429

def title
  @title
end

#uriString

The URI of the retrieved data source. Corresponds to the JSON property uri

Returns:

  • (String)


25434
25435
25436
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25434

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25441
25442
25443
25444
25445
25446
25447
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25441

def update!(**args)
  @document_name = args[:document_name] if args.key?(:document_name)
  @rag_chunk = args[:rag_chunk] if args.key?(:rag_chunk)
  @text = args[:text] if args.key?(:text)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end