Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Context retrieved from a data source to ground the model's response. This is used when a retrieval tool fetches information from a user-provided corpus or a public dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext.



20642
20643
20644
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_nameString

Output only. The full resource name of the referenced Vertex AI Search document. This is used to identify the specific document that was retrieved. The format is projects/project/locations/location/collections/collection /dataStores/data_store/branches/branch/documents/document`. Corresponds to the JSON propertydocumentName`

Returns:

  • (String)


20619
20620
20621
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20619

def document_name
  @document_name
end

#rag_chunkGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk

A RagChunk includes the content of a chunk of a RagFile, and associated metadata. Corresponds to the JSON property ragChunk



20625
20626
20627
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20625

def rag_chunk
  @rag_chunk
end

#textString

The content of the retrieved data source. Corresponds to the JSON property text

Returns:

  • (String)


20630
20631
20632
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20630

def text
  @text
end

#titleString

The title of the retrieved data source. Corresponds to the JSON property title

Returns:

  • (String)


20635
20636
20637
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20635

def title
  @title
end

#uriString

The URI of the retrieved data source. Corresponds to the JSON property uri

Returns:

  • (String)


20640
20641
20642
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20640

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20647
20648
20649
20650
20651
20652
20653
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20647

def update!(**args)
  @document_name = args[:document_name] if args.key?(:document_name)
  @rag_chunk = args[:rag_chunk] if args.key?(:rag_chunk)
  @text = args[:text] if args.key?(:text)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end