Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkWeb
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkWeb
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A Web chunk is a piece of evidence that comes from a web page. It contains
the URI of the web page, the title of the page, and the domain of the page.
This is used to provide the user with a link to the source of the information.
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain of the web page that contains the evidence.
-
#title ⇒ String
The title of the web page that contains the evidence.
-
#uri ⇒ String
The URI of the web page that contains the evidence.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkWeb
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkWeb.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkWeb
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkWeb.
20678 20679 20680 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20678 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
The domain of the web page that contains the evidence. This can be used to
filter out low-quality sources.
Corresponds to the JSON property domain
20666 20667 20668 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20666 def domain @domain end |
#title ⇒ String
The title of the web page that contains the evidence.
Corresponds to the JSON property title
20671 20672 20673 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20671 def title @title end |
#uri ⇒ String
The URI of the web page that contains the evidence.
Corresponds to the JSON property uri
20676 20677 20678 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20676 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20683 20684 20685 20686 20687 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20683 def update!(**args) @domain = args[:domain] if args.key?(:domain) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |