Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunkWeb

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A Web chunk is a piece of evidence that comes from a web page. It contains the URI of the web page, the title of the page, and the domain of the page. This is used to provide the user with a link to the source of the information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkWeb

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkWeb.



20612
20613
20614
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

The domain of the web page that contains the evidence. This can be used to filter out low-quality sources. Corresponds to the JSON property domain

Returns:

  • (String)


20600
20601
20602
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20600

def domain
  @domain
end

#titleString

The title of the web page that contains the evidence. Corresponds to the JSON property title

Returns:

  • (String)


20605
20606
20607
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20605

def title
  @title
end

#uriString

The URI of the web page that contains the evidence. Corresponds to the JSON property uri

Returns:

  • (String)


20610
20611
20612
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20610

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20617
20618
20619
20620
20621
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20617

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end