Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingMetadata.



20692
20693
20694
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20692

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_maps_widget_context_tokenString

Optional. Output only. A token that can be used to render a Google Maps widget with the contextual data. This field is populated only when the grounding source is Google Maps. Corresponds to the JSON property googleMapsWidgetContextToken

Returns:

  • (String)


20635
20636
20637
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20635

def google_maps_widget_context_token
  @google_maps_widget_context_token
end

#grounding_chunksArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingChunk>

A list of supporting references retrieved from the grounding source. This field is populated when the grounding source is Google Search, Vertex AI Search, or Google Maps. Corresponds to the JSON property groundingChunks



20642
20643
20644
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20642

def grounding_chunks
  @grounding_chunks
end

#grounding_supportsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingSupport>

Optional. A list of grounding supports that connect the generated content to the grounding chunks. This field is populated when the grounding source is Google Search or Vertex AI Search. Corresponds to the JSON property groundingSupports



20649
20650
20651
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20649

def grounding_supports
  @grounding_supports
end

#image_search_queriesArray<String>

Optional. The image search queries that were used to generate the content. This field is populated only when the grounding source is Google Search with the Image Search search_type enabled. Corresponds to the JSON property imageSearchQueries

Returns:

  • (Array<String>)


20656
20657
20658
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20656

def image_search_queries
  @image_search_queries
end

#retrieval_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrievalMetadata

Metadata related to the retrieval grounding source. This is part of the GroundingMetadata returned when grounding is enabled. Corresponds to the JSON property retrievalMetadata



20662
20663
20664
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20662

def 
  @retrieval_metadata
end

#retrieval_queriesArray<String>

Optional. The queries that were executed by the retrieval tools. This field is populated only when the grounding source is a retrieval tool, such as Vertex AI Search. Corresponds to the JSON property retrievalQueries

Returns:

  • (Array<String>)


20669
20670
20671
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20669

def retrieval_queries
  @retrieval_queries
end

#search_entry_pointGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchEntryPoint

An entry point for displaying Google Search results. A SearchEntryPoint is populated when the grounding source for a model's response is Google Search. It provides information that you can use to display the search results in your application. Corresponds to the JSON property searchEntryPoint



20677
20678
20679
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20677

def search_entry_point
  @search_entry_point
end

#source_flagging_urisArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingMetadataSourceFlaggingUri>

Optional. Output only. A list of URIs that can be used to flag a place or review for inappropriate content. This field is populated only when the grounding source is Google Maps. Corresponds to the JSON property sourceFlaggingUris



20684
20685
20686
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20684

def source_flagging_uris
  @source_flagging_uris
end

#web_search_queriesArray<String>

Optional. The web search queries that were used to generate the content. This field is populated only when the grounding source is Google Search. Corresponds to the JSON property webSearchQueries

Returns:

  • (Array<String>)


20690
20691
20692
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20690

def web_search_queries
  @web_search_queries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20697
20698
20699
20700
20701
20702
20703
20704
20705
20706
20707
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20697

def update!(**args)
  @google_maps_widget_context_token = args[:google_maps_widget_context_token] if args.key?(:google_maps_widget_context_token)
  @grounding_chunks = args[:grounding_chunks] if args.key?(:grounding_chunks)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @image_search_queries = args[:image_search_queries] if args.key?(:image_search_queries)
  @retrieval_metadata = args[:retrieval_metadata] if args.key?(:retrieval_metadata)
  @retrieval_queries = args[:retrieval_queries] if args.key?(:retrieval_queries)
  @search_entry_point = args[:search_entry_point] if args.key?(:search_entry_point)
  @source_flagging_uris = args[:source_flagging_uris] if args.key?(:source_flagging_uris)
  @web_search_queries = args[:web_search_queries] if args.key?(:web_search_queries)
end