Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingMetadataSourceFlaggingUri
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GroundingMetadataSourceFlaggingUri
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A URI that can be used to flag a place or review for inappropriate content. This is populated only when the grounding source is Google Maps.
Instance Attribute Summary collapse
-
#flag_content_uri ⇒ String
The URI that can be used to flag the content.
-
#source_id ⇒ String
The ID of the place or review.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingMetadataSourceFlaggingUri
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingMetadataSourceFlaggingUri.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingMetadataSourceFlaggingUri
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingMetadataSourceFlaggingUri.
20725 20726 20727 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flag_content_uri ⇒ String
The URI that can be used to flag the content.
Corresponds to the JSON property flagContentUri
20718 20719 20720 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20718 def flag_content_uri @flag_content_uri end |
#source_id ⇒ String
The ID of the place or review.
Corresponds to the JSON property sourceId
20723 20724 20725 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20723 def source_id @source_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20730 20731 20732 20733 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 20730 def update!(**args) @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri) @source_id = args[:source_id] if args.key?(:source_id) end |