Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1HyperparameterTuningJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a HyperparameterTuningJob. A HyperparameterTuningJob has a Study specification and multiple CustomJobs with identical CustomJob specification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1HyperparameterTuningJob

Returns a new instance of GoogleCloudAiplatformV1beta1HyperparameterTuningJob.



29242
29243
29244
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29242

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the HyperparameterTuningJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


29137
29138
29139
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29137

def create_time
  @create_time
end

#display_nameString

Required. The display name of the HyperparameterTuningJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


29143
29144
29145
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29143

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



29149
29150
29151
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29149

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the HyperparameterTuningJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


29156
29157
29158
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29156

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



29166
29167
29168
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29166

def error
  @error
end

#labelsHash<String,String>

The labels with user-defined metadata to organize HyperparameterTuningJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


29175
29176
29177
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29175

def labels
  @labels
end

#max_failed_trial_countFixnum

The number of failed Trials that need to be seen before failing the HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must fail before the whole job fails. Corresponds to the JSON property maxFailedTrialCount

Returns:

  • (Fixnum)


29182
29183
29184
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29182

def max_failed_trial_count
  @max_failed_trial_count
end

#max_trial_countFixnum

Required. The desired total number of Trials. Corresponds to the JSON property maxTrialCount

Returns:

  • (Fixnum)


29187
29188
29189
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29187

def max_trial_count
  @max_trial_count
end

#nameString

Output only. Resource name of the HyperparameterTuningJob. Corresponds to the JSON property name

Returns:

  • (String)


29192
29193
29194
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29192

def name
  @name
end

#parallel_trial_countFixnum

Required. The desired number of Trials to run in parallel. Corresponds to the JSON property parallelTrialCount

Returns:

  • (Fixnum)


29197
29198
29199
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29197

def parallel_trial_count
  @parallel_trial_count
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


29202
29203
29204
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29202

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


29208
29209
29210
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29208

def satisfies_pzs
  @satisfies_pzs
end

#start_timeString

Output only. Time when the HyperparameterTuningJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


29215
29216
29217
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29215

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


29220
29221
29222
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29220

def state
  @state
end

#study_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



29225
29226
29227
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29225

def study_spec
  @study_spec
end

#trial_job_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property trialJobSpec



29230
29231
29232
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29230

def trial_job_spec
  @trial_job_spec
end

#trialsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Trial>

Output only. Trials of the HyperparameterTuningJob. Corresponds to the JSON property trials



29235
29236
29237
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29235

def trials
  @trials
end

#update_timeString

Output only. Time when the HyperparameterTuningJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


29240
29241
29242
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29240

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29247
29248
29249
29250
29251
29252
29253
29254
29255
29256
29257
29258
29259
29260
29261
29262
29263
29264
29265
29266
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29247

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count)
  @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count)
  @name = args[:name] if args.key?(:name)
  @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
  @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec)
  @trials = args[:trials] if args.key?(:trials)
  @update_time = args[:update_time] if args.key?(:update_time)
end