Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1HyperparameterTuningJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a HyperparameterTuningJob. A HyperparameterTuningJob has a Study specification and multiple CustomJobs with identical CustomJob specification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1HyperparameterTuningJob

Returns a new instance of GoogleCloudAiplatformV1beta1HyperparameterTuningJob.



27734
27735
27736
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the HyperparameterTuningJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


27629
27630
27631
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27629

def create_time
  @create_time
end

#display_nameString

Required. The display name of the HyperparameterTuningJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


27635
27636
27637
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27635

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



27641
27642
27643
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27641

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the HyperparameterTuningJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


27648
27649
27650
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27648

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



27658
27659
27660
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27658

def error
  @error
end

#labelsHash<String,String>

The labels with user-defined metadata to organize HyperparameterTuningJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


27667
27668
27669
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27667

def labels
  @labels
end

#max_failed_trial_countFixnum

The number of failed Trials that need to be seen before failing the HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must fail before the whole job fails. Corresponds to the JSON property maxFailedTrialCount

Returns:

  • (Fixnum)


27674
27675
27676
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27674

def max_failed_trial_count
  @max_failed_trial_count
end

#max_trial_countFixnum

Required. The desired total number of Trials. Corresponds to the JSON property maxTrialCount

Returns:

  • (Fixnum)


27679
27680
27681
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27679

def max_trial_count
  @max_trial_count
end

#nameString

Output only. Resource name of the HyperparameterTuningJob. Corresponds to the JSON property name

Returns:

  • (String)


27684
27685
27686
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27684

def name
  @name
end

#parallel_trial_countFixnum

Required. The desired number of Trials to run in parallel. Corresponds to the JSON property parallelTrialCount

Returns:

  • (Fixnum)


27689
27690
27691
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27689

def parallel_trial_count
  @parallel_trial_count
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


27694
27695
27696
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27694

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


27700
27701
27702
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27700

def satisfies_pzs
  @satisfies_pzs
end

#start_timeString

Output only. Time when the HyperparameterTuningJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


27707
27708
27709
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27707

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


27712
27713
27714
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27712

def state
  @state
end

#study_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



27717
27718
27719
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27717

def study_spec
  @study_spec
end

#trial_job_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property trialJobSpec



27722
27723
27724
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27722

def trial_job_spec
  @trial_job_spec
end

#trialsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Trial>

Output only. Trials of the HyperparameterTuningJob. Corresponds to the JSON property trials



27727
27728
27729
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27727

def trials
  @trials
end

#update_timeString

Output only. Time when the HyperparameterTuningJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


27732
27733
27734
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27732

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27739
27740
27741
27742
27743
27744
27745
27746
27747
27748
27749
27750
27751
27752
27753
27754
27755
27756
27757
27758
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27739

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count)
  @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count)
  @name = args[:name] if args.key?(:name)
  @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
  @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec)
  @trials = args[:trials] if args.key?(:trials)
  @update_time = args[:update_time] if args.key?(:update_time)
end