Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImageConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImageConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for image generation. This message allows you to control various aspects of image generation, such as the output format, aspect ratio, and whether the model can generate images of people.
Instance Attribute Summary collapse
-
#aspect_ratio ⇒ String
Optional.
-
#image_output_options ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImageConfigImageOutputOptions
The image output format for generated images.
-
#image_size ⇒ String
Optional.
-
#person_generation ⇒ String
Optional.
-
#prominent_people ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImageConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1ImageConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImageConfig
Returns a new instance of GoogleCloudAiplatformV1beta1ImageConfig.
27206 27207 27208 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aspect_ratio ⇒ String
Optional. The desired aspect ratio for the generated images. The following
aspect ratios are supported: "1:1" "2:3", "3:2" "3:4", "4:3" "4:5", "5:4" "9:
16", "16:9" "21:9"
Corresponds to the JSON property aspectRatio
27179 27180 27181 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27179 def aspect_ratio @aspect_ratio end |
#image_output_options ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImageConfigImageOutputOptions
The image output format for generated images.
Corresponds to the JSON property imageOutputOptions
27184 27185 27186 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27184 def @image_output_options end |
#image_size ⇒ String
Optional. Specifies the size of generated images. Supported values are 1K,
2K, 4K. If not specified, the model will use default value 1K.
Corresponds to the JSON property imageSize
27190 27191 27192 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27190 def image_size @image_size end |
#person_generation ⇒ String
Optional. Controls whether the model can generate people.
Corresponds to the JSON property personGeneration
27195 27196 27197 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27195 def person_generation @person_generation end |
#prominent_people ⇒ String
Optional. Controls whether prominent people (celebrities) generation is
allowed. If used with personGeneration, personGeneration enum would take
precedence. For instance, if ALLOW_NONE is set, all person generation would be
blocked. If this field is unspecified, the default behavior is to allow
prominent people.
Corresponds to the JSON property prominentPeople
27204 27205 27206 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27204 def prominent_people @prominent_people end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27211 27212 27213 27214 27215 27216 27217 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27211 def update!(**args) @aspect_ratio = args[:aspect_ratio] if args.key?(:aspect_ratio) @image_output_options = args[:image_output_options] if args.key?(:image_output_options) @image_size = args[:image_size] if args.key?(:image_size) @person_generation = args[:person_generation] if args.key?(:person_generation) @prominent_people = args[:prominent_people] if args.key?(:prominent_people) end |