Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImageConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for image generation. This message allows you to control various aspects of image generation, such as the output format, aspect ratio, and whether the model can generate images of people.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImageConfig

Returns a new instance of GoogleCloudAiplatformV1beta1ImageConfig.



27384
27385
27386
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27384

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspect_ratioString

Optional. The desired aspect ratio for the generated images. The following aspect ratios are supported: "1:1" "2:3", "3:2" "3:4", "4:3" "4:5", "5:4" "9: 16", "16:9" "21:9" Corresponds to the JSON property aspectRatio

Returns:

  • (String)


27357
27358
27359
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27357

def aspect_ratio
  @aspect_ratio
end

#image_output_optionsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImageConfigImageOutputOptions

The image output format for generated images. Corresponds to the JSON property imageOutputOptions



27362
27363
27364
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27362

def image_output_options
  @image_output_options
end

#image_sizeString

Optional. Specifies the size of generated images. Supported values are 1K, 2K, 4K. If not specified, the model will use default value 1K. Corresponds to the JSON property imageSize

Returns:

  • (String)


27368
27369
27370
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27368

def image_size
  @image_size
end

#person_generationString

Optional. Controls whether the model can generate people. Corresponds to the JSON property personGeneration

Returns:

  • (String)


27373
27374
27375
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27373

def person_generation
  @person_generation
end

#prominent_peopleString

Optional. Controls whether prominent people (celebrities) generation is allowed. If used with personGeneration, personGeneration enum would take precedence. For instance, if ALLOW_NONE is set, all person generation would be blocked. If this field is unspecified, the default behavior is to allow prominent people. Corresponds to the JSON property prominentPeople

Returns:

  • (String)


27382
27383
27384
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27382

def prominent_people
  @prominent_people
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27389
27390
27391
27392
27393
27394
27395
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27389

def update!(**args)
  @aspect_ratio = args[:aspect_ratio] if args.key?(:aspect_ratio)
  @image_output_options = args[:image_output_options] if args.key?(:image_output_options)
  @image_size = args[:image_size] if args.key?(:image_size)
  @person_generation = args[:person_generation] if args.key?(:person_generation)
  @prominent_people = args[:prominent_people] if args.key?(:prominent_people)
end