Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportDataConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Describes the location from where we import data into a Dataset, together with the labels that will be applied to the DataItems and the Annotations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImportDataConfig

Returns a new instance of GoogleCloudAiplatformV1beta1ImportDataConfig.



21065
21066
21067
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21065

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_labelsHash<String,String>

Labels that will be applied to newly imported Annotations. If two Annotations are identical, one of them will be deduped. Two Annotations are considered identical if their payload, payload_schema_uri and all of their labels are the same. These labels will be overridden by Annotation labels specified inside index file referenced by import_schema_uri, e.g. jsonl file. Corresponds to the JSON property annotationLabels

Returns:

  • (Hash<String,String>)


21036
21037
21038
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21036

def annotation_labels
  @annotation_labels
end

#data_item_labelsHash<String,String>

Labels that will be applied to newly imported DataItems. If an identical DataItem as one being imported already exists in the Dataset, then these labels will be appended to these of the already existing one, and if labels with identical key is imported before, the old label value will be overwritten. If two DataItems are identical in the same import data operation, the labels will be combined and if key collision happens in this case, one of the values will be picked randomly. Two DataItems are considered identical if their content bytes are identical (e.g. image bytes or pdf bytes). These labels will be overridden by Annotation labels specified inside index file referenced by import_schema_uri, e.g. jsonl file. Corresponds to the JSON property dataItemLabels

Returns:

  • (Hash<String,String>)


21050
21051
21052
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21050

def data_item_labels
  @data_item_labels
end

#gcs_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



21055
21056
21057
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21055

def gcs_source
  @gcs_source
end

#import_schema_uriString

Required. Points to a YAML file stored on Google Cloud Storage describing the import format. Validation will be done against the schema. The schema is defined as an OpenAPI 3.0.2 Schema Object. Corresponds to the JSON property importSchemaUri

Returns:

  • (String)


21063
21064
21065
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21063

def import_schema_uri
  @import_schema_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21070
21071
21072
21073
21074
21075
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21070

def update!(**args)
  @annotation_labels = args[:annotation_labels] if args.key?(:annotation_labels)
  @data_item_labels = args[:data_item_labels] if args.key?(:data_item_labels)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @import_schema_uri = args[:import_schema_uri] if args.key?(:import_schema_uri)
end