Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for EvaluationManagementService.ImportEvaluationSet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest

Returns a new instance of GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest.



29558
29559
29560
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_engine_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestAgentEngineSource

Source for loading Agent Engine sessions. Corresponds to the JSON property agentEngineSource



29518
29519
29520
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29518

def agent_engine_source
  @agent_engine_source
end

#bigquery_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryRequestSet

The request set for the evaluation run. Corresponds to the JSON property bigquerySource



29523
29524
29525
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29523

def bigquery_source
  @bigquery_source
end

#cloud_trace_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestCloudTraceSource

Source for loading traces directly from Cloud Trace. Corresponds to the JSON property cloudTraceSource



29528
29529
29530
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29528

def cloud_trace_source
  @cloud_trace_source
end

#evaluation_setGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationSet

EvaluationSet is a collection of related EvaluationItems that are evaluated together. Corresponds to the JSON property evaluationSet



29534
29535
29536
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29534

def evaluation_set
  @evaluation_set
end

#gcs_destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcsDestination



29539
29540
29541
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29539

def gcs_destination
  @gcs_destination
end

#gcs_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestGcsSource

Source for loading data from Cloud Storage. Corresponds to the JSON property gcsSource



29544
29545
29546
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29544

def gcs_source
  @gcs_source
end

#inline_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestInlineSource

Wrapper for inline data. Corresponds to the JSON property inlineSource



29549
29550
29551
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29549

def inline_source
  @inline_source
end

#interactions_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestInteractionsSource

Source for importing interactions from the Interactions API into an EvaluationSet. The agent identity is specified once, with a list of interaction IDs to import. Corresponds to the JSON property interactionsSource



29556
29557
29558
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29556

def interactions_source
  @interactions_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29563
29564
29565
29566
29567
29568
29569
29570
29571
29572
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29563

def update!(**args)
  @agent_engine_source = args[:agent_engine_source] if args.key?(:agent_engine_source)
  @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source)
  @cloud_trace_source = args[:cloud_trace_source] if args.key?(:cloud_trace_source)
  @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @inline_source = args[:inline_source] if args.key?(:inline_source)
  @interactions_source = args[:interactions_source] if args.key?(:interactions_source)
end