Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for EvaluationManagementService.ImportEvaluationSet.
Instance Attribute Summary collapse
-
#agent_engine_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestAgentEngineSource
Source for loading Agent Engine sessions.
-
#bigquery_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryRequestSet
The request set for the evaluation run.
-
#cloud_trace_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestCloudTraceSource
Source for loading traces directly from Cloud Trace.
-
#evaluation_set ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationSet
EvaluationSet is a collection of related EvaluationItems that are evaluated together.
-
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestGcsSource
Source for loading data from Cloud Storage.
-
#inline_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestInlineSource
Wrapper for inline data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest
Returns a new instance of GoogleCloudAiplatformV1beta1ImportEvaluationSetRequest.
29049 29050 29051 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_engine_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestAgentEngineSource
Source for loading Agent Engine sessions.
Corresponds to the JSON property agentEngineSource
29016 29017 29018 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29016 def agent_engine_source @agent_engine_source end |
#bigquery_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryRequestSet
The request set for the evaluation run.
Corresponds to the JSON property bigquerySource
29021 29022 29023 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29021 def bigquery_source @bigquery_source end |
#cloud_trace_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestCloudTraceSource
Source for loading traces directly from Cloud Trace.
Corresponds to the JSON property cloudTraceSource
29026 29027 29028 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29026 def cloud_trace_source @cloud_trace_source end |
#evaluation_set ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationSet
EvaluationSet is a collection of related EvaluationItems that are evaluated
together.
Corresponds to the JSON property evaluationSet
29032 29033 29034 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29032 def evaluation_set @evaluation_set end |
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcsDestination
29037 29038 29039 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29037 def gcs_destination @gcs_destination end |
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestGcsSource
Source for loading data from Cloud Storage.
Corresponds to the JSON property gcsSource
29042 29043 29044 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29042 def gcs_source @gcs_source end |
#inline_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportEvaluationSetRequestInlineSource
Wrapper for inline data.
Corresponds to the JSON property inlineSource
29047 29048 29049 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29047 def inline_source @inline_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29054 29055 29056 29057 29058 29059 29060 29061 29062 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29054 def update!(**args) @agent_engine_source = args[:agent_engine_source] if args.key?(:agent_engine_source) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @cloud_trace_source = args[:cloud_trace_source] if args.key?(:cloud_trace_source) @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @inline_source = args[:inline_source] if args.key?(:inline_source) end |