Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for FeaturestoreService.ImportFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImportFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1ImportFeatureValuesRequest.



29356
29357
29358
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29356

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#avro_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AvroSource

The storage details for Avro input content. Corresponds to the JSON property avroSource



29295
29296
29297
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29295

def avro_source
  @avro_source
end

#bigquery_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigquerySource



29300
29301
29302
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29300

def bigquery_source
  @bigquery_source
end

#csv_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CsvSource

The storage details for CSV input content. Corresponds to the JSON property csvSource



29305
29306
29307
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29305

def csv_source
  @csv_source
end

#disable_ingestion_analysisBoolean Also known as: disable_ingestion_analysis?

If true, API doesn't start ingestion analysis pipeline. Corresponds to the JSON property disableIngestionAnalysis

Returns:

  • (Boolean)


29310
29311
29312
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29310

def disable_ingestion_analysis
  @disable_ingestion_analysis
end

#disable_online_servingBoolean Also known as: disable_online_serving?

If set, data will not be imported for online serving. This is typically used for backfilling, where Feature generation timestamps are not in the timestamp range needed for online serving. Corresponds to the JSON property disableOnlineServing

Returns:

  • (Boolean)


29318
29319
29320
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29318

def disable_online_serving
  @disable_online_serving
end

#entity_id_fieldString

Source column that holds entity IDs. If not provided, entity IDs are extracted from the column named entity_id. Corresponds to the JSON property entityIdField

Returns:

  • (String)


29325
29326
29327
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29325

def entity_id_field
  @entity_id_field
end

#feature_specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportFeatureValuesRequestFeatureSpec>

Required. Specifications defining which Feature values to import from the entity. The request fails if no feature_specs are provided, and having multiple feature_specs for one Feature is not allowed. Corresponds to the JSON property featureSpecs



29332
29333
29334
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29332

def feature_specs
  @feature_specs
end

#feature_timeString

Single Feature timestamp for all entities being imported. The timestamp must not have higher than millisecond precision. Corresponds to the JSON property featureTime

Returns:

  • (String)


29338
29339
29340
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29338

def feature_time
  @feature_time
end

#feature_time_fieldString

Source column that holds the Feature timestamp for all Feature values in each entity. Corresponds to the JSON property featureTimeField

Returns:

  • (String)


29344
29345
29346
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29344

def feature_time_field
  @feature_time_field
end

#worker_countFixnum

Specifies the number of workers that are used to write data to the Featurestore. Consider the online serving capacity that you require to achieve the desired import throughput without interfering with online serving. The value must be positive, and less than or equal to 100. If not set, defaults to using 1 worker. The low count ensures minimal impact on online serving performance. Corresponds to the JSON property workerCount

Returns:

  • (Fixnum)


29354
29355
29356
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29354

def worker_count
  @worker_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29361
29362
29363
29364
29365
29366
29367
29368
29369
29370
29371
29372
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29361

def update!(**args)
  @avro_source = args[:avro_source] if args.key?(:avro_source)
  @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source)
  @csv_source = args[:csv_source] if args.key?(:csv_source)
  @disable_ingestion_analysis = args[:disable_ingestion_analysis] if args.key?(:disable_ingestion_analysis)
  @disable_online_serving = args[:disable_online_serving] if args.key?(:disable_online_serving)
  @entity_id_field = args[:entity_id_field] if args.key?(:entity_id_field)
  @feature_specs = args[:feature_specs] if args.key?(:feature_specs)
  @feature_time = args[:feature_time] if args.key?(:feature_time)
  @feature_time_field = args[:feature_time_field] if args.key?(:feature_time_field)
  @worker_count = args[:worker_count] if args.key?(:worker_count)
end