Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for FeaturestoreService.ImportFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImportFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1ImportFeatureValuesRequest.



27735
27736
27737
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#avro_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AvroSource

The storage details for Avro input content. Corresponds to the JSON property avroSource



27674
27675
27676
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27674

def avro_source
  @avro_source
end

#bigquery_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigquerySource



27679
27680
27681
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27679

def bigquery_source
  @bigquery_source
end

#csv_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CsvSource

The storage details for CSV input content. Corresponds to the JSON property csvSource



27684
27685
27686
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27684

def csv_source
  @csv_source
end

#disable_ingestion_analysisBoolean Also known as: disable_ingestion_analysis?

If true, API doesn't start ingestion analysis pipeline. Corresponds to the JSON property disableIngestionAnalysis

Returns:

  • (Boolean)


27689
27690
27691
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27689

def disable_ingestion_analysis
  @disable_ingestion_analysis
end

#disable_online_servingBoolean Also known as: disable_online_serving?

If set, data will not be imported for online serving. This is typically used for backfilling, where Feature generation timestamps are not in the timestamp range needed for online serving. Corresponds to the JSON property disableOnlineServing

Returns:

  • (Boolean)


27697
27698
27699
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27697

def disable_online_serving
  @disable_online_serving
end

#entity_id_fieldString

Source column that holds entity IDs. If not provided, entity IDs are extracted from the column named entity_id. Corresponds to the JSON property entityIdField

Returns:

  • (String)


27704
27705
27706
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27704

def entity_id_field
  @entity_id_field
end

#feature_specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportFeatureValuesRequestFeatureSpec>

Required. Specifications defining which Feature values to import from the entity. The request fails if no feature_specs are provided, and having multiple feature_specs for one Feature is not allowed. Corresponds to the JSON property featureSpecs



27711
27712
27713
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27711

def feature_specs
  @feature_specs
end

#feature_timeString

Single Feature timestamp for all entities being imported. The timestamp must not have higher than millisecond precision. Corresponds to the JSON property featureTime

Returns:

  • (String)


27717
27718
27719
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27717

def feature_time
  @feature_time
end

#feature_time_fieldString

Source column that holds the Feature timestamp for all Feature values in each entity. Corresponds to the JSON property featureTimeField

Returns:

  • (String)


27723
27724
27725
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27723

def feature_time_field
  @feature_time_field
end

#worker_countFixnum

Specifies the number of workers that are used to write data to the Featurestore. Consider the online serving capacity that you require to achieve the desired import throughput without interfering with online serving. The value must be positive, and less than or equal to 100. If not set, defaults to using 1 worker. The low count ensures minimal impact on online serving performance. Corresponds to the JSON property workerCount

Returns:

  • (Fixnum)


27733
27734
27735
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27733

def worker_count
  @worker_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27740
27741
27742
27743
27744
27745
27746
27747
27748
27749
27750
27751
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27740

def update!(**args)
  @avro_source = args[:avro_source] if args.key?(:avro_source)
  @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source)
  @csv_source = args[:csv_source] if args.key?(:csv_source)
  @disable_ingestion_analysis = args[:disable_ingestion_analysis] if args.key?(:disable_ingestion_analysis)
  @disable_online_serving = args[:disable_online_serving] if args.key?(:disable_online_serving)
  @entity_id_field = args[:entity_id_field] if args.key?(:entity_id_field)
  @feature_specs = args[:feature_specs] if args.key?(:feature_specs)
  @feature_time = args[:feature_time] if args.key?(:feature_time)
  @feature_time_field = args[:feature_time_field] if args.key?(:feature_time_field)
  @worker_count = args[:worker_count] if args.key?(:worker_count)
end