Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportIndexRequestConnectorConfigBigQuerySourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for importing data from a BigQuery table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImportIndexRequestConnectorConfigBigQuerySourceConfig

Returns a new instance of GoogleCloudAiplatformV1beta1ImportIndexRequestConnectorConfigBigQuerySourceConfig.



21423
21424
21425
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datapoint_field_mappingGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportIndexRequestConnectorConfigDatapointFieldMapping

Mapping of datapoint fields to column names for columnar data sources. Corresponds to the JSON property datapointFieldMapping



21415
21416
21417
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21415

def datapoint_field_mapping
  @datapoint_field_mapping
end

#table_pathString

Required. The path to the BigQuery table containing the index data, in the format of bq://... Corresponds to the JSON property tablePath

Returns:

  • (String)


21421
21422
21423
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21421

def table_path
  @table_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21428
21429
21430
21431
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21428

def update!(**args)
  @datapoint_field_mapping = args[:datapoint_field_mapping] if args.key?(:datapoint_field_mapping)
  @table_path = args[:table_path] if args.key?(:table_path)
end