Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ImportRagFilesConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Config for importing RagFiles.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ImportRagFilesConfig

Returns a new instance of GoogleCloudAiplatformV1beta1ImportRagFilesConfig.



21657
21658
21659
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21657

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



21567
21568
21569
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21567

def gcs_source
  @gcs_source
end

#global_max_embedding_requests_per_minFixnum

Optional. The max number of queries per minute that the indexing pipeline job is allowed to make to the embedding model specified in the project. Please follow the quota usage guideline of the embedding model you use to set the value properly.If this value is not specified, max_embedding_requests_per_min will be used by indexing pipeline job as the global limit. Corresponds to the JSON property globalMaxEmbeddingRequestsPerMin

Returns:

  • (Fixnum)


21576
21577
21578
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21576

def global_max_embedding_requests_per_min
  @global_max_embedding_requests_per_min
end

#google_drive_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GoogleDriveSource

The Google Drive location for the input content. Corresponds to the JSON property googleDriveSource



21581
21582
21583
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21581

def google_drive_source
  @google_drive_source
end

#import_result_bigquery_sinkGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property importResultBigquerySink



21586
21587
21588
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21586

def import_result_bigquery_sink
  @import_result_bigquery_sink
end

#import_result_gcs_sinkGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property importResultGcsSink



21591
21592
21593
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21591

def import_result_gcs_sink
  @import_result_gcs_sink
end

#jira_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1JiraSource

The Jira source for the ImportRagFilesRequest. Corresponds to the JSON property jiraSource



21596
21597
21598
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21596

def jira_source
  @jira_source
end

#max_embedding_requests_per_minFixnum

Optional. The max number of queries per minute that this job is allowed to make to the embedding model specified on the corpus. This value is specific to this job and not shared across other import jobs. Consult the Quotas page on the project to set an appropriate value here. If unspecified, a default value of 1,000 QPM would be used. Corresponds to the JSON property maxEmbeddingRequestsPerMin

Returns:

  • (Fixnum)


21605
21606
21607
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21605

def max_embedding_requests_per_min
  @max_embedding_requests_per_min
end

#partial_failure_bigquery_sinkGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property partialFailureBigquerySink



21610
21611
21612
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21610

def partial_failure_bigquery_sink
  @partial_failure_bigquery_sink
end

#partial_failure_gcs_sinkGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property partialFailureGcsSink



21615
21616
21617
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21615

def partial_failure_gcs_sink
  @partial_failure_gcs_sink
end

#rag_file_chunking_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagFileChunkingConfig

Specifies the size and overlap of chunks for RagFiles. Corresponds to the JSON property ragFileChunkingConfig



21620
21621
21622
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21620

def rag_file_chunking_config
  @rag_file_chunking_config
end

#rag_file_metadata_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagFileMetadataConfig

Metadata config for RagFile. Corresponds to the JSON property ragFileMetadataConfig



21625
21626
21627
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21625

def 
  @rag_file_metadata_config
end

#rag_file_parsing_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagFileParsingConfig

Specifies the parsing config for RagFiles. Corresponds to the JSON property ragFileParsingConfig



21630
21631
21632
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21630

def rag_file_parsing_config
  @rag_file_parsing_config
end

#rag_file_transformation_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagFileTransformationConfig

Specifies the transformation config for RagFiles. Corresponds to the JSON property ragFileTransformationConfig



21635
21636
21637
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21635

def rag_file_transformation_config
  @rag_file_transformation_config
end

#rebuild_ann_indexBoolean Also known as: rebuild_ann_index?

Rebuilds the ANN index to optimize for recall on the imported data. Only applicable for RagCorpora running on RagManagedDb with retrieval_strategy set to ANN. The rebuild will be performed using the existing ANN config set on the RagCorpus. To change the ANN config, please use the UpdateRagCorpus API. Default is false, i.e., index is not rebuilt. Corresponds to the JSON property rebuildAnnIndex

Returns:

  • (Boolean)


21644
21645
21646
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21644

def rebuild_ann_index
  @rebuild_ann_index
end

#share_point_sourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SharePointSources

The SharePointSources to pass to ImportRagFiles. Corresponds to the JSON property sharePointSources



21650
21651
21652
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21650

def share_point_sources
  @share_point_sources
end

#slack_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SlackSource

The Slack source for the ImportRagFilesRequest. Corresponds to the JSON property slackSource



21655
21656
21657
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21655

def slack_source
  @slack_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21662
21663
21664
21665
21666
21667
21668
21669
21670
21671
21672
21673
21674
21675
21676
21677
21678
21679
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21662

def update!(**args)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @global_max_embedding_requests_per_min = args[:global_max_embedding_requests_per_min] if args.key?(:global_max_embedding_requests_per_min)
  @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source)
  @import_result_bigquery_sink = args[:import_result_bigquery_sink] if args.key?(:import_result_bigquery_sink)
  @import_result_gcs_sink = args[:import_result_gcs_sink] if args.key?(:import_result_gcs_sink)
  @jira_source = args[:jira_source] if args.key?(:jira_source)
  @max_embedding_requests_per_min = args[:max_embedding_requests_per_min] if args.key?(:max_embedding_requests_per_min)
  @partial_failure_bigquery_sink = args[:partial_failure_bigquery_sink] if args.key?(:partial_failure_bigquery_sink)
  @partial_failure_gcs_sink = args[:partial_failure_gcs_sink] if args.key?(:partial_failure_gcs_sink)
  @rag_file_chunking_config = args[:rag_file_chunking_config] if args.key?(:rag_file_chunking_config)
  @rag_file_metadata_config = args[:rag_file_metadata_config] if args.key?(:rag_file_metadata_config)
  @rag_file_parsing_config = args[:rag_file_parsing_config] if args.key?(:rag_file_parsing_config)
  @rag_file_transformation_config = args[:rag_file_transformation_config] if args.key?(:rag_file_transformation_config)
  @rebuild_ann_index = args[:rebuild_ann_index] if args.key?(:rebuild_ann_index)
  @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources)
  @slack_source = args[:slack_source] if args.key?(:slack_source)
end