Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Index
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Index
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A representation of a collection of database items organized in a way that allows for approximate nearest neighbor (a.k.a ANN) algorithms search.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#deployed_indexes ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedIndexRef>
Output only.
-
#description ⇒ String
The description of the Index.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#index_stats ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexStats
Stats of the Index.
-
#index_update_method ⇒ String
Immutable.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Indexes.
-
#metadata ⇒ Object
An additional information about the Index; the schema of the metadata can be found in metadata_schema.
-
#metadata_schema_uri ⇒ String
Immutable.
-
#name ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Index
constructor
A new instance of GoogleCloudAiplatformV1beta1Index.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Index
Returns a new instance of GoogleCloudAiplatformV1beta1Index.
29885 29886 29887 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Index was created.
Corresponds to the JSON property createTime
29789 29790 29791 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29789 def create_time @create_time end |
#deployed_indexes ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedIndexRef>
Output only. The pointers to DeployedIndexes created from this Index. An Index
can be only deleted if all its DeployedIndexes had been undeployed first.
Corresponds to the JSON property deployedIndexes
29795 29796 29797 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29795 def deployed_indexes @deployed_indexes end |
#description ⇒ String
The description of the Index.
Corresponds to the JSON property description
29800 29801 29802 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29800 def description @description end |
#display_name ⇒ String
Required. The display name of the Index. The name can be up to 128 characters
long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
29806 29807 29808 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29806 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
29812 29813 29814 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29812 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
29818 29819 29820 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29818 def etag @etag end |
#index_stats ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexStats
Stats of the Index.
Corresponds to the JSON property indexStats
29823 29824 29825 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29823 def index_stats @index_stats end |
#index_update_method ⇒ String
Immutable. The update method to use with this Index. If not set, BATCH_UPDATE
will be used by default.
Corresponds to the JSON property indexUpdateMethod
29829 29830 29831 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29829 def index_update_method @index_update_method end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Indexes. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
29838 29839 29840 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29838 def labels @labels end |
#metadata ⇒ Object
An additional information about the Index; the schema of the metadata can be
found in metadata_schema.
Corresponds to the JSON property metadata
29844 29845 29846 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29844 def @metadata end |
#metadata_schema_uri ⇒ String
Immutable. Points to a YAML file stored on Google Cloud Storage describing
additional information about the Index, that is specific to it. Unset if the
Index does not have any additional information. The schema is defined as an
OpenAPI 3.0.2 Schema Object. Note: The URI given on output will
be immutable and probably different, including the URI scheme, than the one
given on input. The output URI will point to a location where the user only
has a read access.
Corresponds to the JSON property metadataSchemaUri
29856 29857 29858 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29856 def @metadata_schema_uri end |
#name ⇒ String
Output only. The resource name of the Index.
Corresponds to the JSON property name
29861 29862 29863 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29861 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
29866 29867 29868 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29866 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
29872 29873 29874 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29872 def satisfies_pzs @satisfies_pzs end |
#update_time ⇒ String
Output only. Timestamp when this Index was most recently updated. This also
includes any update to the contents of the Index. Note that Operations working
on this Index may have their Operations.metadata.generic_metadata.update_time
a little after the value of this timestamp, yet that does not mean their
results are not already reflected in the Index. Result of any successfully
completed Operation on the Index is reflected in it.
Corresponds to the JSON property updateTime
29883 29884 29885 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29883 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29890 29891 29892 29893 29894 29895 29896 29897 29898 29899 29900 29901 29902 29903 29904 29905 29906 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29890 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @deployed_indexes = args[:deployed_indexes] if args.key?(:deployed_indexes) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @index_stats = args[:index_stats] if args.key?(:index_stats) @index_update_method = args[:index_update_method] if args.key?(:index_update_method) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @metadata_schema_uri = args[:metadata_schema_uri] if args.key?(:metadata_schema_uri) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @update_time = args[:update_time] if args.key?(:update_time) end |