Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Index

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A representation of a collection of database items organized in a way that allows for approximate nearest neighbor (a.k.a ANN) algorithms search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Index

Returns a new instance of GoogleCloudAiplatformV1beta1Index.



28264
28265
28266
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Index was created. Corresponds to the JSON property createTime

Returns:

  • (String)


28168
28169
28170
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28168

def create_time
  @create_time
end

#deployed_indexesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedIndexRef>

Output only. The pointers to DeployedIndexes created from this Index. An Index can be only deleted if all its DeployedIndexes had been undeployed first. Corresponds to the JSON property deployedIndexes



28174
28175
28176
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28174

def deployed_indexes
  @deployed_indexes
end

#descriptionString

The description of the Index. Corresponds to the JSON property description

Returns:

  • (String)


28179
28180
28181
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28179

def description
  @description
end

#display_nameString

Required. The display name of the Index. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


28185
28186
28187
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28185

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



28191
28192
28193
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28191

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


28197
28198
28199
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28197

def etag
  @etag
end

#index_statsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexStats

Stats of the Index. Corresponds to the JSON property indexStats



28202
28203
28204
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28202

def index_stats
  @index_stats
end

#index_update_methodString

Immutable. The update method to use with this Index. If not set, BATCH_UPDATE will be used by default. Corresponds to the JSON property indexUpdateMethod

Returns:

  • (String)


28208
28209
28210
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28208

def index_update_method
  @index_update_method
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Indexes. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


28217
28218
28219
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28217

def labels
  @labels
end

#metadataObject

An additional information about the Index; the schema of the metadata can be found in metadata_schema. Corresponds to the JSON property metadata

Returns:

  • (Object)


28223
28224
28225
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28223

def 
  @metadata
end

#metadata_schema_uriString

Immutable. Points to a YAML file stored on Google Cloud Storage describing additional information about the Index, that is specific to it. Unset if the Index does not have any additional information. The schema is defined as an OpenAPI 3.0.2 Schema Object. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access. Corresponds to the JSON property metadataSchemaUri

Returns:

  • (String)


28235
28236
28237
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28235

def 
  @metadata_schema_uri
end

#nameString

Output only. The resource name of the Index. Corresponds to the JSON property name

Returns:

  • (String)


28240
28241
28242
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28240

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


28245
28246
28247
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28245

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


28251
28252
28253
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28251

def satisfies_pzs
  @satisfies_pzs
end

#update_timeString

Output only. Timestamp when this Index was most recently updated. This also includes any update to the contents of the Index. Note that Operations working on this Index may have their Operations.metadata.generic_metadata.update_time a little after the value of this timestamp, yet that does not mean their results are not already reflected in the Index. Result of any successfully completed Operation on the Index is reflected in it. Corresponds to the JSON property updateTime

Returns:

  • (String)


28262
28263
28264
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28262

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28269
28270
28271
28272
28273
28274
28275
28276
28277
28278
28279
28280
28281
28282
28283
28284
28285
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28269

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployed_indexes = args[:deployed_indexes] if args.key?(:deployed_indexes)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @index_stats = args[:index_stats] if args.key?(:index_stats)
  @index_update_method = args[:index_update_method] if args.key?(:index_update_method)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metadata_schema_uri = args[:metadata_schema_uri] if args.key?(:metadata_schema_uri)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @update_time = args[:update_time] if args.key?(:update_time)
end