Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Index
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Index
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A representation of a collection of database items organized in a way that allows for approximate nearest neighbor (a.k.a ANN) algorithms search.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#deployed_indexes ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedIndexRef>
Output only.
-
#description ⇒ String
The description of the Index.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#index_stats ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexStats
Stats of the Index.
-
#index_update_method ⇒ String
Immutable.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Indexes.
-
#metadata ⇒ Object
An additional information about the Index; the schema of the metadata can be found in metadata_schema.
-
#metadata_schema_uri ⇒ String
Immutable.
-
#name ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Index
constructor
A new instance of GoogleCloudAiplatformV1beta1Index.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Index
Returns a new instance of GoogleCloudAiplatformV1beta1Index.
21871 21872 21873 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Index was created.
Corresponds to the JSON property createTime
21775 21776 21777 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21775 def create_time @create_time end |
#deployed_indexes ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedIndexRef>
Output only. The pointers to DeployedIndexes created from this Index. An Index
can be only deleted if all its DeployedIndexes had been undeployed first.
Corresponds to the JSON property deployedIndexes
21781 21782 21783 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21781 def deployed_indexes @deployed_indexes end |
#description ⇒ String
The description of the Index.
Corresponds to the JSON property description
21786 21787 21788 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21786 def description @description end |
#display_name ⇒ String
Required. The display name of the Index. The name can be up to 128 characters
long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
21792 21793 21794 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21792 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
21798 21799 21800 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21798 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
21804 21805 21806 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21804 def etag @etag end |
#index_stats ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexStats
Stats of the Index.
Corresponds to the JSON property indexStats
21809 21810 21811 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21809 def index_stats @index_stats end |
#index_update_method ⇒ String
Immutable. The update method to use with this Index. If not set, BATCH_UPDATE
will be used by default.
Corresponds to the JSON property indexUpdateMethod
21815 21816 21817 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21815 def index_update_method @index_update_method end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Indexes. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
21824 21825 21826 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21824 def labels @labels end |
#metadata ⇒ Object
An additional information about the Index; the schema of the metadata can be
found in metadata_schema.
Corresponds to the JSON property metadata
21830 21831 21832 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21830 def @metadata end |
#metadata_schema_uri ⇒ String
Immutable. Points to a YAML file stored on Google Cloud Storage describing
additional information about the Index, that is specific to it. Unset if the
Index does not have any additional information. The schema is defined as an
OpenAPI 3.0.2 Schema Object. Note: The URI given on output will
be immutable and probably different, including the URI scheme, than the one
given on input. The output URI will point to a location where the user only
has a read access.
Corresponds to the JSON property metadataSchemaUri
21842 21843 21844 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21842 def @metadata_schema_uri end |
#name ⇒ String
Output only. The resource name of the Index.
Corresponds to the JSON property name
21847 21848 21849 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21847 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
21852 21853 21854 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21852 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
21858 21859 21860 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21858 def satisfies_pzs @satisfies_pzs end |
#update_time ⇒ String
Output only. Timestamp when this Index was most recently updated. This also
includes any update to the contents of the Index. Note that Operations working
on this Index may have their Operations.metadata.generic_metadata.update_time
a little after the value of this timestamp, yet that does not mean their
results are not already reflected in the Index. Result of any successfully
completed Operation on the Index is reflected in it.
Corresponds to the JSON property updateTime
21869 21870 21871 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21869 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21876 21877 21878 21879 21880 21881 21882 21883 21884 21885 21886 21887 21888 21889 21890 21891 21892 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 21876 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @deployed_indexes = args[:deployed_indexes] if args.key?(:deployed_indexes) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @index_stats = args[:index_stats] if args.key?(:index_stats) @index_update_method = args[:index_update_method] if args.key?(:index_update_method) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @metadata_schema_uri = args[:metadata_schema_uri] if args.key?(:metadata_schema_uri) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @update_time = args[:update_time] if args.key?(:update_time) end |