Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A datapoint of Index.
Instance Attribute Summary collapse
-
#crowding_tag ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapointCrowdingTag
Crowding tag is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than some value k' of the k neighbors returned have the same value of crowding_attribute.
-
#datapoint_id ⇒ String
Required.
-
#embedding_metadata ⇒ Hash<String,Object>
Optional.
-
#feature_vector ⇒ Array<Float>
Required.
-
#numeric_restricts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapointNumericRestriction>
Optional.
-
#restricts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapointRestriction>
Optional.
-
#sparse_embedding ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapointSparseEmbedding
Feature embedding vector for sparse index.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IndexDatapoint
constructor
A new instance of GoogleCloudAiplatformV1beta1IndexDatapoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IndexDatapoint
Returns a new instance of GoogleCloudAiplatformV1beta1IndexDatapoint.
28514 28515 28516 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crowding_tag ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapointCrowdingTag
Crowding tag is a constraint on a neighbor list produced by nearest neighbor
search requiring that no more than some value k' of the k neighbors returned
have the same value of crowding_attribute.
Corresponds to the JSON property crowdingTag
28475 28476 28477 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28475 def crowding_tag @crowding_tag end |
#datapoint_id ⇒ String
Required. Unique identifier of the datapoint.
Corresponds to the JSON property datapointId
28480 28481 28482 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28480 def datapoint_id @datapoint_id end |
#embedding_metadata ⇒ Hash<String,Object>
Optional. The key-value map of additional metadata for the datapoint.
Corresponds to the JSON property embeddingMetadata
28485 28486 28487 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28485 def @embedding_metadata end |
#feature_vector ⇒ Array<Float>
Required. Feature embedding vector for dense index. An array of numbers with
the length of [NearestNeighborSearchConfig.dimensions].
Corresponds to the JSON property featureVector
28491 28492 28493 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28491 def feature_vector @feature_vector end |
#numeric_restricts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapointNumericRestriction>
Optional. List of Restrict of the datapoint, used to perform "restricted
searches" where boolean rule are used to filter the subset of the database
eligible for matching. This uses numeric comparisons.
Corresponds to the JSON property numericRestricts
28498 28499 28500 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28498 def numeric_restricts @numeric_restricts end |
#restricts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapointRestriction>
Optional. List of Restrict of the datapoint, used to perform "restricted
searches" where boolean rule are used to filter the subset of the database
eligible for matching. This uses categorical tokens. See: https://cloud.google.
com/vertex-ai/docs/matching-engine/filtering
Corresponds to the JSON property restricts
28506 28507 28508 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28506 def restricts @restricts end |
#sparse_embedding ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexDatapointSparseEmbedding
Feature embedding vector for sparse index. An array of numbers whose values
are located in the specified dimensions.
Corresponds to the JSON property sparseEmbedding
28512 28513 28514 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28512 def @sparse_embedding end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28519 28520 28521 28522 28523 28524 28525 28526 28527 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28519 def update!(**args) @crowding_tag = args[:crowding_tag] if args.key?(:crowding_tag) @datapoint_id = args[:datapoint_id] if args.key?(:datapoint_id) @embedding_metadata = args[:embedding_metadata] if args.key?(:embedding_metadata) @feature_vector = args[:feature_vector] if args.key?(:feature_vector) @numeric_restricts = args[:numeric_restricts] if args.key?(:numeric_restricts) @restricts = args[:restricts] if args.key?(:restricts) @sparse_embedding = args[:sparse_embedding] if args.key?(:sparse_embedding) end |