Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Indexes are deployed into it. An IndexEndpoint can have multiple DeployedIndexes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IndexEndpoint

Returns a new instance of GoogleCloudAiplatformV1beta1IndexEndpoint.



29203
29204
29205
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this IndexEndpoint was created. Corresponds to the JSON property createTime

Returns:

  • (String)


29102
29103
29104
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29102

def create_time
  @create_time
end

#deployed_indexesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedIndex>

Output only. The indexes deployed in this endpoint. Corresponds to the JSON property deployedIndexes



29107
29108
29109
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29107

def deployed_indexes
  @deployed_indexes
end

#descriptionString

The description of the IndexEndpoint. Corresponds to the JSON property description

Returns:

  • (String)


29112
29113
29114
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29112

def description
  @description
end

#display_nameString

Required. The display name of the IndexEndpoint. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


29118
29119
29120
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29118

def display_name
  @display_name
end

#enable_private_service_connectBoolean Also known as: enable_private_service_connect?

Optional. Deprecated: If true, expose the IndexEndpoint via private service connect. Only one of the fields, network or enable_private_service_connect, can be set. Corresponds to the JSON property enablePrivateServiceConnect

Returns:

  • (Boolean)


29125
29126
29127
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29125

def enable_private_service_connect
  @enable_private_service_connect
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



29132
29133
29134
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29132

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


29138
29139
29140
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29138

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your IndexEndpoints. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


29147
29148
29149
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29147

def labels
  @labels
end

#nameString

Output only. The resource name of the IndexEndpoint. Corresponds to the JSON property name

Returns:

  • (String)


29152
29153
29154
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29152

def name
  @name
end

#networkString

Optional. The full name of the Google Compute Engine network to which the IndexEndpoint should be peered. Private services access must already be configured for the network. If left unspecified, the Endpoint is not peered with any network. network and private_service_connect_config are mutually exclusive. Format: projects/project/global/networks/network`. Where projectis a project number, as in '12345', andnetworkis network name. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


29164
29165
29166
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29164

def network
  @network
end

#private_service_connect_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig

Represents configuration for private service connect. Corresponds to the JSON property privateServiceConnectConfig



29169
29170
29171
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29169

def private_service_connect_config
  @private_service_connect_config
end

#public_endpoint_domain_nameString

Output only. If public_endpoint_enabled is true, this field will be populated with the domain name to use for this index endpoint. Corresponds to the JSON property publicEndpointDomainName

Returns:

  • (String)


29175
29176
29177
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29175

def public_endpoint_domain_name
  @public_endpoint_domain_name
end

#public_endpoint_enabledBoolean Also known as: public_endpoint_enabled?

Optional. If true, the deployed index will be accessible through public endpoint. Corresponds to the JSON property publicEndpointEnabled

Returns:

  • (Boolean)


29181
29182
29183
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29181

def public_endpoint_enabled
  @public_endpoint_enabled
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


29187
29188
29189
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29187

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


29193
29194
29195
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29193

def satisfies_pzs
  @satisfies_pzs
end

#update_timeString

Output only. Timestamp when this IndexEndpoint was last updated. This timestamp is not updated when the endpoint's DeployedIndexes are updated, e.g. due to updates of the original Indexes they are the deployments of. Corresponds to the JSON property updateTime

Returns:

  • (String)


29201
29202
29203
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29201

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29208
29209
29210
29211
29212
29213
29214
29215
29216
29217
29218
29219
29220
29221
29222
29223
29224
29225
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29208

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployed_indexes = args[:deployed_indexes] if args.key?(:deployed_indexes)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
  @public_endpoint_domain_name = args[:public_endpoint_domain_name] if args.key?(:public_endpoint_domain_name)
  @public_endpoint_enabled = args[:public_endpoint_enabled] if args.key?(:public_endpoint_enabled)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @update_time = args[:update_time] if args.key?(:update_time)
end