Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IndexEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Indexes are deployed into it. An IndexEndpoint can have multiple DeployedIndexes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IndexEndpoint

Returns a new instance of GoogleCloudAiplatformV1beta1IndexEndpoint.



22129
22130
22131
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22129

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this IndexEndpoint was created. Corresponds to the JSON property createTime

Returns:

  • (String)


22028
22029
22030
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22028

def create_time
  @create_time
end

#deployed_indexesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedIndex>

Output only. The indexes deployed in this endpoint. Corresponds to the JSON property deployedIndexes



22033
22034
22035
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22033

def deployed_indexes
  @deployed_indexes
end

#descriptionString

The description of the IndexEndpoint. Corresponds to the JSON property description

Returns:

  • (String)


22038
22039
22040
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22038

def description
  @description
end

#display_nameString

Required. The display name of the IndexEndpoint. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


22044
22045
22046
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22044

def display_name
  @display_name
end

#enable_private_service_connectBoolean Also known as: enable_private_service_connect?

Optional. Deprecated: If true, expose the IndexEndpoint via private service connect. Only one of the fields, network or enable_private_service_connect, can be set. Corresponds to the JSON property enablePrivateServiceConnect

Returns:

  • (Boolean)


22051
22052
22053
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22051

def enable_private_service_connect
  @enable_private_service_connect
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



22058
22059
22060
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22058

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


22064
22065
22066
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22064

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your IndexEndpoints. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


22073
22074
22075
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22073

def labels
  @labels
end

#nameString

Output only. The resource name of the IndexEndpoint. Corresponds to the JSON property name

Returns:

  • (String)


22078
22079
22080
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22078

def name
  @name
end

#networkString

Optional. The full name of the Google Compute Engine network to which the IndexEndpoint should be peered. Private services access must already be configured for the network. If left unspecified, the Endpoint is not peered with any network. network and private_service_connect_config are mutually exclusive. Format: projects/project/global/networks/network`. Where projectis a project number, as in '12345', andnetworkis network name. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


22090
22091
22092
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22090

def network
  @network
end

#private_service_connect_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig

Represents configuration for private service connect. Corresponds to the JSON property privateServiceConnectConfig



22095
22096
22097
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22095

def private_service_connect_config
  @private_service_connect_config
end

#public_endpoint_domain_nameString

Output only. If public_endpoint_enabled is true, this field will be populated with the domain name to use for this index endpoint. Corresponds to the JSON property publicEndpointDomainName

Returns:

  • (String)


22101
22102
22103
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22101

def public_endpoint_domain_name
  @public_endpoint_domain_name
end

#public_endpoint_enabledBoolean Also known as: public_endpoint_enabled?

Optional. If true, the deployed index will be accessible through public endpoint. Corresponds to the JSON property publicEndpointEnabled

Returns:

  • (Boolean)


22107
22108
22109
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22107

def public_endpoint_enabled
  @public_endpoint_enabled
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


22113
22114
22115
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22113

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


22119
22120
22121
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22119

def satisfies_pzs
  @satisfies_pzs
end

#update_timeString

Output only. Timestamp when this IndexEndpoint was last updated. This timestamp is not updated when the endpoint's DeployedIndexes are updated, e.g. due to updates of the original Indexes they are the deployments of. Corresponds to the JSON property updateTime

Returns:

  • (String)


22127
22128
22129
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22127

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22134
22135
22136
22137
22138
22139
22140
22141
22142
22143
22144
22145
22146
22147
22148
22149
22150
22151
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22134

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployed_indexes = args[:deployed_indexes] if args.key?(:deployed_indexes)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
  @public_endpoint_domain_name = args[:public_endpoint_domain_name] if args.key?(:public_endpoint_domain_name)
  @public_endpoint_enabled = args[:public_endpoint_enabled] if args.key?(:public_endpoint_enabled)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @update_time = args[:update_time] if args.key?(:update_time)
end