Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IngestEventsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for MemoryBankService.IngestEvents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IngestEventsRequest

Returns a new instance of GoogleCloudAiplatformV1beta1IngestEventsRequest.



30930
30931
30932
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30930

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#direct_contents_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IngestionDirectContentsSource

Ingest events directly from the request. Corresponds to the JSON property directContentsSource



30868
30869
30870
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30868

def direct_contents_source
  @direct_contents_source
end

#disable_memory_revisionsBoolean Also known as: disable_memory_revisions?

Optional. If true, no revisions will be created for this request. Corresponds to the JSON property disableMemoryRevisions

Returns:

  • (Boolean)


30873
30874
30875
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30873

def disable_memory_revisions
  @disable_memory_revisions
end

#force_flushBoolean Also known as: force_flush?

Optional. Forces a flush of all pending events in the stream and triggers memory generation immediately bypassing any conditions configured in the generation_trigger_config. Corresponds to the JSON property forceFlush

Returns:

  • (Boolean)


30881
30882
30883
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30881

def force_flush
  @force_flush
end

#generation_trigger_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfig

Represents configuration for triggering generation. Corresponds to the JSON property generationTriggerConfig



30887
30888
30889
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30887

def generation_trigger_config
  @generation_trigger_config
end

#metadataHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>

Optional. User-provided metadata for the generated memories. This is not generated by Memory Bank. Corresponds to the JSON property metadata



30893
30894
30895
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30893

def 
  @metadata
end

#metadata_merge_strategyString

Optional. The strategy to use when applying metadata to existing memories. Corresponds to the JSON property metadataMergeStrategy

Returns:

  • (String)


30898
30899
30900
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30898

def 
  @metadata_merge_strategy
end

#revision_expire_timeString

Optional. Timestamp of when the revision is considered expired. If not set, the memory revision will be kept until manually deleted. Corresponds to the JSON property revisionExpireTime

Returns:

  • (String)


30904
30905
30906
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30904

def revision_expire_time
  @revision_expire_time
end

#revision_labelsHash<String,String>

Optional. Labels to be applied to the generated memory revisions. For example, you can use this to label a revision with its data source. Corresponds to the JSON property revisionLabels

Returns:

  • (Hash<String,String>)


30910
30911
30912
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30910

def revision_labels
  @revision_labels
end

#revision_ttlString

Optional. The TTL for the revision. The expiration time is computed: now + TTL. Corresponds to the JSON property revisionTtl

Returns:

  • (String)


30915
30916
30917
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30915

def revision_ttl
  @revision_ttl
end

#scopeHash<String,String>

Required. The scope of the memories that should be generated from the stream. Memories will be consolidated across memories with the same scope. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


30922
30923
30924
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30922

def scope
  @scope
end

#stream_idString

Optional. The ID of the stream to ingest events into. If not provided, a new one will be created. Corresponds to the JSON property streamId

Returns:

  • (String)


30928
30929
30930
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30928

def stream_id
  @stream_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30935
30936
30937
30938
30939
30940
30941
30942
30943
30944
30945
30946
30947
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30935

def update!(**args)
  @direct_contents_source = args[:direct_contents_source] if args.key?(:direct_contents_source)
  @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions)
  @force_flush = args[:force_flush] if args.key?(:force_flush)
  @generation_trigger_config = args[:generation_trigger_config] if args.key?(:generation_trigger_config)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metadata_merge_strategy = args[:metadata_merge_strategy] if args.key?(:metadata_merge_strategy)
  @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time)
  @revision_labels = args[:revision_labels] if args.key?(:revision_labels)
  @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl)
  @scope = args[:scope] if args.key?(:scope)
  @stream_id = args[:stream_id] if args.key?(:stream_id)
end