Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IngestEventsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IngestEventsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for MemoryBankService.IngestEvents.
Instance Attribute Summary collapse
-
#direct_contents_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IngestionDirectContentsSource
Ingest events directly from the request.
-
#disable_memory_revisions ⇒ Boolean
(also: #disable_memory_revisions?)
Optional.
-
#force_flush ⇒ Boolean
(also: #force_flush?)
Optional.
-
#generation_trigger_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfig
Represents configuration for triggering generation.
-
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>
Optional.
-
#metadata_merge_strategy ⇒ String
Optional.
-
#revision_expire_time ⇒ String
Optional.
-
#revision_labels ⇒ Hash<String,String>
Optional.
-
#revision_ttl ⇒ String
Optional.
-
#scope ⇒ Hash<String,String>
Required.
-
#stream_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IngestEventsRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1IngestEventsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IngestEventsRequest
Returns a new instance of GoogleCloudAiplatformV1beta1IngestEventsRequest.
29385 29386 29387 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29385 def initialize(**args) update!(**args) end |
Instance Attribute Details
#direct_contents_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IngestionDirectContentsSource
Ingest events directly from the request.
Corresponds to the JSON property directContentsSource
29323 29324 29325 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29323 def direct_contents_source @direct_contents_source end |
#disable_memory_revisions ⇒ Boolean Also known as: disable_memory_revisions?
Optional. If true, no revisions will be created for this request.
Corresponds to the JSON property disableMemoryRevisions
29328 29329 29330 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29328 def disable_memory_revisions @disable_memory_revisions end |
#force_flush ⇒ Boolean Also known as: force_flush?
Optional. Forces a flush of all pending events in the stream and triggers
memory generation immediately bypassing any conditions configured in the
generation_trigger_config.
Corresponds to the JSON property forceFlush
29336 29337 29338 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29336 def force_flush @force_flush end |
#generation_trigger_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfig
Represents configuration for triggering generation.
Corresponds to the JSON property generationTriggerConfig
29342 29343 29344 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29342 def generation_trigger_config @generation_trigger_config end |
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>
Optional. User-provided metadata for the generated memories. This is not
generated by Memory Bank.
Corresponds to the JSON property metadata
29348 29349 29350 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29348 def @metadata end |
#metadata_merge_strategy ⇒ String
Optional. The strategy to use when applying metadata to existing memories.
Corresponds to the JSON property metadataMergeStrategy
29353 29354 29355 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29353 def @metadata_merge_strategy end |
#revision_expire_time ⇒ String
Optional. Timestamp of when the revision is considered expired. If not set,
the memory revision will be kept until manually deleted.
Corresponds to the JSON property revisionExpireTime
29359 29360 29361 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29359 def revision_expire_time @revision_expire_time end |
#revision_labels ⇒ Hash<String,String>
Optional. Labels to be applied to the generated memory revisions. For example,
you can use this to label a revision with its data source.
Corresponds to the JSON property revisionLabels
29365 29366 29367 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29365 def revision_labels @revision_labels end |
#revision_ttl ⇒ String
Optional. The TTL for the revision. The expiration time is computed: now + TTL.
Corresponds to the JSON property revisionTtl
29370 29371 29372 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29370 def revision_ttl @revision_ttl end |
#scope ⇒ Hash<String,String>
Required. The scope of the memories that should be generated from the stream.
Memories will be consolidated across memories with the same scope. Scope
values cannot contain the wildcard character '*'.
Corresponds to the JSON property scope
29377 29378 29379 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29377 def scope @scope end |
#stream_id ⇒ String
Optional. The ID of the stream to ingest events into. If not provided, a new
one will be created.
Corresponds to the JSON property streamId
29383 29384 29385 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29383 def stream_id @stream_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29390 29391 29392 29393 29394 29395 29396 29397 29398 29399 29400 29401 29402 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29390 def update!(**args) @direct_contents_source = args[:direct_contents_source] if args.key?(:direct_contents_source) @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions) @force_flush = args[:force_flush] if args.key?(:force_flush) @generation_trigger_config = args[:generation_trigger_config] if args.key?(:generation_trigger_config) @metadata = args[:metadata] if args.key?(:metadata) @metadata_merge_strategy = args[:metadata_merge_strategy] if args.key?(:metadata_merge_strategy) @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time) @revision_labels = args[:revision_labels] if args.key?(:revision_labels) @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl) @scope = args[:scope] if args.key?(:scope) @stream_id = args[:stream_id] if args.key?(:stream_id) end |