Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IngestEventsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IngestEventsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for MemoryBankService.IngestEvents.
Instance Attribute Summary collapse
-
#direct_contents_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IngestionDirectContentsSource
Ingest events directly from the request.
-
#force_flush ⇒ Boolean
(also: #force_flush?)
Optional.
-
#generation_trigger_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfig
Represents configuration for triggering generation.
-
#scope ⇒ Hash<String,String>
Required.
-
#stream_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IngestEventsRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1IngestEventsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IngestEventsRequest
Returns a new instance of GoogleCloudAiplatformV1beta1IngestEventsRequest.
27675 27676 27677 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27675 def initialize(**args) update!(**args) end |
Instance Attribute Details
#direct_contents_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IngestionDirectContentsSource
Ingest events directly from the request.
Corresponds to the JSON property directContentsSource
27647 27648 27649 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27647 def direct_contents_source @direct_contents_source end |
#force_flush ⇒ Boolean Also known as: force_flush?
Optional. Forces a flush of all pending events in the stream and triggers
memory generation immediately bypassing any conditions configured in the
generation_trigger_config.
Corresponds to the JSON property forceFlush
27654 27655 27656 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27654 def force_flush @force_flush end |
#generation_trigger_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfig
Represents configuration for triggering generation.
Corresponds to the JSON property generationTriggerConfig
27660 27661 27662 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27660 def generation_trigger_config @generation_trigger_config end |
#scope ⇒ Hash<String,String>
Required. The scope of the memories that should be generated from the stream.
Memories will be consolidated across memories with the same scope. Scope
values cannot contain the wildcard character '*'.
Corresponds to the JSON property scope
27667 27668 27669 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27667 def scope @scope end |
#stream_id ⇒ String
Optional. The ID of the stream to ingest events into. If not provided, a new
one will be created.
Corresponds to the JSON property streamId
27673 27674 27675 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27673 def stream_id @stream_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27680 27681 27682 27683 27684 27685 27686 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27680 def update!(**args) @direct_contents_source = args[:direct_contents_source] if args.key?(:direct_contents_source) @force_flush = args[:force_flush] if args.key?(:force_flush) @generation_trigger_config = args[:generation_trigger_config] if args.key?(:generation_trigger_config) @scope = args[:scope] if args.key?(:scope) @stream_id = args[:stream_id] if args.key?(:stream_id) end |