Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IngestEventsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for MemoryBankService.IngestEvents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IngestEventsRequest

Returns a new instance of GoogleCloudAiplatformV1beta1IngestEventsRequest.



22322
22323
22324
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22322

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#direct_contents_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IngestionDirectContentsSource

Ingest events directly from the request. Corresponds to the JSON property directContentsSource



22294
22295
22296
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22294

def direct_contents_source
  @direct_contents_source
end

#force_flushBoolean Also known as: force_flush?

Optional. Forces a flush of all pending events in the stream and triggers memory generation immediately bypassing any conditions configured in the generation_trigger_config. Corresponds to the JSON property forceFlush

Returns:

  • (Boolean)


22301
22302
22303
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22301

def force_flush
  @force_flush
end

#generation_trigger_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfig

Represents configuration for triggering generation. Corresponds to the JSON property generationTriggerConfig



22307
22308
22309
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22307

def generation_trigger_config
  @generation_trigger_config
end

#scopeHash<String,String>

Required. The scope of the memories that should be generated from the stream. Memories will be consolidated across memories with the same scope. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


22314
22315
22316
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22314

def scope
  @scope
end

#stream_idString

Optional. The ID of the stream to ingest events into. If not provided, a new one will be created. Corresponds to the JSON property streamId

Returns:

  • (String)


22320
22321
22322
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22320

def stream_id
  @stream_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22327
22328
22329
22330
22331
22332
22333
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22327

def update!(**args)
  @direct_contents_source = args[:direct_contents_source] if args.key?(:direct_contents_source)
  @force_flush = args[:force_flush] if args.key?(:force_flush)
  @generation_trigger_config = args[:generation_trigger_config] if args.key?(:generation_trigger_config)
  @scope = args[:scope] if args.key?(:scope)
  @stream_id = args[:stream_id] if args.key?(:stream_id)
end