Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IntegratedGradientsAttribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IntegratedGradientsAttribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An attribution method that computes the Aumann-Shapley value taking advantage of the model's fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1703.01365
Instance Attribute Summary collapse
-
#blur_baseline_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BlurBaselineConfig
Config for blur baseline.
-
#smooth_grad_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SmoothGradConfig
Config for SmoothGrad approximation of gradients.
-
#step_count ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IntegratedGradientsAttribution
constructor
A new instance of GoogleCloudAiplatformV1beta1IntegratedGradientsAttribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IntegratedGradientsAttribution
Returns a new instance of GoogleCloudAiplatformV1beta1IntegratedGradientsAttribution.
22514 22515 22516 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blur_baseline_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BlurBaselineConfig
Config for blur baseline. When enabled, a linear path from the maximally
blurred image to the input image is created. Using a blurred baseline instead
of zero (black image) is motivated by the BlurIG approach explained here:
https://arxiv.org/abs/2004.03383
Corresponds to the JSON property blurBaselineConfig
22496 22497 22498 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22496 def blur_baseline_config @blur_baseline_config end |
#smooth_grad_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SmoothGradConfig
Config for SmoothGrad approximation of gradients. When enabled, the gradients
are approximated by averaging the gradients from noisy samples in the vicinity
of the inputs. Adding noise can help improve the computed gradients. Refer to
this paper for more details: https://arxiv.org/pdf/1706.03825.pdf
Corresponds to the JSON property smoothGradConfig
22504 22505 22506 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22504 def smooth_grad_config @smooth_grad_config end |
#step_count ⇒ Fixnum
Required. The number of steps for approximating the path integral. A good
value to start is 50 and gradually increase until the sum to diff property is
within the desired error range. Valid range of its value is [1, 100],
inclusively.
Corresponds to the JSON property stepCount
22512 22513 22514 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22512 def step_count @step_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22519 22520 22521 22522 22523 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22519 def update!(**args) @blur_baseline_config = args[:blur_baseline_config] if args.key?(:blur_baseline_config) @smooth_grad_config = args[:smooth_grad_config] if args.key?(:smooth_grad_config) @step_count = args[:step_count] if args.key?(:step_count) end |