Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IntermediateExtractedMemory
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IntermediateExtractedMemory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An extracted memory that is the intermediate result before consolidation.
Instance Attribute Summary collapse
-
#context ⇒ String
Output only.
-
#fact ⇒ String
Output only.
-
#structured_data ⇒ Hash<String,Object>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IntermediateExtractedMemory
constructor
A new instance of GoogleCloudAiplatformV1beta1IntermediateExtractedMemory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IntermediateExtractedMemory
Returns a new instance of GoogleCloudAiplatformV1beta1IntermediateExtractedMemory.
29005 29006 29007 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29005 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context ⇒ String
Output only. Represents the explanation of why the information was extracted
from the source content.
Corresponds to the JSON property context
28993 28994 28995 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28993 def context @context end |
#fact ⇒ String
Output only. Represents the fact of the extracted memory.
Corresponds to the JSON property fact
28998 28999 29000 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28998 def fact @fact end |
#structured_data ⇒ Hash<String,Object>
Output only. Represents the structured value of the extracted memory.
Corresponds to the JSON property structuredData
29003 29004 29005 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29003 def structured_data @structured_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29010 29011 29012 29013 29014 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29010 def update!(**args) @context = args[:context] if args.key?(:context) @fact = args[:fact] if args.key?(:fact) @structured_data = args[:structured_data] if args.key?(:structured_data) end |