Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IntermediateExtractedMemory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An extracted memory that is the intermediate result before consolidation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IntermediateExtractedMemory

Returns a new instance of GoogleCloudAiplatformV1beta1IntermediateExtractedMemory.



27965
27966
27967
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contextString

Output only. Represents the explanation of why the information was extracted from the source content. Corresponds to the JSON property context

Returns:

  • (String)


27953
27954
27955
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27953

def context
  @context
end

#factString

Output only. Represents the fact of the extracted memory. Corresponds to the JSON property fact

Returns:

  • (String)


27958
27959
27960
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27958

def fact
  @fact
end

#structured_dataHash<String,Object>

Output only. Represents the structured value of the extracted memory. Corresponds to the JSON property structuredData

Returns:

  • (Hash<String,Object>)


27963
27964
27965
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27963

def structured_data
  @structured_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27970
27971
27972
27973
27974
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27970

def update!(**args)
  @context = args[:context] if args.key?(:context)
  @fact = args[:fact] if args.key?(:fact)
  @structured_data = args[:structured_data] if args.key?(:structured_data)
end