Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IntermediateExtractedMemory
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IntermediateExtractedMemory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An extracted memory that is the intermediate result before consolidation.
Instance Attribute Summary collapse
-
#context ⇒ String
Output only.
-
#fact ⇒ String
Output only.
-
#structured_data ⇒ Hash<String,Object>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IntermediateExtractedMemory
constructor
A new instance of GoogleCloudAiplatformV1beta1IntermediateExtractedMemory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1IntermediateExtractedMemory
Returns a new instance of GoogleCloudAiplatformV1beta1IntermediateExtractedMemory.
22612 22613 22614 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22612 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context ⇒ String
Output only. Represents the explanation of why the information was extracted
from the source content.
Corresponds to the JSON property context
22600 22601 22602 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22600 def context @context end |
#fact ⇒ String
Output only. Represents the fact of the extracted memory.
Corresponds to the JSON property fact
22605 22606 22607 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22605 def fact @fact end |
#structured_data ⇒ Hash<String,Object>
Output only. Represents the structured value of the extracted memory.
Corresponds to the JSON property structuredData
22610 22611 22612 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22610 def structured_data @structured_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22617 22618 22619 22620 22621 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22617 def update!(**args) @context = args[:context] if args.key?(:context) @fact = args[:fact] if args.key?(:fact) @structured_data = args[:structured_data] if args.key?(:structured_data) end |