Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1KeepAliveProbe

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents the configuration for keep-alive probe. Contains configuration on a specified endpoint that a deployment host should use to keep the container alive based on the probe settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1KeepAliveProbe

Returns a new instance of GoogleCloudAiplatformV1beta1KeepAliveProbe.



22704
22705
22706
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#http_getGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1KeepAliveProbeHttpGet

Specifies the HTTP GET configuration for the probe. Corresponds to the JSON property httpGet



22696
22697
22698
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22696

def http_get
  @http_get
end

#max_secondsFixnum

Optional. Specifies the maximum duration (in seconds) to keep the instance alive via this probe. Can be a maximum of 3600 seconds (1 hour). Corresponds to the JSON property maxSeconds

Returns:

  • (Fixnum)


22702
22703
22704
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22702

def max_seconds
  @max_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22709
22710
22711
22712
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 22709

def update!(**args)
  @http_get = args[:http_get] if args.key?(:http_get)
  @max_seconds = args[:max_seconds] if args.key?(:max_seconds)
end