Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LineageSubgraph
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LineageSubgraph
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A subgraph of the overall lineage graph. Event edges connect Artifact and Execution nodes.
Instance Attribute Summary collapse
-
#artifacts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Artifact>
The Artifact nodes in the subgraph.
-
#events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Event>
The Event edges between Artifacts and Executions in the subgraph.
-
#executions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Execution>
The Execution nodes in the subgraph.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LineageSubgraph
constructor
A new instance of GoogleCloudAiplatformV1beta1LineageSubgraph.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LineageSubgraph
Returns a new instance of GoogleCloudAiplatformV1beta1LineageSubgraph.
28265 28266 28267 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28265 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifacts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Artifact>
The Artifact nodes in the subgraph.
Corresponds to the JSON property artifacts
28253 28254 28255 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28253 def artifacts @artifacts end |
#events ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Event>
The Event edges between Artifacts and Executions in the subgraph.
Corresponds to the JSON property events
28258 28259 28260 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28258 def events @events end |
#executions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Execution>
The Execution nodes in the subgraph.
Corresponds to the JSON property executions
28263 28264 28265 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28263 def executions @executions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28270 28271 28272 28273 28274 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28270 def update!(**args) @artifacts = args[:artifacts] if args.key?(:artifacts) @events = args[:events] if args.key?(:events) @executions = args[:executions] if args.key?(:executions) end |