Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListMemoryRevisionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for MemoryBankService.ListMemoryRevisions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListMemoryRevisionsResponse

Returns a new instance of GoogleCloudAiplatformV1beta1ListMemoryRevisionsResponse.



28665
28666
28667
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#memory_revisionsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryRevision>

The list of Memory Revisions in the request page. Corresponds to the JSON property memoryRevisions



28657
28658
28659
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28657

def memory_revisions
  @memory_revisions
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28663
28664
28665
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28663

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28670
28671
28672
28673
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28670

def update!(**args)
  @memory_revisions = args[:memory_revisions] if args.key?(:memory_revisions)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end