Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListMemoryRevisionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListMemoryRevisionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for MemoryBankService.ListMemoryRevisions.
Instance Attribute Summary collapse
-
#memory_revisions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryRevision>
The list of Memory Revisions in the request page.
-
#next_page_token ⇒ String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListMemoryRevisionsResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ListMemoryRevisionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListMemoryRevisionsResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ListMemoryRevisionsResponse.
23779 23780 23781 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23779 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memory_revisions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryRevision>
The list of Memory Revisions in the request page.
Corresponds to the JSON property memoryRevisions
23771 23772 23773 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23771 def memory_revisions @memory_revisions end |
#next_page_token ⇒ String
A token, which can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
23777 23778 23779 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23777 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23784 23785 23786 23787 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 23784 def update!(**args) @memory_revisions = args[:memory_revisions] if args.key?(:memory_revisions) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |