Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListModelVersionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListModelVersionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for ModelService.ListModelVersions
Instance Attribute Summary collapse
-
#models ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Model>
List of Model versions in the requested page.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListModelVersionsResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ListModelVersionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListModelVersionsResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ListModelVersionsResponse.
31334 31335 31336 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31334 def initialize(**args) update!(**args) end |
Instance Attribute Details
#models ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Model>
List of Model versions in the requested page. In the returned Model name field,
version ID instead of regvision tag will be included.
Corresponds to the JSON property models
31326 31327 31328 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31326 def models @models end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListModelVersionsRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
31332 31333 31334 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31332 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31339 31340 31341 31342 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31339 def update!(**args) @models = args[:models] if args.key?(:models) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |