Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListMonitoredAgentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for AgentAnomalyDetectionService.ListMonitoredAgents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListMonitoredAgentsResponse

Returns a new instance of GoogleCloudAiplatformV1beta1ListMonitoredAgentsResponse.



30696
30697
30698
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30696

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#monitored_agentsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MonitoredAgent>

A list of MonitoredAgents that matches the specified filter in the request. Corresponds to the JSON property monitoredAgents



30680
30681
30682
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30680

def monitored_agents
  @monitored_agents
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30686
30687
30688
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30686

def next_page_token
  @next_page_token
end

#total_sizeFixnum

The total number of MonitoredAgents in the request scope after the request filter (if any) is applied. With no filter this is the unconditional count of MonitoredAgents in the parent; with filter = "state = ACTIVE" it is the active-agent count, and so on. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


30694
30695
30696
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30694

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30701
30702
30703
30704
30705
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30701

def update!(**args)
  @monitored_agents = args[:monitored_agents] if args.key?(:monitored_agents)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @total_size = args[:total_size] if args.key?(:total_size)
end