Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListMonitoredAgentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListMonitoredAgentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for AgentAnomalyDetectionService.ListMonitoredAgents.
Instance Attribute Summary collapse
-
#monitored_agents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MonitoredAgent>
A list of MonitoredAgents that matches the specified filter in the request.
-
#next_page_token ⇒ String
A token, which can be sent as
page_tokento retrieve the next page. -
#total_size ⇒ Fixnum
The total number of MonitoredAgents in the request scope after the request
filter(if any) is applied.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListMonitoredAgentsResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ListMonitoredAgentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListMonitoredAgentsResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ListMonitoredAgentsResponse.
30874 30875 30876 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30874 def initialize(**args) update!(**args) end |
Instance Attribute Details
#monitored_agents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MonitoredAgent>
A list of MonitoredAgents that matches the specified filter in the request.
Corresponds to the JSON property monitoredAgents
30858 30859 30860 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30858 def monitored_agents @monitored_agents end |
#next_page_token ⇒ String
A token, which can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
30864 30865 30866 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30864 def next_page_token @next_page_token end |
#total_size ⇒ Fixnum
The total number of MonitoredAgents in the request scope after the request
filter (if any) is applied. With no filter this is the unconditional count of
MonitoredAgents in the parent; with filter = "state = ACTIVE" it is the
active-agent count, and so on.
Corresponds to the JSON property totalSize
30872 30873 30874 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30872 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30879 30880 30881 30882 30883 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30879 def update!(**args) @monitored_agents = args[:monitored_agents] if args.key?(:monitored_agents) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @total_size = args[:total_size] if args.key?(:total_size) end |