Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListReasoningEngineRuntimeRevisionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListReasoningEngineRuntimeRevisionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for ReasoningEngineRuntimeRevisionService. ListReasoningEngineRuntimeRevisions
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#reasoning_engine_runtime_revisions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineRuntimeRevision>
List of ReasoningEngineRuntimeRevisions in the requested page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListReasoningEngineRuntimeRevisionsResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ListReasoningEngineRuntimeRevisionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListReasoningEngineRuntimeRevisionsResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ListReasoningEngineRuntimeRevisionsResponse.
24440 24441 24442 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to
ListReasoningEngineRuntimeRevisionsRequest.page_token to obtain that page.
Corresponds to the JSON property nextPageToken
24433 24434 24435 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24433 def next_page_token @next_page_token end |
#reasoning_engine_runtime_revisions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineRuntimeRevision>
List of ReasoningEngineRuntimeRevisions in the requested page.
Corresponds to the JSON property reasoningEngineRuntimeRevisions
24438 24439 24440 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24438 def reasoning_engine_runtime_revisions @reasoning_engine_runtime_revisions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24445 24446 24447 24448 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24445 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @reasoning_engine_runtime_revisions = args[:reasoning_engine_runtime_revisions] if args.key?(:reasoning_engine_runtime_revisions) end |