Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListSkillRevisionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ListSkillRevisionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for SkillRegistryService.ListSkillRevisions.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token, which can be sent as
page_tokento retrieve the next page. -
#skill_revisions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SkillRevision>
The list of Skill Revisions in the request page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListSkillRevisionsResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ListSkillRevisionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ListSkillRevisionsResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ListSkillRevisionsResponse.
29536 29537 29538 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29536 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token, which can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
29529 29530 29531 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29529 def next_page_token @next_page_token end |
#skill_revisions ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SkillRevision>
The list of Skill Revisions in the request page.
Corresponds to the JSON property skillRevisions
29534 29535 29536 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29534 def skill_revisions @skill_revisions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29541 29542 29543 29544 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29541 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @skill_revisions = args[:skill_revisions] if args.key?(:skill_revisions) end |