Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LogprobsResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LogprobsResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The log probabilities of the tokens generated by the model. This is useful for understanding the model's confidence in its predictions and for debugging. For example, you can use log probabilities to identify when the model is making a less confident prediction or to explore alternative responses that the model considered. A low log probability can also indicate that the model is " hallucinating" or generating factually incorrect information.
Instance Attribute Summary collapse
-
#chosen_candidates ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LogprobsResultCandidate>
A list of the chosen candidate tokens at each decoding step.
-
#top_candidates ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates>
A list of the top candidate tokens at each decoding step.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LogprobsResult
constructor
A new instance of GoogleCloudAiplatformV1beta1LogprobsResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LogprobsResult
Returns a new instance of GoogleCloudAiplatformV1beta1LogprobsResult.
24893 24894 24895 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24893 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chosen_candidates ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LogprobsResultCandidate>
A list of the chosen candidate tokens at each decoding step. The length of
this list is equal to the total number of decoding steps. Note that the chosen
candidate might not be in top_candidates.
Corresponds to the JSON property chosenCandidates
24885 24886 24887 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24885 def chosen_candidates @chosen_candidates end |
#top_candidates ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates>
A list of the top candidate tokens at each decoding step. The length of this
list is equal to the total number of decoding steps.
Corresponds to the JSON property topCandidates
24891 24892 24893 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24891 def top_candidates @top_candidates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24898 24899 24900 24901 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 24898 def update!(**args) @chosen_candidates = args[:chosen_candidates] if args.key?(:chosen_candidates) @top_candidates = args[:top_candidates] if args.key?(:top_candidates) end |