Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A list of the top candidate tokens and their log probabilities at each decoding step. This can be used to see what other tokens the model considered.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates

Returns a new instance of GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates.



31865
31866
31867
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidatesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LogprobsResultCandidate>

The list of candidate tokens, sorted by log probability in descending order. Corresponds to the JSON property candidates



31863
31864
31865
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31863

def candidates
  @candidates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31870
31871
31872
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31870

def update!(**args)
  @candidates = args[:candidates] if args.key?(:candidates)
end