Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A list of the top candidate tokens and their log probabilities at each decoding step. This can be used to see what other tokens the model considered.
Instance Attribute Summary collapse
-
#candidates ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LogprobsResultCandidate>
The list of candidate tokens, sorted by log probability in descending order.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates
constructor
A new instance of GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates
Returns a new instance of GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates.
25017 25018 25019 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidates ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LogprobsResultCandidate>
The list of candidate tokens, sorted by log probability in descending order.
Corresponds to the JSON property candidates
25015 25016 25017 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25015 def candidates @candidates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25022 25023 25024 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25022 def update!(**args) @candidates = args[:candidates] if args.key?(:candidates) end |