Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a semantic grouping of failures (e.g., "Hallucination of Action").

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LossCluster

Returns a new instance of GoogleCloudAiplatformV1beta1LossCluster.



32496
32497
32498
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Unique identifier for the loss cluster within the scope of the analysis result. Corresponds to the JSON property clusterId

Returns:

  • (String)


32478
32479
32480
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32478

def cluster_id
  @cluster_id
end

#examplesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossExample>

A list of examples that belong to this cluster. This links the cluster back to the specific EvaluationItems and Rubrics. Corresponds to the JSON property examples



32484
32485
32486
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32484

def examples
  @examples
end

#item_countFixnum

The total number of EvaluationItems falling into this cluster. Corresponds to the JSON property itemCount

Returns:

  • (Fixnum)


32489
32490
32491
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32489

def item_count
  @item_count
end

#taxonomy_entryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossTaxonomyEntry

Defines a specific entry in the loss pattern taxonomy. Corresponds to the JSON property taxonomyEntry



32494
32495
32496
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32494

def taxonomy_entry
  @taxonomy_entry
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32501
32502
32503
32504
32505
32506
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32501

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @examples = args[:examples] if args.key?(:examples)
  @item_count = args[:item_count] if args.key?(:item_count)
  @taxonomy_entry = args[:taxonomy_entry] if args.key?(:taxonomy_entry)
end