Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossExample

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a specific example of a loss pattern.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LossExample

Returns a new instance of GoogleCloudAiplatformV1beta1LossExample.



30624
30625
30626
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30624

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#evaluation_itemString

Reference to the persisted EvalItem resource name. Format: projects/.../ locations/.../evaluationItems/item_id Used when analysis is run on an EvalSet. Corresponds to the JSON property evaluationItem

Returns:

  • (String)


30610
30611
30612
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30610

def evaluation_item
  @evaluation_item
end

#evaluation_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationResult

Evaluation result. Corresponds to the JSON property evaluationResult



30615
30616
30617
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30615

def evaluation_result
  @evaluation_result
end

#failed_rubricsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FailedRubric>

The specific rubric(s) that failed and caused this example to be classified here. An example might fail multiple rubrics, but only specific ones trigger this loss pattern. Corresponds to the JSON property failedRubrics



30622
30623
30624
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30622

def failed_rubrics
  @failed_rubrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30629
30630
30631
30632
30633
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30629

def update!(**args)
  @evaluation_item = args[:evaluation_item] if args.key?(:evaluation_item)
  @evaluation_result = args[:evaluation_result] if args.key?(:evaluation_result)
  @failed_rubrics = args[:failed_rubrics] if args.key?(:failed_rubrics)
end