Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossExample
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossExample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a specific example of a loss pattern.
Instance Attribute Summary collapse
-
#evaluation_item ⇒ String
Reference to the persisted EvalItem resource name.
-
#evaluation_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationResult
Evaluation result.
-
#failed_rubrics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FailedRubric>
The specific rubric(s) that failed and caused this example to be classified here.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LossExample
constructor
A new instance of GoogleCloudAiplatformV1beta1LossExample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LossExample
Returns a new instance of GoogleCloudAiplatformV1beta1LossExample.
25166 25167 25168 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25166 def initialize(**args) update!(**args) end |
Instance Attribute Details
#evaluation_item ⇒ String
Reference to the persisted EvalItem resource name. Format: projects/.../
locations/.../evaluationItems/item_id Used when analysis is run on an
EvalSet.
Corresponds to the JSON property evaluationItem
25152 25153 25154 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25152 def evaluation_item @evaluation_item end |
#evaluation_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationResult
Evaluation result.
Corresponds to the JSON property evaluationResult
25157 25158 25159 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25157 def evaluation_result @evaluation_result end |
#failed_rubrics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FailedRubric>
The specific rubric(s) that failed and caused this example to be classified
here. An example might fail multiple rubrics, but only specific ones trigger
this loss pattern.
Corresponds to the JSON property failedRubrics
25164 25165 25166 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25164 def failed_rubrics @failed_rubrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25171 25172 25173 25174 25175 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25171 def update!(**args) @evaluation_item = args[:evaluation_item] if args.key?(:evaluation_item) @evaluation_result = args[:evaluation_result] if args.key?(:evaluation_result) @failed_rubrics = args[:failed_rubrics] if args.key?(:failed_rubrics) end |