Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossTaxonomyEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Defines a specific entry in the loss pattern taxonomy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LossTaxonomyEntry

Returns a new instance of GoogleCloudAiplatformV1beta1LossTaxonomyEntry.



32048
32049
32050
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A detailed description of this loss pattern. Example: "The agent verbally confirms an action without executing the tool." Corresponds to the JSON property description

Returns:

  • (String)


32034
32035
32036
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32034

def description
  @description
end

#l1_categoryString

The primary category of the loss (e.g., "Hallucination", "Tool Calling"). This field is typically required. Corresponds to the JSON property l1Category

Returns:

  • (String)


32040
32041
32042
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32040

def l1_category
  @l1_category
end

#l2_categoryString

The secondary category of the loss (e.g., "Hallucination of Action", " Incorrect Tool Selection"). Corresponds to the JSON property l2Category

Returns:

  • (String)


32046
32047
32048
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32046

def l2_category
  @l2_category
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32053
32054
32055
32056
32057
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32053

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @l1_category = args[:l1_category] if args.key?(:l1_category)
  @l2_category = args[:l2_category] if args.key?(:l2_category)
end