Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LossTaxonomyEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Defines a specific entry in the loss pattern taxonomy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LossTaxonomyEntry

Returns a new instance of GoogleCloudAiplatformV1beta1LossTaxonomyEntry.



25200
25201
25202
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A detailed description of this loss pattern. Example: "The agent verbally confirms an action without executing the tool." Corresponds to the JSON property description

Returns:

  • (String)


25186
25187
25188
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25186

def description
  @description
end

#l1_categoryString

The primary category of the loss (e.g., "Hallucination", "Tool Calling"). This field is typically required. Corresponds to the JSON property l1Category

Returns:

  • (String)


25192
25193
25194
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25192

def l1_category
  @l1_category
end

#l2_categoryString

The secondary category of the loss (e.g., "Hallucination of Action", " Incorrect Tool Selection"). Corresponds to the JSON property l2Category

Returns:

  • (String)


25198
25199
25200
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25198

def l2_category
  @l2_category
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25205
25206
25207
25208
25209
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25205

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @l1_category = args[:l1_category] if args.key?(:l1_category)
  @l2_category = args[:l2_category] if args.key?(:l2_category)
end