Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Specification of a single machine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MachineSpec

Returns a new instance of GoogleCloudAiplatformV1beta1MachineSpec.



31999
32000
32001
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_countFixnum

The number of accelerators to attach to the machine. For accelerator optimized machine types, One may set the accelerator_count from 1 to N for machine with N GPUs. If accelerator_count is less than or equal to N / 2, Agent Platform co-schedules the replicas of the model into the same VM to save cost. For example, if the machine type is a3-highgpu-8g, which has 8 H100 GPUs, one can set accelerator_count to 1 to 8. If accelerator_count is 1, 2, 3, or 4, Agent Platform co-schedules 8, 4, 2, or 2 replicas of the model into the same VM to save cost. When co-scheduling, CPU, memory and storage on the VM will be distributed to replicas on the VM. For example, one can expect a co-scheduled replica requesting 2 GPUs out of a 8-GPU VM will receive 25% of the CPU, memory and storage of the VM. Note that the feature is not compatible with multihost_gpu_node_count. When multihost_gpu_node_count is set, the co- scheduling will not be enabled. Corresponds to the JSON property acceleratorCount

Returns:

  • (Fixnum)


31940
31941
31942
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31940

def accelerator_count
  @accelerator_count
end

#accelerator_typeString

Immutable. The type of accelerator(s) that may be attached to the machine as per accelerator_count. Corresponds to the JSON property acceleratorType

Returns:

  • (String)


31946
31947
31948
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31946

def accelerator_type
  @accelerator_type
end

#gpu_partition_sizeString

Optional. Immutable. The Nvidia GPU partition size. When specified, the requested accelerators will be partitioned into smaller GPU partitions. For example, if the request is for 8 units of NVIDIA A100 GPUs, and gpu_partition_size="1g.10gb", the service will create 8 * 7 = 56 partitioned MIG instances. The partition size must be a value supported by the requested accelerator. Refer to Nvidia GPU Partitioning for the available partition sizes. If set, the accelerator_count should be set to 1. Corresponds to the JSON property gpuPartitionSize

Returns:

  • (String)


31959
31960
31961
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31959

def gpu_partition_size
  @gpu_partition_size
end

#machine_typeString

Immutable. The type of the machine. See the list of machine types supported for prediction See the list of machine types supported for custom training. For DeployedModel this field is optional, and the default value is n1- standard-2. For BatchPredictionJob or as part of WorkerPoolSpec this field is required. Corresponds to the JSON property machineType

Returns:

  • (String)


31971
31972
31973
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31971

def machine_type
  @machine_type
end

#min_gpu_driver_versionString

Optional. Immutable. The minimum GPU driver version that this machine requires. For example, "535.104.06". If not specified, the default GPU driver version will be used by the underlying infrastructure. Corresponds to the JSON property minGpuDriverVersion

Returns:

  • (String)


31978
31979
31980
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31978

def min_gpu_driver_version
  @min_gpu_driver_version
end

#multihost_gpu_node_countFixnum

Optional. Immutable. The number of nodes per replica for multihost GPU deployments. Corresponds to the JSON property multihostGpuNodeCount

Returns:

  • (Fixnum)


31984
31985
31986
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31984

def multihost_gpu_node_count
  @multihost_gpu_node_count
end

#reservation_affinityGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReservationAffinity

A ReservationAffinity can be used to configure a Vertex AI resource (e.g., a DeployedModel) to draw its Compute Engine resources from a Shared Reservation, or exclusively from on-demand capacity. Corresponds to the JSON property reservationAffinity



31991
31992
31993
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31991

def reservation_affinity
  @reservation_affinity
end

#tpu_topologyString

Immutable. The topology of the TPUs. Corresponds to the TPU topologies available from GKE. (Example: tpu_topology: "2x2x1"). Corresponds to the JSON property tpuTopology

Returns:

  • (String)


31997
31998
31999
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31997

def tpu_topology
  @tpu_topology
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32004

def update!(**args)
  @accelerator_count = args[:accelerator_count] if args.key?(:accelerator_count)
  @accelerator_type = args[:accelerator_type] if args.key?(:accelerator_type)
  @gpu_partition_size = args[:gpu_partition_size] if args.key?(:gpu_partition_size)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @min_gpu_driver_version = args[:min_gpu_driver_version] if args.key?(:min_gpu_driver_version)
  @multihost_gpu_node_count = args[:multihost_gpu_node_count] if args.key?(:multihost_gpu_node_count)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology)
end