Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Measurement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A message representing a Measurement of a Trial. A Measurement contains the Metrics got by executing a Trial using suggested hyperparameter values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Measurement

Returns a new instance of GoogleCloudAiplatformV1beta1Measurement.



30264
30265
30266
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#elapsed_durationString

Output only. Time that the Trial has been running at the point of this Measurement. Corresponds to the JSON property elapsedDuration

Returns:

  • (String)


30250
30251
30252
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30250

def elapsed_duration
  @elapsed_duration
end

#metricsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MeasurementMetric>

Output only. A list of metrics got by evaluating the objective functions using suggested Parameter values. Corresponds to the JSON property metrics



30256
30257
30258
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30256

def metrics
  @metrics
end

#step_countFixnum

Output only. The number of steps the machine learning model has been trained for. Must be non-negative. Corresponds to the JSON property stepCount

Returns:

  • (Fixnum)


30262
30263
30264
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30262

def step_count
  @step_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30269
30270
30271
30272
30273
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30269

def update!(**args)
  @elapsed_duration = args[:elapsed_duration] if args.key?(:elapsed_duration)
  @metrics = args[:metrics] if args.key?(:metrics)
  @step_count = args[:step_count] if args.key?(:step_count)
end