Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Memory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Memory

Returns a new instance of GoogleCloudAiplatformV1beta1Memory.



33943
33944
33945
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33943

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Represents the timestamp when this Memory was created. Corresponds to the JSON property createTime

Returns:

  • (String)


33843
33844
33845
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33843

def create_time
  @create_time
end

#descriptionString

Optional. Represents the description of the Memory. Corresponds to the JSON property description

Returns:

  • (String)


33848
33849
33850
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33848

def description
  @description
end

#disable_memory_revisionsBoolean Also known as: disable_memory_revisions?

Optional. Input only. Indicates whether no revision will be created for this request. Corresponds to the JSON property disableMemoryRevisions

Returns:

  • (Boolean)


33854
33855
33856
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33854

def disable_memory_revisions
  @disable_memory_revisions
end

#display_nameString

Optional. Represents the display name of the Memory. Corresponds to the JSON property displayName

Returns:

  • (String)


33860
33861
33862
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33860

def display_name
  @display_name
end

#expire_timeString

Optional. Represents the timestamp of when this resource is considered expired. This is always provided on output when expiration is set on input, regardless of whether expire_time or ttl was provided. Corresponds to the JSON property expireTime

Returns:

  • (String)


33867
33868
33869
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33867

def expire_time
  @expire_time
end

#factString

Optional. Represents semantic knowledge extracted from the source content. Corresponds to the JSON property fact

Returns:

  • (String)


33872
33873
33874
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33872

def fact
  @fact
end

#memory_typeString

Optional. Represents the type of the memory. If not set, the NATURAL_LANGUAGE_COLLECTION type is used. If STRUCTURED_COLLECTION or STRUCTURED_PROFILE is used, then structured_data must be provided. Corresponds to the JSON property memoryType

Returns:

  • (String)


33879
33880
33881
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33879

def memory_type
  @memory_type
end

#metadataHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>

Optional. Represents user-provided metadata for the Memory. This information was provided when creating, updating, or generating the Memory. It was not generated by Memory Bank. Corresponds to the JSON property metadata



33886
33887
33888
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33886

def 
  @metadata
end

#nameString

Identifier. Represents the resource name of the Memory. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine/memories/ memory` Corresponds to the JSON propertyname`

Returns:

  • (String)


33893
33894
33895
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33893

def name
  @name
end

#revision_expire_timeString

Optional. Input only. Represents the timestamp of when the revision is considered expired. If not set, the memory revision will be kept until manually deleted. Corresponds to the JSON property revisionExpireTime

Returns:

  • (String)


33900
33901
33902
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33900

def revision_expire_time
  @revision_expire_time
end

#revision_labelsHash<String,String>

Optional. Input only. Represents the labels to apply to the Memory Revision created as a result of this request. Corresponds to the JSON property revisionLabels

Returns:

  • (Hash<String,String>)


33906
33907
33908
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33906

def revision_labels
  @revision_labels
end

#revision_ttlString

Optional. Input only. Represents the TTL for the revision. The expiration time is computed: now + TTL. Corresponds to the JSON property revisionTtl

Returns:

  • (String)


33912
33913
33914
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33912

def revision_ttl
  @revision_ttl
end

#scopeHash<String,String>

Required. Immutable. Represents the scope of the Memory. Memories are isolated within their scope. The scope is defined when creating or generating memories. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


33919
33920
33921
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33919

def scope
  @scope
end

#structured_contentGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryStructuredContent

Represents the structured value of the memory. Corresponds to the JSON property structuredContent



33924
33925
33926
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33924

def structured_content
  @structured_content
end

#topicsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId>

Optional. Represents the Topics of the Memory. Corresponds to the JSON property topics



33929
33930
33931
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33929

def topics
  @topics
end

#ttlString

Optional. Input only. Represents the TTL for this resource. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


33935
33936
33937
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33935

def ttl
  @ttl
end

#update_timeString

Output only. Represents the timestamp when this Memory was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


33941
33942
33943
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33941

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33948
33949
33950
33951
33952
33953
33954
33955
33956
33957
33958
33959
33960
33961
33962
33963
33964
33965
33966
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33948

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @fact = args[:fact] if args.key?(:fact)
  @memory_type = args[:memory_type] if args.key?(:memory_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time)
  @revision_labels = args[:revision_labels] if args.key?(:revision_labels)
  @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl)
  @scope = args[:scope] if args.key?(:scope)
  @structured_content = args[:structured_content] if args.key?(:structured_content)
  @topics = args[:topics] if args.key?(:topics)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end