Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Memory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Memory

Returns a new instance of GoogleCloudAiplatformV1beta1Memory.



32904
32905
32906
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32904

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Represents the timestamp when this Memory was created. Corresponds to the JSON property createTime

Returns:

  • (String)


32804
32805
32806
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32804

def create_time
  @create_time
end

#descriptionString

Optional. Represents the description of the Memory. Corresponds to the JSON property description

Returns:

  • (String)


32809
32810
32811
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32809

def description
  @description
end

#disable_memory_revisionsBoolean Also known as: disable_memory_revisions?

Optional. Input only. Indicates whether no revision will be created for this request. Corresponds to the JSON property disableMemoryRevisions

Returns:

  • (Boolean)


32815
32816
32817
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32815

def disable_memory_revisions
  @disable_memory_revisions
end

#display_nameString

Optional. Represents the display name of the Memory. Corresponds to the JSON property displayName

Returns:

  • (String)


32821
32822
32823
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32821

def display_name
  @display_name
end

#expire_timeString

Optional. Represents the timestamp of when this resource is considered expired. This is always provided on output when expiration is set on input, regardless of whether expire_time or ttl was provided. Corresponds to the JSON property expireTime

Returns:

  • (String)


32828
32829
32830
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32828

def expire_time
  @expire_time
end

#factString

Optional. Represents semantic knowledge extracted from the source content. Corresponds to the JSON property fact

Returns:

  • (String)


32833
32834
32835
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32833

def fact
  @fact
end

#memory_typeString

Optional. Represents the type of the memory. If not set, the NATURAL_LANGUAGE_COLLECTION type is used. If STRUCTURED_COLLECTION or STRUCTURED_PROFILE is used, then structured_data must be provided. Corresponds to the JSON property memoryType

Returns:

  • (String)


32840
32841
32842
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32840

def memory_type
  @memory_type
end

#metadataHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>

Optional. Represents user-provided metadata for the Memory. This information was provided when creating, updating, or generating the Memory. It was not generated by Memory Bank. Corresponds to the JSON property metadata



32847
32848
32849
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32847

def 
  @metadata
end

#nameString

Identifier. Represents the resource name of the Memory. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine/memories/ memory` Corresponds to the JSON propertyname`

Returns:

  • (String)


32854
32855
32856
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32854

def name
  @name
end

#revision_expire_timeString

Optional. Input only. Represents the timestamp of when the revision is considered expired. If not set, the memory revision will be kept until manually deleted. Corresponds to the JSON property revisionExpireTime

Returns:

  • (String)


32861
32862
32863
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32861

def revision_expire_time
  @revision_expire_time
end

#revision_labelsHash<String,String>

Optional. Input only. Represents the labels to apply to the Memory Revision created as a result of this request. Corresponds to the JSON property revisionLabels

Returns:

  • (Hash<String,String>)


32867
32868
32869
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32867

def revision_labels
  @revision_labels
end

#revision_ttlString

Optional. Input only. Represents the TTL for the revision. The expiration time is computed: now + TTL. Corresponds to the JSON property revisionTtl

Returns:

  • (String)


32873
32874
32875
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32873

def revision_ttl
  @revision_ttl
end

#scopeHash<String,String>

Required. Immutable. Represents the scope of the Memory. Memories are isolated within their scope. The scope is defined when creating or generating memories. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


32880
32881
32882
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32880

def scope
  @scope
end

#structured_contentGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryStructuredContent

Represents the structured value of the memory. Corresponds to the JSON property structuredContent



32885
32886
32887
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32885

def structured_content
  @structured_content
end

#topicsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId>

Optional. Represents the Topics of the Memory. Corresponds to the JSON property topics



32890
32891
32892
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32890

def topics
  @topics
end

#ttlString

Optional. Input only. Represents the TTL for this resource. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


32896
32897
32898
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32896

def ttl
  @ttl
end

#update_timeString

Output only. Represents the timestamp when this Memory was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


32902
32903
32904
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32902

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32909
32910
32911
32912
32913
32914
32915
32916
32917
32918
32919
32920
32921
32922
32923
32924
32925
32926
32927
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32909

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @fact = args[:fact] if args.key?(:fact)
  @memory_type = args[:memory_type] if args.key?(:memory_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time)
  @revision_labels = args[:revision_labels] if args.key?(:revision_labels)
  @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl)
  @scope = args[:scope] if args.key?(:scope)
  @structured_content = args[:structured_content] if args.key?(:structured_content)
  @topics = args[:topics] if args.key?(:topics)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end