Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Memory
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Memory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A memory.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#disable_memory_revisions ⇒ Boolean
(also: #disable_memory_revisions?)
Optional.
-
#display_name ⇒ String
Optional.
-
#expire_time ⇒ String
Optional.
-
#fact ⇒ String
Optional.
-
#memory_type ⇒ String
Optional.
-
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>
Optional.
-
#name ⇒ String
Identifier.
-
#revision_expire_time ⇒ String
Optional.
-
#revision_labels ⇒ Hash<String,String>
Optional.
-
#revision_ttl ⇒ String
Optional.
-
#scope ⇒ Hash<String,String>
Required.
-
#structured_content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryStructuredContent
Represents the structured value of the memory.
-
#topics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId>
Optional.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Memory
constructor
A new instance of GoogleCloudAiplatformV1beta1Memory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Memory
Returns a new instance of GoogleCloudAiplatformV1beta1Memory.
30409 30410 30411 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Represents the timestamp when this Memory was created.
Corresponds to the JSON property createTime
30309 30310 30311 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30309 def create_time @create_time end |
#description ⇒ String
Optional. Represents the description of the Memory.
Corresponds to the JSON property description
30314 30315 30316 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30314 def description @description end |
#disable_memory_revisions ⇒ Boolean Also known as: disable_memory_revisions?
Optional. Input only. Indicates whether no revision will be created for this
request.
Corresponds to the JSON property disableMemoryRevisions
30320 30321 30322 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30320 def disable_memory_revisions @disable_memory_revisions end |
#display_name ⇒ String
Optional. Represents the display name of the Memory.
Corresponds to the JSON property displayName
30326 30327 30328 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30326 def display_name @display_name end |
#expire_time ⇒ String
Optional. Represents the timestamp of when this resource is considered expired.
This is always provided on output when expiration is set on input,
regardless of whether expire_time or ttl was provided.
Corresponds to the JSON property expireTime
30333 30334 30335 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30333 def expire_time @expire_time end |
#fact ⇒ String
Optional. Represents semantic knowledge extracted from the source content.
Corresponds to the JSON property fact
30338 30339 30340 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30338 def fact @fact end |
#memory_type ⇒ String
Optional. Represents the type of the memory. If not set, the
NATURAL_LANGUAGE_COLLECTION type is used. If STRUCTURED_COLLECTION or
STRUCTURED_PROFILE is used, then structured_data must be provided.
Corresponds to the JSON property memoryType
30345 30346 30347 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30345 def memory_type @memory_type end |
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>
Optional. Represents user-provided metadata for the Memory. This information
was provided when creating, updating, or generating the Memory. It was not
generated by Memory Bank.
Corresponds to the JSON property metadata
30352 30353 30354 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30352 def @metadata end |
#name ⇒ String
Identifier. Represents the resource name of the Memory. Format: projects/
project/locations/location/reasoningEngines/reasoning_engine/memories/
memory`
Corresponds to the JSON propertyname`
30359 30360 30361 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30359 def name @name end |
#revision_expire_time ⇒ String
Optional. Input only. Represents the timestamp of when the revision is
considered expired. If not set, the memory revision will be kept until
manually deleted.
Corresponds to the JSON property revisionExpireTime
30366 30367 30368 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30366 def revision_expire_time @revision_expire_time end |
#revision_labels ⇒ Hash<String,String>
Optional. Input only. Represents the labels to apply to the Memory Revision
created as a result of this request.
Corresponds to the JSON property revisionLabels
30372 30373 30374 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30372 def revision_labels @revision_labels end |
#revision_ttl ⇒ String
Optional. Input only. Represents the TTL for the revision. The expiration time
is computed: now + TTL.
Corresponds to the JSON property revisionTtl
30378 30379 30380 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30378 def revision_ttl @revision_ttl end |
#scope ⇒ Hash<String,String>
Required. Immutable. Represents the scope of the Memory. Memories are isolated
within their scope. The scope is defined when creating or generating memories.
Scope values cannot contain the wildcard character '*'.
Corresponds to the JSON property scope
30385 30386 30387 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30385 def scope @scope end |
#structured_content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryStructuredContent
Represents the structured value of the memory.
Corresponds to the JSON property structuredContent
30390 30391 30392 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30390 def structured_content @structured_content end |
#topics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId>
Optional. Represents the Topics of the Memory.
Corresponds to the JSON property topics
30395 30396 30397 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30395 def topics @topics end |
#ttl ⇒ String
Optional. Input only. Represents the TTL for this resource. The expiration
time is computed: now + TTL.
Corresponds to the JSON property ttl
30401 30402 30403 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30401 def ttl @ttl end |
#update_time ⇒ String
Output only. Represents the timestamp when this Memory was most recently
updated.
Corresponds to the JSON property updateTime
30407 30408 30409 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30407 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30414 30415 30416 30417 30418 30419 30420 30421 30422 30423 30424 30425 30426 30427 30428 30429 30430 30431 30432 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30414 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @fact = args[:fact] if args.key?(:fact) @memory_type = args[:memory_type] if args.key?(:memory_type) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time) @revision_labels = args[:revision_labels] if args.key?(:revision_labels) @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl) @scope = args[:scope] if args.key?(:scope) @structured_content = args[:structured_content] if args.key?(:structured_content) @topics = args[:topics] if args.key?(:topics) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) end |