Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Memory
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Memory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A memory.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#disable_memory_revisions ⇒ Boolean
(also: #disable_memory_revisions?)
Optional.
-
#display_name ⇒ String
Optional.
-
#expire_time ⇒ String
Optional.
-
#fact ⇒ String
Optional.
-
#memory_type ⇒ String
Optional.
-
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>
Optional.
-
#name ⇒ String
Identifier.
-
#revision_expire_time ⇒ String
Optional.
-
#revision_labels ⇒ Hash<String,String>
Optional.
-
#revision_ttl ⇒ String
Optional.
-
#scope ⇒ Hash<String,String>
Required.
-
#structured_content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryStructuredContent
Represents the structured value of the memory.
-
#topics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId>
Optional.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Memory
constructor
A new instance of GoogleCloudAiplatformV1beta1Memory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Memory
Returns a new instance of GoogleCloudAiplatformV1beta1Memory.
25471 25472 25473 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25471 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Represents the timestamp when this Memory was created.
Corresponds to the JSON property createTime
25371 25372 25373 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25371 def create_time @create_time end |
#description ⇒ String
Optional. Represents the description of the Memory.
Corresponds to the JSON property description
25376 25377 25378 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25376 def description @description end |
#disable_memory_revisions ⇒ Boolean Also known as: disable_memory_revisions?
Optional. Input only. Indicates whether no revision will be created for this
request.
Corresponds to the JSON property disableMemoryRevisions
25382 25383 25384 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25382 def disable_memory_revisions @disable_memory_revisions end |
#display_name ⇒ String
Optional. Represents the display name of the Memory.
Corresponds to the JSON property displayName
25388 25389 25390 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25388 def display_name @display_name end |
#expire_time ⇒ String
Optional. Represents the timestamp of when this resource is considered expired.
This is always provided on output when expiration is set on input,
regardless of whether expire_time or ttl was provided.
Corresponds to the JSON property expireTime
25395 25396 25397 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25395 def expire_time @expire_time end |
#fact ⇒ String
Optional. Represents semantic knowledge extracted from the source content.
Corresponds to the JSON property fact
25400 25401 25402 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25400 def fact @fact end |
#memory_type ⇒ String
Optional. Represents the type of the memory. If not set, the
NATURAL_LANGUAGE_COLLECTION type is used. If STRUCTURED_COLLECTION or
STRUCTURED_PROFILE is used, then structured_data must be provided.
Corresponds to the JSON property memoryType
25407 25408 25409 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25407 def memory_type @memory_type end |
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryMetadataValue>
Optional. Represents user-provided metadata for the Memory. This information
was provided when creating, updating, or generating the Memory. It was not
generated by Memory Bank.
Corresponds to the JSON property metadata
25414 25415 25416 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25414 def @metadata end |
#name ⇒ String
Identifier. Represents the resource name of the Memory. Format: projects/
project/locations/location/reasoningEngines/reasoning_engine/memories/
memory`
Corresponds to the JSON propertyname`
25421 25422 25423 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25421 def name @name end |
#revision_expire_time ⇒ String
Optional. Input only. Represents the timestamp of when the revision is
considered expired. If not set, the memory revision will be kept until
manually deleted.
Corresponds to the JSON property revisionExpireTime
25428 25429 25430 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25428 def revision_expire_time @revision_expire_time end |
#revision_labels ⇒ Hash<String,String>
Optional. Input only. Represents the labels to apply to the Memory Revision
created as a result of this request.
Corresponds to the JSON property revisionLabels
25434 25435 25436 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25434 def revision_labels @revision_labels end |
#revision_ttl ⇒ String
Optional. Input only. Represents the TTL for the revision. The expiration time
is computed: now + TTL.
Corresponds to the JSON property revisionTtl
25440 25441 25442 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25440 def revision_ttl @revision_ttl end |
#scope ⇒ Hash<String,String>
Required. Immutable. Represents the scope of the Memory. Memories are isolated
within their scope. The scope is defined when creating or generating memories.
Scope values cannot contain the wildcard character '*'.
Corresponds to the JSON property scope
25447 25448 25449 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25447 def scope @scope end |
#structured_content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryStructuredContent
Represents the structured value of the memory.
Corresponds to the JSON property structuredContent
25452 25453 25454 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25452 def structured_content @structured_content end |
#topics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId>
Optional. Represents the Topics of the Memory.
Corresponds to the JSON property topics
25457 25458 25459 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25457 def topics @topics end |
#ttl ⇒ String
Optional. Input only. Represents the TTL for this resource. The expiration
time is computed: now + TTL.
Corresponds to the JSON property ttl
25463 25464 25465 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25463 def ttl @ttl end |
#update_time ⇒ String
Output only. Represents the timestamp when this Memory was most recently
updated.
Corresponds to the JSON property updateTime
25469 25470 25471 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25469 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25476 25477 25478 25479 25480 25481 25482 25483 25484 25485 25486 25487 25488 25489 25490 25491 25492 25493 25494 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25476 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @fact = args[:fact] if args.key?(:fact) @memory_type = args[:memory_type] if args.key?(:memory_type) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time) @revision_labels = args[:revision_labels] if args.key?(:revision_labels) @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl) @scope = args[:scope] if args.key?(:scope) @structured_content = args[:structured_content] if args.key?(:structured_content) @topics = args[:topics] if args.key?(:topics) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) end |