Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigConsolidationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents configuration for customizing how memories are consolidated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigConsolidationConfig

Returns a new instance of GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigConsolidationConfig.



32486
32487
32488
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#revisions_per_candidate_countFixnum

Optional. Represents the maximum number of revisions to consider for each candidate memory. If not set, then the default value (1) will be used, which means that only the latest revision will be considered. Corresponds to the JSON property revisionsPerCandidateCount

Returns:

  • (Fixnum)


32484
32485
32486
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32484

def revisions_per_candidate_count
  @revisions_per_candidate_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32491
32492
32493
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32491

def update!(**args)
  @revisions_per_candidate_count = args[:revisions_per_candidate_count] if args.key?(:revisions_per_candidate_count)
end