Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigGenerateMemoriesExample

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An example of how to generate memories for a particular scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigGenerateMemoriesExample

Returns a new instance of GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigGenerateMemoriesExample.



25664
25665
25666
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25664

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigGenerateMemoriesExampleConversationSource

A conversation source for the example. This is similar to DirectContentsSource. Corresponds to the JSON property conversationSource



25655
25656
25657
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25655

def conversation_source
  @conversation_source
end

#generated_memoriesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory>

Optional. Represents the memories that are expected to be generated from the input conversation. An empty list indicates that no memories are expected to be generated for the input conversation. Corresponds to the JSON property generatedMemories



25662
25663
25664
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25662

def generated_memories
  @generated_memories
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25669
25670
25671
25672
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25669

def update!(**args)
  @conversation_source = args[:conversation_source] if args.key?(:conversation_source)
  @generated_memories = args[:generated_memories] if args.key?(:generated_memories)
end