Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigGenerateMemoriesExample

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An example of how to generate memories for a particular scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigGenerateMemoriesExample

Returns a new instance of GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigGenerateMemoriesExample.



25598
25599
25600
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25598

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigGenerateMemoriesExampleConversationSource

A conversation source for the example. This is similar to DirectContentsSource. Corresponds to the JSON property conversationSource



25589
25590
25591
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25589

def conversation_source
  @conversation_source
end

#generated_memoriesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory>

Optional. Represents the memories that are expected to be generated from the input conversation. An empty list indicates that no memories are expected to be generated for the input conversation. Corresponds to the JSON property generatedMemories



25596
25597
25598
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25596

def generated_memories
  @generated_memories
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25603
25604
25605
25606
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25603

def update!(**args)
  @conversation_source = args[:conversation_source] if args.key?(:conversation_source)
  @generated_memories = args[:generated_memories] if args.key?(:generated_memories)
end