Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A memory generated by the operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory

Returns a new instance of GoogleCloudAiplatformV1beta1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory.



25666
25667
25668
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25666

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#factString

Required. Represents the fact to generate a memory from. Corresponds to the JSON property fact

Returns:

  • (String)


25657
25658
25659
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25657

def fact
  @fact
end

#topicsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId>

Optional. Represents the list of topics that the memory should be associated with. For example, use custom_memory_topic_label = "jargon" if the extracted memory is an example of memory extraction for the custom topic jargon. Corresponds to the JSON property topics



25664
25665
25666
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25664

def topics
  @topics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25671
25672
25673
25674
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25671

def update!(**args)
  @fact = args[:fact] if args.key?(:fact)
  @topics = args[:topics] if args.key?(:topics)
end