Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents the active rule that determines when to flush the buffer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule

Returns a new instance of GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule.



33287
33288
33289
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33287

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_countFixnum

Optional. Specifies to trigger generation when the event count reaches this limit. Corresponds to the JSON property eventCount

Returns:

  • (Fixnum)


33267
33268
33269
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33267

def event_count
  @event_count
end

#fixed_intervalString

Optional. Specifies to trigger generation at a fixed interval. The duration must have a minute-level granularity. Corresponds to the JSON property fixedInterval

Returns:

  • (String)


33273
33274
33275
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33273

def fixed_interval
  @fixed_interval
end

#idle_durationString

Optional. Specifies to trigger generation if the stream is inactive for the specified duration after the most recent event. The duration must have a minute-level granularity. Corresponds to the JSON property idleDuration

Returns:

  • (String)


33280
33281
33282
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33280

def idle_duration
  @idle_duration
end

#overlap_event_countFixnum

Optional. Re-include the last N already-processed events in the next window. Corresponds to the JSON property overlapEventCount

Returns:

  • (Fixnum)


33285
33286
33287
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33285

def overlap_event_count
  @overlap_event_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33292
33293
33294
33295
33296
33297
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33292

def update!(**args)
  @event_count = args[:event_count] if args.key?(:event_count)
  @fixed_interval = args[:fixed_interval] if args.key?(:fixed_interval)
  @idle_duration = args[:idle_duration] if args.key?(:idle_duration)
  @overlap_event_count = args[:overlap_event_count] if args.key?(:overlap_event_count)
end