Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents the active rule that determines when to flush the buffer.
Instance Attribute Summary collapse
-
#event_count ⇒ Fixnum
Optional.
-
#fixed_interval ⇒ String
Optional.
-
#idle_duration ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule
constructor
A new instance of GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule
Returns a new instance of GoogleCloudAiplatformV1beta1MemoryGenerationTriggerConfigGenerationTriggerRule.
25849 25850 25851 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_count ⇒ Fixnum
Optional. Specifies to trigger generation when the event count reaches this
limit.
Corresponds to the JSON property eventCount
25834 25835 25836 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25834 def event_count @event_count end |
#fixed_interval ⇒ String
Optional. Specifies to trigger generation at a fixed interval. The duration
must have a minute-level granularity.
Corresponds to the JSON property fixedInterval
25840 25841 25842 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25840 def fixed_interval @fixed_interval end |
#idle_duration ⇒ String
Optional. Specifies to trigger generation if the stream is inactive for the
specified duration after the most recent event. The duration must have a
minute-level granularity.
Corresponds to the JSON property idleDuration
25847 25848 25849 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25847 def idle_duration @idle_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25854 25855 25856 25857 25858 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25854 def update!(**args) @event_count = args[:event_count] if args.key?(:event_count) @fixed_interval = args[:fixed_interval] if args.key?(:fixed_interval) @idle_duration = args[:idle_duration] if args.key?(:idle_duration) end |