Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryRevision
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryRevision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A revision of a Memory.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#expire_time ⇒ String
Output only.
-
#extracted_memories ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IntermediateExtractedMemory>
Output only.
-
#fact ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Output only.
-
#name ⇒ String
Identifier.
-
#structured_data ⇒ Hash<String,Object>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryRevision
constructor
A new instance of GoogleCloudAiplatformV1beta1MemoryRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryRevision
Returns a new instance of GoogleCloudAiplatformV1beta1MemoryRevision.
34991 34992 34993 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34991 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Represents the timestamp when this Memory Revision was created.
Corresponds to the JSON property createTime
34950 34951 34952 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34950 def create_time @create_time end |
#expire_time ⇒ String
Output only. Represents the timestamp of when this resource is considered
expired.
Corresponds to the JSON property expireTime
34956 34957 34958 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34956 def expire_time @expire_time end |
#extracted_memories ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IntermediateExtractedMemory>
Output only. Represents the extracted memories from the source content before
consolidation when the memory was updated via GenerateMemories. This
information was used to modify an existing Memory via Consolidation.
Corresponds to the JSON property extractedMemories
34963 34964 34965 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34963 def extracted_memories @extracted_memories end |
#fact ⇒ String
Output only. Represents the fact of the Memory Revision. This corresponds to
the fact field of the parent Memory at the time of revision creation.
Corresponds to the JSON property fact
34969 34970 34971 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34969 def fact @fact end |
#labels ⇒ Hash<String,String>
Output only. Represents the labels of the Memory Revision. These labels are
applied to the MemoryRevision when it is created based on
GenerateMemoriesRequest.revision_labels.
Corresponds to the JSON property labels
34976 34977 34978 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34976 def labels @labels end |
#name ⇒ String
Identifier. Represents the resource name of the Memory Revision. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
memories/memory/revisions/memory_revision`
Corresponds to the JSON propertyname`
34983 34984 34985 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34983 def name @name end |
#structured_data ⇒ Hash<String,Object>
Output only. Represents the structured value of the memory at the time of
revision creation.
Corresponds to the JSON property structuredData
34989 34990 34991 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34989 def structured_data @structured_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34996 34997 34998 34999 35000 35001 35002 35003 35004 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34996 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @expire_time = args[:expire_time] if args.key?(:expire_time) @extracted_memories = args[:extracted_memories] if args.key?(:extracted_memories) @fact = args[:fact] if args.key?(:fact) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @structured_data = args[:structured_data] if args.key?(:structured_data) end |