Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A revision of a Memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryRevision

Returns a new instance of GoogleCloudAiplatformV1beta1MemoryRevision.



32889
32890
32891
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Represents the timestamp when this Memory Revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


32848
32849
32850
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32848

def create_time
  @create_time
end

#expire_timeString

Output only. Represents the timestamp of when this resource is considered expired. Corresponds to the JSON property expireTime

Returns:

  • (String)


32854
32855
32856
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32854

def expire_time
  @expire_time
end

#extracted_memoriesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IntermediateExtractedMemory>

Output only. Represents the extracted memories from the source content before consolidation when the memory was updated via GenerateMemories. This information was used to modify an existing Memory via Consolidation. Corresponds to the JSON property extractedMemories



32861
32862
32863
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32861

def extracted_memories
  @extracted_memories
end

#factString

Output only. Represents the fact of the Memory Revision. This corresponds to the fact field of the parent Memory at the time of revision creation. Corresponds to the JSON property fact

Returns:

  • (String)


32867
32868
32869
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32867

def fact
  @fact
end

#labelsHash<String,String>

Output only. Represents the labels of the Memory Revision. These labels are applied to the MemoryRevision when it is created based on GenerateMemoriesRequest.revision_labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


32874
32875
32876
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32874

def labels
  @labels
end

#nameString

Identifier. Represents the resource name of the Memory Revision. Format: projects/project/locations/location/reasoningEngines/reasoning_engine/ memories/memory/revisions/memory_revision` Corresponds to the JSON propertyname`

Returns:

  • (String)


32881
32882
32883
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32881

def name
  @name
end

#structured_dataHash<String,Object>

Output only. Represents the structured value of the memory at the time of revision creation. Corresponds to the JSON property structuredData

Returns:

  • (Hash<String,Object>)


32887
32888
32889
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32887

def structured_data
  @structured_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32894
32895
32896
32897
32898
32899
32900
32901
32902
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32894

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @extracted_memories = args[:extracted_memories] if args.key?(:extracted_memories)
  @fact = args[:fact] if args.key?(:fact)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @structured_data = args[:structured_data] if args.key?(:structured_data)
end