Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A revision of a Memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryRevision

Returns a new instance of GoogleCloudAiplatformV1beta1MemoryRevision.



31499
31500
31501
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31499

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Represents the timestamp when this Memory Revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


31458
31459
31460
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31458

def create_time
  @create_time
end

#expire_timeString

Output only. Represents the timestamp of when this resource is considered expired. Corresponds to the JSON property expireTime

Returns:

  • (String)


31464
31465
31466
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31464

def expire_time
  @expire_time
end

#extracted_memoriesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IntermediateExtractedMemory>

Output only. Represents the extracted memories from the source content before consolidation when the memory was updated via GenerateMemories. This information was used to modify an existing Memory via Consolidation. Corresponds to the JSON property extractedMemories



31471
31472
31473
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31471

def extracted_memories
  @extracted_memories
end

#factString

Output only. Represents the fact of the Memory Revision. This corresponds to the fact field of the parent Memory at the time of revision creation. Corresponds to the JSON property fact

Returns:

  • (String)


31477
31478
31479
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31477

def fact
  @fact
end

#labelsHash<String,String>

Output only. Represents the labels of the Memory Revision. These labels are applied to the MemoryRevision when it is created based on GenerateMemoriesRequest.revision_labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


31484
31485
31486
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31484

def labels
  @labels
end

#nameString

Identifier. Represents the resource name of the Memory Revision. Format: projects/project/locations/location/reasoningEngines/reasoning_engine/ memories/memory/revisions/memory_revision` Corresponds to the JSON propertyname`

Returns:

  • (String)


31491
31492
31493
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31491

def name
  @name
end

#structured_dataHash<String,Object>

Output only. Represents the structured value of the memory at the time of revision creation. Corresponds to the JSON property structuredData

Returns:

  • (Hash<String,Object>)


31497
31498
31499
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31497

def structured_data
  @structured_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31504
31505
31506
31507
31508
31509
31510
31511
31512
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31504

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @extracted_memories = args[:extracted_memories] if args.key?(:extracted_memories)
  @fact = args[:fact] if args.key?(:fact)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @structured_data = args[:structured_data] if args.key?(:structured_data)
end