Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryRevision
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryRevision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A revision of a Memory.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#expire_time ⇒ String
Output only.
-
#extracted_memories ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IntermediateExtractedMemory>
Output only.
-
#fact ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Output only.
-
#name ⇒ String
Identifier.
-
#structured_data ⇒ Hash<String,Object>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryRevision
constructor
A new instance of GoogleCloudAiplatformV1beta1MemoryRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryRevision
Returns a new instance of GoogleCloudAiplatformV1beta1MemoryRevision.
25974 25975 25976 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25974 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Represents the timestamp when this Memory Revision was created.
Corresponds to the JSON property createTime
25933 25934 25935 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25933 def create_time @create_time end |
#expire_time ⇒ String
Output only. Represents the timestamp of when this resource is considered
expired.
Corresponds to the JSON property expireTime
25939 25940 25941 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25939 def expire_time @expire_time end |
#extracted_memories ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1IntermediateExtractedMemory>
Output only. Represents the extracted memories from the source content before
consolidation when the memory was updated via GenerateMemories. This
information was used to modify an existing Memory via Consolidation.
Corresponds to the JSON property extractedMemories
25946 25947 25948 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25946 def extracted_memories @extracted_memories end |
#fact ⇒ String
Output only. Represents the fact of the Memory Revision. This corresponds to
the fact field of the parent Memory at the time of revision creation.
Corresponds to the JSON property fact
25952 25953 25954 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25952 def fact @fact end |
#labels ⇒ Hash<String,String>
Output only. Represents the labels of the Memory Revision. These labels are
applied to the MemoryRevision when it is created based on
GenerateMemoriesRequest.revision_labels.
Corresponds to the JSON property labels
25959 25960 25961 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25959 def labels @labels end |
#name ⇒ String
Identifier. Represents the resource name of the Memory Revision. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
memories/memory/revisions/memory_revision`
Corresponds to the JSON propertyname`
25966 25967 25968 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25966 def name @name end |
#structured_data ⇒ Hash<String,Object>
Output only. Represents the structured value of the memory at the time of
revision creation.
Corresponds to the JSON property structuredData
25972 25973 25974 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25972 def structured_data @structured_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25979 25980 25981 25982 25983 25984 25985 25986 25987 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 25979 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @expire_time = args[:expire_time] if args.key?(:expire_time) @extracted_memories = args[:extracted_memories] if args.key?(:extracted_memories) @fact = args[:fact] if args.key?(:fact) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @structured_data = args[:structured_data] if args.key?(:structured_data) end |