Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A memory topic identifier. This will be used to label a Memory and to restrict which topics are eligible for generation or retrieval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryTopicId

Returns a new instance of GoogleCloudAiplatformV1beta1MemoryTopicId.



30968
30969
30970
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_memory_topic_labelString

Optional. Represents the custom memory topic label. Corresponds to the JSON property customMemoryTopicLabel

Returns:

  • (String)


30961
30962
30963
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30961

def custom_memory_topic_label
  @custom_memory_topic_label
end

#managed_memory_topicString

Optional. Represents the managed memory topic. Corresponds to the JSON property managedMemoryTopic

Returns:

  • (String)


30966
30967
30968
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30966

def managed_memory_topic
  @managed_memory_topic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30973
30974
30975
30976
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30973

def update!(**args)
  @custom_memory_topic_label = args[:custom_memory_topic_label] if args.key?(:custom_memory_topic_label)
  @managed_memory_topic = args[:managed_memory_topic] if args.key?(:managed_memory_topic)
end