Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryTopicId
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A memory topic identifier. This will be used to label a Memory and to restrict which topics are eligible for generation or retrieval.
Instance Attribute Summary collapse
-
#custom_memory_topic_label ⇒ String
Optional.
-
#managed_memory_topic ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryTopicId
constructor
A new instance of GoogleCloudAiplatformV1beta1MemoryTopicId.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MemoryTopicId
Returns a new instance of GoogleCloudAiplatformV1beta1MemoryTopicId.
26030 26031 26032 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26030 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_memory_topic_label ⇒ String
Optional. Represents the custom memory topic label.
Corresponds to the JSON property customMemoryTopicLabel
26023 26024 26025 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26023 def custom_memory_topic_label @custom_memory_topic_label end |
#managed_memory_topic ⇒ String
Optional. Represents the managed memory topic.
Corresponds to the JSON property managedMemoryTopic
26028 26029 26030 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26028 def managed_memory_topic @managed_memory_topic end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26035 26036 26037 26038 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26035 def update!(**args) @custom_memory_topic_label = args[:custom_memory_topic_label] if args.key?(:custom_memory_topic_label) @managed_memory_topic = args[:managed_memory_topic] if args.key?(:managed_memory_topic) end |