Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Metadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Metadata for a chunk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Metadata

Returns a new instance of GoogleCloudAiplatformV1beta1Metadata.



34556
34557
34558
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,String>

Optional. Attributes attached to the data. The keys have semantic conventions and the consumers of the attributes should know how to deserialize the value bytes based on the keys. Corresponds to the JSON property attributes

Returns:

  • (Hash<String,String>)


34554
34555
34556
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34554

def attributes
  @attributes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34561
34562
34563
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34561

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
end