Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Metadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Metadata for a chunk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Metadata

Returns a new instance of GoogleCloudAiplatformV1beta1Metadata.



31603
31604
31605
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31603

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,String>

Optional. Attributes attached to the data. The keys have semantic conventions and the consumers of the attributes should know how to deserialize the value bytes based on the keys. Corresponds to the JSON property attributes

Returns:

  • (Hash<String,String>)


31601
31602
31603
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31601

def attributes
  @attributes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31608
31609
31610
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31608

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
end