Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Instance of a metadata store. Contains a set of metadata that can be queried.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetadataStore

Returns a new instance of GoogleCloudAiplatformV1beta1MetadataStore.



33642
33643
33644
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this MetadataStore was created. Corresponds to the JSON property createTime

Returns:

  • (String)


33609
33610
33611
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33609

def create_time
  @create_time
end

#dataplex_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStoreDataplexConfig

Represents Dataplex integration settings. Corresponds to the JSON property dataplexConfig



33614
33615
33616
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33614

def dataplex_config
  @dataplex_config
end

#descriptionString

Description of the MetadataStore. Corresponds to the JSON property description

Returns:

  • (String)


33619
33620
33621
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33619

def description
  @description
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



33625
33626
33627
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33625

def encryption_spec
  @encryption_spec
end

#nameString

Output only. The resource name of the MetadataStore instance. Corresponds to the JSON property name

Returns:

  • (String)


33630
33631
33632
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33630

def name
  @name
end

#stateGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStoreMetadataStoreState

Represents state information for a MetadataStore. Corresponds to the JSON property state



33635
33636
33637
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33635

def state
  @state
end

#update_timeString

Output only. Timestamp when this MetadataStore was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


33640
33641
33642
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33640

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33647
33648
33649
33650
33651
33652
33653
33654
33655
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33647

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config)
  @description = args[:description] if args.key?(:description)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end