Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Instance of a metadata store. Contains a set of metadata that can be queried.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#dataplex_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStoreDataplexConfig
Represents Dataplex integration settings.
-
#description ⇒ String
Description of the MetadataStore.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#name ⇒ String
Output only.
-
#state ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStoreMetadataStoreState
Represents state information for a MetadataStore.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetadataStore
constructor
A new instance of GoogleCloudAiplatformV1beta1MetadataStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetadataStore
Returns a new instance of GoogleCloudAiplatformV1beta1MetadataStore.
32940 32941 32942 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32940 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this MetadataStore was created.
Corresponds to the JSON property createTime
32907 32908 32909 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32907 def create_time @create_time end |
#dataplex_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStoreDataplexConfig
Represents Dataplex integration settings.
Corresponds to the JSON property dataplexConfig
32912 32913 32914 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32912 def dataplex_config @dataplex_config end |
#description ⇒ String
Description of the MetadataStore.
Corresponds to the JSON property description
32917 32918 32919 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32917 def description @description end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
32923 32924 32925 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32923 def encryption_spec @encryption_spec end |
#name ⇒ String
Output only. The resource name of the MetadataStore instance.
Corresponds to the JSON property name
32928 32929 32930 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32928 def name @name end |
#state ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStoreMetadataStoreState
Represents state information for a MetadataStore.
Corresponds to the JSON property state
32933 32934 32935 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32933 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this MetadataStore was last updated.
Corresponds to the JSON property updateTime
32938 32939 32940 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32938 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32945 32946 32947 32948 32949 32950 32951 32952 32953 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32945 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config) @description = args[:description] if args.key?(:description) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |