Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Instance of a metadata store. Contains a set of metadata that can be queried.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetadataStore

Returns a new instance of GoogleCloudAiplatformV1beta1MetadataStore.



26203
26204
26205
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this MetadataStore was created. Corresponds to the JSON property createTime

Returns:

  • (String)


26170
26171
26172
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26170

def create_time
  @create_time
end

#dataplex_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStoreDataplexConfig

Represents Dataplex integration settings. Corresponds to the JSON property dataplexConfig



26175
26176
26177
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26175

def dataplex_config
  @dataplex_config
end

#descriptionString

Description of the MetadataStore. Corresponds to the JSON property description

Returns:

  • (String)


26180
26181
26182
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26180

def description
  @description
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



26186
26187
26188
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26186

def encryption_spec
  @encryption_spec
end

#nameString

Output only. The resource name of the MetadataStore instance. Corresponds to the JSON property name

Returns:

  • (String)


26191
26192
26193
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26191

def name
  @name
end

#stateGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataStoreMetadataStoreState

Represents state information for a MetadataStore. Corresponds to the JSON property state



26196
26197
26198
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26196

def state
  @state
end

#update_timeString

Output only. Timestamp when this MetadataStore was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


26201
26202
26203
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26201

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26208
26209
26210
26211
26212
26213
26214
26215
26216
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26208

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config)
  @description = args[:description] if args.key?(:description)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end