Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Metric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The metric used for running evaluations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Metric

Returns a new instance of GoogleCloudAiplatformV1beta1Metric.



33108
33109
33110
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_metricsArray<String>

Optional. The aggregation metrics to use. Corresponds to the JSON property aggregationMetrics

Returns:

  • (Array<String>)


33053
33054
33055
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33053

def aggregation_metrics
  @aggregation_metrics
end

#bleu_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BleuSpec

Spec for bleu score metric - calculates the precision of n-grams in the prediction as compared to reference - returns a score ranging between 0 to 1. Corresponds to the JSON property bleuSpec



33059
33060
33061
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33059

def bleu_spec
  @bleu_spec
end

#computation_based_metric_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ComputationBasedMetricSpec

Specification for a computation based metric. Corresponds to the JSON property computationBasedMetricSpec



33064
33065
33066
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33064

def computation_based_metric_spec
  @computation_based_metric_spec
end

#custom_code_execution_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomCodeExecutionSpec

Specificies a metric that is populated by evaluating user-defined Python code. Corresponds to the JSON property customCodeExecutionSpec



33069
33070
33071
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33069

def custom_code_execution_spec
  @custom_code_execution_spec
end

#exact_match_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExactMatchSpec

Spec for exact match metric - returns 1 if prediction and reference exactly matches, otherwise 0. Corresponds to the JSON property exactMatchSpec



33075
33076
33077
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33075

def exact_match_spec
  @exact_match_spec
end

#llm_based_metric_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LlmBasedMetricSpec

Specification for an LLM based metric. Corresponds to the JSON property llmBasedMetricSpec



33080
33081
33082
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33080

def llm_based_metric_spec
  @llm_based_metric_spec
end

#metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadata

Metadata about the metric, used for visualization and organization. Corresponds to the JSON property metadata



33085
33086
33087
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33085

def 
  @metadata
end

#pairwise_metric_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseMetricSpec

Spec for pairwise metric. Corresponds to the JSON property pairwiseMetricSpec



33090
33091
33092
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33090

def pairwise_metric_spec
  @pairwise_metric_spec
end

#pointwise_metric_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PointwiseMetricSpec

Spec for pointwise metric. Corresponds to the JSON property pointwiseMetricSpec



33095
33096
33097
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33095

def pointwise_metric_spec
  @pointwise_metric_spec
end

#predefined_metric_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredefinedMetricSpec

The spec for a pre-defined metric. Corresponds to the JSON property predefinedMetricSpec



33100
33101
33102
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33100

def predefined_metric_spec
  @predefined_metric_spec
end

#rouge_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RougeSpec

Spec for rouge score metric - calculates the recall of n-grams in prediction as compared to reference - returns a score ranging between 0 and 1. Corresponds to the JSON property rougeSpec



33106
33107
33108
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33106

def rouge_spec
  @rouge_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33113
33114
33115
33116
33117
33118
33119
33120
33121
33122
33123
33124
33125
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33113

def update!(**args)
  @aggregation_metrics = args[:aggregation_metrics] if args.key?(:aggregation_metrics)
  @bleu_spec = args[:bleu_spec] if args.key?(:bleu_spec)
  @computation_based_metric_spec = args[:computation_based_metric_spec] if args.key?(:computation_based_metric_spec)
  @custom_code_execution_spec = args[:custom_code_execution_spec] if args.key?(:custom_code_execution_spec)
  @exact_match_spec = args[:exact_match_spec] if args.key?(:exact_match_spec)
  @llm_based_metric_spec = args[:llm_based_metric_spec] if args.key?(:llm_based_metric_spec)
  @metadata = args[:metadata] if args.key?(:metadata)
  @pairwise_metric_spec = args[:pairwise_metric_spec] if args.key?(:pairwise_metric_spec)
  @pointwise_metric_spec = args[:pointwise_metric_spec] if args.key?(:pointwise_metric_spec)
  @predefined_metric_spec = args[:predefined_metric_spec] if args.key?(:predefined_metric_spec)
  @rouge_spec = args[:rouge_spec] if args.key?(:rouge_spec)
end