Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Metadata about the metric, used for visualization and organization.
Instance Attribute Summary collapse
-
#other_metadata ⇒ Hash<String,Object>
Optional.
-
#score_range ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadataScoreRange
The range of possible scores for this metric, used for plotting.
-
#title ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetricMetadata
constructor
A new instance of GoogleCloudAiplatformV1beta1MetricMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetricMetadata
Returns a new instance of GoogleCloudAiplatformV1beta1MetricMetadata.
26411 26412 26413 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26411 def initialize(**args) update!(**args) end |
Instance Attribute Details
#other_metadata ⇒ Hash<String,Object>
Optional. Flexible metadata for user-defined attributes.
Corresponds to the JSON property otherMetadata
26398 26399 26400 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26398 def @other_metadata end |
#score_range ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadataScoreRange
The range of possible scores for this metric, used for plotting.
Corresponds to the JSON property scoreRange
26403 26404 26405 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26403 def score_range @score_range end |
#title ⇒ String
Optional. The user-friendly name for the metric. If not set for a registered
metric, it will default to the metric's display name.
Corresponds to the JSON property title
26409 26410 26411 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26409 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26416 26417 26418 26419 26420 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26416 def update!(**args) @other_metadata = args[:other_metadata] if args.key?(:other_metadata) @score_range = args[:score_range] if args.key?(:score_range) @title = args[:title] if args.key?(:title) end |