Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadataScoreRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The range of possible scores for this metric, used for plotting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetricMetadataScoreRange

Returns a new instance of GoogleCloudAiplatformV1beta1MetricMetadataScoreRange.



34926
34927
34928
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The description of the score explaining the directionality etc. Corresponds to the JSON property description

Returns:

  • (String)


34908
34909
34910
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34908

def description
  @description
end

#maxFloat

Required. The maximum value of the score range (inclusive). Corresponds to the JSON property max

Returns:

  • (Float)


34913
34914
34915
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34913

def max
  @max
end

#minFloat

Required. The minimum value of the score range (inclusive). Corresponds to the JSON property min

Returns:

  • (Float)


34918
34919
34920
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34918

def min
  @min
end

#stepFloat

Optional. The distance between discrete steps in the range. If unset, the range is assumed to be continuous. Corresponds to the JSON property step

Returns:

  • (Float)


34924
34925
34926
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34924

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34931
34932
34933
34934
34935
34936
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34931

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @max = args[:max] if args.key?(:max)
  @min = args[:min] if args.key?(:min)
  @step = args[:step] if args.key?(:step)
end