Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadataScoreRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The range of possible scores for this metric, used for plotting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetricMetadataScoreRange

Returns a new instance of GoogleCloudAiplatformV1beta1MetricMetadataScoreRange.



33887
33888
33889
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The description of the score explaining the directionality etc. Corresponds to the JSON property description

Returns:

  • (String)


33869
33870
33871
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33869

def description
  @description
end

#maxFloat

Required. The maximum value of the score range (inclusive). Corresponds to the JSON property max

Returns:

  • (Float)


33874
33875
33876
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33874

def max
  @max
end

#minFloat

Required. The minimum value of the score range (inclusive). Corresponds to the JSON property min

Returns:

  • (Float)


33879
33880
33881
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33879

def min
  @min
end

#stepFloat

Optional. The distance between discrete steps in the range. If unset, the range is assumed to be continuous. Corresponds to the JSON property step

Returns:

  • (Float)


33885
33886
33887
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33885

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33892
33893
33894
33895
33896
33897
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33892

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @max = args[:max] if args.key?(:max)
  @min = args[:min] if args.key?(:min)
  @step = args[:step] if args.key?(:step)
end