Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadataScoreRange
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadataScoreRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The range of possible scores for this metric, used for plotting.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#max ⇒ Float
Required.
-
#min ⇒ Float
Required.
-
#step ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetricMetadataScoreRange
constructor
A new instance of GoogleCloudAiplatformV1beta1MetricMetadataScoreRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetricMetadataScoreRange
Returns a new instance of GoogleCloudAiplatformV1beta1MetricMetadataScoreRange.
26514 26515 26516 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The description of the score explaining the directionality etc.
Corresponds to the JSON property description
26496 26497 26498 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26496 def description @description end |
#max ⇒ Float
Required. The maximum value of the score range (inclusive).
Corresponds to the JSON property max
26501 26502 26503 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26501 def max @max end |
#min ⇒ Float
Required. The minimum value of the score range (inclusive).
Corresponds to the JSON property min
26506 26507 26508 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26506 def min @min end |
#step ⇒ Float
Optional. The distance between discrete steps in the range. If unset, the
range is assumed to be continuous.
Corresponds to the JSON property step
26512 26513 26514 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26512 def step @step end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26519 26520 26521 26522 26523 26524 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26519 def update!(**args) @description = args[:description] if args.key?(:description) @max = args[:max] if args.key?(:max) @min = args[:min] if args.key?(:min) @step = args[:step] if args.key?(:step) end |