Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadataScoreRange
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricMetadataScoreRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The range of possible scores for this metric, used for plotting.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#max ⇒ Float
Required.
-
#min ⇒ Float
Required.
-
#step ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetricMetadataScoreRange
constructor
A new instance of GoogleCloudAiplatformV1beta1MetricMetadataScoreRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetricMetadataScoreRange
Returns a new instance of GoogleCloudAiplatformV1beta1MetricMetadataScoreRange.
26448 26449 26450 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26448 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The description of the score explaining the directionality etc.
Corresponds to the JSON property description
26430 26431 26432 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26430 def description @description end |
#max ⇒ Float
Required. The maximum value of the score range (inclusive).
Corresponds to the JSON property max
26435 26436 26437 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26435 def max @max end |
#min ⇒ Float
Required. The minimum value of the score range (inclusive).
Corresponds to the JSON property min
26440 26441 26442 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26440 def min @min end |
#step ⇒ Float
Optional. The distance between discrete steps in the range. If unset, the
range is assumed to be continuous.
Corresponds to the JSON property step
26446 26447 26448 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26446 def step @step end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26453 26454 26455 26456 26457 26458 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 26453 def update!(**args) @description = args[:description] if args.key?(:description) @max = args[:max] if args.key?(:max) @min = args[:min] if args.key?(:min) @step = args[:step] if args.key?(:step) end |