Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Result for a single metric on a single instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MetricResult

Returns a new instance of GoogleCloudAiplatformV1beta1MetricResult.



34969
34970
34971
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34969

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



34951
34952
34953
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34951

def error
  @error
end

#explanationString

Output only. The explanation for the metric result. Corresponds to the JSON property explanation

Returns:

  • (String)


34956
34957
34958
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34956

def explanation
  @explanation
end

#rubric_verdictsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricVerdict>

Output only. For rubric-based metrics, the verdicts for each rubric. Corresponds to the JSON property rubricVerdicts



34961
34962
34963
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34961

def rubric_verdicts
  @rubric_verdicts
end

#scoreFloat

Output only. The score for the metric. Please refer to each metric's documentation for the meaning of the score. Corresponds to the JSON property score

Returns:

  • (Float)


34967
34968
34969
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34967

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34974
34975
34976
34977
34978
34979
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34974

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @explanation = args[:explanation] if args.key?(:explanation)
  @rubric_verdicts = args[:rubric_verdicts] if args.key?(:rubric_verdicts)
  @score = args[:score] if args.key?(:score)
end