Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModalityTokenCount
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModalityTokenCount
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a breakdown of token usage by modality. This message is used in CountTokensResponse and GenerateContentResponse.UsageMetadata to provide a detailed view of how many tokens are used by each modality (e.g., text, image, video) in a request. This is particularly useful for multimodal models, allowing you to track and manage token consumption for billing and quota purposes.
Instance Attribute Summary collapse
-
#modality ⇒ String
The modality that this token count applies to.
-
#token_count ⇒ Fixnum
The number of tokens counted for this modality.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModalityTokenCount
constructor
A new instance of GoogleCloudAiplatformV1beta1ModalityTokenCount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModalityTokenCount
Returns a new instance of GoogleCloudAiplatformV1beta1ModalityTokenCount.
32004 32005 32006 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32004 def initialize(**args) update!(**args) end |
Instance Attribute Details
#modality ⇒ String
The modality that this token count applies to.
Corresponds to the JSON property modality
31997 31998 31999 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31997 def modality @modality end |
#token_count ⇒ Fixnum
The number of tokens counted for this modality.
Corresponds to the JSON property tokenCount
32002 32003 32004 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32002 def token_count @token_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32009 32010 32011 32012 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32009 def update!(**args) @modality = args[:modality] if args.key?(:modality) @token_count = args[:token_count] if args.key?(:token_count) end |