Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Model
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Model
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A trained machine learning Model.
Instance Attribute Summary collapse
-
#artifact_uri ⇒ String
Immutable.
-
#base_model_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelBaseModelSource
User input field to specify the base model source.
-
#checkpoints ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Checkpoint>
Optional.
-
#container_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelContainerSpec
Specification of a container for serving predictions.
-
#create_time ⇒ String
Output only.
-
#default_checkpoint_id ⇒ String
The default checkpoint id of a model version.
-
#deployed_models ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModelRef>
Output only.
-
#description ⇒ String
The description of the Model.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#explanation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpec
Specification of Model explanation.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Models.
-
#metadata ⇒ Object
Immutable.
-
#metadata_artifact ⇒ String
Output only.
-
#metadata_schema_uri ⇒ String
Immutable.
-
#model_source_info ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelSourceInfo
Detail description of the source information of the model.
-
#name ⇒ String
Identifier.
-
#original_model_info ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelOriginalModelInfo
Contains information about the original Model if this Model is a copy.
-
#predict_schemata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictSchemata
Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#supported_deployment_resources_types ⇒ Array<String>
Output only.
-
#supported_export_formats ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelExportFormat>
Output only.
-
#supported_input_storage_formats ⇒ Array<String>
Output only.
-
#supported_output_storage_formats ⇒ Array<String>
Output only.
-
#training_pipeline ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#version_aliases ⇒ Array<String>
User provided version aliases so that a model version can be referenced via alias (i.e.
projects/project/locations/location/models/model_id@version_alias`instead of auto-generated version id (i.e.projects/project/ locations/location/models/model_id@version_id). The format is a-z0,126[a-z0-9] to distinguish from version_id. A default version alias will be created for the first version of the model, and there must be exactly one default version alias for a model. Corresponds to the JSON propertyversionAliases`. -
#version_create_time ⇒ String
Output only.
-
#version_description ⇒ String
The description of this version.
-
#version_id ⇒ String
Output only.
-
#version_update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Model
constructor
A new instance of GoogleCloudAiplatformV1beta1Model.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Model
Returns a new instance of GoogleCloudAiplatformV1beta1Model.
27320 27321 27322 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27320 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_uri ⇒ String
Immutable. The path to the directory containing the Model artifact and any of
its supporting files. Not required for AutoML Models.
Corresponds to the JSON property artifactUri
27085 27086 27087 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27085 def artifact_uri @artifact_uri end |
#base_model_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelBaseModelSource
User input field to specify the base model source. Currently it only supports
specifing the Model Garden models and Genie models.
Corresponds to the JSON property baseModelSource
27091 27092 27093 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27091 def base_model_source @base_model_source end |
#checkpoints ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Checkpoint>
Optional. Output only. The checkpoints of the model.
Corresponds to the JSON property checkpoints
27096 27097 27098 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27096 def checkpoints @checkpoints end |
#container_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelContainerSpec
Specification of a container for serving predictions. Some fields in this
message correspond to fields in the Kubernetes Container v1 core
specification.
Corresponds to the JSON property containerSpec
27104 27105 27106 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27104 def container_spec @container_spec end |
#create_time ⇒ String
Output only. Timestamp when this Model was uploaded into Vertex AI.
Corresponds to the JSON property createTime
27109 27110 27111 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27109 def create_time @create_time end |
#default_checkpoint_id ⇒ String
The default checkpoint id of a model version.
Corresponds to the JSON property defaultCheckpointId
27114 27115 27116 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27114 def default_checkpoint_id @default_checkpoint_id end |
#deployed_models ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DeployedModelRef>
Output only. The pointers to DeployedModels created from this Model. Note that
Model could have been deployed to Endpoints in different Locations.
Corresponds to the JSON property deployedModels
27120 27121 27122 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27120 def deployed_models @deployed_models end |
#description ⇒ String
The description of the Model.
Corresponds to the JSON property description
27125 27126 27127 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27125 def description @description end |
#display_name ⇒ String
Required. The display name of the Model. The name can be up to 128 characters
long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
27131 27132 27133 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27131 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
27137 27138 27139 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27137 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
27143 27144 27145 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27143 def etag @etag end |
#explanation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpec
Specification of Model explanation.
Corresponds to the JSON property explanationSpec
27148 27149 27150 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27148 def explanation_spec @explanation_spec end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Models. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
27157 27158 27159 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27157 def labels @labels end |
#metadata ⇒ Object
Immutable. An additional information about the Model; the schema of the
metadata can be found in metadata_schema. Unset if the Model does not have any
additional information.
Corresponds to the JSON property metadata
27164 27165 27166 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27164 def @metadata end |
#metadata_artifact ⇒ String
Output only. The resource name of the Artifact that was created in
MetadataStore when creating the Model. The Artifact resource name pattern is
projects/project/locations/location/metadataStores/metadata_store/
artifacts/artifact`.
Corresponds to the JSON propertymetadataArtifact`
27172 27173 27174 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27172 def @metadata_artifact end |
#metadata_schema_uri ⇒ String
Immutable. Points to a YAML file stored on Google Cloud Storage describing
additional information about the Model, that is specific to it. Unset if the
Model does not have any additional information. The schema is defined as an
OpenAPI 3.0.2 Schema Object. AutoML Models always have this
field populated by Vertex AI, if no additional metadata is needed, this field
is set to an empty string. Note: The URI given on output will be immutable and
probably different, including the URI scheme, than the one given on input. The
output URI will point to a location where the user only has a read access.
Corresponds to the JSON property metadataSchemaUri
27185 27186 27187 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27185 def @metadata_schema_uri end |
#model_source_info ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelSourceInfo
Detail description of the source information of the model.
Corresponds to the JSON property modelSourceInfo
27190 27191 27192 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27190 def model_source_info @model_source_info end |
#name ⇒ String
Identifier. The resource name of the Model.
Corresponds to the JSON property name
27195 27196 27197 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27195 def name @name end |
#original_model_info ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelOriginalModelInfo
Contains information about the original Model if this Model is a copy.
Corresponds to the JSON property originalModelInfo
27200 27201 27202 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27200 def original_model_info @original_model_info end |
#predict_schemata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictSchemata
Contains the schemata used in Model's predictions and explanations via
PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
Corresponds to the JSON property predictSchemata
27206 27207 27208 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27206 def predict_schemata @predict_schemata end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
27211 27212 27213 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27211 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
27217 27218 27219 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27217 def satisfies_pzs @satisfies_pzs end |
#supported_deployment_resources_types ⇒ Array<String>
Output only. When this Model is deployed, its prediction resources are
described by the prediction_resources field of the Endpoint.deployed_models
object. Because not all Models support all resource configuration types, the
configuration types this Model supports are listed here. If no configuration
types are listed, the Model cannot be deployed to an Endpoint and does not
support online predictions (PredictionService.Predict or PredictionService.
Explain). Such a Model can serve predictions by using a BatchPredictionJob, if
it has at least one entry each in supported_input_storage_formats and
supported_output_storage_formats.
Corresponds to the JSON property supportedDeploymentResourcesTypes
27231 27232 27233 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27231 def supported_deployment_resources_types @supported_deployment_resources_types end |
#supported_export_formats ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelExportFormat>
Output only. The formats in which this Model may be exported. If empty, this
Model is not available for export.
Corresponds to the JSON property supportedExportFormats
27237 27238 27239 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27237 def supported_export_formats @supported_export_formats end |
#supported_input_storage_formats ⇒ Array<String>
Output only. The formats this Model supports in BatchPredictionJob.
input_config. If PredictSchemata.instance_schema_uri exists, the instances
should be given as per that schema. The possible formats are: * jsonl The
JSON Lines format, where each instance is a single line. Uses GcsSource. *
csv The CSV format, where each instance is a single comma-separated line. The
first line in the file is the header, containing comma-separated field names.
Uses GcsSource. * tf-record The TFRecord format, where each instance is a
single record in tfrecord syntax. Uses GcsSource. * tf-record-gzip Similar
to tf-record, but the file is gzipped. Uses GcsSource. * bigquery Each
instance is a single row in BigQuery. Uses BigQuerySource. * file-list Each
line of the file is the location of an instance to process, uses gcs_source
field of the InputConfig object. If this Model doesn't support any of these
formats it means it cannot be used with a BatchPredictionJob. However, if it
has supported_deployment_resources_types, it could serve online predictions by
using PredictionService.Predict or PredictionService.Explain.
Corresponds to the JSON property supportedInputStorageFormats
27256 27257 27258 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27256 def supported_input_storage_formats @supported_input_storage_formats end |
#supported_output_storage_formats ⇒ Array<String>
Output only. The formats this Model supports in BatchPredictionJob.
output_config. If both PredictSchemata.instance_schema_uri and PredictSchemata.
prediction_schema_uri exist, the predictions are returned together with their
instances. In other words, the prediction has the original instance data first,
followed by the actual prediction content (as per the schema). The possible
formats are: * jsonl The JSON Lines format, where each prediction is a
single line. Uses GcsDestination. * csv The CSV format, where each
prediction is a single comma-separated line. The first line in the file is the
header, containing comma-separated field names. Uses GcsDestination. *
bigquery Each prediction is a single row in a BigQuery table, uses
BigQueryDestination . If this Model doesn't support any of these formats it
means it cannot be used with a BatchPredictionJob. However, if it has
supported_deployment_resources_types, it could serve online predictions by
using PredictionService.Predict or PredictionService.Explain.
Corresponds to the JSON property supportedOutputStorageFormats
27274 27275 27276 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27274 def supported_output_storage_formats @supported_output_storage_formats end |
#training_pipeline ⇒ String
Output only. The resource name of the TrainingPipeline that uploaded this
Model, if any.
Corresponds to the JSON property trainingPipeline
27280 27281 27282 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27280 def training_pipeline @training_pipeline end |
#update_time ⇒ String
Output only. Timestamp when this Model was most recently updated.
Corresponds to the JSON property updateTime
27285 27286 27287 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27285 def update_time @update_time end |
#version_aliases ⇒ Array<String>
User provided version aliases so that a model version can be referenced via
alias (i.e. projects/project/locations/location/models/model_id@
version_alias`instead of auto-generated version id (i.e.projects/project/
locations/location/models/model_id@version_id). The format is a-z0,126
[a-z0-9] to distinguish from version_id. A default version alias will be
created for the first version of the model, and there must be exactly one
default version alias for a model.
Corresponds to the JSON propertyversionAliases`
27296 27297 27298 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27296 def version_aliases @version_aliases end |
#version_create_time ⇒ String
Output only. Timestamp when this version was created.
Corresponds to the JSON property versionCreateTime
27301 27302 27303 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27301 def version_create_time @version_create_time end |
#version_description ⇒ String
The description of this version.
Corresponds to the JSON property versionDescription
27306 27307 27308 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27306 def version_description @version_description end |
#version_id ⇒ String
Output only. Immutable. The version ID of the model. A new version is
committed when a new model version is uploaded or trained under an existing
model id. It is an auto-incrementing decimal number in string representation.
Corresponds to the JSON property versionId
27313 27314 27315 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27313 def version_id @version_id end |
#version_update_time ⇒ String
Output only. Timestamp when this version was most recently updated.
Corresponds to the JSON property versionUpdateTime
27318 27319 27320 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27318 def version_update_time @version_update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27325 27326 27327 27328 27329 27330 27331 27332 27333 27334 27335 27336 27337 27338 27339 27340 27341 27342 27343 27344 27345 27346 27347 27348 27349 27350 27351 27352 27353 27354 27355 27356 27357 27358 27359 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27325 def update!(**args) @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri) @base_model_source = args[:base_model_source] if args.key?(:base_model_source) @checkpoints = args[:checkpoints] if args.key?(:checkpoints) @container_spec = args[:container_spec] if args.key?(:container_spec) @create_time = args[:create_time] if args.key?(:create_time) @default_checkpoint_id = args[:default_checkpoint_id] if args.key?(:default_checkpoint_id) @deployed_models = args[:deployed_models] if args.key?(:deployed_models) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @metadata_artifact = args[:metadata_artifact] if args.key?(:metadata_artifact) @metadata_schema_uri = args[:metadata_schema_uri] if args.key?(:metadata_schema_uri) @model_source_info = args[:model_source_info] if args.key?(:model_source_info) @name = args[:name] if args.key?(:name) @original_model_info = args[:original_model_info] if args.key?(:original_model_info) @predict_schemata = args[:predict_schemata] if args.key?(:predict_schemata) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @supported_deployment_resources_types = args[:supported_deployment_resources_types] if args.key?(:supported_deployment_resources_types) @supported_export_formats = args[:supported_export_formats] if args.key?(:supported_export_formats) @supported_input_storage_formats = args[:supported_input_storage_formats] if args.key?(:supported_input_storage_formats) @supported_output_storage_formats = args[:supported_output_storage_formats] if args.key?(:supported_output_storage_formats) @training_pipeline = args[:training_pipeline] if args.key?(:training_pipeline) @update_time = args[:update_time] if args.key?(:update_time) @version_aliases = args[:version_aliases] if args.key?(:version_aliases) @version_create_time = args[:version_create_time] if args.key?(:version_create_time) @version_description = args[:version_description] if args.key?(:version_description) @version_id = args[:version_id] if args.key?(:version_id) @version_update_time = args[:version_update_time] if args.key?(:version_update_time) end |