Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a job that runs periodically to monitor the deployed models in an endpoint. It will analyze the logged training & prediction data to detect any abnormal behaviors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringJob

Returns a new instance of GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringJob.



27873
27874
27875
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_instance_schema_uriString

YAML schema file uri describing the format of a single instance that you want Tensorflow Data Validation (TFDV) to analyze. If this field is empty, all the feature data types are inferred from predict_instance_schema_uri, meaning that TFDV will use the data in the exact format(data type) as prediction request/ response. If there are any data type differences between predict instance and TFDV instance, this field can be used to override the schema. For models trained with Vertex AI, this field must be set as all the fields in predict instance formatted as string. Corresponds to the JSON property analysisInstanceSchemaUri

Returns:

  • (String)


27716
27717
27718
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27716

def analysis_instance_schema_uri
  @analysis_instance_schema_uri
end

#bigquery_tablesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringBigQueryTable>

Output only. The created bigquery tables for the job under customer project. Customer could do their own query & analysis. There could be 4 log tables in maximum: 1. Training data logging predict request/response 2. Serving data logging predict request/response Corresponds to the JSON property bigqueryTables



27724
27725
27726
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27724

def bigquery_tables
  @bigquery_tables
end

#create_timeString

Output only. Timestamp when this ModelDeploymentMonitoringJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


27729
27730
27731
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27729

def create_time
  @create_time
end

#display_nameString

Required. The user-defined name of the ModelDeploymentMonitoringJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Display name of a ModelDeploymentMonitoringJob. Corresponds to the JSON property displayName

Returns:

  • (String)


27736
27737
27738
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27736

def display_name
  @display_name
end

#enable_monitoring_pipeline_logsBoolean Also known as: enable_monitoring_pipeline_logs?

If true, the scheduled monitoring pipeline logs are sent to Google Cloud Logging, including pipeline status and anomalies detected. Please note the logs incur cost, which are subject to Cloud Logging pricing. Corresponds to the JSON property enableMonitoringPipelineLogs

Returns:

  • (Boolean)


27744
27745
27746
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27744

def enable_monitoring_pipeline_logs
  @enable_monitoring_pipeline_logs
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



27751
27752
27753
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27751

def encryption_spec
  @encryption_spec
end

#endpointString

Required. Endpoint resource name. Format: projects/project/locations/ location/endpoints/endpoint` Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


27757
27758
27759
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27757

def endpoint
  @endpoint
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



27767
27768
27769
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27767

def error
  @error
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your ModelDeploymentMonitoringJob. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


27776
27777
27778
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27776

def labels
  @labels
end

#latest_monitoring_pipeline_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata

All metadata of most recent monitoring pipelines. Corresponds to the JSON property latestMonitoringPipelineMetadata



27781
27782
27783
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27781

def 
  @latest_monitoring_pipeline_metadata
end

#log_ttlString

The TTL of BigQuery tables in user projects which stores logs. A day is the basic unit of the TTL and we take the ceil of TTL/86400(a day). e.g. second: 3600 indicates ttl = 1 day. Corresponds to the JSON property logTtl

Returns:

  • (String)


27788
27789
27790
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27788

def log_ttl
  @log_ttl
end

#logging_sampling_strategyGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SamplingStrategy

Sampling Strategy for logging, can be for both training and prediction dataset. Corresponds to the JSON property loggingSamplingStrategy



27793
27794
27795
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27793

def logging_sampling_strategy
  @logging_sampling_strategy
end

#model_deployment_monitoring_objective_configsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringObjectiveConfig>

Required. The config for monitoring objectives. This is a per DeployedModel config. Each DeployedModel needs to be configured separately. Corresponds to the JSON property modelDeploymentMonitoringObjectiveConfigs



27799
27800
27801
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27799

def model_deployment_monitoring_objective_configs
  @model_deployment_monitoring_objective_configs
end

#model_deployment_monitoring_schedule_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringScheduleConfig

The config for scheduling monitoring job. Corresponds to the JSON property modelDeploymentMonitoringScheduleConfig



27804
27805
27806
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27804

def model_deployment_monitoring_schedule_config
  @model_deployment_monitoring_schedule_config
end

#model_monitoring_alert_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertConfig

The alert config for model monitoring. Corresponds to the JSON property modelMonitoringAlertConfig



27809
27810
27811
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27809

def model_monitoring_alert_config
  @model_monitoring_alert_config
end

#nameString

Output only. Resource name of a ModelDeploymentMonitoringJob. Corresponds to the JSON property name

Returns:

  • (String)


27814
27815
27816
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27814

def name
  @name
end

#next_schedule_timeString

Output only. Timestamp when this monitoring pipeline will be scheduled to run for the next round. Corresponds to the JSON property nextScheduleTime

Returns:

  • (String)


27820
27821
27822
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27820

def next_schedule_time
  @next_schedule_time
end

#predict_instance_schema_uriString

YAML schema file uri describing the format of a single instance, which are given to format this Endpoint's prediction (and explanation). If not set, we will generate predict schema from collected predict requests. Corresponds to the JSON property predictInstanceSchemaUri

Returns:

  • (String)


27827
27828
27829
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27827

def predict_instance_schema_uri
  @predict_instance_schema_uri
end

#sample_predict_instanceObject

Sample Predict instance, same format as PredictRequest.instances, this can be set as a replacement of ModelDeploymentMonitoringJob. predict_instance_schema_uri. If not set, we will generate predict schema from collected predict requests. Corresponds to the JSON property samplePredictInstance

Returns:

  • (Object)


27835
27836
27837
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27835

def sample_predict_instance
  @sample_predict_instance
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


27840
27841
27842
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27840

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


27846
27847
27848
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27846

def satisfies_pzs
  @satisfies_pzs
end

#schedule_stateString

Output only. Schedule state when the monitoring job is in Running state. Corresponds to the JSON property scheduleState

Returns:

  • (String)


27852
27853
27854
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27852

def schedule_state
  @schedule_state
end

#stateString

Output only. The detailed state of the monitoring job. When the job is still creating, the state will be 'PENDING'. Once the job is successfully created, the state will be 'RUNNING'. Pause the job, the state will be 'PAUSED'. Resume the job, the state will return to 'RUNNING'. Corresponds to the JSON property state

Returns:

  • (String)


27860
27861
27862
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27860

def state
  @state
end

#stats_anomalies_base_directoryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property statsAnomaliesBaseDirectory



27865
27866
27867
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27865

def stats_anomalies_base_directory
  @stats_anomalies_base_directory
end

#update_timeString

Output only. Timestamp when this ModelDeploymentMonitoringJob was updated most recently. Corresponds to the JSON property updateTime

Returns:

  • (String)


27871
27872
27873
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27871

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27878
27879
27880
27881
27882
27883
27884
27885
27886
27887
27888
27889
27890
27891
27892
27893
27894
27895
27896
27897
27898
27899
27900
27901
27902
27903
27904
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 27878

def update!(**args)
  @analysis_instance_schema_uri = args[:analysis_instance_schema_uri] if args.key?(:analysis_instance_schema_uri)
  @bigquery_tables = args[:bigquery_tables] if args.key?(:bigquery_tables)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_monitoring_pipeline_logs = args[:enable_monitoring_pipeline_logs] if args.key?(:enable_monitoring_pipeline_logs)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @latest_monitoring_pipeline_metadata = args[:latest_monitoring_pipeline_metadata] if args.key?(:latest_monitoring_pipeline_metadata)
  @log_ttl = args[:log_ttl] if args.key?(:log_ttl)
  @logging_sampling_strategy = args[:logging_sampling_strategy] if args.key?(:logging_sampling_strategy)
  @model_deployment_monitoring_objective_configs = args[:model_deployment_monitoring_objective_configs] if args.key?(:model_deployment_monitoring_objective_configs)
  @model_deployment_monitoring_schedule_config = args[:model_deployment_monitoring_schedule_config] if args.key?(:model_deployment_monitoring_schedule_config)
  @model_monitoring_alert_config = args[:model_monitoring_alert_config] if args.key?(:model_monitoring_alert_config)
  @name = args[:name] if args.key?(:name)
  @next_schedule_time = args[:next_schedule_time] if args.key?(:next_schedule_time)
  @predict_instance_schema_uri = args[:predict_instance_schema_uri] if args.key?(:predict_instance_schema_uri)
  @sample_predict_instance = args[:sample_predict_instance] if args.key?(:sample_predict_instance)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @schedule_state = args[:schedule_state] if args.key?(:schedule_state)
  @state = args[:state] if args.key?(:state)
  @stats_anomalies_base_directory = args[:stats_anomalies_base_directory] if args.key?(:stats_anomalies_base_directory)
  @update_time = args[:update_time] if args.key?(:update_time)
end