Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringScheduleConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringScheduleConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The config for scheduling monitoring job.
Instance Attribute Summary collapse
-
#monitor_interval ⇒ String
Required.
-
#monitor_window ⇒ String
The time window of the prediction data being included in each prediction dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringScheduleConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringScheduleConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringScheduleConfig
Returns a new instance of GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringScheduleConfig.
33510 33511 33512 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33510 def initialize(**args) update!(**args) end |
Instance Attribute Details
#monitor_interval ⇒ String
Required. The model monitoring job scheduling interval. It will be rounded up
to next full hour. This defines how often the monitoring jobs are triggered.
Corresponds to the JSON property monitorInterval
33497 33498 33499 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33497 def monitor_interval @monitor_interval end |
#monitor_window ⇒ String
The time window of the prediction data being included in each prediction
dataset. This window specifies how long the data should be collected from
historical model results for each run. If not set,
ModelDeploymentMonitoringScheduleConfig.monitor_interval will be used. e.g. If
currently the cutoff time is 2022-01-08 14:30:00 and the monitor_window is set
to be 3600, then data from 2022-01-08 13:30:00 to 2022-01-08 14:30:00 will be
retrieved and aggregated to calculate the monitoring statistics.
Corresponds to the JSON property monitorWindow
33508 33509 33510 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33508 def monitor_window @monitor_window end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33515 33516 33517 33518 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33515 def update!(**args) @monitor_interval = args[:monitor_interval] if args.key?(:monitor_interval) @monitor_window = args[:monitor_window] if args.key?(:monitor_window) end |