Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringScheduleConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringScheduleConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The config for scheduling monitoring job.
Instance Attribute Summary collapse
-
#monitor_interval ⇒ String
Required.
-
#monitor_window ⇒ String
The time window of the prediction data being included in each prediction dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringScheduleConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringScheduleConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringScheduleConfig
Returns a new instance of GoogleCloudAiplatformV1beta1ModelDeploymentMonitoringScheduleConfig.
28051 28052 28053 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28051 def initialize(**args) update!(**args) end |
Instance Attribute Details
#monitor_interval ⇒ String
Required. The model monitoring job scheduling interval. It will be rounded up
to next full hour. This defines how often the monitoring jobs are triggered.
Corresponds to the JSON property monitorInterval
28038 28039 28040 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28038 def monitor_interval @monitor_interval end |
#monitor_window ⇒ String
The time window of the prediction data being included in each prediction
dataset. This window specifies how long the data should be collected from
historical model results for each run. If not set,
ModelDeploymentMonitoringScheduleConfig.monitor_interval will be used. e.g. If
currently the cutoff time is 2022-01-08 14:30:00 and the monitor_window is set
to be 3600, then data from 2022-01-08 13:30:00 to 2022-01-08 14:30:00 will be
retrieved and aggregated to calculate the monitoring statistics.
Corresponds to the JSON property monitorWindow
28049 28050 28051 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28049 def monitor_window @monitor_window end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28056 28057 28058 28059 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28056 def update!(**args) @monitor_interval = args[:monitor_interval] if args.key?(:monitor_interval) @monitor_window = args[:monitor_window] if args.key?(:monitor_window) end |