Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A collection of metrics calculated by comparing Model's predictions on all of the test data against annotations from the test data.
Instance Attribute Summary collapse
-
#bias_configs ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationBiasConfig
Configuration for bias detection.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The display name of the ModelEvaluation.
-
#explanation_specs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationModelEvaluationExplanationSpec>
Describes the values of ExplanationSpec that are used for explaining the predicted values on the evaluated data.
-
#metadata ⇒ Object
The metadata of the ModelEvaluation.
-
#metrics ⇒ Object
Evaluation metrics of the Model.
-
#metrics_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing the metrics of this ModelEvaluation.
-
#model_explanation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelExplanation
Aggregated explanation metrics for a Model over a set of instances.
-
#name ⇒ String
Output only.
-
#slice_dimensions ⇒ Array<String>
All possible dimensions of ModelEvaluationSlices.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelEvaluation
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelEvaluation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelEvaluation
Returns a new instance of GoogleCloudAiplatformV1beta1ModelEvaluation.
34976 34977 34978 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34976 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bias_configs ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationBiasConfig
Configuration for bias detection.
Corresponds to the JSON property biasConfigs
34919 34920 34921 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34919 def bias_configs @bias_configs end |
#create_time ⇒ String
Output only. Timestamp when this ModelEvaluation was created.
Corresponds to the JSON property createTime
34924 34925 34926 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34924 def create_time @create_time end |
#display_name ⇒ String
The display name of the ModelEvaluation.
Corresponds to the JSON property displayName
34929 34930 34931 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34929 def display_name @display_name end |
#explanation_specs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationModelEvaluationExplanationSpec>
Describes the values of ExplanationSpec that are used for explaining the
predicted values on the evaluated data.
Corresponds to the JSON property explanationSpecs
34935 34936 34937 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34935 def explanation_specs @explanation_specs end |
#metadata ⇒ Object
The metadata of the ModelEvaluation. For the ModelEvaluation uploaded from
Managed Pipeline, metadata contains a structured value with keys of "
pipeline_job_id", "evaluation_dataset_type", "evaluation_dataset_path", "
row_based_metrics_path".
Corresponds to the JSON property metadata
34943 34944 34945 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34943 def @metadata end |
#metrics ⇒ Object
Evaluation metrics of the Model. The schema of the metrics is stored in
metrics_schema_uri
Corresponds to the JSON property metrics
34949 34950 34951 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34949 def metrics @metrics end |
#metrics_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing the metrics of
this ModelEvaluation. The schema is defined as an OpenAPI 3.0.2 Schema Object.
Corresponds to the JSON property metricsSchemaUri
34957 34958 34959 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34957 def metrics_schema_uri @metrics_schema_uri end |
#model_explanation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelExplanation
Aggregated explanation metrics for a Model over a set of instances.
Corresponds to the JSON property modelExplanation
34962 34963 34964 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34962 def model_explanation @model_explanation end |
#name ⇒ String
Output only. The resource name of the ModelEvaluation.
Corresponds to the JSON property name
34967 34968 34969 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34967 def name @name end |
#slice_dimensions ⇒ Array<String>
All possible dimensions of ModelEvaluationSlices. The dimensions can be used
as the filter of the ModelService.ListModelEvaluationSlices request, in the
form of slice.dimension =.
Corresponds to the JSON property sliceDimensions
34974 34975 34976 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34974 def slice_dimensions @slice_dimensions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34981 34982 34983 34984 34985 34986 34987 34988 34989 34990 34991 34992 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34981 def update!(**args) @bias_configs = args[:bias_configs] if args.key?(:bias_configs) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @explanation_specs = args[:explanation_specs] if args.key?(:explanation_specs) @metadata = args[:metadata] if args.key?(:metadata) @metrics = args[:metrics] if args.key?(:metrics) @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri) @model_explanation = args[:model_explanation] if args.key?(:model_explanation) @name = args[:name] if args.key?(:name) @slice_dimensions = args[:slice_dimensions] if args.key?(:slice_dimensions) end |