Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A collection of metrics calculated by comparing Model's predictions on all of the test data against annotations from the test data.
Instance Attribute Summary collapse
-
#bias_configs ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationBiasConfig
Configuration for bias detection.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The display name of the ModelEvaluation.
-
#explanation_specs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationModelEvaluationExplanationSpec>
Describes the values of ExplanationSpec that are used for explaining the predicted values on the evaluated data.
-
#metadata ⇒ Object
The metadata of the ModelEvaluation.
-
#metrics ⇒ Object
Evaluation metrics of the Model.
-
#metrics_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing the metrics of this ModelEvaluation.
-
#model_explanation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelExplanation
Aggregated explanation metrics for a Model over a set of instances.
-
#name ⇒ String
Output only.
-
#slice_dimensions ⇒ Array<String>
All possible dimensions of ModelEvaluationSlices.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelEvaluation
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelEvaluation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelEvaluation
Returns a new instance of GoogleCloudAiplatformV1beta1ModelEvaluation.
33586 33587 33588 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33586 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bias_configs ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationBiasConfig
Configuration for bias detection.
Corresponds to the JSON property biasConfigs
33529 33530 33531 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33529 def bias_configs @bias_configs end |
#create_time ⇒ String
Output only. Timestamp when this ModelEvaluation was created.
Corresponds to the JSON property createTime
33534 33535 33536 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33534 def create_time @create_time end |
#display_name ⇒ String
The display name of the ModelEvaluation.
Corresponds to the JSON property displayName
33539 33540 33541 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33539 def display_name @display_name end |
#explanation_specs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationModelEvaluationExplanationSpec>
Describes the values of ExplanationSpec that are used for explaining the
predicted values on the evaluated data.
Corresponds to the JSON property explanationSpecs
33545 33546 33547 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33545 def explanation_specs @explanation_specs end |
#metadata ⇒ Object
The metadata of the ModelEvaluation. For the ModelEvaluation uploaded from
Managed Pipeline, metadata contains a structured value with keys of "
pipeline_job_id", "evaluation_dataset_type", "evaluation_dataset_path", "
row_based_metrics_path".
Corresponds to the JSON property metadata
33553 33554 33555 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33553 def @metadata end |
#metrics ⇒ Object
Evaluation metrics of the Model. The schema of the metrics is stored in
metrics_schema_uri
Corresponds to the JSON property metrics
33559 33560 33561 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33559 def metrics @metrics end |
#metrics_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing the metrics of
this ModelEvaluation. The schema is defined as an OpenAPI 3.0.2 Schema Object.
Corresponds to the JSON property metricsSchemaUri
33567 33568 33569 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33567 def metrics_schema_uri @metrics_schema_uri end |
#model_explanation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelExplanation
Aggregated explanation metrics for a Model over a set of instances.
Corresponds to the JSON property modelExplanation
33572 33573 33574 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33572 def model_explanation @model_explanation end |
#name ⇒ String
Output only. The resource name of the ModelEvaluation.
Corresponds to the JSON property name
33577 33578 33579 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33577 def name @name end |
#slice_dimensions ⇒ Array<String>
All possible dimensions of ModelEvaluationSlices. The dimensions can be used
as the filter of the ModelService.ListModelEvaluationSlices request, in the
form of slice.dimension =.
Corresponds to the JSON property sliceDimensions
33584 33585 33586 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33584 def slice_dimensions @slice_dimensions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33591 33592 33593 33594 33595 33596 33597 33598 33599 33600 33601 33602 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33591 def update!(**args) @bias_configs = args[:bias_configs] if args.key?(:bias_configs) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @explanation_specs = args[:explanation_specs] if args.key?(:explanation_specs) @metadata = args[:metadata] if args.key?(:metadata) @metrics = args[:metrics] if args.key?(:metrics) @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri) @model_explanation = args[:model_explanation] if args.key?(:model_explanation) @name = args[:name] if args.key?(:name) @slice_dimensions = args[:slice_dimensions] if args.key?(:slice_dimensions) end |