Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A collection of metrics calculated by comparing Model's predictions on all of the test data against annotations from the test data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelEvaluation

Returns a new instance of GoogleCloudAiplatformV1beta1ModelEvaluation.



28127
28128
28129
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28127

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bias_configsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationBiasConfig

Configuration for bias detection. Corresponds to the JSON property biasConfigs



28070
28071
28072
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28070

def bias_configs
  @bias_configs
end

#create_timeString

Output only. Timestamp when this ModelEvaluation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


28075
28076
28077
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28075

def create_time
  @create_time
end

#display_nameString

The display name of the ModelEvaluation. Corresponds to the JSON property displayName

Returns:

  • (String)


28080
28081
28082
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28080

def display_name
  @display_name
end

#explanation_specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationModelEvaluationExplanationSpec>

Describes the values of ExplanationSpec that are used for explaining the predicted values on the evaluated data. Corresponds to the JSON property explanationSpecs



28086
28087
28088
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28086

def explanation_specs
  @explanation_specs
end

#metadataObject

The metadata of the ModelEvaluation. For the ModelEvaluation uploaded from Managed Pipeline, metadata contains a structured value with keys of " pipeline_job_id", "evaluation_dataset_type", "evaluation_dataset_path", " row_based_metrics_path". Corresponds to the JSON property metadata

Returns:

  • (Object)


28094
28095
28096
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28094

def 
  @metadata
end

#metricsObject

Evaluation metrics of the Model. The schema of the metrics is stored in metrics_schema_uri Corresponds to the JSON property metrics

Returns:

  • (Object)


28100
28101
28102
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28100

def metrics
  @metrics
end

#metrics_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing the metrics of this ModelEvaluation. The schema is defined as an OpenAPI 3.0.2 Schema Object. Corresponds to the JSON property metricsSchemaUri

Returns:

  • (String)


28108
28109
28110
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28108

def metrics_schema_uri
  @metrics_schema_uri
end

#model_explanationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelExplanation

Aggregated explanation metrics for a Model over a set of instances. Corresponds to the JSON property modelExplanation



28113
28114
28115
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28113

def model_explanation
  @model_explanation
end

#nameString

Output only. The resource name of the ModelEvaluation. Corresponds to the JSON property name

Returns:

  • (String)


28118
28119
28120
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28118

def name
  @name
end

#slice_dimensionsArray<String>

All possible dimensions of ModelEvaluationSlices. The dimensions can be used as the filter of the ModelService.ListModelEvaluationSlices request, in the form of slice.dimension =. Corresponds to the JSON property sliceDimensions

Returns:

  • (Array<String>)


28125
28126
28127
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28125

def slice_dimensions
  @slice_dimensions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28132
28133
28134
28135
28136
28137
28138
28139
28140
28141
28142
28143
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28132

def update!(**args)
  @bias_configs = args[:bias_configs] if args.key?(:bias_configs)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @explanation_specs = args[:explanation_specs] if args.key?(:explanation_specs)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metrics = args[:metrics] if args.key?(:metrics)
  @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri)
  @model_explanation = args[:model_explanation] if args.key?(:model_explanation)
  @name = args[:name] if args.key?(:name)
  @slice_dimensions = args[:slice_dimensions] if args.key?(:slice_dimensions)
end