Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A collection of metrics calculated by comparing Model's predictions on all of the test data against annotations from the test data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelEvaluation

Returns a new instance of GoogleCloudAiplatformV1beta1ModelEvaluation.



28061
28062
28063
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28061

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bias_configsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationBiasConfig

Configuration for bias detection. Corresponds to the JSON property biasConfigs



28004
28005
28006
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28004

def bias_configs
  @bias_configs
end

#create_timeString

Output only. Timestamp when this ModelEvaluation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


28009
28010
28011
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28009

def create_time
  @create_time
end

#display_nameString

The display name of the ModelEvaluation. Corresponds to the JSON property displayName

Returns:

  • (String)


28014
28015
28016
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28014

def display_name
  @display_name
end

#explanation_specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationModelEvaluationExplanationSpec>

Describes the values of ExplanationSpec that are used for explaining the predicted values on the evaluated data. Corresponds to the JSON property explanationSpecs



28020
28021
28022
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28020

def explanation_specs
  @explanation_specs
end

#metadataObject

The metadata of the ModelEvaluation. For the ModelEvaluation uploaded from Managed Pipeline, metadata contains a structured value with keys of " pipeline_job_id", "evaluation_dataset_type", "evaluation_dataset_path", " row_based_metrics_path". Corresponds to the JSON property metadata

Returns:

  • (Object)


28028
28029
28030
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28028

def 
  @metadata
end

#metricsObject

Evaluation metrics of the Model. The schema of the metrics is stored in metrics_schema_uri Corresponds to the JSON property metrics

Returns:

  • (Object)


28034
28035
28036
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28034

def metrics
  @metrics
end

#metrics_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing the metrics of this ModelEvaluation. The schema is defined as an OpenAPI 3.0.2 Schema Object. Corresponds to the JSON property metricsSchemaUri

Returns:

  • (String)


28042
28043
28044
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28042

def metrics_schema_uri
  @metrics_schema_uri
end

#model_explanationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelExplanation

Aggregated explanation metrics for a Model over a set of instances. Corresponds to the JSON property modelExplanation



28047
28048
28049
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28047

def model_explanation
  @model_explanation
end

#nameString

Output only. The resource name of the ModelEvaluation. Corresponds to the JSON property name

Returns:

  • (String)


28052
28053
28054
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28052

def name
  @name
end

#slice_dimensionsArray<String>

All possible dimensions of ModelEvaluationSlices. The dimensions can be used as the filter of the ModelService.ListModelEvaluationSlices request, in the form of slice.dimension =. Corresponds to the JSON property sliceDimensions

Returns:

  • (Array<String>)


28059
28060
28061
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28059

def slice_dimensions
  @slice_dimensions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28066
28067
28068
28069
28070
28071
28072
28073
28074
28075
28076
28077
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28066

def update!(**args)
  @bias_configs = args[:bias_configs] if args.key?(:bias_configs)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @explanation_specs = args[:explanation_specs] if args.key?(:explanation_specs)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metrics = args[:metrics] if args.key?(:metrics)
  @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri)
  @model_explanation = args[:model_explanation] if args.key?(:model_explanation)
  @name = args[:name] if args.key?(:name)
  @slice_dimensions = args[:slice_dimensions] if args.key?(:slice_dimensions)
end