Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationSlice
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationSlice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A collection of metrics calculated by comparing Model's predictions on a slice of the test data against ground truth annotations.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#metrics ⇒ Object
Output only.
-
#metrics_schema_uri ⇒ String
Output only.
-
#model_explanation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelExplanation
Aggregated explanation metrics for a Model over a set of instances.
-
#name ⇒ String
Output only.
-
#slice ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationSliceSlice
Definition of a slice.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelEvaluationSlice
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelEvaluationSlice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelEvaluationSlice
Returns a new instance of GoogleCloudAiplatformV1beta1ModelEvaluationSlice.
36648 36649 36650 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36648 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this ModelEvaluationSlice was created.
Corresponds to the JSON property createTime
36617 36618 36619 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36617 def create_time @create_time end |
#metrics ⇒ Object
Output only. Sliced evaluation metrics of the Model. The schema of the metrics
is stored in metrics_schema_uri
Corresponds to the JSON property metrics
36623 36624 36625 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36623 def metrics @metrics end |
#metrics_schema_uri ⇒ String
Output only. Points to a YAML file stored on Google Cloud Storage describing
the metrics of this ModelEvaluationSlice. The schema is defined as an OpenAPI
3.0.2 Schema Object.
Corresponds to the JSON property metricsSchemaUri
36631 36632 36633 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36631 def metrics_schema_uri @metrics_schema_uri end |
#model_explanation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelExplanation
Aggregated explanation metrics for a Model over a set of instances.
Corresponds to the JSON property modelExplanation
36636 36637 36638 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36636 def model_explanation @model_explanation end |
#name ⇒ String
Output only. The resource name of the ModelEvaluationSlice.
Corresponds to the JSON property name
36641 36642 36643 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36641 def name @name end |
#slice ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationSliceSlice
Definition of a slice.
Corresponds to the JSON property slice
36646 36647 36648 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36646 def slice @slice end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36653 36654 36655 36656 36657 36658 36659 36660 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36653 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @metrics = args[:metrics] if args.key?(:metrics) @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri) @model_explanation = args[:model_explanation] if args.key?(:model_explanation) @name = args[:name] if args.key?(:name) @slice = args[:slice] if args.key?(:slice) end |