Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationSlice
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationSlice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A collection of metrics calculated by comparing Model's predictions on a slice of the test data against ground truth annotations.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#metrics ⇒ Object
Output only.
-
#metrics_schema_uri ⇒ String
Output only.
-
#model_explanation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelExplanation
Aggregated explanation metrics for a Model over a set of instances.
-
#name ⇒ String
Output only.
-
#slice ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationSliceSlice
Definition of a slice.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelEvaluationSlice
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelEvaluationSlice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelEvaluationSlice
Returns a new instance of GoogleCloudAiplatformV1beta1ModelEvaluationSlice.
28236 28237 28238 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this ModelEvaluationSlice was created.
Corresponds to the JSON property createTime
28205 28206 28207 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28205 def create_time @create_time end |
#metrics ⇒ Object
Output only. Sliced evaluation metrics of the Model. The schema of the metrics
is stored in metrics_schema_uri
Corresponds to the JSON property metrics
28211 28212 28213 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28211 def metrics @metrics end |
#metrics_schema_uri ⇒ String
Output only. Points to a YAML file stored on Google Cloud Storage describing
the metrics of this ModelEvaluationSlice. The schema is defined as an OpenAPI
3.0.2 Schema Object.
Corresponds to the JSON property metricsSchemaUri
28219 28220 28221 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28219 def metrics_schema_uri @metrics_schema_uri end |
#model_explanation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelExplanation
Aggregated explanation metrics for a Model over a set of instances.
Corresponds to the JSON property modelExplanation
28224 28225 28226 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28224 def model_explanation @model_explanation end |
#name ⇒ String
Output only. The resource name of the ModelEvaluationSlice.
Corresponds to the JSON property name
28229 28230 28231 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28229 def name @name end |
#slice ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelEvaluationSliceSlice
Definition of a slice.
Corresponds to the JSON property slice
28234 28235 28236 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28234 def slice @slice end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28241 28242 28243 28244 28245 28246 28247 28248 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 28241 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @metrics = args[:metrics] if args.key?(:metrics) @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri) @model_explanation = args[:model_explanation] if args.key?(:model_explanation) @name = args[:name] if args.key?(:name) @slice = args[:slice] if args.key?(:slice) end |