Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelGardenSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Contains information about the source of the models generated from Model Garden.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelGardenSource

Returns a new instance of GoogleCloudAiplatformV1beta1ModelGardenSource.



33952
33953
33954
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33952

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#public_model_nameString

Required. The model garden source model resource name. Corresponds to the JSON property publicModelName

Returns:

  • (String)


33939
33940
33941
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33939

def public_model_name
  @public_model_name
end

#skip_hf_model_cacheBoolean Also known as: skip_hf_model_cache?

Optional. Whether to avoid pulling the model from the HF cache. Corresponds to the JSON property skipHfModelCache

Returns:

  • (Boolean)


33944
33945
33946
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33944

def skip_hf_model_cache
  @skip_hf_model_cache
end

#version_idString

Optional. The model garden source model version ID. Corresponds to the JSON property versionId

Returns:

  • (String)


33950
33951
33952
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33950

def version_id
  @version_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33957
33958
33959
33960
33961
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33957

def update!(**args)
  @public_model_name = args[:public_model_name] if args.key?(:public_model_name)
  @skip_hf_model_cache = args[:skip_hf_model_cache] if args.key?(:skip_hf_model_cache)
  @version_id = args[:version_id] if args.key?(:version_id)
end