Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Vertex AI Model Monitoring Service serves as a central hub for the analysis and visualization of data quality and performance related to models. ModelMonitor stands as a top level resource for overseeing your model monitoring tasks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitor

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitor.



35963
35964
35965
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this ModelMonitor was created. Corresponds to the JSON property createTime

Returns:

  • (String)


35888
35889
35890
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35888

def create_time
  @create_time
end

#display_nameString

The display name of the ModelMonitor. The name can be up to 128 characters long and can consist of any UTF-8. Corresponds to the JSON property displayName

Returns:

  • (String)


35894
35895
35896
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35894

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



35900
35901
35902
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35900

def encryption_spec
  @encryption_spec
end

#explanation_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpec

Specification of Model explanation. Corresponds to the JSON property explanationSpec



35905
35906
35907
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35905

def explanation_spec
  @explanation_spec
end

#model_monitoring_schemaGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchema

The Model Monitoring Schema definition. Corresponds to the JSON property modelMonitoringSchema



35910
35911
35912
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35910

def model_monitoring_schema
  @model_monitoring_schema
end

#model_monitoring_targetGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitorModelMonitoringTarget

The monitoring target refers to the entity that is subject to analysis. e.g. Vertex AI Model version. Corresponds to the JSON property modelMonitoringTarget



35916
35917
35918
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35916

def model_monitoring_target
  @model_monitoring_target
end

#nameString

Immutable. Resource name of the ModelMonitor. Format: projects/project/ locations/location/modelMonitors/model_monitor`. Corresponds to the JSON propertyname`

Returns:

  • (String)


35922
35923
35924
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35922

def name
  @name
end

#notification_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringNotificationSpec

Notification spec(email, notification channel) for model monitoring statistics/ alerts. Corresponds to the JSON property notificationSpec



35928
35929
35930
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35928

def notification_spec
  @notification_spec
end

#output_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringOutputSpec

Specification for the export destination of monitoring results, including metrics, logs, etc. Corresponds to the JSON property outputSpec



35934
35935
35936
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35934

def output_spec
  @output_spec
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


35939
35940
35941
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35939

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


35945
35946
35947
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35945

def satisfies_pzs
  @satisfies_pzs
end

#tabular_objectiveGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecTabularObjective

Tabular monitoring objective. Corresponds to the JSON property tabularObjective



35951
35952
35953
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35951

def tabular_objective
  @tabular_objective
end

#training_datasetGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInput

Model monitoring data input spec. Corresponds to the JSON property trainingDataset



35956
35957
35958
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35956

def training_dataset
  @training_dataset
end

#update_timeString

Output only. Timestamp when this ModelMonitor was updated most recently. Corresponds to the JSON property updateTime

Returns:

  • (String)


35961
35962
35963
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35961

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35968
35969
35970
35971
35972
35973
35974
35975
35976
35977
35978
35979
35980
35981
35982
35983
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35968

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec)
  @model_monitoring_schema = args[:model_monitoring_schema] if args.key?(:model_monitoring_schema)
  @model_monitoring_target = args[:model_monitoring_target] if args.key?(:model_monitoring_target)
  @name = args[:name] if args.key?(:name)
  @notification_spec = args[:notification_spec] if args.key?(:notification_spec)
  @output_spec = args[:output_spec] if args.key?(:output_spec)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @tabular_objective = args[:tabular_objective] if args.key?(:tabular_objective)
  @training_dataset = args[:training_dataset] if args.key?(:training_dataset)
  @update_time = args[:update_time] if args.key?(:update_time)
end