Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitor
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Vertex AI Model Monitoring Service serves as a central hub for the analysis and visualization of data quality and performance related to models. ModelMonitor stands as a top level resource for overseeing your model monitoring tasks.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The display name of the ModelMonitor.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#explanation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpec
Specification of Model explanation.
-
#model_monitoring_schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchema
The Model Monitoring Schema definition.
-
#model_monitoring_target ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitorModelMonitoringTarget
The monitoring target refers to the entity that is subject to analysis.
-
#name ⇒ String
Immutable.
-
#notification_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringNotificationSpec
Notification spec(email, notification channel) for model monitoring statistics/ alerts.
-
#output_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringOutputSpec
Specification for the export destination of monitoring results, including metrics, logs, etc.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#tabular_objective ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecTabularObjective
Tabular monitoring objective.
-
#training_dataset ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInput
Model monitoring data input spec.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitor
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitor
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitor.
35261 35262 35263 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35261 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this ModelMonitor was created.
Corresponds to the JSON property createTime
35186 35187 35188 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35186 def create_time @create_time end |
#display_name ⇒ String
The display name of the ModelMonitor. The name can be up to 128 characters
long and can consist of any UTF-8.
Corresponds to the JSON property displayName
35192 35193 35194 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35192 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
35198 35199 35200 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35198 def encryption_spec @encryption_spec end |
#explanation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpec
Specification of Model explanation.
Corresponds to the JSON property explanationSpec
35203 35204 35205 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35203 def explanation_spec @explanation_spec end |
#model_monitoring_schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchema
The Model Monitoring Schema definition.
Corresponds to the JSON property modelMonitoringSchema
35208 35209 35210 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35208 def model_monitoring_schema @model_monitoring_schema end |
#model_monitoring_target ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitorModelMonitoringTarget
The monitoring target refers to the entity that is subject to analysis. e.g.
Vertex AI Model version.
Corresponds to the JSON property modelMonitoringTarget
35214 35215 35216 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35214 def model_monitoring_target @model_monitoring_target end |
#name ⇒ String
Immutable. Resource name of the ModelMonitor. Format: projects/project/
locations/location/modelMonitors/model_monitor`.
Corresponds to the JSON propertyname`
35220 35221 35222 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35220 def name @name end |
#notification_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringNotificationSpec
Notification spec(email, notification channel) for model monitoring statistics/
alerts.
Corresponds to the JSON property notificationSpec
35226 35227 35228 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35226 def notification_spec @notification_spec end |
#output_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringOutputSpec
Specification for the export destination of monitoring results, including
metrics, logs, etc.
Corresponds to the JSON property outputSpec
35232 35233 35234 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35232 def output_spec @output_spec end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
35237 35238 35239 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35237 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
35243 35244 35245 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35243 def satisfies_pzs @satisfies_pzs end |
#tabular_objective ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecTabularObjective
Tabular monitoring objective.
Corresponds to the JSON property tabularObjective
35249 35250 35251 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35249 def tabular_objective @tabular_objective end |
#training_dataset ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInput
Model monitoring data input spec.
Corresponds to the JSON property trainingDataset
35254 35255 35256 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35254 def training_dataset @training_dataset end |
#update_time ⇒ String
Output only. Timestamp when this ModelMonitor was updated most recently.
Corresponds to the JSON property updateTime
35259 35260 35261 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35259 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35266 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec) @model_monitoring_schema = args[:model_monitoring_schema] if args.key?(:model_monitoring_schema) @model_monitoring_target = args[:model_monitoring_target] if args.key?(:model_monitoring_target) @name = args[:name] if args.key?(:name) @notification_spec = args[:notification_spec] if args.key?(:notification_spec) @output_spec = args[:output_spec] if args.key?(:output_spec) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @tabular_objective = args[:tabular_objective] if args.key?(:tabular_objective) @training_dataset = args[:training_dataset] if args.key?(:training_dataset) @update_time = args[:update_time] if args.key?(:update_time) end |