Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitor
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Vertex AI Model Monitoring Service serves as a central hub for the analysis and visualization of data quality and performance related to models. ModelMonitor stands as a top level resource for overseeing your model monitoring tasks.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The display name of the ModelMonitor.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#explanation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpec
Specification of Model explanation.
-
#model_monitoring_schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchema
The Model Monitoring Schema definition.
-
#model_monitoring_target ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitorModelMonitoringTarget
The monitoring target refers to the entity that is subject to analysis.
-
#name ⇒ String
Immutable.
-
#notification_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringNotificationSpec
Notification spec(email, notification channel) for model monitoring statistics/ alerts.
-
#output_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringOutputSpec
Specification for the export destination of monitoring results, including metrics, logs, etc.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#tabular_objective ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecTabularObjective
Tabular monitoring objective.
-
#training_dataset ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInput
Model monitoring data input spec.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitor
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitor
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitor.
34049 34050 34051 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this ModelMonitor was created.
Corresponds to the JSON property createTime
33974 33975 33976 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33974 def create_time @create_time end |
#display_name ⇒ String
The display name of the ModelMonitor. The name can be up to 128 characters
long and can consist of any UTF-8.
Corresponds to the JSON property displayName
33980 33981 33982 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33980 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
33986 33987 33988 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33986 def encryption_spec @encryption_spec end |
#explanation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpec
Specification of Model explanation.
Corresponds to the JSON property explanationSpec
33991 33992 33993 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33991 def explanation_spec @explanation_spec end |
#model_monitoring_schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchema
The Model Monitoring Schema definition.
Corresponds to the JSON property modelMonitoringSchema
33996 33997 33998 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33996 def model_monitoring_schema @model_monitoring_schema end |
#model_monitoring_target ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitorModelMonitoringTarget
The monitoring target refers to the entity that is subject to analysis. e.g.
Vertex AI Model version.
Corresponds to the JSON property modelMonitoringTarget
34002 34003 34004 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34002 def model_monitoring_target @model_monitoring_target end |
#name ⇒ String
Immutable. Resource name of the ModelMonitor. Format: projects/project/
locations/location/modelMonitors/model_monitor`.
Corresponds to the JSON propertyname`
34008 34009 34010 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34008 def name @name end |
#notification_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringNotificationSpec
Notification spec(email, notification channel) for model monitoring statistics/
alerts.
Corresponds to the JSON property notificationSpec
34014 34015 34016 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34014 def notification_spec @notification_spec end |
#output_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringOutputSpec
Specification for the export destination of monitoring results, including
metrics, logs, etc.
Corresponds to the JSON property outputSpec
34020 34021 34022 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34020 def output_spec @output_spec end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
34025 34026 34027 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34025 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
34031 34032 34033 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34031 def satisfies_pzs @satisfies_pzs end |
#tabular_objective ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecTabularObjective
Tabular monitoring objective.
Corresponds to the JSON property tabularObjective
34037 34038 34039 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34037 def tabular_objective @tabular_objective end |
#training_dataset ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInput
Model monitoring data input spec.
Corresponds to the JSON property trainingDataset
34042 34043 34044 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34042 def training_dataset @training_dataset end |
#update_time ⇒ String
Output only. Timestamp when this ModelMonitor was updated most recently.
Corresponds to the JSON property updateTime
34047 34048 34049 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34047 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34054 34055 34056 34057 34058 34059 34060 34061 34062 34063 34064 34065 34066 34067 34068 34069 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34054 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec) @model_monitoring_schema = args[:model_monitoring_schema] if args.key?(:model_monitoring_schema) @model_monitoring_target = args[:model_monitoring_target] if args.key?(:model_monitoring_target) @name = args[:name] if args.key?(:name) @notification_spec = args[:notification_spec] if args.key?(:notification_spec) @output_spec = args[:output_spec] if args.key?(:output_spec) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @tabular_objective = args[:tabular_objective] if args.key?(:tabular_objective) @training_dataset = args[:training_dataset] if args.key?(:training_dataset) @update_time = args[:update_time] if args.key?(:update_time) end |