Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Vertex AI Model Monitoring Service serves as a central hub for the analysis and visualization of data quality and performance related to models. ModelMonitor stands as a top level resource for overseeing your model monitoring tasks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitor

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitor.



33462
33463
33464
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this ModelMonitor was created. Corresponds to the JSON property createTime

Returns:

  • (String)


33387
33388
33389
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33387

def create_time
  @create_time
end

#display_nameString

The display name of the ModelMonitor. The name can be up to 128 characters long and can consist of any UTF-8. Corresponds to the JSON property displayName

Returns:

  • (String)


33393
33394
33395
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33393

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



33399
33400
33401
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33399

def encryption_spec
  @encryption_spec
end

#explanation_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExplanationSpec

Specification of Model explanation. Corresponds to the JSON property explanationSpec



33404
33405
33406
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33404

def explanation_spec
  @explanation_spec
end

#model_monitoring_schemaGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchema

The Model Monitoring Schema definition. Corresponds to the JSON property modelMonitoringSchema



33409
33410
33411
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33409

def model_monitoring_schema
  @model_monitoring_schema
end

#model_monitoring_targetGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitorModelMonitoringTarget

The monitoring target refers to the entity that is subject to analysis. e.g. Vertex AI Model version. Corresponds to the JSON property modelMonitoringTarget



33415
33416
33417
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33415

def model_monitoring_target
  @model_monitoring_target
end

#nameString

Immutable. Resource name of the ModelMonitor. Format: projects/project/ locations/location/modelMonitors/model_monitor`. Corresponds to the JSON propertyname`

Returns:

  • (String)


33421
33422
33423
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33421

def name
  @name
end

#notification_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringNotificationSpec

Notification spec(email, notification channel) for model monitoring statistics/ alerts. Corresponds to the JSON property notificationSpec



33427
33428
33429
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33427

def notification_spec
  @notification_spec
end

#output_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringOutputSpec

Specification for the export destination of monitoring results, including metrics, logs, etc. Corresponds to the JSON property outputSpec



33433
33434
33435
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33433

def output_spec
  @output_spec
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


33438
33439
33440
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33438

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


33444
33445
33446
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33444

def satisfies_pzs
  @satisfies_pzs
end

#tabular_objectiveGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecTabularObjective

Tabular monitoring objective. Corresponds to the JSON property tabularObjective



33450
33451
33452
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33450

def tabular_objective
  @tabular_objective
end

#training_datasetGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInput

Model monitoring data input spec. Corresponds to the JSON property trainingDataset



33455
33456
33457
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33455

def training_dataset
  @training_dataset
end

#update_timeString

Output only. Timestamp when this ModelMonitor was updated most recently. Corresponds to the JSON property updateTime

Returns:

  • (String)


33460
33461
33462
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33460

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33467
33468
33469
33470
33471
33472
33473
33474
33475
33476
33477
33478
33479
33480
33481
33482
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33467

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec)
  @model_monitoring_schema = args[:model_monitoring_schema] if args.key?(:model_monitoring_schema)
  @model_monitoring_target = args[:model_monitoring_target] if args.key?(:model_monitoring_target)
  @name = args[:name] if args.key?(:name)
  @notification_spec = args[:notification_spec] if args.key?(:notification_spec)
  @output_spec = args[:output_spec] if args.key?(:output_spec)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @tabular_objective = args[:tabular_objective] if args.key?(:tabular_objective)
  @training_dataset = args[:training_dataset] if args.key?(:training_dataset)
  @update_time = args[:update_time] if args.key?(:update_time)
end