Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlert

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a single monitoring alert. This is currently used in the SearchModelMonitoringAlerts api, thus the alert wrapped in this message belongs to the resource asked in the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringAlert

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringAlert.



33558
33559
33560
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alert_timeString

Alert creation time. Corresponds to the JSON property alertTime

Returns:

  • (String)


33540
33541
33542
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33540

def alert_time
  @alert_time
end

#anomalyGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAnomaly

Represents a single model monitoring anomaly. Corresponds to the JSON property anomaly



33545
33546
33547
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33545

def anomaly
  @anomaly
end

#objective_typeString

One of the supported monitoring objectives: raw-feature-drift prediction- output-drift feature-attribution Corresponds to the JSON property objectiveType

Returns:

  • (String)


33551
33552
33553
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33551

def objective_type
  @objective_type
end

#stats_nameString

The stats name. Corresponds to the JSON property statsName

Returns:

  • (String)


33556
33557
33558
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33556

def stats_name
  @stats_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33563
33564
33565
33566
33567
33568
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33563

def update!(**args)
  @alert_time = args[:alert_time] if args.key?(:alert_time)
  @anomaly = args[:anomaly] if args.key?(:anomaly)
  @objective_type = args[:objective_type] if args.key?(:objective_type)
  @stats_name = args[:stats_name] if args.key?(:stats_name)
end