Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Monitoring alert triggered condition.
Instance Attribute Summary collapse
-
#threshold ⇒ Float
A condition that compares a stats value against a threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition.
34168 34169 34170 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#threshold ⇒ Float
A condition that compares a stats value against a threshold. Alert will be
triggered if value above the threshold.
Corresponds to the JSON property threshold
34166 34167 34168 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34166 def threshold @threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34173 34174 34175 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34173 def update!(**args) @threshold = args[:threshold] if args.key?(:threshold) end |