Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The model monitoring configuration used for Batch Prediction Job.
Instance Attribute Summary collapse
-
#alert_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertConfig
The alert config for model monitoring.
-
#analysis_instance_schema_uri ⇒ String
YAML schema file uri in Cloud Storage describing the format of a single instance that you want Tensorflow Data Validation (TFDV) to analyze.
-
#objective_configs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfig>
Model monitoring objective config.
-
#stats_anomalies_base_directory ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitoringConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringConfig
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringConfig.
34336 34337 34338 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alert_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertConfig
The alert config for model monitoring.
Corresponds to the JSON property alertConfig
34314 34315 34316 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34314 def alert_config @alert_config end |
#analysis_instance_schema_uri ⇒ String
YAML schema file uri in Cloud Storage describing the format of a single
instance that you want Tensorflow Data Validation (TFDV) to analyze. If there
are any data type differences between predict instance and TFDV instance, this
field can be used to override the schema. For models trained with Vertex AI,
this field must be set as all the fields in predict instance formatted as
string.
Corresponds to the JSON property analysisInstanceSchemaUri
34324 34325 34326 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34324 def analysis_instance_schema_uri @analysis_instance_schema_uri end |
#objective_configs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfig>
Model monitoring objective config.
Corresponds to the JSON property objectiveConfigs
34329 34330 34331 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34329 def objective_configs @objective_configs end |
#stats_anomalies_base_directory ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property statsAnomaliesBaseDirectory
34334 34335 34336 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34334 def stats_anomalies_base_directory @stats_anomalies_base_directory end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34341 34342 34343 34344 34345 34346 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34341 def update!(**args) @alert_config = args[:alert_config] if args.key?(:alert_config) @analysis_instance_schema_uri = args[:analysis_instance_schema_uri] if args.key?(:analysis_instance_schema_uri) @objective_configs = args[:objective_configs] if args.key?(:objective_configs) @stats_anomalies_base_directory = args[:stats_anomalies_base_directory] if args.key?(:stats_anomalies_base_directory) end |