Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The model monitoring configuration used for Batch Prediction Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringConfig

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringConfig.



33749
33750
33751
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alert_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertConfig

The alert config for model monitoring. Corresponds to the JSON property alertConfig



33727
33728
33729
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33727

def alert_config
  @alert_config
end

#analysis_instance_schema_uriString

YAML schema file uri in Cloud Storage describing the format of a single instance that you want Tensorflow Data Validation (TFDV) to analyze. If there are any data type differences between predict instance and TFDV instance, this field can be used to override the schema. For models trained with Vertex AI, this field must be set as all the fields in predict instance formatted as string. Corresponds to the JSON property analysisInstanceSchemaUri

Returns:

  • (String)


33737
33738
33739
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33737

def analysis_instance_schema_uri
  @analysis_instance_schema_uri
end

#objective_configsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfig>

Model monitoring objective config. Corresponds to the JSON property objectiveConfigs



33742
33743
33744
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33742

def objective_configs
  @objective_configs
end

#stats_anomalies_base_directoryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property statsAnomaliesBaseDirectory



33747
33748
33749
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33747

def stats_anomalies_base_directory
  @stats_anomalies_base_directory
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33754
33755
33756
33757
33758
33759
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33754

def update!(**args)
  @alert_config = args[:alert_config] if args.key?(:alert_config)
  @analysis_instance_schema_uri = args[:analysis_instance_schema_uri] if args.key?(:analysis_instance_schema_uri)
  @objective_configs = args[:objective_configs] if args.key?(:objective_configs)
  @stats_anomalies_base_directory = args[:stats_anomalies_base_directory] if args.key?(:stats_anomalies_base_directory)
end