Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Model monitoring data input spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringInput

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringInput.



35593
35594
35595
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35593

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#batch_prediction_outputGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputBatchPredictionOutput

Data from Vertex AI Batch prediction job output. Corresponds to the JSON property batchPredictionOutput



35568
35569
35570
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35568

def batch_prediction_output
  @batch_prediction_output
end

#columnized_datasetGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDataset

Input dataset spec. Corresponds to the JSON property columnizedDataset



35573
35574
35575
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35573

def columnized_dataset
  @columnized_dataset
end

#time_intervalGoogle::Apis::AiplatformV1beta1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property timeInterval



35581
35582
35583
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35581

def time_interval
  @time_interval
end

#time_offsetGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputTimeOffset

Time offset setting. Corresponds to the JSON property timeOffset



35586
35587
35588
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35586

def time_offset
  @time_offset
end

#vertex_endpoint_logsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputVertexEndpointLogs

Data from Vertex AI Endpoint request response logging. Corresponds to the JSON property vertexEndpointLogs



35591
35592
35593
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35591

def vertex_endpoint_logs
  @vertex_endpoint_logs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35598
35599
35600
35601
35602
35603
35604
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35598

def update!(**args)
  @batch_prediction_output = args[:batch_prediction_output] if args.key?(:batch_prediction_output)
  @columnized_dataset = args[:columnized_dataset] if args.key?(:columnized_dataset)
  @time_interval = args[:time_interval] if args.key?(:time_interval)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
  @vertex_endpoint_logs = args[:vertex_endpoint_logs] if args.key?(:vertex_endpoint_logs)
end