Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInput
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInput
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Model monitoring data input spec.
Instance Attribute Summary collapse
-
#batch_prediction_output ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputBatchPredictionOutput
Data from Vertex AI Batch prediction job output.
-
#columnized_dataset ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDataset
Input dataset spec.
-
#time_interval ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#time_offset ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputTimeOffset
Time offset setting.
-
#vertex_endpoint_logs ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputVertexEndpointLogs
Data from Vertex AI Endpoint request response logging.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringInput
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitoringInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringInput
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringInput.
34381 34382 34383 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34381 def initialize(**args) update!(**args) end |
Instance Attribute Details
#batch_prediction_output ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputBatchPredictionOutput
Data from Vertex AI Batch prediction job output.
Corresponds to the JSON property batchPredictionOutput
34356 34357 34358 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34356 def batch_prediction_output @batch_prediction_output end |
#columnized_dataset ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDataset
Input dataset spec.
Corresponds to the JSON property columnizedDataset
34361 34362 34363 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34361 def columnized_dataset @columnized_dataset end |
#time_interval ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property timeInterval
34369 34370 34371 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34369 def time_interval @time_interval end |
#time_offset ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputTimeOffset
Time offset setting.
Corresponds to the JSON property timeOffset
34374 34375 34376 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34374 def time_offset @time_offset end |
#vertex_endpoint_logs ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputVertexEndpointLogs
Data from Vertex AI Endpoint request response logging.
Corresponds to the JSON property vertexEndpointLogs
34379 34380 34381 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34379 def vertex_endpoint_logs @vertex_endpoint_logs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34386 34387 34388 34389 34390 34391 34392 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34386 def update!(**args) @batch_prediction_output = args[:batch_prediction_output] if args.key?(:batch_prediction_output) @columnized_dataset = args[:columnized_dataset] if args.key?(:columnized_dataset) @time_interval = args[:time_interval] if args.key?(:time_interval) @time_offset = args[:time_offset] if args.key?(:time_offset) @vertex_endpoint_logs = args[:vertex_endpoint_logs] if args.key?(:vertex_endpoint_logs) end |