Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDataset
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Input dataset spec.
Instance Attribute Summary collapse
-
#bigquery_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDatasetModelMonitoringBigQuerySource
Dataset spec for data sotred in BigQuery.
-
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDatasetModelMonitoringGcsSource
Dataset spec for data stored in Google Cloud Storage.
-
#timestamp_field ⇒ String
The timestamp field.
-
#vertex_dataset ⇒ String
Resource name of the Vertex AI managed dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDataset
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDataset
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDataset.
37392 37393 37394 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDatasetModelMonitoringBigQuerySource
Dataset spec for data sotred in BigQuery.
Corresponds to the JSON property bigquerySource
37375 37376 37377 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37375 def bigquery_source @bigquery_source end |
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringInputModelMonitoringDatasetModelMonitoringGcsSource
Dataset spec for data stored in Google Cloud Storage.
Corresponds to the JSON property gcsSource
37380 37381 37382 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37380 def gcs_source @gcs_source end |
#timestamp_field ⇒ String
The timestamp field. Usually for serving data.
Corresponds to the JSON property timestampField
37385 37386 37387 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37385 def @timestamp_field end |
#vertex_dataset ⇒ String
Resource name of the Vertex AI managed dataset.
Corresponds to the JSON property vertexDataset
37390 37391 37392 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37390 def vertex_dataset @vertex_dataset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37397 37398 37399 37400 37401 37402 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37397 def update!(**args) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @timestamp_field = args[:timestamp_field] if args.key?(:timestamp_field) @vertex_dataset = args[:vertex_dataset] if args.key?(:vertex_dataset) end |