Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a model monitoring job that analyze dataset using different monitoring algorithm.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringJob

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringJob.



34618
34619
34620
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this ModelMonitoringJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


34566
34567
34568
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34566

def create_time
  @create_time
end

#display_nameString

The display name of the ModelMonitoringJob. The name can be up to 128 characters long and can consist of any UTF-8. Corresponds to the JSON property displayName

Returns:

  • (String)


34572
34573
34574
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34572

def display_name
  @display_name
end

#job_execution_detailGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetail

Represent the execution details of the job. Corresponds to the JSON property jobExecutionDetail



34577
34578
34579
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34577

def job_execution_detail
  @job_execution_detail
end

#model_monitoring_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSpec

Monitoring monitoring job spec. It outlines the specifications for monitoring objectives, notifications, and result exports. Corresponds to the JSON property modelMonitoringSpec



34583
34584
34585
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34583

def model_monitoring_spec
  @model_monitoring_spec
end

#nameString

Output only. Resource name of a ModelMonitoringJob. Format: projects/ project_id/locations/location_id/modelMonitors/model_monitor_id/ modelMonitoringJobs/model_monitoring_job_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


34590
34591
34592
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34590

def name
  @name
end

#scheduleString

Output only. Schedule resource name. It will only appear when this job is triggered by a schedule. Corresponds to the JSON property schedule

Returns:

  • (String)


34596
34597
34598
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34596

def schedule
  @schedule
end

#schedule_timeString

Output only. Timestamp when this ModelMonitoringJob was scheduled. It will only appear when this job is triggered by a schedule. Corresponds to the JSON property scheduleTime

Returns:

  • (String)


34602
34603
34604
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34602

def schedule_time
  @schedule_time
end

#stateString

Output only. The state of the monitoring job. * When the job is still creating, the state will be 'JOB_STATE_PENDING'. * Once the job is successfully created, the state will be 'JOB_STATE_RUNNING'. * Once the job is finished, the state will be one of 'JOB_STATE_FAILED', 'JOB_STATE_SUCCEEDED', ' JOB_STATE_PARTIALLY_SUCCEEDED'. Corresponds to the JSON property state

Returns:

  • (String)


34611
34612
34613
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34611

def state
  @state
end

#update_timeString

Output only. Timestamp when this ModelMonitoringJob was updated most recently. Corresponds to the JSON property updateTime

Returns:

  • (String)


34616
34617
34618
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34616

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34623
34624
34625
34626
34627
34628
34629
34630
34631
34632
34633
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34623

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @job_execution_detail = args[:job_execution_detail] if args.key?(:job_execution_detail)
  @model_monitoring_spec = args[:model_monitoring_spec] if args.key?(:model_monitoring_spec)
  @name = args[:name] if args.key?(:name)
  @schedule = args[:schedule] if args.key?(:schedule)
  @schedule_time = args[:schedule_time] if args.key?(:schedule_time)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end