Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a model monitoring job that analyze dataset using different monitoring algorithm.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The display name of the ModelMonitoringJob.
-
#job_execution_detail ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetail
Represent the execution details of the job.
-
#model_monitoring_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSpec
Monitoring monitoring job spec.
-
#name ⇒ String
Output only.
-
#schedule ⇒ String
Output only.
-
#schedule_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringJob
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitoringJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringJob
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringJob.
29159 29160 29161 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this ModelMonitoringJob was created.
Corresponds to the JSON property createTime
29107 29108 29109 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29107 def create_time @create_time end |
#display_name ⇒ String
The display name of the ModelMonitoringJob. The name can be up to 128
characters long and can consist of any UTF-8.
Corresponds to the JSON property displayName
29113 29114 29115 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29113 def display_name @display_name end |
#job_execution_detail ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetail
Represent the execution details of the job.
Corresponds to the JSON property jobExecutionDetail
29118 29119 29120 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29118 def job_execution_detail @job_execution_detail end |
#model_monitoring_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSpec
Monitoring monitoring job spec. It outlines the specifications for monitoring
objectives, notifications, and result exports.
Corresponds to the JSON property modelMonitoringSpec
29124 29125 29126 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29124 def model_monitoring_spec @model_monitoring_spec end |
#name ⇒ String
Output only. Resource name of a ModelMonitoringJob. Format: projects/
project_id/locations/location_id/modelMonitors/model_monitor_id/
modelMonitoringJobs/model_monitoring_job_id`
Corresponds to the JSON propertyname`
29131 29132 29133 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29131 def name @name end |
#schedule ⇒ String
Output only. Schedule resource name. It will only appear when this job is
triggered by a schedule.
Corresponds to the JSON property schedule
29137 29138 29139 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29137 def schedule @schedule end |
#schedule_time ⇒ String
Output only. Timestamp when this ModelMonitoringJob was scheduled. It will
only appear when this job is triggered by a schedule.
Corresponds to the JSON property scheduleTime
29143 29144 29145 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29143 def schedule_time @schedule_time end |
#state ⇒ String
Output only. The state of the monitoring job. * When the job is still creating,
the state will be 'JOB_STATE_PENDING'. * Once the job is successfully created,
the state will be 'JOB_STATE_RUNNING'. * Once the job is finished, the state
will be one of 'JOB_STATE_FAILED', 'JOB_STATE_SUCCEEDED', '
JOB_STATE_PARTIALLY_SUCCEEDED'.
Corresponds to the JSON property state
29152 29153 29154 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29152 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this ModelMonitoringJob was updated most recently.
Corresponds to the JSON property updateTime
29157 29158 29159 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29157 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29164 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @job_execution_detail = args[:job_execution_detail] if args.key?(:job_execution_detail) @model_monitoring_spec = args[:model_monitoring_spec] if args.key?(:model_monitoring_spec) @name = args[:name] if args.key?(:name) @schedule = args[:schedule] if args.key?(:schedule) @schedule_time = args[:schedule_time] if args.key?(:schedule_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |