Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Processed dataset information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset.



36609
36610
36611
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

Actual data location of the processed dataset. Corresponds to the JSON property location

Returns:

  • (String)


36599
36600
36601
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36599

def location
  @location
end

#time_rangeGoogle::Apis::AiplatformV1beta1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property timeRange



36607
36608
36609
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36607

def time_range
  @time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36614
36615
36616
36617
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36614

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @time_range = args[:time_range] if args.key?(:time_range)
end