Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Processed dataset information.
Instance Attribute Summary collapse
-
#location ⇒ String
Actual data location of the processed dataset.
-
#time_range ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset.
34695 34696 34697 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34695 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location ⇒ String
Actual data location of the processed dataset.
Corresponds to the JSON property location
34685 34686 34687 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34685 def location @location end |
#time_range ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property timeRange
34693 34694 34695 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34693 def time_range @time_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34700 34701 34702 34703 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34700 def update!(**args) @location = args[:location] if args.key?(:location) @time_range = args[:time_range] if args.key?(:time_range) end |