Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Processed dataset information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringJobExecutionDetailProcessedDataset.



34108
34109
34110
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

Actual data location of the processed dataset. Corresponds to the JSON property location

Returns:

  • (String)


34098
34099
34100
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34098

def location
  @location
end

#time_rangeGoogle::Apis::AiplatformV1beta1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property timeRange



34106
34107
34108
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34106

def time_range
  @time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34113
34114
34115
34116
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34113

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @time_range = args[:time_range] if args.key?(:time_range)
end