Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Output from BatchPredictionJob for Model Monitoring baseline dataset, which can be used to generate baseline attribution scores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline.



29346
29347
29348
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigqueryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property bigquery



29334
29335
29336
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29334

def bigquery
  @bigquery
end

#gcsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcs



29339
29340
29341
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29339

def gcs
  @gcs
end

#prediction_formatString

The storage format of the predictions generated BatchPrediction job. Corresponds to the JSON property predictionFormat

Returns:

  • (String)


29344
29345
29346
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29344

def prediction_format
  @prediction_format
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29351
29352
29353
29354
29355
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29351

def update!(**args)
  @bigquery = args[:bigquery] if args.key?(:bigquery)
  @gcs = args[:gcs] if args.key?(:gcs)
  @prediction_format = args[:prediction_format] if args.key?(:prediction_format)
end