Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigTrainingDataset
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigTrainingDataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Training Dataset information.
Instance Attribute Summary collapse
-
#bigquery_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQuerySource
The BigQuery location for the input content.
-
#data_format ⇒ String
Data format of the dataset, only applicable if the input is from Google Cloud Storage.
-
#dataset ⇒ String
The resource name of the Dataset used to train this Model.
-
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource
The Google Cloud Storage location for the input content.
-
#logging_sampling_strategy ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SamplingStrategy
Sampling Strategy for logging, can be for both training and prediction dataset.
-
#target_field ⇒ String
The target field name the model is to predict.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigTrainingDataset
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigTrainingDataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigTrainingDataset
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigTrainingDataset.
34369 34370 34371 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQuerySource
The BigQuery location for the input content.
Corresponds to the JSON property bigquerySource
34338 34339 34340 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34338 def bigquery_source @bigquery_source end |
#data_format ⇒ String
Data format of the dataset, only applicable if the input is from Google Cloud
Storage. The possible formats are: "tf-record" The source file is a TFRecord
file. "csv" The source file is a CSV file. "jsonl" The source file is a JSONL
file.
Corresponds to the JSON property dataFormat
34346 34347 34348 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34346 def data_format @data_format end |
#dataset ⇒ String
The resource name of the Dataset used to train this Model.
Corresponds to the JSON property dataset
34351 34352 34353 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34351 def dataset @dataset end |
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
34356 34357 34358 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34356 def gcs_source @gcs_source end |
#logging_sampling_strategy ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SamplingStrategy
Sampling Strategy for logging, can be for both training and prediction dataset.
Corresponds to the JSON property loggingSamplingStrategy
34361 34362 34363 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34361 def logging_sampling_strategy @logging_sampling_strategy end |
#target_field ⇒ String
The target field name the model is to predict. This field will be excluded
when doing Predict and (or) Explain for the training data.
Corresponds to the JSON property targetField
34367 34368 34369 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34367 def target_field @target_field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34374 34375 34376 34377 34378 34379 34380 34381 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34374 def update!(**args) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @data_format = args[:data_format] if args.key?(:data_format) @dataset = args[:dataset] if args.key?(:dataset) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @logging_sampling_strategy = args[:logging_sampling_strategy] if args.key?(:logging_sampling_strategy) @target_field = args[:target_field] if args.key?(:target_field) end |