Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The config for Training & Prediction data skew detection. It specifies the training dataset sources and the skew detection parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig.



36385
36386
36387
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36385

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_score_skew_thresholdsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ThresholdConfig>

Key is the feature name and value is the threshold. The threshold here is against attribution score distance between the training and prediction feature. Corresponds to the JSON property attributionScoreSkewThresholds



36370
36371
36372
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36370

def attribution_score_skew_thresholds
  @attribution_score_skew_thresholds
end

#default_skew_thresholdGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ThresholdConfig

The config for feature monitoring threshold. Corresponds to the JSON property defaultSkewThreshold



36375
36376
36377
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36375

def default_skew_threshold
  @default_skew_threshold
end

#skew_thresholdsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ThresholdConfig>

Key is the feature name and value is the threshold. If a feature needs to be monitored for skew, a value threshold must be configured for that feature. The threshold here is against feature distribution distance between the training and prediction feature. Corresponds to the JSON property skewThresholds



36383
36384
36385
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36383

def skew_thresholds
  @skew_thresholds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36390
36391
36392
36393
36394
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36390

def update!(**args)
  @attribution_score_skew_thresholds = args[:attribution_score_skew_thresholds] if args.key?(:attribution_score_skew_thresholds)
  @default_skew_threshold = args[:default_skew_threshold] if args.key?(:default_skew_threshold)
  @skew_thresholds = args[:skew_thresholds] if args.key?(:skew_thresholds)
end