Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Data drift monitoring spec. Data drift measures the distribution distance between the current dataset and a baseline dataset. A typical use case is to detect data drift between the recent production serving dataset and the training dataset, or to compare the recent production dataset with a dataset from a previous period.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec.



38038
38039
38040
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categorical_metric_typeString

Supported metrics type: * l_infinity * jensen_shannon_divergence Corresponds to the JSON property categoricalMetricType

Returns:

  • (String)


38008
38009
38010
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38008

def categorical_metric_type
  @categorical_metric_type
end

#default_categorical_alert_conditionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition

Monitoring alert triggered condition. Corresponds to the JSON property defaultCategoricalAlertCondition



38013
38014
38015
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38013

def default_categorical_alert_condition
  @default_categorical_alert_condition
end

#default_numeric_alert_conditionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition

Monitoring alert triggered condition. Corresponds to the JSON property defaultNumericAlertCondition



38018
38019
38020
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38018

def default_numeric_alert_condition
  @default_numeric_alert_condition
end

#feature_alert_conditionsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>

Per feature alert condition will override default alert condition. Corresponds to the JSON property featureAlertConditions



38023
38024
38025
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38023

def feature_alert_conditions
  @feature_alert_conditions
end

#featuresArray<String>

Feature names / Prediction output names interested in monitoring. These should be a subset of the input feature names or prediction output names specified in the monitoring schema. If the field is not specified all features / prediction outputs outlied in the monitoring schema will be used. Corresponds to the JSON property features

Returns:

  • (Array<String>)


38031
38032
38033
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38031

def features
  @features
end

#numeric_metric_typeString

Supported metrics type: * jensen_shannon_divergence Corresponds to the JSON property numericMetricType

Returns:

  • (String)


38036
38037
38038
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38036

def numeric_metric_type
  @numeric_metric_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38043
38044
38045
38046
38047
38048
38049
38050
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38043

def update!(**args)
  @categorical_metric_type = args[:categorical_metric_type] if args.key?(:categorical_metric_type)
  @default_categorical_alert_condition = args[:default_categorical_alert_condition] if args.key?(:default_categorical_alert_condition)
  @default_numeric_alert_condition = args[:default_numeric_alert_condition] if args.key?(:default_numeric_alert_condition)
  @feature_alert_conditions = args[:feature_alert_conditions] if args.key?(:feature_alert_conditions)
  @features = args[:features] if args.key?(:features)
  @numeric_metric_type = args[:numeric_metric_type] if args.key?(:numeric_metric_type)
end