Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Data drift monitoring spec. Data drift measures the distribution distance between the current dataset and a baseline dataset. A typical use case is to detect data drift between the recent production serving dataset and the training dataset, or to compare the recent production dataset with a dataset from a previous period.
Instance Attribute Summary collapse
-
#categorical_metric_type ⇒ String
Supported metrics type: * l_infinity * jensen_shannon_divergence Corresponds to the JSON property
categoricalMetricType. -
#default_categorical_alert_condition ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
Monitoring alert triggered condition.
-
#default_numeric_alert_condition ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
Monitoring alert triggered condition.
-
#feature_alert_conditions ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>
Per feature alert condition will override default alert condition.
-
#features ⇒ Array<String>
Feature names / Prediction output names interested in monitoring.
-
#numeric_metric_type ⇒ String
Supported metrics type: * jensen_shannon_divergence Corresponds to the JSON property
numericMetricType.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec.
29560 29561 29562 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29560 def initialize(**args) update!(**args) end |
Instance Attribute Details
#categorical_metric_type ⇒ String
Supported metrics type: * l_infinity * jensen_shannon_divergence
Corresponds to the JSON property categoricalMetricType
29530 29531 29532 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29530 def categorical_metric_type @categorical_metric_type end |
#default_categorical_alert_condition ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
Monitoring alert triggered condition.
Corresponds to the JSON property defaultCategoricalAlertCondition
29535 29536 29537 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29535 def default_categorical_alert_condition @default_categorical_alert_condition end |
#default_numeric_alert_condition ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
Monitoring alert triggered condition.
Corresponds to the JSON property defaultNumericAlertCondition
29540 29541 29542 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29540 def default_numeric_alert_condition @default_numeric_alert_condition end |
#feature_alert_conditions ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>
Per feature alert condition will override default alert condition.
Corresponds to the JSON property featureAlertConditions
29545 29546 29547 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29545 def feature_alert_conditions @feature_alert_conditions end |
#features ⇒ Array<String>
Feature names / Prediction output names interested in monitoring. These should
be a subset of the input feature names or prediction output names specified in
the monitoring schema. If the field is not specified all features / prediction
outputs outlied in the monitoring schema will be used.
Corresponds to the JSON property features
29553 29554 29555 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29553 def features @features end |
#numeric_metric_type ⇒ String
Supported metrics type: * jensen_shannon_divergence
Corresponds to the JSON property numericMetricType
29558 29559 29560 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29558 def numeric_metric_type @numeric_metric_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29565 29566 29567 29568 29569 29570 29571 29572 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29565 def update!(**args) @categorical_metric_type = args[:categorical_metric_type] if args.key?(:categorical_metric_type) @default_categorical_alert_condition = args[:default_categorical_alert_condition] if args.key?(:default_categorical_alert_condition) @default_numeric_alert_condition = args[:default_numeric_alert_condition] if args.key?(:default_numeric_alert_condition) @feature_alert_conditions = args[:feature_alert_conditions] if args.key?(:feature_alert_conditions) @features = args[:features] if args.key?(:features) @numeric_metric_type = args[:numeric_metric_type] if args.key?(:numeric_metric_type) end |