Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecFeatureAttributionSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Feature attribution monitoring spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecFeatureAttributionSpec

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecFeatureAttributionSpec.



37041
37042
37043
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#batch_explanation_dedicated_resourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchDedicatedResources

A description of resources that are used for performing batch operations, are dedicated to a Model, and need manual configuration. Corresponds to the JSON property batchExplanationDedicatedResources



37022
37023
37024
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37022

def batch_explanation_dedicated_resources
  @batch_explanation_dedicated_resources
end

#default_alert_conditionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition

Monitoring alert triggered condition. Corresponds to the JSON property defaultAlertCondition



37027
37028
37029
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37027

def default_alert_condition
  @default_alert_condition
end

#feature_alert_conditionsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>

Per feature alert condition will override default alert condition. Corresponds to the JSON property featureAlertConditions



37032
37033
37034
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37032

def feature_alert_conditions
  @feature_alert_conditions
end

#featuresArray<String>

Feature names interested in monitoring. These should be a subset of the input feature names specified in the monitoring schema. If the field is not specified all features outlied in the monitoring schema will be used. Corresponds to the JSON property features

Returns:

  • (Array<String>)


37039
37040
37041
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37039

def features
  @features
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37046
37047
37048
37049
37050
37051
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37046

def update!(**args)
  @batch_explanation_dedicated_resources = args[:batch_explanation_dedicated_resources] if args.key?(:batch_explanation_dedicated_resources)
  @default_alert_condition = args[:default_alert_condition] if args.key?(:default_alert_condition)
  @feature_alert_conditions = args[:feature_alert_conditions] if args.key?(:feature_alert_conditions)
  @features = args[:features] if args.key?(:features)
end