Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecFeatureAttributionSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecFeatureAttributionSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Feature attribution monitoring spec.
Instance Attribute Summary collapse
-
#batch_explanation_dedicated_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchDedicatedResources
A description of resources that are used for performing batch operations, are dedicated to a Model, and need manual configuration.
-
#default_alert_condition ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
Monitoring alert triggered condition.
-
#feature_alert_conditions ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>
Per feature alert condition will override default alert condition.
-
#features ⇒ Array<String>
Feature names interested in monitoring.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecFeatureAttributionSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecFeatureAttributionSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecFeatureAttributionSpec
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecFeatureAttributionSpec.
29668 29669 29670 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#batch_explanation_dedicated_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BatchDedicatedResources
A description of resources that are used for performing batch operations, are
dedicated to a Model, and need manual configuration.
Corresponds to the JSON property batchExplanationDedicatedResources
29649 29650 29651 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29649 def batch_explanation_dedicated_resources @batch_explanation_dedicated_resources end |
#default_alert_condition ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition
Monitoring alert triggered condition.
Corresponds to the JSON property defaultAlertCondition
29654 29655 29656 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29654 def default_alert_condition @default_alert_condition end |
#feature_alert_conditions ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlertCondition>
Per feature alert condition will override default alert condition.
Corresponds to the JSON property featureAlertConditions
29659 29660 29661 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29659 def feature_alert_conditions @feature_alert_conditions end |
#features ⇒ Array<String>
Feature names interested in monitoring. These should be a subset of the input
feature names specified in the monitoring schema. If the field is not
specified all features outlied in the monitoring schema will be used.
Corresponds to the JSON property features
29666 29667 29668 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29666 def features @features end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29673 29674 29675 29676 29677 29678 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29673 def update!(**args) @batch_explanation_dedicated_resources = args[:batch_explanation_dedicated_resources] if args.key?(:batch_explanation_dedicated_resources) @default_alert_condition = args[:default_alert_condition] if args.key?(:default_alert_condition) @feature_alert_conditions = args[:feature_alert_conditions] if args.key?(:feature_alert_conditions) @features = args[:features] if args.key?(:features) end |