Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecTabularObjective

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Tabular monitoring objective.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecTabularObjective

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecTabularObjective.



29708
29709
29710
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29708

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feature_attribution_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecFeatureAttributionSpec

Feature attribution monitoring spec. Corresponds to the JSON property featureAttributionSpec



29688
29689
29690
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29688

def feature_attribution_spec
  @feature_attribution_spec
end

#feature_drift_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec

Data drift monitoring spec. Data drift measures the distribution distance between the current dataset and a baseline dataset. A typical use case is to detect data drift between the recent production serving dataset and the training dataset, or to compare the recent production dataset with a dataset from a previous period. Corresponds to the JSON property featureDriftSpec



29697
29698
29699
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29697

def feature_drift_spec
  @feature_drift_spec
end

#prediction_output_drift_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpecDataDriftSpec

Data drift monitoring spec. Data drift measures the distribution distance between the current dataset and a baseline dataset. A typical use case is to detect data drift between the recent production serving dataset and the training dataset, or to compare the recent production dataset with a dataset from a previous period. Corresponds to the JSON property predictionOutputDriftSpec



29706
29707
29708
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29706

def prediction_output_drift_spec
  @prediction_output_drift_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29713
29714
29715
29716
29717
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29713

def update!(**args)
  @feature_attribution_spec = args[:feature_attribution_spec] if args.key?(:feature_attribution_spec)
  @feature_drift_spec = args[:feature_drift_spec] if args.key?(:feature_drift_spec)
  @prediction_output_drift_spec = args[:prediction_output_drift_spec] if args.key?(:prediction_output_drift_spec)
end