Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchema
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The Model Monitoring Schema definition.
Instance Attribute Summary collapse
-
#feature_fields ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema>
Feature names of the model.
-
#ground_truth_fields ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema>
Target /ground truth names of the model.
-
#prediction_fields ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema>
Prediction output names of the model.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringSchema
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitoringSchema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringSchema
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringSchema.
29780 29781 29782 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29780 def initialize(**args) update!(**args) end |
Instance Attribute Details
#feature_fields ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema>
Feature names of the model. Vertex AI will try to match the features from your
dataset as follows: * For 'csv' files, the header names are required, and we
will extract the corresponding feature values when the header names align with
the feature names. * For 'jsonl' files, we will extract the corresponding
feature values if the key names match the feature names. Note: Nested features
are not supported, so please ensure your features are flattened. Ensure the
feature values are scalar or an array of scalars. * For 'bigquery' dataset, we
will extract the corresponding feature values if the column names match the
feature names. Note: The column type can be a scalar or an array of scalars.
STRUCT or JSON types are not supported. You may use SQL queries to select or
aggregate the relevant features from your original table. However, ensure that
the 'schema' of the query results meets our requirements. * For the Vertex AI
Endpoint Request Response Logging table or Vertex AI Batch Prediction Job
results. If the instance_type is an array, ensure that the sequence in
feature_fields matches the order of features in the prediction instance. We
will match the feature with the array in the order specified in [
feature_fields].
Corresponds to the JSON property featureFields
29763 29764 29765 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29763 def feature_fields @feature_fields end |
#ground_truth_fields ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema>
Target /ground truth names of the model.
Corresponds to the JSON property groundTruthFields
29768 29769 29770 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29768 def ground_truth_fields @ground_truth_fields end |
#prediction_fields ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema>
Prediction output names of the model. The requirements are the same as the
feature_fields. For AutoML Tables, the prediction output name presented in
schema will be: predicted_target_column`, thetarget_column` is the one
you specified when you train the model. For Prediction output drift analysis: *
AutoML Classification, the distribution of the argmax label will be analyzed.
- AutoML Regression, the distribution of the value will be analyzed.
Corresponds to the JSON property
predictionFields
29778 29779 29780 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29778 def prediction_fields @prediction_fields end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29785 29786 29787 29788 29789 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29785 def update!(**args) @feature_fields = args[:feature_fields] if args.key?(:feature_fields) @ground_truth_fields = args[:ground_truth_fields] if args.key?(:ground_truth_fields) @prediction_fields = args[:prediction_fields] if args.key?(:prediction_fields) end |