Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Schema field definition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema.



34684
34685
34686
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34684

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_typeString

Supported data types are: float integer boolean string categorical Corresponds to the JSON property dataType

Returns:

  • (String)


34671
34672
34673
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34671

def data_type
  @data_type
end

#nameString

Field name. Corresponds to the JSON property name

Returns:

  • (String)


34676
34677
34678
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34676

def name
  @name
end

#repeatedBoolean Also known as: repeated?

Describes if the schema field is an array of given data type. Corresponds to the JSON property repeated

Returns:

  • (Boolean)


34681
34682
34683
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34681

def repeated
  @repeated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34689
34690
34691
34692
34693
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34689

def update!(**args)
  @data_type = args[:data_type] if args.key?(:data_type)
  @name = args[:name] if args.key?(:name)
  @repeated = args[:repeated] if args.key?(:repeated)
end