Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Schema field definition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringSchemaFieldSchema.



29746
29747
29748
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_typeString

Supported data types are: float integer boolean string categorical Corresponds to the JSON property dataType

Returns:

  • (String)


29733
29734
29735
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29733

def data_type
  @data_type
end

#nameString

Field name. Corresponds to the JSON property name

Returns:

  • (String)


29738
29739
29740
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29738

def name
  @name
end

#repeatedBoolean Also known as: repeated?

Describes if the schema field is an array of given data type. Corresponds to the JSON property repeated

Returns:

  • (Boolean)


29743
29744
29745
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29743

def repeated
  @repeated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29751
29752
29753
29754
29755
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 29751

def update!(**args)
  @data_type = args[:data_type] if args.key?(:data_type)
  @name = args[:name] if args.key?(:name)
  @repeated = args[:repeated] if args.key?(:repeated)
end