Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Monitoring monitoring job spec. It outlines the specifications for monitoring objectives, notifications, and result exports.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringSpec

Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringSpec.



37219
37220
37221
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37219

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#notification_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringNotificationSpec

Notification spec(email, notification channel) for model monitoring statistics/ alerts. Corresponds to the JSON property notificationSpec



37206
37207
37208
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37206

def notification_spec
  @notification_spec
end

#objective_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringObjectiveSpec

Monitoring objectives spec. Corresponds to the JSON property objectiveSpec



37211
37212
37213
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37211

def objective_spec
  @objective_spec
end

#output_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringOutputSpec

Specification for the export destination of monitoring results, including metrics, logs, etc. Corresponds to the JSON property outputSpec



37217
37218
37219
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37217

def output_spec
  @output_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37224
37225
37226
37227
37228
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37224

def update!(**args)
  @notification_spec = args[:notification_spec] if args.key?(:notification_spec)
  @objective_spec = args[:objective_spec] if args.key?(:objective_spec)
  @output_spec = args[:output_spec] if args.key?(:output_spec)
end