Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Historical Stats (and Anomalies) for a specific Feature.
Instance Attribute Summary collapse
-
#feature_display_name ⇒ String
Display Name of the Feature.
-
#prediction_stats ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAnomaly>
A list of historical stats generated by different time window's Prediction Dataset.
-
#threshold ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ThresholdConfig
The config for feature monitoring threshold.
-
#training_stats ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAnomaly
Stats and Anomaly generated at specific timestamp for specific Feature.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies
Returns a new instance of GoogleCloudAiplatformV1beta1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies.
36618 36619 36620 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36618 def initialize(**args) update!(**args) end |
Instance Attribute Details
#feature_display_name ⇒ String
Display Name of the Feature.
Corresponds to the JSON property featureDisplayName
36593 36594 36595 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36593 def feature_display_name @feature_display_name end |
#prediction_stats ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAnomaly>
A list of historical stats generated by different time window's Prediction
Dataset.
Corresponds to the JSON property predictionStats
36599 36600 36601 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36599 def prediction_stats @prediction_stats end |
#threshold ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ThresholdConfig
The config for feature monitoring threshold.
Corresponds to the JSON property threshold
36604 36605 36606 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36604 def threshold @threshold end |
#training_stats ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureStatsAnomaly
Stats and Anomaly generated at specific timestamp for specific Feature. The
start_time and end_time are used to define the time range of the dataset that
current stats belongs to, e.g. prediction traffic is bucketed into prediction
datasets by time window. If the Dataset is not defined by time window,
start_time = end_time. Timestamp of the stats and anomalies always refers to
end_time. Raw stats and anomalies are stored in stats_uri or anomaly_uri in
the tensorflow defined protos. Field data_stats contains almost identical
information with the raw stats in Vertex AI defined proto, for UI to display.
Corresponds to the JSON property trainingStats
36616 36617 36618 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36616 def training_stats @training_stats end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36623 36624 36625 36626 36627 36628 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36623 def update!(**args) @feature_display_name = args[:feature_display_name] if args.key?(:feature_display_name) @prediction_stats = args[:prediction_stats] if args.key?(:prediction_stats) @threshold = args[:threshold] if args.key?(:threshold) @training_stats = args[:training_stats] if args.key?(:training_stats) end |