Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MonitoredAgent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MonitoredAgent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A monitored agent in a specific Location.
Instance Attribute Summary collapse
-
#agent_resource ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentResource
Defines the identity of an agent being monitored.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#log_buckets ⇒ Array<String>
Optional.
-
#name ⇒ String
Identifier.
-
#observability_buckets ⇒ Array<String>
Optional.
-
#state ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MonitoredAgent
constructor
A new instance of GoogleCloudAiplatformV1beta1MonitoredAgent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MonitoredAgent
Returns a new instance of GoogleCloudAiplatformV1beta1MonitoredAgent.
36915 36916 36917 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36915 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_resource ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentResource
Defines the identity of an agent being monitored.
Corresponds to the JSON property agentResource
36869 36870 36871 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36869 def agent_resource @agent_resource end |
#create_time ⇒ String
Output only. The time the MonitoredAgent was created.
Corresponds to the JSON property createTime
36874 36875 36876 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36874 def create_time @create_time end |
#display_name ⇒ String
Optional. The display name of the MonitoredAgent.
Corresponds to the JSON property displayName
36879 36880 36881 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36879 def display_name @display_name end |
#log_buckets ⇒ Array<String>
Optional. The log buckets configured for the agent, in MVP this will be
restricted to 1. Format: projects/project/locations/location/buckets/
bucket`
Corresponds to the JSON propertylogBuckets`
36886 36887 36888 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36886 def log_buckets @log_buckets end |
#name ⇒ String
Identifier. The resource name of the MonitoredAgent.
Corresponds to the JSON property name
36891 36892 36893 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36891 def name @name end |
#observability_buckets ⇒ Array<String>
Optional. The observability buckets configured for the agent, in MVP this will
be restricted to 1. Format: projects/project/locations/location/
observationBuckets/observation_bucket`
Corresponds to the JSON propertyobservabilityBuckets`
36898 36899 36900 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36898 def observability_buckets @observability_buckets end |
#state ⇒ String
Output only. The current state of the agent's enablement.
Corresponds to the JSON property state
36903 36904 36905 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36903 def state @state end |
#status_message ⇒ String
Output only. A brief message explaining the current state.
Corresponds to the JSON property statusMessage
36908 36909 36910 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36908 def @status_message end |
#update_time ⇒ String
Output only. The time the MonitoredAgent was last updated.
Corresponds to the JSON property updateTime
36913 36914 36915 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36913 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36920 36921 36922 36923 36924 36925 36926 36927 36928 36929 36930 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36920 def update!(**args) @agent_resource = args[:agent_resource] if args.key?(:agent_resource) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @log_buckets = args[:log_buckets] if args.key?(:log_buckets) @name = args[:name] if args.key?(:name) @observability_buckets = args[:observability_buckets] if args.key?(:observability_buckets) @state = args[:state] if args.key?(:state) @status_message = args[:status_message] if args.key?(:status_message) @update_time = args[:update_time] if args.key?(:update_time) end |