Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MonitoredAgent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A monitored agent in a specific Location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1MonitoredAgent

Returns a new instance of GoogleCloudAiplatformV1beta1MonitoredAgent.



37093
37094
37095
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_resourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AgentResource

Defines the identity of an agent being monitored. Corresponds to the JSON property agentResource



37047
37048
37049
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37047

def agent_resource
  @agent_resource
end

#create_timeString

Output only. The time the MonitoredAgent was created. Corresponds to the JSON property createTime

Returns:

  • (String)


37052
37053
37054
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37052

def create_time
  @create_time
end

#display_nameString

Optional. The display name of the MonitoredAgent. Corresponds to the JSON property displayName

Returns:

  • (String)


37057
37058
37059
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37057

def display_name
  @display_name
end

#log_bucketsArray<String>

Optional. The log buckets configured for the agent, in MVP this will be restricted to 1. Format: projects/project/locations/location/buckets/ bucket` Corresponds to the JSON propertylogBuckets`

Returns:

  • (Array<String>)


37064
37065
37066
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37064

def log_buckets
  @log_buckets
end

#nameString

Identifier. The resource name of the MonitoredAgent. Corresponds to the JSON property name

Returns:

  • (String)


37069
37070
37071
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37069

def name
  @name
end

#observability_bucketsArray<String>

Optional. The observability buckets configured for the agent, in MVP this will be restricted to 1. Format: projects/project/locations/location/ observationBuckets/observation_bucket` Corresponds to the JSON propertyobservabilityBuckets`

Returns:

  • (Array<String>)


37076
37077
37078
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37076

def observability_buckets
  @observability_buckets
end

#stateString

Output only. The current state of the agent's enablement. Corresponds to the JSON property state

Returns:

  • (String)


37081
37082
37083
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37081

def state
  @state
end

#status_messageString

Output only. A brief message explaining the current state. Corresponds to the JSON property statusMessage

Returns:

  • (String)


37086
37087
37088
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37086

def status_message
  @status_message
end

#update_timeString

Output only. The time the MonitoredAgent was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


37091
37092
37093
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37091

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37098
37099
37100
37101
37102
37103
37104
37105
37106
37107
37108
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37098

def update!(**args)
  @agent_resource = args[:agent_resource] if args.key?(:agent_resource)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @log_buckets = args[:log_buckets] if args.key?(:log_buckets)
  @name = args[:name] if args.key?(:name)
  @observability_buckets = args[:observability_buckets] if args.key?(:observability_buckets)
  @state = args[:state] if args.key?(:state)
  @status_message = args[:status_message] if args.key?(:status_message)
  @update_time = args[:update_time] if args.key?(:update_time)
end