Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NasJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NasJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a Neural Architecture Search (NAS) job.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#enable_restricted_image_training ⇒ Boolean
(also: #enable_restricted_image_training?)
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize NasJobs.
-
#name ⇒ String
Output only.
-
#nas_job_output ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NasJobOutput
Represents a uCAIP NasJob output.
-
#nas_job_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NasJobSpec
Represents the spec of a NasJob.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NasJob
constructor
A new instance of GoogleCloudAiplatformV1beta1NasJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NasJob
Returns a new instance of GoogleCloudAiplatformV1beta1NasJob.
30415 30416 30417 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the NasJob was created.
Corresponds to the JSON property createTime
30326 30327 30328 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30326 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the NasJob. The name can be up to 128 characters
long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
30332 30333 30334 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30332 def display_name @display_name end |
#enable_restricted_image_training ⇒ Boolean Also known as: enable_restricted_image_training?
Optional. Enable a separation of Custom model training and restricted image
training for tenant project.
Corresponds to the JSON property enableRestrictedImageTraining
30338 30339 30340 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30338 def enable_restricted_image_training @enable_restricted_image_training end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
30345 30346 30347 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30345 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the NasJob entered any of the following states:
JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED.
Corresponds to the JSON property endTime
30351 30352 30353 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30351 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
30361 30362 30363 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30361 def error @error end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize NasJobs. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
30370 30371 30372 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30370 def labels @labels end |
#name ⇒ String
Output only. Resource name of the NasJob.
Corresponds to the JSON property name
30375 30376 30377 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30375 def name @name end |
#nas_job_output ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NasJobOutput
Represents a uCAIP NasJob output.
Corresponds to the JSON property nasJobOutput
30380 30381 30382 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30380 def nas_job_output @nas_job_output end |
#nas_job_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NasJobSpec
Represents the spec of a NasJob.
Corresponds to the JSON property nasJobSpec
30385 30386 30387 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30385 def nas_job_spec @nas_job_spec end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
30390 30391 30392 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30390 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
30396 30397 30398 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30396 def satisfies_pzs @satisfies_pzs end |
#start_time ⇒ String
Output only. Time when the NasJob for the first time entered the
JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
30403 30404 30405 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30403 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
30408 30409 30410 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30408 def state @state end |
#update_time ⇒ String
Output only. Time when the NasJob was most recently updated.
Corresponds to the JSON property updateTime
30413 30414 30415 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30413 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30420 30421 30422 30423 30424 30425 30426 30427 30428 30429 30430 30431 30432 30433 30434 30435 30436 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 30420 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @enable_restricted_image_training = args[:enable_restricted_image_training] if args.key?(:enable_restricted_image_training) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @nas_job_output = args[:nas_job_output] if args.key?(:nas_job_output) @nas_job_spec = args[:nas_job_spec] if args.key?(:nas_job_spec) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |