Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represent spec for search trials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec

Returns a new instance of GoogleCloudAiplatformV1beta1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.



39072
39073
39074
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39072

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_failed_trial_countFixnum

The number of failed trials that need to be seen before failing the NasJob. If set to 0, Vertex AI decides how many trials must fail before the whole job fails. Corresponds to the JSON property maxFailedTrialCount

Returns:

  • (Fixnum)


39055
39056
39057
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39055

def max_failed_trial_count
  @max_failed_trial_count
end

#max_parallel_trial_countFixnum

Required. The maximum number of trials to run in parallel. Corresponds to the JSON property maxParallelTrialCount

Returns:

  • (Fixnum)


39060
39061
39062
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39060

def max_parallel_trial_count
  @max_parallel_trial_count
end

#max_trial_countFixnum

Required. The maximum number of Neural Architecture Search (NAS) trials to run. Corresponds to the JSON property maxTrialCount

Returns:

  • (Fixnum)


39065
39066
39067
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39065

def max_trial_count
  @max_trial_count
end

#search_trial_job_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property searchTrialJobSpec



39070
39071
39072
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39070

def search_trial_job_spec
  @search_trial_job_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39077
39078
39079
39080
39081
39082
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39077

def update!(**args)
  @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count)
  @max_parallel_trial_count = args[:max_parallel_trial_count] if args.key?(:max_parallel_trial_count)
  @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count)
  @search_trial_job_spec = args[:search_trial_job_spec] if args.key?(:search_trial_job_spec)
end