Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represent spec for search trials.
Instance Attribute Summary collapse
-
#max_failed_trial_count ⇒ Fixnum
The number of failed trials that need to be seen before failing the NasJob.
-
#max_parallel_trial_count ⇒ Fixnum
Required.
-
#max_trial_count ⇒ Fixnum
Required.
-
#search_trial_job_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomJobSpec
Represents the spec of a CustomJob.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
Returns a new instance of GoogleCloudAiplatformV1beta1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.
37525 37526 37527 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37525 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_failed_trial_count ⇒ Fixnum
The number of failed trials that need to be seen before failing the NasJob. If
set to 0, Vertex AI decides how many trials must fail before the whole job
fails.
Corresponds to the JSON property maxFailedTrialCount
37508 37509 37510 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37508 def max_failed_trial_count @max_failed_trial_count end |
#max_parallel_trial_count ⇒ Fixnum
Required. The maximum number of trials to run in parallel.
Corresponds to the JSON property maxParallelTrialCount
37513 37514 37515 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37513 def max_parallel_trial_count @max_parallel_trial_count end |
#max_trial_count ⇒ Fixnum
Required. The maximum number of Neural Architecture Search (NAS) trials to run.
Corresponds to the JSON property maxTrialCount
37518 37519 37520 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37518 def max_trial_count @max_trial_count end |
#search_trial_job_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomJobSpec
Represents the spec of a CustomJob.
Corresponds to the JSON property searchTrialJobSpec
37523 37524 37525 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37523 def search_trial_job_spec @search_trial_job_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37530 37531 37532 37533 37534 37535 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37530 def update!(**args) @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count) @max_parallel_trial_count = args[:max_parallel_trial_count] if args.key?(:max_parallel_trial_count) @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count) @search_trial_job_spec = args[:search_trial_job_spec] if args.key?(:search_trial_job_spec) end |