Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborQueryParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Parameters that can be overrided in each query to tune query latency and recall.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NearestNeighborQueryParameters

Returns a new instance of GoogleCloudAiplatformV1beta1NearestNeighborQueryParameters.



37624
37625
37626
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37624

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approximate_neighbor_candidatesFixnum

Optional. The number of neighbors to find via approximate search before exact reordering is performed; if set, this value must be > neighbor_count. Corresponds to the JSON property approximateNeighborCandidates

Returns:

  • (Fixnum)


37615
37616
37617
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37615

def approximate_neighbor_candidates
  @approximate_neighbor_candidates
end

#leaf_nodes_search_fractionFloat

Optional. The fraction of the number of leaves to search, set at query time allows user to tune search performance. This value increase result in both search accuracy and latency increase. The value should be between 0.0 and 1.0. Corresponds to the JSON property leafNodesSearchFraction

Returns:

  • (Float)


37622
37623
37624
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37622

def leaf_nodes_search_fraction
  @leaf_nodes_search_fraction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37629
37630
37631
37632
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37629

def update!(**args)
  @approximate_neighbor_candidates = args[:approximate_neighbor_candidates] if args.key?(:approximate_neighbor_candidates)
  @leaf_nodes_search_fraction = args[:leaf_nodes_search_fraction] if args.key?(:leaf_nodes_search_fraction)
end