Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborQueryParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Parameters that can be overrided in each query to tune query latency and recall.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NearestNeighborQueryParameters

Returns a new instance of GoogleCloudAiplatformV1beta1NearestNeighborQueryParameters.



35754
35755
35756
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approximate_neighbor_candidatesFixnum

Optional. The number of neighbors to find via approximate search before exact reordering is performed; if set, this value must be > neighbor_count. Corresponds to the JSON property approximateNeighborCandidates

Returns:

  • (Fixnum)


35745
35746
35747
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35745

def approximate_neighbor_candidates
  @approximate_neighbor_candidates
end

#leaf_nodes_search_fractionFloat

Optional. The fraction of the number of leaves to search, set at query time allows user to tune search performance. This value increase result in both search accuracy and latency increase. The value should be between 0.0 and 1.0. Corresponds to the JSON property leafNodesSearchFraction

Returns:

  • (Float)


35752
35753
35754
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35752

def leaf_nodes_search_fraction
  @leaf_nodes_search_fraction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35759
35760
35761
35762
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35759

def update!(**args)
  @approximate_neighbor_candidates = args[:approximate_neighbor_candidates] if args.key?(:approximate_neighbor_candidates)
  @leaf_nodes_search_fraction = args[:leaf_nodes_search_fraction] if args.key?(:leaf_nodes_search_fraction)
end