Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookReservationAffinity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Notebook Reservation Affinity for consuming Zonal reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NotebookReservationAffinity

Returns a new instance of GoogleCloudAiplatformV1beta1NotebookReservationAffinity.



38295
38296
38297
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consume_reservation_typeString

Required. Specifies the type of reservation from which this instance can consume resources: RESERVATION_ANY (default), RESERVATION_SPECIFIC, or RESERVATION_NONE. See Consuming reserved instances for examples. Corresponds to the JSON property consumeReservationType

Returns:

  • (String)


38280
38281
38282
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38280

def consume_reservation_type
  @consume_reservation_type
end

#keyString

Optional. Corresponds to the label key of a reservation resource. To target a RESERVATION_SPECIFIC by name, use compute.googleapis.com/reservation-name as the key and specify the name of your reservation as its value. Corresponds to the JSON property key

Returns:

  • (String)


38287
38288
38289
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38287

def key
  @key
end

#valuesArray<String>

Optional. Corresponds to the label values of a reservation resource. This must be the full path name of Reservation. Corresponds to the JSON property values

Returns:

  • (Array<String>)


38293
38294
38295
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38293

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38300
38301
38302
38303
38304
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38300

def update!(**args)
  @consume_reservation_type = args[:consume_reservation_type] if args.key?(:consume_reservation_type)
  @key = args[:key] if args.key?(:key)
  @values = args[:values] if args.key?(:values)
end