Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookReservationAffinity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Notebook Reservation Affinity for consuming Zonal reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NotebookReservationAffinity

Returns a new instance of GoogleCloudAiplatformV1beta1NotebookReservationAffinity.



38473
38474
38475
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consume_reservation_typeString

Required. Specifies the type of reservation from which this instance can consume resources: RESERVATION_ANY (default), RESERVATION_SPECIFIC, or RESERVATION_NONE. See Consuming reserved instances for examples. Corresponds to the JSON property consumeReservationType

Returns:

  • (String)


38458
38459
38460
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38458

def consume_reservation_type
  @consume_reservation_type
end

#keyString

Optional. Corresponds to the label key of a reservation resource. To target a RESERVATION_SPECIFIC by name, use compute.googleapis.com/reservation-name as the key and specify the name of your reservation as its value. Corresponds to the JSON property key

Returns:

  • (String)


38465
38466
38467
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38465

def key
  @key
end

#valuesArray<String>

Optional. Corresponds to the label values of a reservation resource. This must be the full path name of Reservation. Corresponds to the JSON property values

Returns:

  • (Array<String>)


38471
38472
38473
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38471

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38478
38479
38480
38481
38482
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38478

def update!(**args)
  @consume_reservation_type = args[:consume_reservation_type] if args.key?(:consume_reservation_type)
  @key = args[:key] if args.key?(:key)
  @values = args[:values] if args.key?(:values)
end