Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookRuntime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A runtime is a virtual machine allocated to a particular user for a particular Notebook file on temporary basis with lifetime. Default runtimes have a lifetime of 18 hours, while custom runtimes last for 6 months from their creation or last upgrade.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NotebookRuntime

Returns a new instance of GoogleCloudAiplatformV1beta1NotebookRuntime.



40329
40330
40331
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40329

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this NotebookRuntime was created. Corresponds to the JSON property createTime

Returns:

  • (String)


40161
40162
40163
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40161

def create_time
  @create_time
end

#data_persistent_disk_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PersistentDiskSpec

Represents the spec of persistent disk and hyperdisk options. Corresponds to the JSON property dataPersistentDiskSpec



40166
40167
40168
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40166

def data_persistent_disk_spec
  @data_persistent_disk_spec
end

#descriptionString

The description of the NotebookRuntime. Corresponds to the JSON property description

Returns:

  • (String)


40171
40172
40173
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40171

def description
  @description
end

#display_nameString

Required. The display name of the NotebookRuntime. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


40177
40178
40179
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40177

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



40183
40184
40185
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40183

def encryption_spec
  @encryption_spec
end

#euc_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookEucConfig

The euc configuration of NotebookRuntimeTemplate. Corresponds to the JSON property eucConfig



40188
40189
40190
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40188

def euc_config
  @euc_config
end

#expiration_timeString

Output only. Timestamp when this NotebookRuntime will be expired: 1. System Predefined NotebookRuntime: 24 hours after creation. After expiration, system predifined runtime will be deleted. 2. User created NotebookRuntime: 6 months after last upgrade. After expiration, user created runtime will be stopped and allowed for upgrade. Corresponds to the JSON property expirationTime

Returns:

  • (String)


40197
40198
40199
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40197

def expiration_time
  @expiration_time
end

#health_stateString

Output only. The health state of the NotebookRuntime. Corresponds to the JSON property healthState

Returns:

  • (String)


40202
40203
40204
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40202

def health_state
  @health_state
end

#idle_shutdown_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookIdleShutdownConfig

The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field. Corresponds to the JSON property idleShutdownConfig



40208
40209
40210
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40208

def idle_shutdown_config
  @idle_shutdown_config
end

#is_upgradableBoolean Also known as: is_upgradable?

Output only. Whether NotebookRuntime is upgradable. Corresponds to the JSON property isUpgradable

Returns:

  • (Boolean)


40213
40214
40215
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40213

def is_upgradable
  @is_upgradable
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your NotebookRuntime. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one NotebookRuntime (System labels are excluded). See https:// goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for NotebookRuntime: * "aiplatform.googleapis. com/notebook_runtime_gce_instance_id": output only, its value is the Compute Engine instance id. * "aiplatform.googleapis.com/ colab_enterprise_entry_service": its value is either "bigquery" or "vertex"; if absent, it should be "vertex". This is to describe the entry service, either BigQuery or Vertex. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


40231
40232
40233
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40231

def labels
  @labels
end

#machine_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



40236
40237
40238
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40236

def machine_spec
  @machine_spec
end

#nameString

Output only. The resource name of the NotebookRuntime. Corresponds to the JSON property name

Returns:

  • (String)


40241
40242
40243
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40241

def name
  @name
end

#network_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NetworkSpec

Network spec. Corresponds to the JSON property networkSpec



40246
40247
40248
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40246

def network_spec
  @network_spec
end

#network_tagsArray<String>

Optional. The Compute Engine tags to add to runtime (see Tagging instances). Corresponds to the JSON property networkTags

Returns:

  • (Array<String>)


40252
40253
40254
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40252

def network_tags
  @network_tags
end

#notebook_runtime_template_refGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookRuntimeTemplateRef

Points to a NotebookRuntimeTemplateRef. Corresponds to the JSON property notebookRuntimeTemplateRef



40257
40258
40259
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40257

def notebook_runtime_template_ref
  @notebook_runtime_template_ref
end

#notebook_runtime_typeString

Output only. The type of the notebook runtime. Corresponds to the JSON property notebookRuntimeType

Returns:

  • (String)


40262
40263
40264
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40262

def notebook_runtime_type
  @notebook_runtime_type
end

#proxy_uriString

Output only. The proxy endpoint used to access the NotebookRuntime. Corresponds to the JSON property proxyUri

Returns:

  • (String)


40267
40268
40269
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40267

def proxy_uri
  @proxy_uri
end

#reservation_affinityGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookReservationAffinity

Notebook Reservation Affinity for consuming Zonal reservation. Corresponds to the JSON property reservationAffinity



40272
40273
40274
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40272

def reservation_affinity
  @reservation_affinity
end

#runtime_stateString

Output only. The runtime (instance) state of the NotebookRuntime. Corresponds to the JSON property runtimeState

Returns:

  • (String)


40277
40278
40279
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40277

def runtime_state
  @runtime_state
end

#runtime_userString

Required. The user email of the NotebookRuntime. Corresponds to the JSON property runtimeUser

Returns:

  • (String)


40282
40283
40284
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40282

def runtime_user
  @runtime_user
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


40287
40288
40289
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40287

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


40293
40294
40295
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40293

def satisfies_pzs
  @satisfies_pzs
end

#service_accountString

Output only. Deprecated: This field is no longer used and the "Vertex AI Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam. gserviceaccount.com) is used for the runtime workload identity. See https:// cloud.google.com/iam/docs/service-agents#vertex-ai-notebook-service-account for more details. The service account that the NotebookRuntime workload runs as. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


40304
40305
40306
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40304

def 
  @service_account
end

#shielded_vm_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ShieldedVmConfig

A set of Shielded Instance options. See Images using supported Shielded VM features. Corresponds to the JSON property shieldedVmConfig



40311
40312
40313
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40311

def shielded_vm_config
  @shielded_vm_config
end

#software_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookSoftwareConfig

Notebook Software Config. This is passed to the backend when user makes software configurations in UI. Corresponds to the JSON property softwareConfig



40317
40318
40319
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40317

def software_config
  @software_config
end

#update_timeString

Output only. Timestamp when this NotebookRuntime was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


40322
40323
40324
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40322

def update_time
  @update_time
end

#versionString

Output only. The VM os image version of NotebookRuntime. Corresponds to the JSON property version

Returns:

  • (String)


40327
40328
40329
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40327

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40334
40335
40336
40337
40338
40339
40340
40341
40342
40343
40344
40345
40346
40347
40348
40349
40350
40351
40352
40353
40354
40355
40356
40357
40358
40359
40360
40361
40362
40363
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40334

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_persistent_disk_spec = args[:data_persistent_disk_spec] if args.key?(:data_persistent_disk_spec)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @euc_config = args[:euc_config] if args.key?(:euc_config)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @health_state = args[:health_state] if args.key?(:health_state)
  @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config)
  @is_upgradable = args[:is_upgradable] if args.key?(:is_upgradable)
  @labels = args[:labels] if args.key?(:labels)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @name = args[:name] if args.key?(:name)
  @network_spec = args[:network_spec] if args.key?(:network_spec)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @notebook_runtime_template_ref = args[:notebook_runtime_template_ref] if args.key?(:notebook_runtime_template_ref)
  @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type)
  @proxy_uri = args[:proxy_uri] if args.key?(:proxy_uri)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @runtime_state = args[:runtime_state] if args.key?(:runtime_state)
  @runtime_user = args[:runtime_user] if args.key?(:runtime_user)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @service_account = args[:service_account] if args.key?(:service_account)
  @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config)
  @software_config = args[:software_config] if args.key?(:software_config)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version = args[:version] if args.key?(:version)
end