Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookRuntime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A runtime is a virtual machine allocated to a particular user for a particular Notebook file on temporary basis with lifetime. Default runtimes have a lifetime of 18 hours, while custom runtimes last for 6 months from their creation or last upgrade.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NotebookRuntime

Returns a new instance of GoogleCloudAiplatformV1beta1NotebookRuntime.



39171
39172
39173
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39171

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this NotebookRuntime was created. Corresponds to the JSON property createTime

Returns:

  • (String)


39003
39004
39005
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39003

def create_time
  @create_time
end

#data_persistent_disk_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PersistentDiskSpec

Represents the spec of persistent disk and hyperdisk options. Corresponds to the JSON property dataPersistentDiskSpec



39008
39009
39010
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39008

def data_persistent_disk_spec
  @data_persistent_disk_spec
end

#descriptionString

The description of the NotebookRuntime. Corresponds to the JSON property description

Returns:

  • (String)


39013
39014
39015
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39013

def description
  @description
end

#display_nameString

Required. The display name of the NotebookRuntime. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


39019
39020
39021
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39019

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



39025
39026
39027
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39025

def encryption_spec
  @encryption_spec
end

#euc_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookEucConfig

The euc configuration of NotebookRuntimeTemplate. Corresponds to the JSON property eucConfig



39030
39031
39032
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39030

def euc_config
  @euc_config
end

#expiration_timeString

Output only. Timestamp when this NotebookRuntime will be expired: 1. System Predefined NotebookRuntime: 24 hours after creation. After expiration, system predifined runtime will be deleted. 2. User created NotebookRuntime: 6 months after last upgrade. After expiration, user created runtime will be stopped and allowed for upgrade. Corresponds to the JSON property expirationTime

Returns:

  • (String)


39039
39040
39041
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39039

def expiration_time
  @expiration_time
end

#health_stateString

Output only. The health state of the NotebookRuntime. Corresponds to the JSON property healthState

Returns:

  • (String)


39044
39045
39046
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39044

def health_state
  @health_state
end

#idle_shutdown_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookIdleShutdownConfig

The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field. Corresponds to the JSON property idleShutdownConfig



39050
39051
39052
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39050

def idle_shutdown_config
  @idle_shutdown_config
end

#is_upgradableBoolean Also known as: is_upgradable?

Output only. Whether NotebookRuntime is upgradable. Corresponds to the JSON property isUpgradable

Returns:

  • (Boolean)


39055
39056
39057
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39055

def is_upgradable
  @is_upgradable
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your NotebookRuntime. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one NotebookRuntime (System labels are excluded). See https:// goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for NotebookRuntime: * "aiplatform.googleapis. com/notebook_runtime_gce_instance_id": output only, its value is the Compute Engine instance id. * "aiplatform.googleapis.com/ colab_enterprise_entry_service": its value is either "bigquery" or "vertex"; if absent, it should be "vertex". This is to describe the entry service, either BigQuery or Vertex. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


39073
39074
39075
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39073

def labels
  @labels
end

#machine_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



39078
39079
39080
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39078

def machine_spec
  @machine_spec
end

#nameString

Output only. The resource name of the NotebookRuntime. Corresponds to the JSON property name

Returns:

  • (String)


39083
39084
39085
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39083

def name
  @name
end

#network_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NetworkSpec

Network spec. Corresponds to the JSON property networkSpec



39088
39089
39090
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39088

def network_spec
  @network_spec
end

#network_tagsArray<String>

Optional. The Compute Engine tags to add to runtime (see Tagging instances). Corresponds to the JSON property networkTags

Returns:

  • (Array<String>)


39094
39095
39096
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39094

def network_tags
  @network_tags
end

#notebook_runtime_template_refGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookRuntimeTemplateRef

Points to a NotebookRuntimeTemplateRef. Corresponds to the JSON property notebookRuntimeTemplateRef



39099
39100
39101
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39099

def notebook_runtime_template_ref
  @notebook_runtime_template_ref
end

#notebook_runtime_typeString

Output only. The type of the notebook runtime. Corresponds to the JSON property notebookRuntimeType

Returns:

  • (String)


39104
39105
39106
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39104

def notebook_runtime_type
  @notebook_runtime_type
end

#proxy_uriString

Output only. The proxy endpoint used to access the NotebookRuntime. Corresponds to the JSON property proxyUri

Returns:

  • (String)


39109
39110
39111
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39109

def proxy_uri
  @proxy_uri
end

#reservation_affinityGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookReservationAffinity

Notebook Reservation Affinity for consuming Zonal reservation. Corresponds to the JSON property reservationAffinity



39114
39115
39116
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39114

def reservation_affinity
  @reservation_affinity
end

#runtime_stateString

Output only. The runtime (instance) state of the NotebookRuntime. Corresponds to the JSON property runtimeState

Returns:

  • (String)


39119
39120
39121
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39119

def runtime_state
  @runtime_state
end

#runtime_userString

Required. The user email of the NotebookRuntime. Corresponds to the JSON property runtimeUser

Returns:

  • (String)


39124
39125
39126
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39124

def runtime_user
  @runtime_user
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


39129
39130
39131
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39129

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


39135
39136
39137
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39135

def satisfies_pzs
  @satisfies_pzs
end

#service_accountString

Output only. Deprecated: This field is no longer used and the "Vertex AI Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam. gserviceaccount.com) is used for the runtime workload identity. See https:// cloud.google.com/iam/docs/service-agents#vertex-ai-notebook-service-account for more details. The service account that the NotebookRuntime workload runs as. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


39146
39147
39148
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39146

def 
  @service_account
end

#shielded_vm_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ShieldedVmConfig

A set of Shielded Instance options. See Images using supported Shielded VM features. Corresponds to the JSON property shieldedVmConfig



39153
39154
39155
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39153

def shielded_vm_config
  @shielded_vm_config
end

#software_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookSoftwareConfig

Notebook Software Config. This is passed to the backend when user makes software configurations in UI. Corresponds to the JSON property softwareConfig



39159
39160
39161
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39159

def software_config
  @software_config
end

#update_timeString

Output only. Timestamp when this NotebookRuntime was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


39164
39165
39166
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39164

def update_time
  @update_time
end

#versionString

Output only. The VM os image version of NotebookRuntime. Corresponds to the JSON property version

Returns:

  • (String)


39169
39170
39171
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39169

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39176
39177
39178
39179
39180
39181
39182
39183
39184
39185
39186
39187
39188
39189
39190
39191
39192
39193
39194
39195
39196
39197
39198
39199
39200
39201
39202
39203
39204
39205
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39176

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_persistent_disk_spec = args[:data_persistent_disk_spec] if args.key?(:data_persistent_disk_spec)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @euc_config = args[:euc_config] if args.key?(:euc_config)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @health_state = args[:health_state] if args.key?(:health_state)
  @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config)
  @is_upgradable = args[:is_upgradable] if args.key?(:is_upgradable)
  @labels = args[:labels] if args.key?(:labels)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @name = args[:name] if args.key?(:name)
  @network_spec = args[:network_spec] if args.key?(:network_spec)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @notebook_runtime_template_ref = args[:notebook_runtime_template_ref] if args.key?(:notebook_runtime_template_ref)
  @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type)
  @proxy_uri = args[:proxy_uri] if args.key?(:proxy_uri)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @runtime_state = args[:runtime_state] if args.key?(:runtime_state)
  @runtime_user = args[:runtime_user] if args.key?(:runtime_user)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @service_account = args[:service_account] if args.key?(:service_account)
  @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config)
  @software_config = args[:software_config] if args.key?(:software_config)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version = args[:version] if args.key?(:version)
end