Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookRuntimeTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A template that specifies runtime configurations such as machine type, runtime version, network configurations, etc. Multiple runtimes can be created from a runtime template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NotebookRuntimeTemplate

Returns a new instance of GoogleCloudAiplatformV1beta1NotebookRuntimeTemplate.



38652
38653
38654
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this NotebookRuntimeTemplate was created. Corresponds to the JSON property createTime

Returns:

  • (String)


38531
38532
38533
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38531

def create_time
  @create_time
end

#data_persistent_disk_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PersistentDiskSpec

Represents the spec of persistent disk and hyperdisk options. Corresponds to the JSON property dataPersistentDiskSpec



38536
38537
38538
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38536

def data_persistent_disk_spec
  @data_persistent_disk_spec
end

#descriptionString

The description of the NotebookRuntimeTemplate. Corresponds to the JSON property description

Returns:

  • (String)


38541
38542
38543
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38541

def description
  @description
end

#display_nameString

Required. The display name of the NotebookRuntimeTemplate. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


38547
38548
38549
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38547

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



38553
38554
38555
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38553

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


38559
38560
38561
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38559

def etag
  @etag
end

#euc_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookEucConfig

The euc configuration of NotebookRuntimeTemplate. Corresponds to the JSON property eucConfig



38564
38565
38566
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38564

def euc_config
  @euc_config
end

#idle_shutdown_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookIdleShutdownConfig

The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field. Corresponds to the JSON property idleShutdownConfig



38570
38571
38572
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38570

def idle_shutdown_config
  @idle_shutdown_config
end

#is_defaultBoolean Also known as: is_default?

Output only. Deprecated: This field has no behavior. Use notebook_runtime_type = 'ONE_CLICK' instead. The default template to use if not specified. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


38576
38577
38578
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38576

def is_default
  @is_default
end

#labelsHash<String,String>

The labels with user-defined metadata to organize the NotebookRuntimeTemplates. Label keys and values can be no longer than 64 characters (Unicode codepoints) , can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


38586
38587
38588
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38586

def labels
  @labels
end

#machine_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



38591
38592
38593
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38591

def machine_spec
  @machine_spec
end

#nameString

The resource name of the NotebookRuntimeTemplate. Corresponds to the JSON property name

Returns:

  • (String)


38596
38597
38598
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38596

def name
  @name
end

#network_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NetworkSpec

Network spec. Corresponds to the JSON property networkSpec



38601
38602
38603
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38601

def network_spec
  @network_spec
end

#network_tagsArray<String>

Optional. The Compute Engine tags to add to runtime (see Tagging instances). Corresponds to the JSON property networkTags

Returns:

  • (Array<String>)


38607
38608
38609
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38607

def network_tags
  @network_tags
end

#notebook_runtime_typeString

Optional. Immutable. The type of the notebook runtime template. Corresponds to the JSON property notebookRuntimeType

Returns:

  • (String)


38612
38613
38614
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38612

def notebook_runtime_type
  @notebook_runtime_type
end

#reservation_affinityGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookReservationAffinity

Notebook Reservation Affinity for consuming Zonal reservation. Corresponds to the JSON property reservationAffinity



38617
38618
38619
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38617

def reservation_affinity
  @reservation_affinity
end

#service_accountString

Deprecated: This field is ignored and the "Vertex AI Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.gserviceaccount.com) is used for the runtime workload identity. See https://cloud.google.com/iam/docs/ service-agents#vertex-ai-notebook-service-account for more details. For NotebookExecutionJob, use NotebookExecutionJob.service_account instead. The service account that the runtime workload runs as. You can use any service account within the same project, but you must have the service account user permission to use the instance. If not specified, the Compute Engine default service account is used. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


38631
38632
38633
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38631

def 
  @service_account
end

#shielded_vm_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ShieldedVmConfig

A set of Shielded Instance options. See Images using supported Shielded VM features. Corresponds to the JSON property shieldedVmConfig



38638
38639
38640
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38638

def shielded_vm_config
  @shielded_vm_config
end

#software_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookSoftwareConfig

Notebook Software Config. This is passed to the backend when user makes software configurations in UI. Corresponds to the JSON property softwareConfig



38644
38645
38646
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38644

def software_config
  @software_config
end

#update_timeString

Output only. Timestamp when this NotebookRuntimeTemplate was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


38650
38651
38652
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38650

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38657
38658
38659
38660
38661
38662
38663
38664
38665
38666
38667
38668
38669
38670
38671
38672
38673
38674
38675
38676
38677
38678
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38657

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_persistent_disk_spec = args[:data_persistent_disk_spec] if args.key?(:data_persistent_disk_spec)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @euc_config = args[:euc_config] if args.key?(:euc_config)
  @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config)
  @is_default = args[:is_default] if args.key?(:is_default)
  @labels = args[:labels] if args.key?(:labels)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @name = args[:name] if args.key?(:name)
  @network_spec = args[:network_spec] if args.key?(:network_spec)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @service_account = args[:service_account] if args.key?(:service_account)
  @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config)
  @software_config = args[:software_config] if args.key?(:software_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end