Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookRuntimeTemplate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookRuntimeTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A template that specifies runtime configurations such as machine type, runtime version, network configurations, etc. Multiple runtimes can be created from a runtime template.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PersistentDiskSpec
Represents the spec of persistent disk options.
-
#description ⇒ String
The description of the NotebookRuntimeTemplate.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#euc_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
-
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field.
-
#is_default ⇒ Boolean
(also: #is_default?)
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize the NotebookRuntimeTemplates.
-
#machine_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec
Specification of a single machine.
-
#name ⇒ String
The resource name of the NotebookRuntimeTemplate.
-
#network_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NetworkSpec
Network spec.
-
#network_tags ⇒ Array<String>
Optional.
-
#notebook_runtime_type ⇒ String
Optional.
-
#reservation_affinity ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
-
#service_account ⇒ String
Deprecated: This field is ignored and the "Vertex AI Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.gserviceaccount.com) is used for the runtime workload identity.
-
#shielded_vm_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ShieldedVmConfig
A set of Shielded Instance options.
-
#software_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookSoftwareConfig
Notebook Software Config.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NotebookRuntimeTemplate
constructor
A new instance of GoogleCloudAiplatformV1beta1NotebookRuntimeTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1NotebookRuntimeTemplate
Returns a new instance of GoogleCloudAiplatformV1beta1NotebookRuntimeTemplate.
31844 31845 31846 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31844 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this NotebookRuntimeTemplate was created.
Corresponds to the JSON property createTime
31723 31724 31725 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31723 def create_time @create_time end |
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PersistentDiskSpec
Represents the spec of persistent disk options.
Corresponds to the JSON property dataPersistentDiskSpec
31728 31729 31730 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31728 def data_persistent_disk_spec @data_persistent_disk_spec end |
#description ⇒ String
The description of the NotebookRuntimeTemplate.
Corresponds to the JSON property description
31733 31734 31735 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31733 def description @description end |
#display_name ⇒ String
Required. The display name of the NotebookRuntimeTemplate. The name can be up
to 128 characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
31739 31740 31741 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31739 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
31745 31746 31747 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31745 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
31751 31752 31753 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31751 def etag @etag end |
#euc_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
Corresponds to the JSON property eucConfig
31756 31757 31758 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31756 def euc_config @euc_config end |
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the
idle_timeout as required field.
Corresponds to the JSON property idleShutdownConfig
31762 31763 31764 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31762 def idle_shutdown_config @idle_shutdown_config end |
#is_default ⇒ Boolean Also known as: is_default?
Output only. Deprecated: This field has no behavior. Use notebook_runtime_type
= 'ONE_CLICK' instead. The default template to use if not specified.
Corresponds to the JSON property isDefault
31768 31769 31770 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31768 def is_default @is_default end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize the NotebookRuntimeTemplates.
Label keys and values can be no longer than 64 characters (Unicode codepoints)
, can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information and examples of labels.
Corresponds to the JSON property labels
31778 31779 31780 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31778 def labels @labels end |
#machine_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
31783 31784 31785 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31783 def machine_spec @machine_spec end |
#name ⇒ String
The resource name of the NotebookRuntimeTemplate.
Corresponds to the JSON property name
31788 31789 31790 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31788 def name @name end |
#network_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NetworkSpec
Network spec.
Corresponds to the JSON property networkSpec
31793 31794 31795 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31793 def network_spec @network_spec end |
#network_tags ⇒ Array<String>
Optional. The Compute Engine tags to add to runtime (see Tagging instances).
Corresponds to the JSON property networkTags
31799 31800 31801 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31799 def @network_tags end |
#notebook_runtime_type ⇒ String
Optional. Immutable. The type of the notebook runtime template.
Corresponds to the JSON property notebookRuntimeType
31804 31805 31806 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31804 def notebook_runtime_type @notebook_runtime_type end |
#reservation_affinity ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
Corresponds to the JSON property reservationAffinity
31809 31810 31811 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31809 def reservation_affinity @reservation_affinity end |
#service_account ⇒ String
Deprecated: This field is ignored and the "Vertex AI Notebook Service Account"
(service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.gserviceaccount.com) is used
for the runtime workload identity. See https://cloud.google.com/iam/docs/
service-agents#vertex-ai-notebook-service-account for more details. For
NotebookExecutionJob, use NotebookExecutionJob.service_account instead. The
service account that the runtime workload runs as. You can use any service
account within the same project, but you must have the service account user
permission to use the instance. If not specified, the Compute Engine default
service account is used.
Corresponds to the JSON property serviceAccount
31823 31824 31825 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31823 def service_account @service_account end |
#shielded_vm_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ShieldedVmConfig
A set of Shielded Instance options. See Images using supported Shielded VM
features.
Corresponds to the JSON property shieldedVmConfig
31830 31831 31832 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31830 def shielded_vm_config @shielded_vm_config end |
#software_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NotebookSoftwareConfig
Notebook Software Config. This is passed to the backend when user makes
software configurations in UI.
Corresponds to the JSON property softwareConfig
31836 31837 31838 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31836 def software_config @software_config end |
#update_time ⇒ String
Output only. Timestamp when this NotebookRuntimeTemplate was most recently
updated.
Corresponds to the JSON property updateTime
31842 31843 31844 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31842 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31849 31850 31851 31852 31853 31854 31855 31856 31857 31858 31859 31860 31861 31862 31863 31864 31865 31866 31867 31868 31869 31870 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 31849 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_persistent_disk_spec = args[:data_persistent_disk_spec] if args.key?(:data_persistent_disk_spec) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @euc_config = args[:euc_config] if args.key?(:euc_config) @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config) @is_default = args[:is_default] if args.key?(:is_default) @labels = args[:labels] if args.key?(:labels) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @name = args[:name] if args.key?(:name) @network_spec = args[:network_spec] if args.key?(:network_spec) @network_tags = args[:network_tags] if args.key?(:network_tags) @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @service_account = args[:service_account] if args.key?(:service_account) @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config) @software_config = args[:software_config] if args.key?(:software_config) @update_time = args[:update_time] if args.key?(:update_time) end |