Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluator

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An OnlineEvaluator contains the configuration for an Online Evaluation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluator

Returns a new instance of GoogleCloudAiplatformV1beta1OnlineEvaluator.



38980
38981
38982
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38980

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_resourceString

Required. Immutable. The name of the agent that the OnlineEvaluator evaluates periodically. This value is used to filter the traces with a matching cloud. resource_id and link the evaluation results with relevant dashboards/UIs. This field is immutable. Once set, it cannot be changed. Corresponds to the JSON property agentResource

Returns:

  • (String)


38921
38922
38923
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38921

def agent_resource
  @agent_resource
end

#cloud_observabilityGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability

Data source for the OnlineEvaluator, based on Google Cloud Observability stack (Cloud Trace & Cloud Logging). Corresponds to the JSON property cloudObservability



38927
38928
38929
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38927

def cloud_observability
  @cloud_observability
end

#configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorConfig

Configuration for sampling behavior of the OnlineEvaluator. The OnlineEvaluator runs at a fixed interval of 10 minutes. Corresponds to the JSON property config



38933
38934
38935
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38933

def config
  @config
end

#create_timeString

Output only. Timestamp when the OnlineEvaluator was created. Corresponds to the JSON property createTime

Returns:

  • (String)


38938
38939
38940
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38938

def create_time
  @create_time
end

#display_nameString

Optional. Human-readable name for the OnlineEvaluator. The name doesn't have to be unique. The name can consist of any UTF-8 characters. The maximum length is 63 characters. If the display name exceeds max characters, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property displayName

Returns:

  • (String)


38946
38947
38948
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38946

def display_name
  @display_name
end

#metric_sourcesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricSource>

Required. A list of metric sources to be used for evaluating samples. At least one MetricSource must be provided. Right now, only predefined metrics and registered metrics are supported. Every registered metric must have display_name (or title) and score_range defined. Otherwise, the evaluations will fail. The maximum number of metric_sources is 25. Corresponds to the JSON property metricSources



38955
38956
38957
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38955

def metric_sources
  @metric_sources
end

#nameString

Identifier. The resource name of the OnlineEvaluator. Format: projects/ project/locations/location/onlineEvaluators/id. Corresponds to the JSON property name

Returns:

  • (String)


38961
38962
38963
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38961

def name
  @name
end

#stateString

Output only. The state of the OnlineEvaluator. Corresponds to the JSON property state

Returns:

  • (String)


38966
38967
38968
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38966

def state
  @state
end

#state_detailsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorStateDetails>

Output only. Contains additional information about the state of the OnlineEvaluator. This is used to provide more details in the event of a failure. Corresponds to the JSON property stateDetails



38973
38974
38975
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38973

def state_details
  @state_details
end

#update_timeString

Output only. Timestamp when the OnlineEvaluator was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


38978
38979
38980
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38978

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38985
38986
38987
38988
38989
38990
38991
38992
38993
38994
38995
38996
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38985

def update!(**args)
  @agent_resource = args[:agent_resource] if args.key?(:agent_resource)
  @cloud_observability = args[:cloud_observability] if args.key?(:cloud_observability)
  @config = args[:config] if args.key?(:config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @metric_sources = args[:metric_sources] if args.key?(:metric_sources)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
  @update_time = args[:update_time] if args.key?(:update_time)
end