Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluator
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluator
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An OnlineEvaluator contains the configuration for an Online Evaluation.
Instance Attribute Summary collapse
-
#agent_resource ⇒ String
Required.
-
#cloud_observability ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability
Data source for the OnlineEvaluator, based on GCP Observability stack (Cloud Trace & Cloud Logging).
-
#config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorConfig
Configuration for sampling behavior of the OnlineEvaluator.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#metric_sources ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricSource>
Required.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#state_details ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorStateDetails>
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluator
constructor
A new instance of GoogleCloudAiplatformV1beta1OnlineEvaluator.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluator
Returns a new instance of GoogleCloudAiplatformV1beta1OnlineEvaluator.
37519 37520 37521 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37519 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_resource ⇒ String
Required. Immutable. The name of the agent that the OnlineEvaluator evaluates
periodically. This value is used to filter the traces with a matching cloud.
resource_id and link the evaluation results with relevant dashboards/UIs. This
field is immutable. Once set, it cannot be changed.
Corresponds to the JSON property agentResource
37460 37461 37462 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37460 def agent_resource @agent_resource end |
#cloud_observability ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability
Data source for the OnlineEvaluator, based on GCP Observability stack (Cloud
Trace & Cloud Logging).
Corresponds to the JSON property cloudObservability
37466 37467 37468 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37466 def cloud_observability @cloud_observability end |
#config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorConfig
Configuration for sampling behavior of the OnlineEvaluator. The
OnlineEvaluator runs at a fixed interval of 10 minutes.
Corresponds to the JSON property config
37472 37473 37474 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37472 def config @config end |
#create_time ⇒ String
Output only. Timestamp when the OnlineEvaluator was created.
Corresponds to the JSON property createTime
37477 37478 37479 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37477 def create_time @create_time end |
#display_name ⇒ String
Optional. Human-readable name for the OnlineEvaluator. The name doesn't have
to be unique. The name can consist of any UTF-8 characters. The maximum length
is 63 characters. If the display name exceeds max characters, an
INVALID_ARGUMENT error is returned.
Corresponds to the JSON property displayName
37485 37486 37487 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37485 def display_name @display_name end |
#metric_sources ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetricSource>
Required. A list of metric sources to be used for evaluating samples. At least
one MetricSource must be provided. Right now, only predefined metrics and
registered metrics are supported. Every registered metric must have
display_name (or title) and score_range defined. Otherwise, the
evaluations will fail. The maximum number of metric_sources is 25.
Corresponds to the JSON property metricSources
37494 37495 37496 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37494 def metric_sources @metric_sources end |
#name ⇒ String
Identifier. The resource name of the OnlineEvaluator. Format: projects/
project/locations/location/onlineEvaluators/id.
Corresponds to the JSON property name
37500 37501 37502 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37500 def name @name end |
#state ⇒ String
Output only. The state of the OnlineEvaluator.
Corresponds to the JSON property state
37505 37506 37507 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37505 def state @state end |
#state_details ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorStateDetails>
Output only. Contains additional information about the state of the
OnlineEvaluator. This is used to provide more details in the event of a
failure.
Corresponds to the JSON property stateDetails
37512 37513 37514 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37512 def state_details @state_details end |
#update_time ⇒ String
Output only. Timestamp when the OnlineEvaluator was last updated.
Corresponds to the JSON property updateTime
37517 37518 37519 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37517 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37524 37525 37526 37527 37528 37529 37530 37531 37532 37533 37534 37535 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37524 def update!(**args) @agent_resource = args[:agent_resource] if args.key?(:agent_resource) @cloud_observability = args[:cloud_observability] if args.key?(:cloud_observability) @config = args[:config] if args.key?(:config) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @metric_sources = args[:metric_sources] if args.key?(:metric_sources) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @state_details = args[:state_details] if args.key?(:state_details) @update_time = args[:update_time] if args.key?(:update_time) end |