Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Data source for the OnlineEvaluator, based on GCP Observability stack (Cloud Trace & Cloud Logging).
Instance Attribute Summary collapse
-
#log_view ⇒ String
Optional.
-
#open_telemetry ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityOpenTelemetry
Configuration for data source following OpenTelemetry.
-
#trace_scope ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScope
If chosen, the online evaluator will evaluate single traces matching specified
filter. -
#trace_view ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability
constructor
A new instance of GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability
Returns a new instance of GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservability.
32041 32042 32043 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32041 def initialize(**args) update!(**args) end |
Instance Attribute Details
#log_view ⇒ String
Optional. Optional log view that will be used to query logs. If empty, the
_Default view will be used.
Corresponds to the JSON property logView
32022 32023 32024 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32022 def log_view @log_view end |
#open_telemetry ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityOpenTelemetry
Configuration for data source following OpenTelemetry.
Corresponds to the JSON property openTelemetry
32027 32028 32029 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32027 def open_telemetry @open_telemetry end |
#trace_scope ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScope
If chosen, the online evaluator will evaluate single traces matching specified
filter.
Corresponds to the JSON property traceScope
32033 32034 32035 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32033 def trace_scope @trace_scope end |
#trace_view ⇒ String
Optional. Optional trace view that will be used to query traces. If empty, the
_Default view will be used.
Corresponds to the JSON property traceView
32039 32040 32041 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32039 def trace_view @trace_view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32046 32047 32048 32049 32050 32051 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32046 def update!(**args) @log_view = args[:log_view] if args.key?(:log_view) @open_telemetry = args[:open_telemetry] if args.key?(:open_telemetry) @trace_scope = args[:trace_scope] if args.key?(:trace_scope) @trace_view = args[:trace_view] if args.key?(:trace_view) end |