Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScopePredicate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScopePredicate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Defines a single filter predicate.
Instance Attribute Summary collapse
-
#duration ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
-
#total_token_usage ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScopePredicate
constructor
A new instance of GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScopePredicate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScopePredicate
Returns a new instance of GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityTraceScopePredicate.
32134 32135 32136 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32134 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
Corresponds to the JSON property duration
32127 32128 32129 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32127 def duration @duration end |
#total_token_usage ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
Corresponds to the JSON property totalTokenUsage
32132 32133 32134 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32132 def total_token_usage @total_token_usage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32139 32140 32141 32142 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32139 def update!(**args) @duration = args[:duration] if args.key?(:duration) @total_token_usage = args[:total_token_usage] if args.key?(:total_token_usage) end |