Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OutputFieldSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1OutputFieldSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Specifies the properties of a single field that are included in each generated synthetic example. This helps the model understand what kind of data to generate for each field.
Instance Attribute Summary collapse
-
#field_name ⇒ String
Required.
-
#field_type ⇒ String
Optional.
-
#guidance ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OutputFieldSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1OutputFieldSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1OutputFieldSpec
Returns a new instance of GoogleCloudAiplatformV1beta1OutputFieldSpec.
39292 39293 39294 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39292 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_name ⇒ String
Required. The name of this field in the generated synthetic data, such as "
email_subject" or "customer_review".
Corresponds to the JSON property fieldName
39276 39277 39278 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39276 def field_name @field_name end |
#field_type ⇒ String
Optional. The data type of the field. Defaults to CONTENT if not set.
Corresponds to the JSON property fieldType
39281 39282 39283 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39281 def field_type @field_type end |
#guidance ⇒ String
Optional. Specific instructions for the large language model on how to
generate content for this particular field. While the LLM can sometimes infer
content from the field name, providing explicit guidance is preferred. For
example, for a field named "review", the guidance could be "A positive review
about a coffee maker."
Corresponds to the JSON property guidance
39290 39291 39292 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39290 def guidance @guidance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39297 39298 39299 39300 39301 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39297 def update!(**args) @field_name = args[:field_name] if args.key?(:field_name) @field_type = args[:field_type] if args.key?(:field_type) @guidance = args[:guidance] if args.key?(:guidance) end |