Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PairwiseMetricInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Pairwise metric instance. Usually one instance corresponds to one row in an evaluation dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PairwiseMetricInstance

Returns a new instance of GoogleCloudAiplatformV1beta1PairwiseMetricInstance.



32432
32433
32434
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_map_instanceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContentMap

Map of placeholder in metric prompt template to contents of model input. Corresponds to the JSON property contentMapInstance



32424
32425
32426
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32424

def content_map_instance
  @content_map_instance
end

#json_instanceString

Instance specified as a json string. String key-value pairs are expected in the json_instance to render PairwiseMetricSpec.instance_prompt_template. Corresponds to the JSON property jsonInstance

Returns:

  • (String)


32430
32431
32432
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32430

def json_instance
  @json_instance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32437
32438
32439
32440
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32437

def update!(**args)
  @content_map_instance = args[:content_map_instance] if args.key?(:content_map_instance)
  @json_instance = args[:json_instance] if args.key?(:json_instance)
end