Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A datatype containing media that is part of a multi-part Content message. A
Part consists of data which has an associated datatype. A Part can only
contain one of the accepted types in Part.data. For media types that are not
text, Part must have a fixed IANA MIME type identifying the type and subtype
of the media if inline_data or file_data field is filled with raw bytes.
Instance Attribute Summary collapse
-
#audio_transcription ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscription
The transcription of an audio part.
-
#code_execution_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CodeExecutionResult
Result of executing the ExecutableCode.
-
#executable_code ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExecutableCode
Code generated by the model that is meant to be executed, and the result returned to the model.
-
#file_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FileData
URI-based data.
-
#function_call ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionCall
A predicted FunctionCall returned from the model that contains a string representing the FunctionDeclaration.name and a structured JSON object containing the parameters and their values.
-
#function_response ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionResponse
The result output from a FunctionCall that contains a string representing the FunctionDeclaration.name and a structured JSON object containing any output from the function is used as context to the model.
-
#inline_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Blob
A content blob.
-
#media_resolution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PartMediaResolution
per part media resolution.
-
#text ⇒ String
Optional.
-
#thought ⇒ Boolean
(also: #thought?)
Optional.
-
#thought_signature ⇒ String
Optional.
-
#video_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VideoMetadata
Provides metadata for a video, including the start and end offsets for clipping and the frame rate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Part
constructor
A new instance of GoogleCloudAiplatformV1beta1Part.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Part
Returns a new instance of GoogleCloudAiplatformV1beta1Part.
41512 41513 41514 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41512 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_transcription ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AudioTranscription
The transcription of an audio part. For multi-speaker audio, each speaker
segment is a separate Part with its own AudioTranscription carrying the
speaker_label.
Corresponds to the JSON property audioTranscription
41435 41436 41437 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41435 def audio_transcription @audio_transcription end |
#code_execution_result ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CodeExecutionResult
Result of executing the ExecutableCode. Generated only when the CodeExecution
tool is used.
Corresponds to the JSON property codeExecutionResult
41441 41442 41443 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41441 def code_execution_result @code_execution_result end |
#executable_code ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExecutableCode
Code generated by the model that is meant to be executed, and the result
returned to the model. Generated when using the CodeExecution tool, in which
the code will be automatically executed, and a corresponding
CodeExecutionResult will also be generated.
Corresponds to the JSON property executableCode
41449 41450 41451 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41449 def executable_code @executable_code end |
#file_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FileData
URI-based data. A FileData message contains a URI pointing to data of a
specific media type. It is used to represent images, audio, and video stored
in Google Cloud Storage.
Corresponds to the JSON property fileData
41456 41457 41458 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41456 def file_data @file_data end |
#function_call ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionCall
A predicted FunctionCall returned from the model that contains a string
representing the FunctionDeclaration.name and a structured JSON object
containing the parameters and their values.
Corresponds to the JSON property functionCall
41463 41464 41465 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41463 def function_call @function_call end |
#function_response ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionResponse
The result output from a FunctionCall that contains a string representing the
FunctionDeclaration.name and a structured JSON object containing any output
from the function is used as context to the model. This should contain the
result of a FunctionCall made based on model prediction.
Corresponds to the JSON property functionResponse
41471 41472 41473 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41471 def function_response @function_response end |
#inline_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Blob
A content blob. A Blob contains data of a specific media type. It is used to
represent images, audio, and video.
Corresponds to the JSON property inlineData
41477 41478 41479 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41477 def inline_data @inline_data end |
#media_resolution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PartMediaResolution
per part media resolution. Media resolution for the input media.
Corresponds to the JSON property mediaResolution
41482 41483 41484 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41482 def media_resolution @media_resolution end |
#text ⇒ String
Optional. The text content of the part. When sent from the VSCode Gemini Code
Assist extension, references to @mentioned items will be converted to markdown
boldface text. For example @my-repo will be converted to and sent as **my-
repo** by the IDE agent.
Corresponds to the JSON property text
41490 41491 41492 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41490 def text @text end |
#thought ⇒ Boolean Also known as: thought?
Optional. Indicates whether the part represents the model's thought process
or reasoning.
Corresponds to the JSON property thought
41496 41497 41498 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41496 def thought @thought end |
#thought_signature ⇒ String
Optional. An opaque signature for the thought so it can be reused in
subsequent requests.
Corresponds to the JSON property thoughtSignature
NOTE: Values are automatically base64 encoded/decoded in the client library.
41504 41505 41506 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41504 def thought_signature @thought_signature end |
#video_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VideoMetadata
Provides metadata for a video, including the start and end offsets for
clipping and the frame rate.
Corresponds to the JSON property videoMetadata
41510 41511 41512 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41510 def @video_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41517 41518 41519 41520 41521 41522 41523 41524 41525 41526 41527 41528 41529 41530 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41517 def update!(**args) @audio_transcription = args[:audio_transcription] if args.key?(:audio_transcription) @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result) @executable_code = args[:executable_code] if args.key?(:executable_code) @file_data = args[:file_data] if args.key?(:file_data) @function_call = args[:function_call] if args.key?(:function_call) @function_response = args[:function_response] if args.key?(:function_response) @inline_data = args[:inline_data] if args.key?(:inline_data) @media_resolution = args[:media_resolution] if args.key?(:media_resolution) @text = args[:text] if args.key?(:text) @thought = args[:thought] if args.key?(:thought) @thought_signature = args[:thought_signature] if args.key?(:thought_signature) @video_metadata = args[:video_metadata] if args.key?(:video_metadata) end |