Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A datatype containing media that is part of a multi-part Content message. A Part consists of data which has an associated datatype. A Part can only contain one of the accepted types in Part.data. For media types that are not text, Part must have a fixed IANA MIME type identifying the type and subtype of the media if inline_data or file_data field is filled with raw bytes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Part

Returns a new instance of GoogleCloudAiplatformV1beta1Part.



32852
32853
32854
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32852

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_execution_resultGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CodeExecutionResult

Result of executing the ExecutableCode. Generated only when the CodeExecution tool is used. Corresponds to the JSON property codeExecutionResult



32781
32782
32783
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32781

def code_execution_result
  @code_execution_result
end

#executable_codeGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExecutableCode

Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the CodeExecution tool, in which the code will be automatically executed, and a corresponding CodeExecutionResult will also be generated. Corresponds to the JSON property executableCode



32789
32790
32791
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32789

def executable_code
  @executable_code
end

#file_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FileData

URI-based data. A FileData message contains a URI pointing to data of a specific media type. It is used to represent images, audio, and video stored in Google Cloud Storage. Corresponds to the JSON property fileData



32796
32797
32798
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32796

def file_data
  @file_data
end

#function_callGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionCall

A predicted FunctionCall returned from the model that contains a string representing the FunctionDeclaration.name and a structured JSON object containing the parameters and their values. Corresponds to the JSON property functionCall



32803
32804
32805
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32803

def function_call
  @function_call
end

#function_responseGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionResponse

The result output from a FunctionCall that contains a string representing the FunctionDeclaration.name and a structured JSON object containing any output from the function is used as context to the model. This should contain the result of a FunctionCall made based on model prediction. Corresponds to the JSON property functionResponse



32811
32812
32813
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32811

def function_response
  @function_response
end

#inline_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Blob

A content blob. A Blob contains data of a specific media type. It is used to represent images, audio, and video. Corresponds to the JSON property inlineData



32817
32818
32819
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32817

def inline_data
  @inline_data
end

#media_resolutionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PartMediaResolution

per part media resolution. Media resolution for the input media. Corresponds to the JSON property mediaResolution



32822
32823
32824
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32822

def media_resolution
  @media_resolution
end

#textString

Optional. The text content of the part. When sent from the VSCode Gemini Code Assist extension, references to @mentioned items will be converted to markdown boldface text. For example @my-repo will be converted to and sent as **my- repo** by the IDE agent. Corresponds to the JSON property text

Returns:

  • (String)


32830
32831
32832
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32830

def text
  @text
end

#thoughtBoolean Also known as: thought?

Optional. Indicates whether the part represents the model's thought process or reasoning. Corresponds to the JSON property thought

Returns:

  • (Boolean)


32836
32837
32838
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32836

def thought
  @thought
end

#thought_signatureString

Optional. An opaque signature for the thought so it can be reused in subsequent requests. Corresponds to the JSON property thoughtSignature NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


32844
32845
32846
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32844

def thought_signature
  @thought_signature
end

#video_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VideoMetadata

Provides metadata for a video, including the start and end offsets for clipping and the frame rate. Corresponds to the JSON property videoMetadata



32850
32851
32852
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32850

def 
  @video_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32857
32858
32859
32860
32861
32862
32863
32864
32865
32866
32867
32868
32869
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 32857

def update!(**args)
  @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result)
  @executable_code = args[:executable_code] if args.key?(:executable_code)
  @file_data = args[:file_data] if args.key?(:file_data)
  @function_call = args[:function_call] if args.key?(:function_call)
  @function_response = args[:function_response] if args.key?(:function_response)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
  @media_resolution = args[:media_resolution] if args.key?(:media_resolution)
  @text = args[:text] if args.key?(:text)
  @thought = args[:thought] if args.key?(:thought)
  @thought_signature = args[:thought_signature] if args.key?(:thought_signature)
  @video_metadata = args[:video_metadata] if args.key?(:video_metadata)
end