Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PersistentResource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PersistentResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents long-lasting resources that are dedicated to users to runs custom workloads. A PersistentResource can have multiple node pools and each node pool can have its own machine spec.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#network ⇒ String
Optional.
-
#psc_interface_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscInterfaceConfig
Configuration for PSC-I.
-
#reserved_ip_ranges ⇒ Array<String>
Optional.
-
#resource_pools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourcePool>
Required.
-
#resource_runtime ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourceRuntime
Persistent Cluster runtime information as output Corresponds to the JSON property
resourceRuntime. -
#resource_runtime_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourceRuntimeSpec
Configuration for the runtime on a PersistentResource instance, including but not limited to: * Service accounts used to run the workloads.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PersistentResource
constructor
A new instance of GoogleCloudAiplatformV1beta1PersistentResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PersistentResource
Returns a new instance of GoogleCloudAiplatformV1beta1PersistentResource.
42367 42368 42369 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42367 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the PersistentResource was created.
Corresponds to the JSON property createTime
42257 42258 42259 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42257 def create_time @create_time end |
#display_name ⇒ String
Optional. The display name of the PersistentResource. The name can be up to
128 characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
42263 42264 42265 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42263 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
42269 42270 42271 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42269 def encryption_spec @encryption_spec end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
42279 42280 42281 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42279 def error @error end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize PersistentResource.
Label keys and values can be no longer than 64 characters (Unicode codepoints)
, can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information and examples of labels.
Corresponds to the JSON property labels
42288 42289 42290 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42288 def labels @labels end |
#name ⇒ String
Immutable. Resource name of a PersistentResource.
Corresponds to the JSON property name
42293 42294 42295 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42293 def name @name end |
#network ⇒ String
Optional. The full name of the Compute Engine network to peered with Vertex AI to host the persistent
resources. For example, projects/12345/global/networks/myVPC. Format is of the form projects/
project/global/networks/network`. Whereprojectis a project number, as
in12345, andnetworkis a network name. To specify this field, you must
have already [configured VPC Network Peering for Vertex AI](https://cloud.
google.com/vertex-ai/docs/general/vpc-peering). If this field is left
unspecified, the resources aren't peered with any network.
Corresponds to the JSON propertynetwork`
42306 42307 42308 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42306 def network @network end |
#psc_interface_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscInterfaceConfig
Configuration for PSC-I.
Corresponds to the JSON property pscInterfaceConfig
42311 42312 42313 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42311 def psc_interface_config @psc_interface_config end |
#reserved_ip_ranges ⇒ Array<String>
Optional. A list of names for the reserved IP ranges under the VPC network
that can be used for this persistent resource. If set, we will deploy the
persistent resource within the provided IP ranges. Otherwise, the persistent
resource is deployed to any IP ranges under the provided VPC network. Example:
['vertex-ai-ip-range'].
Corresponds to the JSON property reservedIpRanges
42320 42321 42322 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42320 def reserved_ip_ranges @reserved_ip_ranges end |
#resource_pools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourcePool>
Required. The spec of the pools of different resources.
Corresponds to the JSON property resourcePools
42325 42326 42327 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42325 def resource_pools @resource_pools end |
#resource_runtime ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourceRuntime
Persistent Cluster runtime information as output
Corresponds to the JSON property resourceRuntime
42330 42331 42332 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42330 def resource_runtime @resource_runtime end |
#resource_runtime_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourceRuntimeSpec
Configuration for the runtime on a PersistentResource instance, including but
not limited to: * Service accounts used to run the workloads. * Whether to
make it a dedicated Ray Cluster.
Corresponds to the JSON property resourceRuntimeSpec
42337 42338 42339 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42337 def resource_runtime_spec @resource_runtime_spec end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
42342 42343 42344 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42342 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
42348 42349 42350 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42348 def satisfies_pzs @satisfies_pzs end |
#start_time ⇒ String
Output only. Time when the PersistentResource for the first time entered the
RUNNING state.
Corresponds to the JSON property startTime
42355 42356 42357 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42355 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of a Study.
Corresponds to the JSON property state
42360 42361 42362 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42360 def state @state end |
#update_time ⇒ String
Output only. Time when the PersistentResource was most recently updated.
Corresponds to the JSON property updateTime
42365 42366 42367 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42365 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42372 42373 42374 42375 42376 42377 42378 42379 42380 42381 42382 42383 42384 42385 42386 42387 42388 42389 42390 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42372 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @error = args[:error] if args.key?(:error) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config) @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges) @resource_pools = args[:resource_pools] if args.key?(:resource_pools) @resource_runtime = args[:resource_runtime] if args.key?(:resource_runtime) @resource_runtime_spec = args[:resource_runtime_spec] if args.key?(:resource_runtime_spec) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |