Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PersistentResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents long-lasting resources that are dedicated to users to runs custom workloads. A PersistentResource can have multiple node pools and each node pool can have its own machine spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PersistentResource

Returns a new instance of GoogleCloudAiplatformV1beta1PersistentResource.



39976
39977
39978
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39976

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the PersistentResource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


39866
39867
39868
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39866

def create_time
  @create_time
end

#display_nameString

Optional. The display name of the PersistentResource. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


39872
39873
39874
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39872

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



39878
39879
39880
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39878

def encryption_spec
  @encryption_spec
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



39888
39889
39890
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39888

def error
  @error
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize PersistentResource. Label keys and values can be no longer than 64 characters (Unicode codepoints) , can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


39897
39898
39899
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39897

def labels
  @labels
end

#nameString

Immutable. Resource name of a PersistentResource. Corresponds to the JSON property name

Returns:

  • (String)


39902
39903
39904
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39902

def name
  @name
end

#networkString

Optional. The full name of the Compute Engine network to peered with Vertex AI to host the persistent resources. For example, projects/12345/global/networks/myVPC. Format is of the form projects/ project/global/networks/network`. Whereprojectis a project number, as in12345, andnetworkis a network name. To specify this field, you must have already [configured VPC Network Peering for Vertex AI](https://cloud. google.com/vertex-ai/docs/general/vpc-peering). If this field is left unspecified, the resources aren't peered with any network. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


39915
39916
39917
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39915

def network
  @network
end

#psc_interface_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscInterfaceConfig

Configuration for PSC-I. Corresponds to the JSON property pscInterfaceConfig



39920
39921
39922
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39920

def psc_interface_config
  @psc_interface_config
end

#reserved_ip_rangesArray<String>

Optional. A list of names for the reserved IP ranges under the VPC network that can be used for this persistent resource. If set, we will deploy the persistent resource within the provided IP ranges. Otherwise, the persistent resource is deployed to any IP ranges under the provided VPC network. Example: ['vertex-ai-ip-range']. Corresponds to the JSON property reservedIpRanges

Returns:

  • (Array<String>)


39929
39930
39931
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39929

def reserved_ip_ranges
  @reserved_ip_ranges
end

#resource_poolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourcePool>

Required. The spec of the pools of different resources. Corresponds to the JSON property resourcePools



39934
39935
39936
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39934

def resource_pools
  @resource_pools
end

#resource_runtimeGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourceRuntime

Persistent Cluster runtime information as output Corresponds to the JSON property resourceRuntime



39939
39940
39941
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39939

def resource_runtime
  @resource_runtime
end

#resource_runtime_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourceRuntimeSpec

Configuration for the runtime on a PersistentResource instance, including but not limited to: * Service accounts used to run the workloads. * Whether to make it a dedicated Ray Cluster. Corresponds to the JSON property resourceRuntimeSpec



39946
39947
39948
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39946

def resource_runtime_spec
  @resource_runtime_spec
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


39951
39952
39953
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39951

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


39957
39958
39959
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39957

def satisfies_pzs
  @satisfies_pzs
end

#start_timeString

Output only. Time when the PersistentResource for the first time entered the RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


39964
39965
39966
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39964

def start_time
  @start_time
end

#stateString

Output only. The detailed state of a Study. Corresponds to the JSON property state

Returns:

  • (String)


39969
39970
39971
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39969

def state
  @state
end

#update_timeString

Output only. Time when the PersistentResource was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


39974
39975
39976
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39974

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39981
39982
39983
39984
39985
39986
39987
39988
39989
39990
39991
39992
39993
39994
39995
39996
39997
39998
39999
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39981

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config)
  @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges)
  @resource_pools = args[:resource_pools] if args.key?(:resource_pools)
  @resource_runtime = args[:resource_runtime] if args.key?(:resource_runtime)
  @resource_runtime_spec = args[:resource_runtime_spec] if args.key?(:resource_runtime_spec)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end