Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An instance of a machine learning PipelineJob.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The display name of the Pipeline.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#job_detail ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJobDetail
The runtime detail of PipelineJob.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize PipelineJob.
-
#name ⇒ String
Output only.
-
#network ⇒ String
The full name of the Compute Engine network to which the Pipeline Job's workload should be peered.
-
#original_pipeline_job_id ⇒ Fixnum
Optional.
-
#pipeline_spec ⇒ Hash<String,Object>
A compiled definition of a pipeline, represented as a
JSONobject. -
#pipeline_task_rerun_configs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskRerunConfig>
Optional.
-
#preflight_validations ⇒ Boolean
(also: #preflight_validations?)
Optional.
-
#psc_interface_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscInterfaceConfig
Configuration for PSC-I.
-
#reserved_ip_ranges ⇒ Array<String>
A list of names for the reserved ip ranges under the VPC network that can be used for this Pipeline Job's workload.
-
#runtime_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJobRuntimeConfig
The runtime config of a PipelineJob.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#schedule_name ⇒ String
Output only.
-
#service_account ⇒ String
The service account that the pipeline workload runs as.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#template_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTemplateMetadata
Pipeline template metadata if PipelineJob.template_uri is from supported template registry.
-
#template_uri ⇒ String
A template uri from where the PipelineJob.pipeline_spec, if empty, will be downloaded.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PipelineJob
constructor
A new instance of GoogleCloudAiplatformV1beta1PipelineJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PipelineJob
Returns a new instance of GoogleCloudAiplatformV1beta1PipelineJob.
42569 42570 42571 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42569 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Pipeline creation time.
Corresponds to the JSON property createTime
42400 42401 42402 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42400 def create_time @create_time end |
#display_name ⇒ String
The display name of the Pipeline. The name can be up to 128 characters long
and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
42406 42407 42408 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42406 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
42412 42413 42414 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42412 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Pipeline end time.
Corresponds to the JSON property endTime
42417 42418 42419 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42417 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
42427 42428 42429 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42427 def error @error end |
#job_detail ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJobDetail
The runtime detail of PipelineJob.
Corresponds to the JSON property jobDetail
42432 42433 42434 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42432 def job_detail @job_detail end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize PipelineJob. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels. Note there is some reserved label key for
Vertex AI Pipelines. - vertex-ai-pipelines-run-billing-id, user set value
will get overrided.
Corresponds to the JSON property labels
42443 42444 42445 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42443 def labels @labels end |
#name ⇒ String
Output only. The resource name of the PipelineJob.
Corresponds to the JSON property name
42448 42449 42450 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42448 def name @name end |
#network ⇒ String
The full name of the Compute Engine network to which the Pipeline Job's workload should be peered. For
example, projects/12345/global/networks/myVPC. Format is of the form projects/project/global/
networks/network`. Whereprojectis a project number, as in12345, and
networkis a network name. Private services access must already be configured
for the network. Pipeline job will apply the network configuration to the
Google Cloud resources being launched, if applied, such as Vertex AI Training
or Dataflow job. If left unspecified, the workload is not peered with any
network.
Corresponds to the JSON propertynetwork`
42462 42463 42464 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42462 def network @network end |
#original_pipeline_job_id ⇒ Fixnum
Optional. The original pipeline job id if this pipeline job is a rerun of a
previous pipeline job.
Corresponds to the JSON property originalPipelineJobId
42468 42469 42470 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42468 def original_pipeline_job_id @original_pipeline_job_id end |
#pipeline_spec ⇒ Hash<String,Object>
A compiled definition of a pipeline, represented as a JSON object. Defines
the structure of the pipeline, including its components, tasks, and parameters.
This specification is generated by compiling a pipeline function defined in
Python using the Kubeflow Pipelines SDK.
Corresponds to the JSON property pipelineSpec
42476 42477 42478 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42476 def pipeline_spec @pipeline_spec end |
#pipeline_task_rerun_configs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskRerunConfig>
Optional. The rerun configs for each task in the pipeline job. By default, the
rerun will: 1. Use the same input artifacts as the original run. 2. Use the
same input parameters as the original run. 3. Skip all the tasks that are
already succeeded in the original run. 4. Rerun all the tasks that are not
succeeded in the original run. By providing this field, users can override the
default behavior and specify the rerun config for each task.
Corresponds to the JSON property pipelineTaskRerunConfigs
42486 42487 42488 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42486 def pipeline_task_rerun_configs @pipeline_task_rerun_configs end |
#preflight_validations ⇒ Boolean Also known as: preflight_validations?
Optional. Whether to do component level validations before job creation.
Corresponds to the JSON property preflightValidations
42491 42492 42493 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42491 def preflight_validations @preflight_validations end |
#psc_interface_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscInterfaceConfig
Configuration for PSC-I.
Corresponds to the JSON property pscInterfaceConfig
42497 42498 42499 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42497 def psc_interface_config @psc_interface_config end |
#reserved_ip_ranges ⇒ Array<String>
A list of names for the reserved ip ranges under the VPC network that can be
used for this Pipeline Job's workload. If set, we will deploy the Pipeline Job'
s workload within the provided ip ranges. Otherwise, the job will be deployed
to any ip ranges under the provided VPC network. Example: ['vertex-ai-ip-range'
].
Corresponds to the JSON property reservedIpRanges
42506 42507 42508 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42506 def reserved_ip_ranges @reserved_ip_ranges end |
#runtime_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJobRuntimeConfig
The runtime config of a PipelineJob.
Corresponds to the JSON property runtimeConfig
42511 42512 42513 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42511 def runtime_config @runtime_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
42516 42517 42518 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42516 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
42522 42523 42524 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42522 def satisfies_pzs @satisfies_pzs end |
#schedule_name ⇒ String
Output only. The schedule resource name. Only returned if the Pipeline is
created by Schedule API.
Corresponds to the JSON property scheduleName
42529 42530 42531 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42529 def schedule_name @schedule_name end |
#service_account ⇒ String
The service account that the pipeline workload runs as. If not specified, the
Compute Engine default service account in the project will be used. See https:/
/cloud.google.com/compute/docs/access/service-accounts#default_service_account
Users starting the pipeline must have the iam.serviceAccounts.actAs
permission on this service account.
Corresponds to the JSON property serviceAccount
42538 42539 42540 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42538 def service_account @service_account end |
#start_time ⇒ String
Output only. Pipeline start time.
Corresponds to the JSON property startTime
42543 42544 42545 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42543 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
42548 42549 42550 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42548 def state @state end |
#template_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTemplateMetadata
Pipeline template metadata if PipelineJob.template_uri is from supported
template registry. Currently, the only supported registry is Artifact Registry.
Corresponds to the JSON property templateMetadata
42554 42555 42556 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42554 def @template_metadata end |
#template_uri ⇒ String
A template uri from where the PipelineJob.pipeline_spec, if empty, will be
downloaded. Currently, only uri from Vertex Template Registry & Gallery is
supported. Reference to https://cloud.google.com/vertex-ai/docs/pipelines/
create-pipeline-template.
Corresponds to the JSON property templateUri
42562 42563 42564 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42562 def template_uri @template_uri end |
#update_time ⇒ String
Output only. Timestamp when this PipelineJob was most recently updated.
Corresponds to the JSON property updateTime
42567 42568 42569 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42567 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42574 42575 42576 42577 42578 42579 42580 42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42574 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @job_detail = args[:job_detail] if args.key?(:job_detail) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @original_pipeline_job_id = args[:original_pipeline_job_id] if args.key?(:original_pipeline_job_id) @pipeline_spec = args[:pipeline_spec] if args.key?(:pipeline_spec) @pipeline_task_rerun_configs = args[:pipeline_task_rerun_configs] if args.key?(:pipeline_task_rerun_configs) @preflight_validations = args[:preflight_validations] if args.key?(:preflight_validations) @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config) @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges) @runtime_config = args[:runtime_config] if args.key?(:runtime_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @schedule_name = args[:schedule_name] if args.key?(:schedule_name) @service_account = args[:service_account] if args.key?(:service_account) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @template_metadata = args[:template_metadata] if args.key?(:template_metadata) @template_uri = args[:template_uri] if args.key?(:template_uri) @update_time = args[:update_time] if args.key?(:update_time) end |