Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An instance of a machine learning PipelineJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PipelineJob

Returns a new instance of GoogleCloudAiplatformV1beta1PipelineJob.



38882
38883
38884
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38882

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Pipeline creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


38713
38714
38715
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38713

def create_time
  @create_time
end

#display_nameString

The display name of the Pipeline. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


38719
38720
38721
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38719

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



38725
38726
38727
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38725

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Pipeline end time. Corresponds to the JSON property endTime

Returns:

  • (String)


38730
38731
38732
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38730

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



38740
38741
38742
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38740

def error
  @error
end

#job_detailGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJobDetail

The runtime detail of PipelineJob. Corresponds to the JSON property jobDetail



38745
38746
38747
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38745

def job_detail
  @job_detail
end

#labelsHash<String,String>

The labels with user-defined metadata to organize PipelineJob. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Note there is some reserved label key for Vertex AI Pipelines. - vertex-ai-pipelines-run-billing-id, user set value will get overrided. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


38756
38757
38758
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38756

def labels
  @labels
end

#nameString

Output only. The resource name of the PipelineJob. Corresponds to the JSON property name

Returns:

  • (String)


38761
38762
38763
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38761

def name
  @name
end

#networkString

The full name of the Compute Engine network to which the Pipeline Job's workload should be peered. For example, projects/12345/global/networks/myVPC. Format is of the form projects/project/global/ networks/network`. Whereprojectis a project number, as in12345, and networkis a network name. Private services access must already be configured for the network. Pipeline job will apply the network configuration to the Google Cloud resources being launched, if applied, such as Vertex AI Training or Dataflow job. If left unspecified, the workload is not peered with any network. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


38775
38776
38777
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38775

def network
  @network
end

#original_pipeline_job_idFixnum

Optional. The original pipeline job id if this pipeline job is a rerun of a previous pipeline job. Corresponds to the JSON property originalPipelineJobId

Returns:

  • (Fixnum)


38781
38782
38783
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38781

def original_pipeline_job_id
  @original_pipeline_job_id
end

#pipeline_specHash<String,Object>

A compiled definition of a pipeline, represented as a JSON object. Defines the structure of the pipeline, including its components, tasks, and parameters. This specification is generated by compiling a pipeline function defined in Python using the Kubeflow Pipelines SDK. Corresponds to the JSON property pipelineSpec

Returns:

  • (Hash<String,Object>)


38789
38790
38791
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38789

def pipeline_spec
  @pipeline_spec
end

#pipeline_task_rerun_configsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskRerunConfig>

Optional. The rerun configs for each task in the pipeline job. By default, the rerun will: 1. Use the same input artifacts as the original run. 2. Use the same input parameters as the original run. 3. Skip all the tasks that are already succeeded in the original run. 4. Rerun all the tasks that are not succeeded in the original run. By providing this field, users can override the default behavior and specify the rerun config for each task. Corresponds to the JSON property pipelineTaskRerunConfigs



38799
38800
38801
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38799

def pipeline_task_rerun_configs
  @pipeline_task_rerun_configs
end

#preflight_validationsBoolean Also known as: preflight_validations?

Optional. Whether to do component level validations before job creation. Corresponds to the JSON property preflightValidations

Returns:

  • (Boolean)


38804
38805
38806
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38804

def preflight_validations
  @preflight_validations
end

#psc_interface_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscInterfaceConfig

Configuration for PSC-I. Corresponds to the JSON property pscInterfaceConfig



38810
38811
38812
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38810

def psc_interface_config
  @psc_interface_config
end

#reserved_ip_rangesArray<String>

A list of names for the reserved ip ranges under the VPC network that can be used for this Pipeline Job's workload. If set, we will deploy the Pipeline Job' s workload within the provided ip ranges. Otherwise, the job will be deployed to any ip ranges under the provided VPC network. Example: ['vertex-ai-ip-range' ]. Corresponds to the JSON property reservedIpRanges

Returns:

  • (Array<String>)


38819
38820
38821
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38819

def reserved_ip_ranges
  @reserved_ip_ranges
end

#runtime_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJobRuntimeConfig

The runtime config of a PipelineJob. Corresponds to the JSON property runtimeConfig



38824
38825
38826
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38824

def runtime_config
  @runtime_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


38829
38830
38831
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38829

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


38835
38836
38837
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38835

def satisfies_pzs
  @satisfies_pzs
end

#schedule_nameString

Output only. The schedule resource name. Only returned if the Pipeline is created by Schedule API. Corresponds to the JSON property scheduleName

Returns:

  • (String)


38842
38843
38844
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38842

def schedule_name
  @schedule_name
end

#service_accountString

The service account that the pipeline workload runs as. If not specified, the Compute Engine default service account in the project will be used. See https:/ /cloud.google.com/compute/docs/access/service-accounts#default_service_account Users starting the pipeline must have the iam.serviceAccounts.actAs permission on this service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


38851
38852
38853
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38851

def 
  @service_account
end

#start_timeString

Output only. Pipeline start time. Corresponds to the JSON property startTime

Returns:

  • (String)


38856
38857
38858
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38856

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


38861
38862
38863
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38861

def state
  @state
end

#template_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTemplateMetadata

Pipeline template metadata if PipelineJob.template_uri is from supported template registry. Currently, the only supported registry is Artifact Registry. Corresponds to the JSON property templateMetadata



38867
38868
38869
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38867

def 
  @template_metadata
end

#template_uriString

A template uri from where the PipelineJob.pipeline_spec, if empty, will be downloaded. Currently, only uri from Vertex Template Registry & Gallery is supported. Reference to https://cloud.google.com/vertex-ai/docs/pipelines/ create-pipeline-template. Corresponds to the JSON property templateUri

Returns:

  • (String)


38875
38876
38877
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38875

def template_uri
  @template_uri
end

#update_timeString

Output only. Timestamp when this PipelineJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


38880
38881
38882
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38880

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38887
38888
38889
38890
38891
38892
38893
38894
38895
38896
38897
38898
38899
38900
38901
38902
38903
38904
38905
38906
38907
38908
38909
38910
38911
38912
38913
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38887

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @job_detail = args[:job_detail] if args.key?(:job_detail)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @original_pipeline_job_id = args[:original_pipeline_job_id] if args.key?(:original_pipeline_job_id)
  @pipeline_spec = args[:pipeline_spec] if args.key?(:pipeline_spec)
  @pipeline_task_rerun_configs = args[:pipeline_task_rerun_configs] if args.key?(:pipeline_task_rerun_configs)
  @preflight_validations = args[:preflight_validations] if args.key?(:preflight_validations)
  @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config)
  @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges)
  @runtime_config = args[:runtime_config] if args.key?(:runtime_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @schedule_name = args[:schedule_name] if args.key?(:schedule_name)
  @service_account = args[:service_account] if args.key?(:service_account)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @template_metadata = args[:template_metadata] if args.key?(:template_metadata)
  @template_uri = args[:template_uri] if args.key?(:template_uri)
  @update_time = args[:update_time] if args.key?(:update_time)
end