Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An instance of a machine learning PipelineJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PipelineJob

Returns a new instance of GoogleCloudAiplatformV1beta1PipelineJob.



33353
33354
33355
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33353

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Pipeline creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


33184
33185
33186
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33184

def create_time
  @create_time
end

#display_nameString

The display name of the Pipeline. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


33190
33191
33192
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33190

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



33196
33197
33198
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33196

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Pipeline end time. Corresponds to the JSON property endTime

Returns:

  • (String)


33201
33202
33203
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33201

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



33211
33212
33213
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33211

def error
  @error
end

#job_detailGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJobDetail

The runtime detail of PipelineJob. Corresponds to the JSON property jobDetail



33216
33217
33218
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33216

def job_detail
  @job_detail
end

#labelsHash<String,String>

The labels with user-defined metadata to organize PipelineJob. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Note there is some reserved label key for Vertex AI Pipelines. - vertex-ai-pipelines-run-billing-id, user set value will get overrided. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


33227
33228
33229
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33227

def labels
  @labels
end

#nameString

Output only. The resource name of the PipelineJob. Corresponds to the JSON property name

Returns:

  • (String)


33232
33233
33234
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33232

def name
  @name
end

#networkString

The full name of the Compute Engine network to which the Pipeline Job's workload should be peered. For example, projects/12345/global/networks/myVPC. Format is of the form projects/project/global/ networks/network`. Whereprojectis a project number, as in12345, and networkis a network name. Private services access must already be configured for the network. Pipeline job will apply the network configuration to the Google Cloud resources being launched, if applied, such as Vertex AI Training or Dataflow job. If left unspecified, the workload is not peered with any network. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


33246
33247
33248
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33246

def network
  @network
end

#original_pipeline_job_idFixnum

Optional. The original pipeline job id if this pipeline job is a rerun of a previous pipeline job. Corresponds to the JSON property originalPipelineJobId

Returns:

  • (Fixnum)


33252
33253
33254
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33252

def original_pipeline_job_id
  @original_pipeline_job_id
end

#pipeline_specHash<String,Object>

A compiled definition of a pipeline, represented as a JSON object. Defines the structure of the pipeline, including its components, tasks, and parameters. This specification is generated by compiling a pipeline function defined in Python using the Kubeflow Pipelines SDK. Corresponds to the JSON property pipelineSpec

Returns:

  • (Hash<String,Object>)


33260
33261
33262
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33260

def pipeline_spec
  @pipeline_spec
end

#pipeline_task_rerun_configsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskRerunConfig>

Optional. The rerun configs for each task in the pipeline job. By default, the rerun will: 1. Use the same input artifacts as the original run. 2. Use the same input parameters as the original run. 3. Skip all the tasks that are already succeeded in the original run. 4. Rerun all the tasks that are not succeeded in the original run. By providing this field, users can override the default behavior and specify the rerun config for each task. Corresponds to the JSON property pipelineTaskRerunConfigs



33270
33271
33272
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33270

def pipeline_task_rerun_configs
  @pipeline_task_rerun_configs
end

#preflight_validationsBoolean Also known as: preflight_validations?

Optional. Whether to do component level validations before job creation. Corresponds to the JSON property preflightValidations

Returns:

  • (Boolean)


33275
33276
33277
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33275

def preflight_validations
  @preflight_validations
end

#psc_interface_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscInterfaceConfig

Configuration for PSC-I. Corresponds to the JSON property pscInterfaceConfig



33281
33282
33283
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33281

def psc_interface_config
  @psc_interface_config
end

#reserved_ip_rangesArray<String>

A list of names for the reserved ip ranges under the VPC network that can be used for this Pipeline Job's workload. If set, we will deploy the Pipeline Job' s workload within the provided ip ranges. Otherwise, the job will be deployed to any ip ranges under the provided VPC network. Example: ['vertex-ai-ip-range' ]. Corresponds to the JSON property reservedIpRanges

Returns:

  • (Array<String>)


33290
33291
33292
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33290

def reserved_ip_ranges
  @reserved_ip_ranges
end

#runtime_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineJobRuntimeConfig

The runtime config of a PipelineJob. Corresponds to the JSON property runtimeConfig



33295
33296
33297
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33295

def runtime_config
  @runtime_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


33300
33301
33302
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33300

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


33306
33307
33308
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33306

def satisfies_pzs
  @satisfies_pzs
end

#schedule_nameString

Output only. The schedule resource name. Only returned if the Pipeline is created by Schedule API. Corresponds to the JSON property scheduleName

Returns:

  • (String)


33313
33314
33315
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33313

def schedule_name
  @schedule_name
end

#service_accountString

The service account that the pipeline workload runs as. If not specified, the Compute Engine default service account in the project will be used. See https:/ /cloud.google.com/compute/docs/access/service-accounts#default_service_account Users starting the pipeline must have the iam.serviceAccounts.actAs permission on this service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


33322
33323
33324
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33322

def 
  @service_account
end

#start_timeString

Output only. Pipeline start time. Corresponds to the JSON property startTime

Returns:

  • (String)


33327
33328
33329
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33327

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


33332
33333
33334
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33332

def state
  @state
end

#template_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTemplateMetadata

Pipeline template metadata if PipelineJob.template_uri is from supported template registry. Currently, the only supported registry is Artifact Registry. Corresponds to the JSON property templateMetadata



33338
33339
33340
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33338

def 
  @template_metadata
end

#template_uriString

A template uri from where the PipelineJob.pipeline_spec, if empty, will be downloaded. Currently, only uri from Vertex Template Registry & Gallery is supported. Reference to https://cloud.google.com/vertex-ai/docs/pipelines/ create-pipeline-template. Corresponds to the JSON property templateUri

Returns:

  • (String)


33346
33347
33348
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33346

def template_uri
  @template_uri
end

#update_timeString

Output only. Timestamp when this PipelineJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


33351
33352
33353
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33351

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33358
33359
33360
33361
33362
33363
33364
33365
33366
33367
33368
33369
33370
33371
33372
33373
33374
33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33358

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @job_detail = args[:job_detail] if args.key?(:job_detail)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @original_pipeline_job_id = args[:original_pipeline_job_id] if args.key?(:original_pipeline_job_id)
  @pipeline_spec = args[:pipeline_spec] if args.key?(:pipeline_spec)
  @pipeline_task_rerun_configs = args[:pipeline_task_rerun_configs] if args.key?(:pipeline_task_rerun_configs)
  @preflight_validations = args[:preflight_validations] if args.key?(:preflight_validations)
  @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config)
  @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges)
  @runtime_config = args[:runtime_config] if args.key?(:runtime_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @schedule_name = args[:schedule_name] if args.key?(:schedule_name)
  @service_account = args[:service_account] if args.key?(:service_account)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @template_metadata = args[:template_metadata] if args.key?(:template_metadata)
  @template_uri = args[:template_uri] if args.key?(:template_uri)
  @update_time = args[:update_time] if args.key?(:update_time)
end