Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The runtime detail of a task execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PipelineTaskDetail

Returns a new instance of GoogleCloudAiplatformV1beta1PipelineTaskDetail.



40477
40478
40479
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Task create time. Corresponds to the JSON property createTime

Returns:

  • (String)


40397
40398
40399
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40397

def create_time
  @create_time
end

#end_timeString

Output only. Task end time. Corresponds to the JSON property endTime

Returns:

  • (String)


40402
40403
40404
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40402

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



40412
40413
40414
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40412

def error
  @error
end

#executionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Execution

Instance of a general execution. Corresponds to the JSON property execution



40417
40418
40419
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40417

def execution
  @execution
end

#executor_detailGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskExecutorDetail

The runtime detail of a pipeline executor. Corresponds to the JSON property executorDetail



40422
40423
40424
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40422

def executor_detail
  @executor_detail
end

#inputsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetailArtifactList>

Output only. The runtime input artifacts of the task. Corresponds to the JSON property inputs



40427
40428
40429
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40427

def inputs
  @inputs
end

#outputsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetailArtifactList>

Output only. The runtime output artifacts of the task. Corresponds to the JSON property outputs



40432
40433
40434
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40432

def outputs
  @outputs
end

#parent_task_idFixnum

Output only. The id of the parent task if the task is within a component scope. Empty if the task is at the root level. Corresponds to the JSON property parentTaskId

Returns:

  • (Fixnum)


40438
40439
40440
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40438

def parent_task_id
  @parent_task_id
end

#pipeline_task_statusArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetailPipelineTaskStatus>

Output only. A list of task status. This field keeps a record of task status evolving over time. Corresponds to the JSON property pipelineTaskStatus



40444
40445
40446
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40444

def pipeline_task_status
  @pipeline_task_status
end

#start_timeString

Output only. Task start time. Corresponds to the JSON property startTime

Returns:

  • (String)


40449
40450
40451
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40449

def start_time
  @start_time
end

#stateString

Output only. State of the task. Corresponds to the JSON property state

Returns:

  • (String)


40454
40455
40456
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40454

def state
  @state
end

#task_idFixnum

Output only. The system generated ID of the task. Corresponds to the JSON property taskId

Returns:

  • (Fixnum)


40459
40460
40461
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40459

def task_id
  @task_id
end

#task_nameString

Output only. The user specified name of the task that is defined in pipeline_spec. Corresponds to the JSON property taskName

Returns:

  • (String)


40465
40466
40467
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40465

def task_name
  @task_name
end

#task_unique_nameString

Output only. The unique name of a task. This field is used by rerun pipeline job. Console UI and Vertex AI SDK will support triggering pipeline job reruns. The name is constructed by concatenating all the parent tasks name with the task name. For example, if a task named "child_task" has a parent task named " parent_task_1" and parent task 1 has a parent task named "parent_task_2", the task unique name will be "parent_task_2.parent_task_1.child_task". Corresponds to the JSON property taskUniqueName

Returns:

  • (String)


40475
40476
40477
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40475

def task_unique_name
  @task_unique_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40482
40483
40484
40485
40486
40487
40488
40489
40490
40491
40492
40493
40494
40495
40496
40497
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40482

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @execution = args[:execution] if args.key?(:execution)
  @executor_detail = args[:executor_detail] if args.key?(:executor_detail)
  @inputs = args[:inputs] if args.key?(:inputs)
  @outputs = args[:outputs] if args.key?(:outputs)
  @parent_task_id = args[:parent_task_id] if args.key?(:parent_task_id)
  @pipeline_task_status = args[:pipeline_task_status] if args.key?(:pipeline_task_status)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @task_id = args[:task_id] if args.key?(:task_id)
  @task_name = args[:task_name] if args.key?(:task_name)
  @task_unique_name = args[:task_unique_name] if args.key?(:task_unique_name)
end