Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetail
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The runtime detail of a task execution.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#execution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Execution
Instance of a general execution.
-
#executor_detail ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskExecutorDetail
The runtime detail of a pipeline executor.
-
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetailArtifactList>
Output only.
-
#outputs ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetailArtifactList>
Output only.
-
#parent_task_id ⇒ Fixnum
Output only.
-
#pipeline_task_status ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetailPipelineTaskStatus>
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#task_id ⇒ Fixnum
Output only.
-
#task_name ⇒ String
Output only.
-
#task_unique_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PipelineTaskDetail
constructor
A new instance of GoogleCloudAiplatformV1beta1PipelineTaskDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PipelineTaskDetail
Returns a new instance of GoogleCloudAiplatformV1beta1PipelineTaskDetail.
39181 39182 39183 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39181 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Task create time.
Corresponds to the JSON property createTime
39101 39102 39103 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39101 def create_time @create_time end |
#end_time ⇒ String
Output only. Task end time.
Corresponds to the JSON property endTime
39106 39107 39108 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39106 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
39116 39117 39118 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39116 def error @error end |
#execution ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Execution
Instance of a general execution.
Corresponds to the JSON property execution
39121 39122 39123 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39121 def execution @execution end |
#executor_detail ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskExecutorDetail
The runtime detail of a pipeline executor.
Corresponds to the JSON property executorDetail
39126 39127 39128 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39126 def executor_detail @executor_detail end |
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetailArtifactList>
Output only. The runtime input artifacts of the task.
Corresponds to the JSON property inputs
39131 39132 39133 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39131 def inputs @inputs end |
#outputs ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetailArtifactList>
Output only. The runtime output artifacts of the task.
Corresponds to the JSON property outputs
39136 39137 39138 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39136 def outputs @outputs end |
#parent_task_id ⇒ Fixnum
Output only. The id of the parent task if the task is within a component scope.
Empty if the task is at the root level.
Corresponds to the JSON property parentTaskId
39142 39143 39144 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39142 def parent_task_id @parent_task_id end |
#pipeline_task_status ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetailPipelineTaskStatus>
Output only. A list of task status. This field keeps a record of task status
evolving over time.
Corresponds to the JSON property pipelineTaskStatus
39148 39149 39150 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39148 def pipeline_task_status @pipeline_task_status end |
#start_time ⇒ String
Output only. Task start time.
Corresponds to the JSON property startTime
39153 39154 39155 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39153 def start_time @start_time end |
#state ⇒ String
Output only. State of the task.
Corresponds to the JSON property state
39158 39159 39160 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39158 def state @state end |
#task_id ⇒ Fixnum
Output only. The system generated ID of the task.
Corresponds to the JSON property taskId
39163 39164 39165 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39163 def task_id @task_id end |
#task_name ⇒ String
Output only. The user specified name of the task that is defined in
pipeline_spec.
Corresponds to the JSON property taskName
39169 39170 39171 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39169 def task_name @task_name end |
#task_unique_name ⇒ String
Output only. The unique name of a task. This field is used by rerun pipeline
job. Console UI and Vertex AI SDK will support triggering pipeline job reruns.
The name is constructed by concatenating all the parent tasks name with the
task name. For example, if a task named "child_task" has a parent task named "
parent_task_1" and parent task 1 has a parent task named "parent_task_2", the
task unique name will be "parent_task_2.parent_task_1.child_task".
Corresponds to the JSON property taskUniqueName
39179 39180 39181 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39179 def task_unique_name @task_unique_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39186 39187 39188 39189 39190 39191 39192 39193 39194 39195 39196 39197 39198 39199 39200 39201 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39186 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @execution = args[:execution] if args.key?(:execution) @executor_detail = args[:executor_detail] if args.key?(:executor_detail) @inputs = args[:inputs] if args.key?(:inputs) @outputs = args[:outputs] if args.key?(:outputs) @parent_task_id = args[:parent_task_id] if args.key?(:parent_task_id) @pipeline_task_status = args[:pipeline_task_status] if args.key?(:pipeline_task_status) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @task_id = args[:task_id] if args.key?(:task_id) @task_name = args[:task_name] if args.key?(:task_name) @task_unique_name = args[:task_unique_name] if args.key?(:task_unique_name) end |