Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetailPipelineTaskStatus
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetailPipelineTaskStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A single record of the task status.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PipelineTaskDetailPipelineTaskStatus
constructor
A new instance of GoogleCloudAiplatformV1beta1PipelineTaskDetailPipelineTaskStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PipelineTaskDetailPipelineTaskStatus
Returns a new instance of GoogleCloudAiplatformV1beta1PipelineTaskDetailPipelineTaskStatus.
42395 42396 42397 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
42383 42384 42385 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42383 def error @error end |
#state ⇒ String
Output only. The state of the task.
Corresponds to the JSON property state
42388 42389 42390 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42388 def state @state end |
#update_time ⇒ String
Output only. Update time of this status.
Corresponds to the JSON property updateTime
42393 42394 42395 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42393 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42400 42401 42402 42403 42404 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42400 def update!(**args) @error = args[:error] if args.key?(:error) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |