Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskDetailPipelineTaskStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A single record of the task status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PipelineTaskDetailPipelineTaskStatus

Returns a new instance of GoogleCloudAiplatformV1beta1PipelineTaskDetailPipelineTaskStatus.



33785
33786
33787
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33785

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



33773
33774
33775
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33773

def error
  @error
end

#stateString

Output only. The state of the task. Corresponds to the JSON property state

Returns:

  • (String)


33778
33779
33780
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33778

def state
  @state
end

#update_timeString

Output only. Update time of this status. Corresponds to the JSON property updateTime

Returns:

  • (String)


33783
33784
33785
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33783

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33790
33791
33792
33793
33794
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 33790

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end