Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PipelineTaskExecutorDetailContainerDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The detail of a container execution. It contains the job names of the lifecycle of a container execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PipelineTaskExecutorDetailContainerDetail

Returns a new instance of GoogleCloudAiplatformV1beta1PipelineTaskExecutorDetailContainerDetail.



39317
39318
39319
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39317

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failed_main_jobsArray<String>

Output only. The names of the previously failed CustomJob for the main container executions. The list includes the all attempts in chronological order. Corresponds to the JSON property failedMainJobs

Returns:

  • (Array<String>)


39295
39296
39297
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39295

def failed_main_jobs
  @failed_main_jobs
end

#failed_pre_caching_check_jobsArray<String>

Output only. The names of the previously failed CustomJob for the pre-caching- check container executions. This job will be available if the PipelineJob. pipeline_spec specifies the pre_caching_check hook in the lifecycle events. The list includes the all attempts in chronological order. Corresponds to the JSON property failedPreCachingCheckJobs

Returns:

  • (Array<String>)


39303
39304
39305
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39303

def failed_pre_caching_check_jobs
  @failed_pre_caching_check_jobs
end

#main_jobString

Output only. The name of the CustomJob for the main container execution. Corresponds to the JSON property mainJob

Returns:

  • (String)


39308
39309
39310
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39308

def main_job
  @main_job
end

#pre_caching_check_jobString

Output only. The name of the CustomJob for the pre-caching-check container execution. This job will be available if the PipelineJob.pipeline_spec specifies the pre_caching_check hook in the lifecycle events. Corresponds to the JSON property preCachingCheckJob

Returns:

  • (String)


39315
39316
39317
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39315

def pre_caching_check_job
  @pre_caching_check_job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39322
39323
39324
39325
39326
39327
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39322

def update!(**args)
  @failed_main_jobs = args[:failed_main_jobs] if args.key?(:failed_main_jobs)
  @failed_pre_caching_check_jobs = args[:failed_pre_caching_check_jobs] if args.key?(:failed_pre_caching_check_jobs)
  @main_job = args[:main_job] if args.key?(:main_job)
  @pre_caching_check_job = args[:pre_caching_check_job] if args.key?(:pre_caching_check_job)
end