Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PostStartupScriptConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PostStartupScriptConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Post startup script config.
Instance Attribute Summary collapse
-
#post_startup_script ⇒ String
Optional.
-
#post_startup_script_behavior ⇒ String
Optional.
-
#post_startup_script_url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PostStartupScriptConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1PostStartupScriptConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PostStartupScriptConfig
Returns a new instance of GoogleCloudAiplatformV1beta1PostStartupScriptConfig.
43310 43311 43312 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43310 def initialize(**args) update!(**args) end |
Instance Attribute Details
#post_startup_script ⇒ String
Optional. Post startup script to run after runtime is started.
Corresponds to the JSON property postStartupScript
43297 43298 43299 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43297 def post_startup_script @post_startup_script end |
#post_startup_script_behavior ⇒ String
Optional. Post startup script behavior that defines download and execution
behavior.
Corresponds to the JSON property postStartupScriptBehavior
43303 43304 43305 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43303 def post_startup_script_behavior @post_startup_script_behavior end |
#post_startup_script_url ⇒ String
Optional. Post startup script url to download. Example: gs://bucket/script.sh
Corresponds to the JSON property postStartupScriptUrl
43308 43309 43310 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43308 def post_startup_script_url @post_startup_script_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43315 43316 43317 43318 43319 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43315 def update!(**args) @post_startup_script = args[:post_startup_script] if args.key?(:post_startup_script) @post_startup_script_behavior = args[:post_startup_script_behavior] if args.key?(:post_startup_script_behavior) @post_startup_script_url = args[:post_startup_script_url] if args.key?(:post_startup_script_url) end |