Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PostStartupScriptConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Post startup script config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PostStartupScriptConfig

Returns a new instance of GoogleCloudAiplatformV1beta1PostStartupScriptConfig.



39033
39034
39035
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#post_startup_scriptString

Optional. Post startup script to run after runtime is started. Corresponds to the JSON property postStartupScript

Returns:

  • (String)


39020
39021
39022
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39020

def post_startup_script
  @post_startup_script
end

#post_startup_script_behaviorString

Optional. Post startup script behavior that defines download and execution behavior. Corresponds to the JSON property postStartupScriptBehavior

Returns:

  • (String)


39026
39027
39028
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39026

def post_startup_script_behavior
  @post_startup_script_behavior
end

#post_startup_script_urlString

Optional. Post startup script url to download. Example: gs://bucket/script.sh Corresponds to the JSON property postStartupScriptUrl

Returns:

  • (String)


39031
39032
39033
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39031

def post_startup_script_url
  @post_startup_script_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39038
39039
39040
39041
39042
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39038

def update!(**args)
  @post_startup_script = args[:post_startup_script] if args.key?(:post_startup_script)
  @post_startup_script_behavior = args[:post_startup_script_behavior] if args.key?(:post_startup_script_behavior)
  @post_startup_script_url = args[:post_startup_script_url] if args.key?(:post_startup_script_url)
end