Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreTunedModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A pre-tuned model for continuous tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PreTunedModel

Returns a new instance of GoogleCloudAiplatformV1beta1PreTunedModel.



34130
34131
34132
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34130

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_modelString

Output only. The name of the base model this PreTunedModel was tuned from. Corresponds to the JSON property baseModel

Returns:

  • (String)


34113
34114
34115
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34113

def base_model
  @base_model
end

#checkpoint_idString

Optional. The source checkpoint id. If not specified, the default checkpoint will be used. Corresponds to the JSON property checkpointId

Returns:

  • (String)


34119
34120
34121
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34119

def checkpoint_id
  @checkpoint_id
end

#tuned_model_nameString

The resource name of the Model. E.g., a model resource name with a specified version id or alias: projects/project/locations/location/models/model@ version_id`projects/`project`/locations/`location`/models/`model`@`alias Or, omit the version id to use the default version: projects/project/ locations/location/models/model` Corresponds to the JSON propertytunedModelName`

Returns:

  • (String)


34128
34129
34130
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34128

def tuned_model_name
  @tuned_model_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34135
34136
34137
34138
34139
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34135

def update!(**args)
  @base_model = args[:base_model] if args.key?(:base_model)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @tuned_model_name = args[:tuned_model_name] if args.key?(:tuned_model_name)
end