Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictLongRunningRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for PredictionService.PredictLongRunning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PredictLongRunningRequest

Returns a new instance of GoogleCloudAiplatformV1beta1PredictLongRunningRequest.



39193
39194
39195
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Object>

Required. The instances that are the input to the prediction call. A DeployedModel may have an upper limit on the number of instances it supports per request, and when it is exceeded the prediction call errors in case of AutoML Models, or, in case of customer created Models, the behaviour is as documented by that Model. The schema of any single instance may be specified via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri. Corresponds to the JSON property instances

Returns:

  • (Array<Object>)


39175
39176
39177
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39175

def instances
  @instances
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata for the request. It is used for billing and reporting only. Label keys and values can be no longer than 63 characters (Unicode codepoints) and can only contain lowercase letters, numeric characters, underscores, and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


39184
39185
39186
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39184

def labels
  @labels
end

#parametersObject

Optional. The parameters that govern the prediction. The schema of the parameters may be specified via Endpoint's DeployedModels' Model's PredictSchemata's parameters_schema_uri. Corresponds to the JSON property parameters

Returns:

  • (Object)


39191
39192
39193
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39191

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39198
39199
39200
39201
39202
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39198

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @labels = args[:labels] if args.key?(:labels)
  @parameters = args[:parameters] if args.key?(:parameters)
end