Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for PredictionService.Predict.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PredictRequest

Returns a new instance of GoogleCloudAiplatformV1beta1PredictRequest.



43528
43529
43530
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43528

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Object>

Required. The instances that are the input to the prediction call. A DeployedModel may have an upper limit on the number of instances it supports per request, and when it is exceeded the prediction call errors in case of AutoML Models, or, in case of customer created Models, the behaviour is as documented by that Model. The schema of any single instance may be specified via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri. Corresponds to the JSON property instances

Returns:

  • (Array<Object>)


43513
43514
43515
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43513

def instances
  @instances
end

#labelsHash<String,String>

Optional. The user labels for Imagen billing usage only. Only Imagen supports labels. For other use cases, it will be ignored. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


43519
43520
43521
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43519

def labels
  @labels
end

#parametersObject

The parameters that govern the prediction. The schema of the parameters may be specified via Endpoint's DeployedModels' Model's PredictSchemata's parameters_schema_uri. Corresponds to the JSON property parameters

Returns:

  • (Object)


43526
43527
43528
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43526

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43533
43534
43535
43536
43537
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43533

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @labels = args[:labels] if args.key?(:labels)
  @parameters = args[:parameters] if args.key?(:parameters)
end