Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for PredictionService.Predict.
Instance Attribute Summary collapse
-
#instances ⇒ Array<Object>
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#parameters ⇒ Object
The parameters that govern the prediction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PredictRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1PredictRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PredictRequest
Returns a new instance of GoogleCloudAiplatformV1beta1PredictRequest.
39251 39252 39253 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39251 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Object>
Required. The instances that are the input to the prediction call. A
DeployedModel may have an upper limit on the number of instances it supports
per request, and when it is exceeded the prediction call errors in case of
AutoML Models, or, in case of customer created Models, the behaviour is as
documented by that Model. The schema of any single instance may be specified
via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri.
Corresponds to the JSON property instances
39236 39237 39238 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39236 def instances @instances end |
#labels ⇒ Hash<String,String>
Optional. The user labels for Imagen billing usage only. Only Imagen supports
labels. For other use cases, it will be ignored.
Corresponds to the JSON property labels
39242 39243 39244 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39242 def labels @labels end |
#parameters ⇒ Object
The parameters that govern the prediction. The schema of the parameters may be
specified via Endpoint's DeployedModels' Model's PredictSchemata's
parameters_schema_uri.
Corresponds to the JSON property parameters
39249 39250 39251 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39249 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39256 39257 39258 39259 39260 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39256 def update!(**args) @instances = args[:instances] if args.key?(:instances) @labels = args[:labels] if args.key?(:labels) @parameters = args[:parameters] if args.key?(:parameters) end |