Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictRequestResponseLoggingConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictRequestResponseLoggingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for logging request-response to a BigQuery table.
Instance Attribute Summary collapse
-
#bigquery_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryDestination
The BigQuery location for the output content.
-
#enable_otel_logging ⇒ Boolean
(also: #enable_otel_logging?)
This field is used for large models.
-
#enabled ⇒ Boolean
(also: #enabled?)
If logging is enabled or not.
-
#error_sampling_rate ⇒ Float
Optional.
-
#request_response_logging_schema_version ⇒ String
Output only.
-
#sampling_rate ⇒ Float
Percentage of requests to be logged, expressed as a fraction in range(0,1].
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PredictRequestResponseLoggingConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1PredictRequestResponseLoggingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PredictRequestResponseLoggingConfig
Returns a new instance of GoogleCloudAiplatformV1beta1PredictRequestResponseLoggingConfig.
39895 39896 39897 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39895 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1BigQueryDestination
The BigQuery location for the output content.
Corresponds to the JSON property bigqueryDestination
39860 39861 39862 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39860 def bigquery_destination @bigquery_destination end |
#enable_otel_logging ⇒ Boolean Also known as: enable_otel_logging?
This field is used for large models. If true, in addition to the original
large model logs, logs will be converted in OTel schema format, and saved in
otel_log column. Default value is false.
Corresponds to the JSON property enableOtelLogging
39867 39868 39869 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39867 def enable_otel_logging @enable_otel_logging end |
#enabled ⇒ Boolean Also known as: enabled?
If logging is enabled or not.
Corresponds to the JSON property enabled
39873 39874 39875 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39873 def enabled @enabled end |
#error_sampling_rate ⇒ Float
Optional. Percentage of failed requests to be logged, expressed as a fraction
in range [0,1]. Only non-transient errors will be logged (currently 500/
Internal errors).
Corresponds to the JSON property errorSamplingRate
39881 39882 39883 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39881 def error_sampling_rate @error_sampling_rate end |
#request_response_logging_schema_version ⇒ String
Output only. The schema version used in creating the BigQuery table for the
request response logging. The versions are "v1" and "v2". The current default
version is "v1".
Corresponds to the JSON property requestResponseLoggingSchemaVersion
39888 39889 39890 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39888 def request_response_logging_schema_version @request_response_logging_schema_version end |
#sampling_rate ⇒ Float
Percentage of requests to be logged, expressed as a fraction in range(0,1].
Corresponds to the JSON property samplingRate
39893 39894 39895 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39893 def sampling_rate @sampling_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39900 39901 39902 39903 39904 39905 39906 39907 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39900 def update!(**args) @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination) @enable_otel_logging = args[:enable_otel_logging] if args.key?(:enable_otel_logging) @enabled = args[:enabled] if args.key?(:enabled) @error_sampling_rate = args[:error_sampling_rate] if args.key?(:error_sampling_rate) @request_response_logging_schema_version = args[:request_response_logging_schema_version] if args.key?(:request_response_logging_schema_version) @sampling_rate = args[:sampling_rate] if args.key?(:sampling_rate) end |