Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for PredictionService.Predict.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PredictResponse

Returns a new instance of GoogleCloudAiplatformV1beta1PredictResponse.



41424
41425
41426
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41424

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_model_idString

ID of the Endpoint's DeployedModel that served this prediction. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


41391
41392
41393
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41391

def deployed_model_id
  @deployed_model_id
end

#metadataObject

Output only. Request-level metadata returned by the model. The metadata type will be dependent upon the model implementation. Corresponds to the JSON property metadata

Returns:

  • (Object)


41397
41398
41399
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41397

def 
  @metadata
end

#modelString

Output only. The resource name of the Model which is deployed as the DeployedModel that this prediction hits. Corresponds to the JSON property model

Returns:

  • (String)


41403
41404
41405
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41403

def model
  @model
end

#model_display_nameString

Output only. The display name of the Model which is deployed as the DeployedModel that this prediction hits. Corresponds to the JSON property modelDisplayName

Returns:

  • (String)


41409
41410
41411
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41409

def model_display_name
  @model_display_name
end

#model_version_idString

Output only. The version ID of the Model which is deployed as the DeployedModel that this prediction hits. Corresponds to the JSON property modelVersionId

Returns:

  • (String)


41415
41416
41417
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41415

def model_version_id
  @model_version_id
end

#predictionsArray<Object>

The predictions that are the output of the predictions call. The schema of any single prediction may be specified via Endpoint's DeployedModels' Model's PredictSchemata's prediction_schema_uri. Corresponds to the JSON property predictions

Returns:

  • (Array<Object>)


41422
41423
41424
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41422

def predictions
  @predictions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41429
41430
41431
41432
41433
41434
41435
41436
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41429

def update!(**args)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @model = args[:model] if args.key?(:model)
  @model_display_name = args[:model_display_name] if args.key?(:model_display_name)
  @model_version_id = args[:model_version_id] if args.key?(:model_version_id)
  @predictions = args[:predictions] if args.key?(:predictions)
end