Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreferenceOptimizationSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreferenceOptimizationSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Tuning Spec for Preference Optimization.
Instance Attribute Summary collapse
-
#export_last_checkpoint_only ⇒ Boolean
(also: #export_last_checkpoint_only?)
Optional.
-
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreferenceOptimizationHyperParameters
Hyperparameters for Preference Optimization.
-
#training_dataset_uri ⇒ String
Required.
-
#validation_dataset_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PreferenceOptimizationSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1PreferenceOptimizationSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PreferenceOptimizationSpec
Returns a new instance of GoogleCloudAiplatformV1beta1PreferenceOptimizationSpec.
41637 41638 41639 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_last_checkpoint_only ⇒ Boolean Also known as: export_last_checkpoint_only?
Optional. If set to true, disable intermediate checkpoints for Preference
Optimization and only the last checkpoint will be exported. Otherwise, enable
intermediate checkpoints for Preference Optimization. Default is false.
Corresponds to the JSON property exportLastCheckpointOnly
41617 41618 41619 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41617 def export_last_checkpoint_only @export_last_checkpoint_only end |
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreferenceOptimizationHyperParameters
Hyperparameters for Preference Optimization.
Corresponds to the JSON property hyperParameters
41623 41624 41625 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41623 def hyper_parameters @hyper_parameters end |
#training_dataset_uri ⇒ String
Required. Cloud Storage path to file containing training dataset for
preference optimization tuning. The dataset must be formatted as a JSONL file.
Corresponds to the JSON property trainingDatasetUri
41629 41630 41631 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41629 def training_dataset_uri @training_dataset_uri end |
#validation_dataset_uri ⇒ String
Optional. Cloud Storage path to file containing validation dataset for
preference optimization tuning. The dataset must be formatted as a JSONL file.
Corresponds to the JSON property validationDatasetUri
41635 41636 41637 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41635 def validation_dataset_uri @validation_dataset_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41642 41643 41644 41645 41646 41647 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41642 def update!(**args) @export_last_checkpoint_only = args[:export_last_checkpoint_only] if args.key?(:export_last_checkpoint_only) @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters) @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri) @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri) end |