Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreferenceOptimizationSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Tuning Spec for Preference Optimization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PreferenceOptimizationSpec

Returns a new instance of GoogleCloudAiplatformV1beta1PreferenceOptimizationSpec.



40163
40164
40165
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_last_checkpoint_onlyBoolean Also known as: export_last_checkpoint_only?

Optional. If set to true, disable intermediate checkpoints for Preference Optimization and only the last checkpoint will be exported. Otherwise, enable intermediate checkpoints for Preference Optimization. Default is false. Corresponds to the JSON property exportLastCheckpointOnly

Returns:

  • (Boolean)


40143
40144
40145
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40143

def export_last_checkpoint_only
  @export_last_checkpoint_only
end

#hyper_parametersGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreferenceOptimizationHyperParameters

Hyperparameters for Preference Optimization. Corresponds to the JSON property hyperParameters



40149
40150
40151
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40149

def hyper_parameters
  @hyper_parameters
end

#training_dataset_uriString

Required. Cloud Storage path to file containing training dataset for preference optimization tuning. The dataset must be formatted as a JSONL file. Corresponds to the JSON property trainingDatasetUri

Returns:

  • (String)


40155
40156
40157
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40155

def training_dataset_uri
  @training_dataset_uri
end

#validation_dataset_uriString

Optional. Cloud Storage path to file containing validation dataset for preference optimization tuning. The dataset must be formatted as a JSONL file. Corresponds to the JSON property validationDatasetUri

Returns:

  • (String)


40161
40162
40163
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40161

def validation_dataset_uri
  @validation_dataset_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40168
40169
40170
40171
40172
40173
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40168

def update!(**args)
  @export_last_checkpoint_only = args[:export_last_checkpoint_only] if args.key?(:export_last_checkpoint_only)
  @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters)
  @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri)
  @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri)
end