Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Presets
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Presets
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Preset configuration for example-based explanations
Instance Attribute Summary collapse
-
#modality ⇒ String
The modality of the uploaded model, which automatically configures the distance measurement and feature normalization for the underlying example index and queries.
-
#query ⇒ String
Preset option controlling parameters for speed-precision trade-off when querying for examples.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Presets
constructor
A new instance of GoogleCloudAiplatformV1beta1Presets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Presets
Returns a new instance of GoogleCloudAiplatformV1beta1Presets.
34732 34733 34734 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34732 def initialize(**args) update!(**args) end |
Instance Attribute Details
#modality ⇒ String
The modality of the uploaded model, which automatically configures the
distance measurement and feature normalization for the underlying example
index and queries. If your model does not precisely fit one of these types, it
is okay to choose the closest type.
Corresponds to the JSON property modality
34724 34725 34726 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34724 def modality @modality end |
#query ⇒ String
Preset option controlling parameters for speed-precision trade-off when
querying for examples. If omitted, defaults to PRECISE.
Corresponds to the JSON property query
34730 34731 34732 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34730 def query @query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34737 34738 34739 34740 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34737 def update!(**args) @modality = args[:modality] if args.key?(:modality) @query = args[:query] if args.key?(:query) end |