Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Presets

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Preset configuration for example-based explanations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Presets

Returns a new instance of GoogleCloudAiplatformV1beta1Presets.



34665
34666
34667
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modalityString

The modality of the uploaded model, which automatically configures the distance measurement and feature normalization for the underlying example index and queries. If your model does not precisely fit one of these types, it is okay to choose the closest type. Corresponds to the JSON property modality

Returns:

  • (String)


34657
34658
34659
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34657

def modality
  @modality
end

#queryString

Preset option controlling parameters for speed-precision trade-off when querying for examples. If omitted, defaults to PRECISE. Corresponds to the JSON property query

Returns:

  • (String)


34663
34664
34665
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34663

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34670
34671
34672
34673
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34670

def update!(**args)
  @modality = args[:modality] if args.key?(:modality)
  @query = args[:query] if args.key?(:query)
end