Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents configuration for private service connect.
Instance Attribute Summary collapse
-
#enable_private_service_connect ⇒ Boolean
(also: #enable_private_service_connect?)
Required.
-
#enable_secure_private_service_connect ⇒ Boolean
(also: #enable_secure_private_service_connect?)
Optional.
-
#project_allowlist ⇒ Array<String>
A list of Projects from which the forwarding rule will target the service attachment.
-
#psc_automation_configs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscAutomationConfig>
Optional.
-
#service_attachment ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig
Returns a new instance of GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig.
44155 44156 44157 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44155 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_private_service_connect ⇒ Boolean Also known as: enable_private_service_connect?
Required. If true, expose the IndexEndpoint via private service connect.
Corresponds to the JSON property enablePrivateServiceConnect
44125 44126 44127 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44125 def enable_private_service_connect @enable_private_service_connect end |
#enable_secure_private_service_connect ⇒ Boolean Also known as: enable_secure_private_service_connect?
Optional. If set to true, enable secure private service connect with IAM
authorization. Otherwise, private service connect will be done without
authorization. Note latency will be slightly increased if authorization is
enabled.
Corresponds to the JSON property enableSecurePrivateServiceConnect
44134 44135 44136 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44134 def enable_secure_private_service_connect @enable_secure_private_service_connect end |
#project_allowlist ⇒ Array<String>
A list of Projects from which the forwarding rule will target the service
attachment.
Corresponds to the JSON property projectAllowlist
44141 44142 44143 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44141 def project_allowlist @project_allowlist end |
#psc_automation_configs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscAutomationConfig>
Optional. List of projects and networks where the PSC endpoints will be
created. This field is used by Online Inference(Prediction) only.
Corresponds to the JSON property pscAutomationConfigs
44147 44148 44149 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44147 def psc_automation_configs @psc_automation_configs end |
#service_attachment ⇒ String
Output only. The name of the generated service attachment resource. This is
only populated if the endpoint is deployed with PrivateServiceConnect.
Corresponds to the JSON property serviceAttachment
44153 44154 44155 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44153 def @service_attachment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44160 44161 44162 44163 44164 44165 44166 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44160 def update!(**args) @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect) @enable_secure_private_service_connect = args[:enable_secure_private_service_connect] if args.key?(:enable_secure_private_service_connect) @project_allowlist = args[:project_allowlist] if args.key?(:project_allowlist) @psc_automation_configs = args[:psc_automation_configs] if args.key?(:psc_automation_configs) @service_attachment = args[:service_attachment] if args.key?(:service_attachment) end |