Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents configuration for private service connect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig

Returns a new instance of GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig.



43431
43432
43433
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_private_service_connectBoolean Also known as: enable_private_service_connect?

Required. If true, expose the IndexEndpoint via private service connect. Corresponds to the JSON property enablePrivateServiceConnect

Returns:

  • (Boolean)


43401
43402
43403
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43401

def enable_private_service_connect
  @enable_private_service_connect
end

#enable_secure_private_service_connectBoolean Also known as: enable_secure_private_service_connect?

Optional. If set to true, enable secure private service connect with IAM authorization. Otherwise, private service connect will be done without authorization. Note latency will be slightly increased if authorization is enabled. Corresponds to the JSON property enableSecurePrivateServiceConnect

Returns:

  • (Boolean)


43410
43411
43412
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43410

def enable_secure_private_service_connect
  @enable_secure_private_service_connect
end

#project_allowlistArray<String>

A list of Projects from which the forwarding rule will target the service attachment. Corresponds to the JSON property projectAllowlist

Returns:

  • (Array<String>)


43417
43418
43419
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43417

def project_allowlist
  @project_allowlist
end

#psc_automation_configsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscAutomationConfig>

Optional. List of projects and networks where the PSC endpoints will be created. This field is used by Online Inference(Prediction) only. Corresponds to the JSON property pscAutomationConfigs



43423
43424
43425
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43423

def psc_automation_configs
  @psc_automation_configs
end

#service_attachmentString

Output only. The name of the generated service attachment resource. This is only populated if the endpoint is deployed with PrivateServiceConnect. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


43429
43430
43431
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43429

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43436
43437
43438
43439
43440
43441
43442
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43436

def update!(**args)
  @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect)
  @enable_secure_private_service_connect = args[:enable_secure_private_service_connect] if args.key?(:enable_secure_private_service_connect)
  @project_allowlist = args[:project_allowlist] if args.key?(:project_allowlist)
  @psc_automation_configs = args[:psc_automation_configs] if args.key?(:psc_automation_configs)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end