Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents configuration for private service connect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig

Returns a new instance of GoogleCloudAiplatformV1beta1PrivateServiceConnectConfig.



34821
34822
34823
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34821

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_private_service_connectBoolean Also known as: enable_private_service_connect?

Required. If true, expose the IndexEndpoint via private service connect. Corresponds to the JSON property enablePrivateServiceConnect

Returns:

  • (Boolean)


34791
34792
34793
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34791

def enable_private_service_connect
  @enable_private_service_connect
end

#enable_secure_private_service_connectBoolean Also known as: enable_secure_private_service_connect?

Optional. If set to true, enable secure private service connect with IAM authorization. Otherwise, private service connect will be done without authorization. Note latency will be slightly increased if authorization is enabled. Corresponds to the JSON property enableSecurePrivateServiceConnect

Returns:

  • (Boolean)


34800
34801
34802
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34800

def enable_secure_private_service_connect
  @enable_secure_private_service_connect
end

#project_allowlistArray<String>

A list of Projects from which the forwarding rule will target the service attachment. Corresponds to the JSON property projectAllowlist

Returns:

  • (Array<String>)


34807
34808
34809
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34807

def project_allowlist
  @project_allowlist
end

#psc_automation_configsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscAutomationConfig>

Optional. List of projects and networks where the PSC endpoints will be created. This field is used by Online Inference(Prediction) only. Corresponds to the JSON property pscAutomationConfigs



34813
34814
34815
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34813

def psc_automation_configs
  @psc_automation_configs
end

#service_attachmentString

Output only. The name of the generated service attachment resource. This is only populated if the endpoint is deployed with PrivateServiceConnect. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


34819
34820
34821
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34819

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34826
34827
34828
34829
34830
34831
34832
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34826

def update!(**args)
  @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect)
  @enable_secure_private_service_connect = args[:enable_secure_private_service_connect] if args.key?(:enable_secure_private_service_connect)
  @project_allowlist = args[:project_allowlist] if args.key?(:project_allowlist)
  @psc_automation_configs = args[:psc_automation_configs] if args.key?(:psc_automation_configs)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end