Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Probe
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Probe
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
Instance Attribute Summary collapse
-
#exec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeExecAction
ExecAction specifies a command to execute.
-
#failure_threshold ⇒ Fixnum
Number of consecutive failures before the probe is considered failed.
-
#grpc ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeGrpcAction
GrpcAction checks the health of a container using a gRPC service.
-
#http_get ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpGetAction
HttpGetAction describes an action based on HTTP Get requests.
-
#initial_delay_seconds ⇒ Fixnum
Number of seconds to wait before starting the probe.
-
#period_seconds ⇒ Fixnum
How often (in seconds) to perform the probe.
-
#success_threshold ⇒ Fixnum
Number of consecutive successes before the probe is considered successful.
-
#tcp_socket ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeTcpSocketAction
TcpSocketAction probes the health of a container by opening a TCP socket connection.
-
#timeout_seconds ⇒ Fixnum
Number of seconds after which the probe times out.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Probe
constructor
A new instance of GoogleCloudAiplatformV1beta1Probe.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Probe
Returns a new instance of GoogleCloudAiplatformV1beta1Probe.
44043 44044 44045 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44043 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeExecAction
ExecAction specifies a command to execute.
Corresponds to the JSON property exec
43992 43993 43994 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43992 def exec @exec end |
#failure_threshold ⇒ Fixnum
Number of consecutive failures before the probe is considered failed. Defaults
to 3. Minimum value is 1. Maps to Kubernetes probe argument 'failureThreshold'.
Corresponds to the JSON property failureThreshold
43998 43999 44000 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43998 def failure_threshold @failure_threshold end |
#grpc ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeGrpcAction
GrpcAction checks the health of a container using a gRPC service.
Corresponds to the JSON property grpc
44003 44004 44005 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44003 def grpc @grpc end |
#http_get ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpGetAction
HttpGetAction describes an action based on HTTP Get requests.
Corresponds to the JSON property httpGet
44008 44009 44010 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44008 def http_get @http_get end |
#initial_delay_seconds ⇒ Fixnum
Number of seconds to wait before starting the probe. Defaults to 0. Minimum
value is 0. Maps to Kubernetes probe argument 'initialDelaySeconds'.
Corresponds to the JSON property initialDelaySeconds
44014 44015 44016 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44014 def initial_delay_seconds @initial_delay_seconds end |
#period_seconds ⇒ Fixnum
How often (in seconds) to perform the probe. Default to 10 seconds. Minimum
value is 1. Must be less than timeout_seconds. Maps to Kubernetes probe
argument 'periodSeconds'.
Corresponds to the JSON property periodSeconds
44021 44022 44023 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44021 def period_seconds @period_seconds end |
#success_threshold ⇒ Fixnum
Number of consecutive successes before the probe is considered successful.
Defaults to 1. Minimum value is 1. Maps to Kubernetes probe argument '
successThreshold'.
Corresponds to the JSON property successThreshold
44028 44029 44030 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44028 def success_threshold @success_threshold end |
#tcp_socket ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeTcpSocketAction
TcpSocketAction probes the health of a container by opening a TCP socket
connection.
Corresponds to the JSON property tcpSocket
44034 44035 44036 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44034 def tcp_socket @tcp_socket end |
#timeout_seconds ⇒ Fixnum
Number of seconds after which the probe times out. Defaults to 1 second.
Minimum value is 1. Must be greater or equal to period_seconds. Maps to
Kubernetes probe argument 'timeoutSeconds'.
Corresponds to the JSON property timeoutSeconds
44041 44042 44043 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44041 def timeout_seconds @timeout_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44048 44049 44050 44051 44052 44053 44054 44055 44056 44057 44058 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44048 def update!(**args) @exec = args[:exec] if args.key?(:exec) @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold) @grpc = args[:grpc] if args.key?(:grpc) @http_get = args[:http_get] if args.key?(:http_get) @initial_delay_seconds = args[:initial_delay_seconds] if args.key?(:initial_delay_seconds) @period_seconds = args[:period_seconds] if args.key?(:period_seconds) @success_threshold = args[:success_threshold] if args.key?(:success_threshold) @tcp_socket = args[:tcp_socket] if args.key?(:tcp_socket) @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds) end |