Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Probe

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Probe

Returns a new instance of GoogleCloudAiplatformV1beta1Probe.



41652
41653
41654
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#execGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeExecAction

ExecAction specifies a command to execute. Corresponds to the JSON property exec



41601
41602
41603
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41601

def exec
  @exec
end

#failure_thresholdFixnum

Number of consecutive failures before the probe is considered failed. Defaults to 3. Minimum value is 1. Maps to Kubernetes probe argument 'failureThreshold'. Corresponds to the JSON property failureThreshold

Returns:

  • (Fixnum)


41607
41608
41609
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41607

def failure_threshold
  @failure_threshold
end

#grpcGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeGrpcAction

GrpcAction checks the health of a container using a gRPC service. Corresponds to the JSON property grpc



41612
41613
41614
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41612

def grpc
  @grpc
end

#http_getGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpGetAction

HttpGetAction describes an action based on HTTP Get requests. Corresponds to the JSON property httpGet



41617
41618
41619
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41617

def http_get
  @http_get
end

#initial_delay_secondsFixnum

Number of seconds to wait before starting the probe. Defaults to 0. Minimum value is 0. Maps to Kubernetes probe argument 'initialDelaySeconds'. Corresponds to the JSON property initialDelaySeconds

Returns:

  • (Fixnum)


41623
41624
41625
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41623

def initial_delay_seconds
  @initial_delay_seconds
end

#period_secondsFixnum

How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1. Must be less than timeout_seconds. Maps to Kubernetes probe argument 'periodSeconds'. Corresponds to the JSON property periodSeconds

Returns:

  • (Fixnum)


41630
41631
41632
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41630

def period_seconds
  @period_seconds
end

#success_thresholdFixnum

Number of consecutive successes before the probe is considered successful. Defaults to 1. Minimum value is 1. Maps to Kubernetes probe argument ' successThreshold'. Corresponds to the JSON property successThreshold

Returns:

  • (Fixnum)


41637
41638
41639
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41637

def success_threshold
  @success_threshold
end

#tcp_socketGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeTcpSocketAction

TcpSocketAction probes the health of a container by opening a TCP socket connection. Corresponds to the JSON property tcpSocket



41643
41644
41645
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41643

def tcp_socket
  @tcp_socket
end

#timeout_secondsFixnum

Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. Must be greater or equal to period_seconds. Maps to Kubernetes probe argument 'timeoutSeconds'. Corresponds to the JSON property timeoutSeconds

Returns:

  • (Fixnum)


41650
41651
41652
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41650

def timeout_seconds
  @timeout_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41657
41658
41659
41660
41661
41662
41663
41664
41665
41666
41667
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41657

def update!(**args)
  @exec = args[:exec] if args.key?(:exec)
  @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold)
  @grpc = args[:grpc] if args.key?(:grpc)
  @http_get = args[:http_get] if args.key?(:http_get)
  @initial_delay_seconds = args[:initial_delay_seconds] if args.key?(:initial_delay_seconds)
  @period_seconds = args[:period_seconds] if args.key?(:period_seconds)
  @success_threshold = args[:success_threshold] if args.key?(:success_threshold)
  @tcp_socket = args[:tcp_socket] if args.key?(:tcp_socket)
  @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds)
end