Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Probe

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Probe

Returns a new instance of GoogleCloudAiplatformV1beta1Probe.



39766
39767
39768
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#execGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeExecAction

ExecAction specifies a command to execute. Corresponds to the JSON property exec



39715
39716
39717
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39715

def exec
  @exec
end

#failure_thresholdFixnum

Number of consecutive failures before the probe is considered failed. Defaults to 3. Minimum value is 1. Maps to Kubernetes probe argument 'failureThreshold'. Corresponds to the JSON property failureThreshold

Returns:

  • (Fixnum)


39721
39722
39723
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39721

def failure_threshold
  @failure_threshold
end

#grpcGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeGrpcAction

GrpcAction checks the health of a container using a gRPC service. Corresponds to the JSON property grpc



39726
39727
39728
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39726

def grpc
  @grpc
end

#http_getGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpGetAction

HttpGetAction describes an action based on HTTP Get requests. Corresponds to the JSON property httpGet



39731
39732
39733
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39731

def http_get
  @http_get
end

#initial_delay_secondsFixnum

Number of seconds to wait before starting the probe. Defaults to 0. Minimum value is 0. Maps to Kubernetes probe argument 'initialDelaySeconds'. Corresponds to the JSON property initialDelaySeconds

Returns:

  • (Fixnum)


39737
39738
39739
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39737

def initial_delay_seconds
  @initial_delay_seconds
end

#period_secondsFixnum

How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1. Must be less than timeout_seconds. Maps to Kubernetes probe argument 'periodSeconds'. Corresponds to the JSON property periodSeconds

Returns:

  • (Fixnum)


39744
39745
39746
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39744

def period_seconds
  @period_seconds
end

#success_thresholdFixnum

Number of consecutive successes before the probe is considered successful. Defaults to 1. Minimum value is 1. Maps to Kubernetes probe argument ' successThreshold'. Corresponds to the JSON property successThreshold

Returns:

  • (Fixnum)


39751
39752
39753
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39751

def success_threshold
  @success_threshold
end

#tcp_socketGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeTcpSocketAction

TcpSocketAction probes the health of a container by opening a TCP socket connection. Corresponds to the JSON property tcpSocket



39757
39758
39759
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39757

def tcp_socket
  @tcp_socket
end

#timeout_secondsFixnum

Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. Must be greater or equal to period_seconds. Maps to Kubernetes probe argument 'timeoutSeconds'. Corresponds to the JSON property timeoutSeconds

Returns:

  • (Fixnum)


39764
39765
39766
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39764

def timeout_seconds
  @timeout_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39771
39772
39773
39774
39775
39776
39777
39778
39779
39780
39781
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39771

def update!(**args)
  @exec = args[:exec] if args.key?(:exec)
  @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold)
  @grpc = args[:grpc] if args.key?(:grpc)
  @http_get = args[:http_get] if args.key?(:http_get)
  @initial_delay_seconds = args[:initial_delay_seconds] if args.key?(:initial_delay_seconds)
  @period_seconds = args[:period_seconds] if args.key?(:period_seconds)
  @success_threshold = args[:success_threshold] if args.key?(:success_threshold)
  @tcp_socket = args[:tcp_socket] if args.key?(:tcp_socket)
  @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds)
end