Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Probe

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Probe

Returns a new instance of GoogleCloudAiplatformV1beta1Probe.



34894
34895
34896
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#execGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeExecAction

ExecAction specifies a command to execute. Corresponds to the JSON property exec



34843
34844
34845
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34843

def exec
  @exec
end

#failure_thresholdFixnum

Number of consecutive failures before the probe is considered failed. Defaults to 3. Minimum value is 1. Maps to Kubernetes probe argument 'failureThreshold'. Corresponds to the JSON property failureThreshold

Returns:

  • (Fixnum)


34849
34850
34851
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34849

def failure_threshold
  @failure_threshold
end

#grpcGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeGrpcAction

GrpcAction checks the health of a container using a gRPC service. Corresponds to the JSON property grpc



34854
34855
34856
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34854

def grpc
  @grpc
end

#http_getGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpGetAction

HttpGetAction describes an action based on HTTP Get requests. Corresponds to the JSON property httpGet



34859
34860
34861
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34859

def http_get
  @http_get
end

#initial_delay_secondsFixnum

Number of seconds to wait before starting the probe. Defaults to 0. Minimum value is 0. Maps to Kubernetes probe argument 'initialDelaySeconds'. Corresponds to the JSON property initialDelaySeconds

Returns:

  • (Fixnum)


34865
34866
34867
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34865

def initial_delay_seconds
  @initial_delay_seconds
end

#period_secondsFixnum

How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1. Must be less than timeout_seconds. Maps to Kubernetes probe argument 'periodSeconds'. Corresponds to the JSON property periodSeconds

Returns:

  • (Fixnum)


34872
34873
34874
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34872

def period_seconds
  @period_seconds
end

#success_thresholdFixnum

Number of consecutive successes before the probe is considered successful. Defaults to 1. Minimum value is 1. Maps to Kubernetes probe argument ' successThreshold'. Corresponds to the JSON property successThreshold

Returns:

  • (Fixnum)


34879
34880
34881
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34879

def success_threshold
  @success_threshold
end

#tcp_socketGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeTcpSocketAction

TcpSocketAction probes the health of a container by opening a TCP socket connection. Corresponds to the JSON property tcpSocket



34885
34886
34887
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34885

def tcp_socket
  @tcp_socket
end

#timeout_secondsFixnum

Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. Must be greater or equal to period_seconds. Maps to Kubernetes probe argument 'timeoutSeconds'. Corresponds to the JSON property timeoutSeconds

Returns:

  • (Fixnum)


34892
34893
34894
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34892

def timeout_seconds
  @timeout_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34899
34900
34901
34902
34903
34904
34905
34906
34907
34908
34909
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34899

def update!(**args)
  @exec = args[:exec] if args.key?(:exec)
  @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold)
  @grpc = args[:grpc] if args.key?(:grpc)
  @http_get = args[:http_get] if args.key?(:http_get)
  @initial_delay_seconds = args[:initial_delay_seconds] if args.key?(:initial_delay_seconds)
  @period_seconds = args[:period_seconds] if args.key?(:period_seconds)
  @success_threshold = args[:success_threshold] if args.key?(:success_threshold)
  @tcp_socket = args[:tcp_socket] if args.key?(:tcp_socket)
  @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds)
end