Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeGrpcAction
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeGrpcAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
GrpcAction checks the health of a container using a gRPC service.
Instance Attribute Summary collapse
-
#port ⇒ Fixnum
Port number of the gRPC service.
-
#service ⇒ String
Service is the name of the service to place in the gRPC HealthCheckRequest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeGrpcAction
constructor
A new instance of GoogleCloudAiplatformV1beta1ProbeGrpcAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeGrpcAction
Returns a new instance of GoogleCloudAiplatformV1beta1ProbeGrpcAction.
34952 34953 34954 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34952 def initialize(**args) update!(**args) end |
Instance Attribute Details
#port ⇒ Fixnum
Port number of the gRPC service. Number must be in the range 1 to 65535.
Corresponds to the JSON property port
34943 34944 34945 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34943 def port @port end |
#service ⇒ String
Service is the name of the service to place in the gRPC HealthCheckRequest.
See https://github.com/grpc/grpc/blob/master/doc/health-checking.md. If this
is not specified, the default behavior is defined by gRPC.
Corresponds to the JSON property service
34950 34951 34952 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34950 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34957 34958 34959 34960 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34957 def update!(**args) @port = args[:port] if args.key?(:port) @service = args[:service] if args.key?(:service) end |