Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeGrpcAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

GrpcAction checks the health of a container using a gRPC service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeGrpcAction

Returns a new instance of GoogleCloudAiplatformV1beta1ProbeGrpcAction.



34885
34886
34887
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#portFixnum

Port number of the gRPC service. Number must be in the range 1 to 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


34876
34877
34878
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34876

def port
  @port
end

#serviceString

Service is the name of the service to place in the gRPC HealthCheckRequest. See https://github.com/grpc/grpc/blob/master/doc/health-checking.md. If this is not specified, the default behavior is defined by gRPC. Corresponds to the JSON property service

Returns:

  • (String)


34883
34884
34885
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34883

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34890
34891
34892
34893
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34890

def update!(**args)
  @port = args[:port] if args.key?(:port)
  @service = args[:service] if args.key?(:service)
end