Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpGetAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

HttpGetAction describes an action based on HTTP Get requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeHttpGetAction

Returns a new instance of GoogleCloudAiplatformV1beta1ProbeHttpGetAction.



43605
43606
43607
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43605

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

Host name to connect to, defaults to the model serving container's IP. You probably want to set "Host" in httpHeaders instead. Corresponds to the JSON property host

Returns:

  • (String)


43581
43582
43583
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43581

def host
  @host
end

#http_headersArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpHeader>

Custom headers to set in the request. HTTP allows repeated headers. Corresponds to the JSON property httpHeaders



43586
43587
43588
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43586

def http_headers
  @http_headers
end

#pathString

Path to access on the HTTP server. Corresponds to the JSON property path

Returns:

  • (String)


43591
43592
43593
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43591

def path
  @path
end

#portFixnum

Number of the port to access on the container. Number must be in the range 1 to 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


43597
43598
43599
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43597

def port
  @port
end

#schemeString

Scheme to use for connecting to the host. Defaults to HTTP. Acceptable values are "HTTP" or "HTTPS". Corresponds to the JSON property scheme

Returns:

  • (String)


43603
43604
43605
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43603

def scheme
  @scheme
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43610
43611
43612
43613
43614
43615
43616
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43610

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @http_headers = args[:http_headers] if args.key?(:http_headers)
  @path = args[:path] if args.key?(:path)
  @port = args[:port] if args.key?(:port)
  @scheme = args[:scheme] if args.key?(:scheme)
end