Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpGetAction
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpGetAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
HttpGetAction describes an action based on HTTP Get requests.
Instance Attribute Summary collapse
-
#host ⇒ String
Host name to connect to, defaults to the model serving container's IP.
-
#http_headers ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpHeader>
Custom headers to set in the request.
-
#path ⇒ String
Path to access on the HTTP server.
-
#port ⇒ Fixnum
Number of the port to access on the container.
-
#scheme ⇒ String
Scheme to use for connecting to the host.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeHttpGetAction
constructor
A new instance of GoogleCloudAiplatformV1beta1ProbeHttpGetAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeHttpGetAction
Returns a new instance of GoogleCloudAiplatformV1beta1ProbeHttpGetAction.
41753 41754 41755 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41753 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
Host name to connect to, defaults to the model serving container's IP. You
probably want to set "Host" in httpHeaders instead.
Corresponds to the JSON property host
41729 41730 41731 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41729 def host @host end |
#http_headers ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpHeader>
Custom headers to set in the request. HTTP allows repeated headers.
Corresponds to the JSON property httpHeaders
41734 41735 41736 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41734 def http_headers @http_headers end |
#path ⇒ String
Path to access on the HTTP server.
Corresponds to the JSON property path
41739 41740 41741 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41739 def path @path end |
#port ⇒ Fixnum
Number of the port to access on the container. Number must be in the range 1
to 65535.
Corresponds to the JSON property port
41745 41746 41747 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41745 def port @port end |
#scheme ⇒ String
Scheme to use for connecting to the host. Defaults to HTTP. Acceptable values
are "HTTP" or "HTTPS".
Corresponds to the JSON property scheme
41751 41752 41753 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41751 def scheme @scheme end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41758 41759 41760 41761 41762 41763 41764 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41758 def update!(**args) @host = args[:host] if args.key?(:host) @http_headers = args[:http_headers] if args.key?(:http_headers) @path = args[:path] if args.key?(:path) @port = args[:port] if args.key?(:port) @scheme = args[:scheme] if args.key?(:scheme) end |