Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpGetAction
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpGetAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
HttpGetAction describes an action based on HTTP Get requests.
Instance Attribute Summary collapse
-
#host ⇒ String
Host name to connect to, defaults to the model serving container's IP.
-
#http_headers ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpHeader>
Custom headers to set in the request.
-
#path ⇒ String
Path to access on the HTTP server.
-
#port ⇒ Fixnum
Number of the port to access on the container.
-
#scheme ⇒ String
Scheme to use for connecting to the host.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeHttpGetAction
constructor
A new instance of GoogleCloudAiplatformV1beta1ProbeHttpGetAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeHttpGetAction
Returns a new instance of GoogleCloudAiplatformV1beta1ProbeHttpGetAction.
39867 39868 39869 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
Host name to connect to, defaults to the model serving container's IP. You
probably want to set "Host" in httpHeaders instead.
Corresponds to the JSON property host
39843 39844 39845 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39843 def host @host end |
#http_headers ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpHeader>
Custom headers to set in the request. HTTP allows repeated headers.
Corresponds to the JSON property httpHeaders
39848 39849 39850 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39848 def http_headers @http_headers end |
#path ⇒ String
Path to access on the HTTP server.
Corresponds to the JSON property path
39853 39854 39855 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39853 def path @path end |
#port ⇒ Fixnum
Number of the port to access on the container. Number must be in the range 1
to 65535.
Corresponds to the JSON property port
39859 39860 39861 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39859 def port @port end |
#scheme ⇒ String
Scheme to use for connecting to the host. Defaults to HTTP. Acceptable values
are "HTTP" or "HTTPS".
Corresponds to the JSON property scheme
39865 39866 39867 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39865 def scheme @scheme end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39872 39873 39874 39875 39876 39877 39878 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39872 def update!(**args) @host = args[:host] if args.key?(:host) @http_headers = args[:http_headers] if args.key?(:http_headers) @path = args[:path] if args.key?(:path) @port = args[:port] if args.key?(:port) @scheme = args[:scheme] if args.key?(:scheme) end |