Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpGetAction
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpGetAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
HttpGetAction describes an action based on HTTP Get requests.
Instance Attribute Summary collapse
-
#host ⇒ String
Host name to connect to, defaults to the model serving container's IP.
-
#http_headers ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpHeader>
Custom headers to set in the request.
-
#path ⇒ String
Path to access on the HTTP server.
-
#port ⇒ Fixnum
Number of the port to access on the container.
-
#scheme ⇒ String
Scheme to use for connecting to the host.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeHttpGetAction
constructor
A new instance of GoogleCloudAiplatformV1beta1ProbeHttpGetAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeHttpGetAction
Returns a new instance of GoogleCloudAiplatformV1beta1ProbeHttpGetAction.
34928 34929 34930 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34928 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
Host name to connect to, defaults to the model serving container's IP. You
probably want to set "Host" in httpHeaders instead.
Corresponds to the JSON property host
34904 34905 34906 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34904 def host @host end |
#http_headers ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpHeader>
Custom headers to set in the request. HTTP allows repeated headers.
Corresponds to the JSON property httpHeaders
34909 34910 34911 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34909 def http_headers @http_headers end |
#path ⇒ String
Path to access on the HTTP server.
Corresponds to the JSON property path
34914 34915 34916 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34914 def path @path end |
#port ⇒ Fixnum
Number of the port to access on the container. Number must be in the range 1
to 65535.
Corresponds to the JSON property port
34920 34921 34922 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34920 def port @port end |
#scheme ⇒ String
Scheme to use for connecting to the host. Defaults to HTTP. Acceptable values
are "HTTP" or "HTTPS".
Corresponds to the JSON property scheme
34926 34927 34928 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34926 def scheme @scheme end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34933 34934 34935 34936 34937 34938 34939 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34933 def update!(**args) @host = args[:host] if args.key?(:host) @http_headers = args[:http_headers] if args.key?(:http_headers) @path = args[:path] if args.key?(:path) @port = args[:port] if args.key?(:port) @scheme = args[:scheme] if args.key?(:scheme) end |