Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpHeader

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

HttpHeader describes a custom header to be used in HTTP probes

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeHttpHeader

Returns a new instance of GoogleCloudAiplatformV1beta1ProbeHttpHeader.



41782
41783
41784
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The header field name. This will be canonicalized upon output, so case-variant names will be understood as the same header. Corresponds to the JSON property name

Returns:

  • (String)


41775
41776
41777
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41775

def name
  @name
end

#valueString

The header field value Corresponds to the JSON property value

Returns:

  • (String)


41780
41781
41782
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41780

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41787
41788
41789
41790
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41787

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end