Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProbeHttpHeader

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

HttpHeader describes a custom header to be used in HTTP probes

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProbeHttpHeader

Returns a new instance of GoogleCloudAiplatformV1beta1ProbeHttpHeader.



34957
34958
34959
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The header field name. This will be canonicalized upon output, so case-variant names will be understood as the same header. Corresponds to the JSON property name

Returns:

  • (String)


34950
34951
34952
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34950

def name
  @name
end

#valueString

The header field value Corresponds to the JSON property value

Returns:

  • (String)


34955
34956
34957
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34955

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34962
34963
34964
34965
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 34962

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end