Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProcessDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProcessDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for GenAiTuningService.ProcessData.
Instance Attribute Summary collapse
-
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource
The Google Cloud Storage location for the input content.
-
#input_bucket_project_number ⇒ Fixnum
Optional.
-
#output_bucket_project_number ⇒ Fixnum
Optional.
-
#veo_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProcessDataRequestVeoSpec
Spec for Veo data processing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProcessDataRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1ProcessDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProcessDataRequest
Returns a new instance of GoogleCloudAiplatformV1beta1ProcessDataRequest.
44249 44250 44251 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44249 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcsDestination
44219 44220 44221 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44219 def gcs_destination @gcs_destination end |
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
44224 44225 44226 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44224 def gcs_source @gcs_source end |
#input_bucket_project_number ⇒ Fixnum
Optional. The project number of the project that the user expects to own the
input Cloud Storage bucket referenced by gcs_source. The service verifies that
the bucket is actually owned by this project before reading from it, in order
to prevent bucket squatting. If unset, the bucket is verified to be owned by
the project the request is made for (parent).
Corresponds to the JSON property inputBucketProjectNumber
44233 44234 44235 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44233 def input_bucket_project_number @input_bucket_project_number end |
#output_bucket_project_number ⇒ Fixnum
Optional. The project number of the project that the user expects to own the
output Cloud Storage bucket referenced by gcs_destination. The service
verifies that the bucket is actually owned by this project before writing to
it, in order to prevent bucket squatting. If unset, the bucket is verified to
be owned by the project the request is made for (parent).
Corresponds to the JSON property outputBucketProjectNumber
44242 44243 44244 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44242 def output_bucket_project_number @output_bucket_project_number end |
#veo_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProcessDataRequestVeoSpec
Spec for Veo data processing.
Corresponds to the JSON property veoSpec
44247 44248 44249 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44247 def veo_spec @veo_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44254 44255 44256 44257 44258 44259 44260 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44254 def update!(**args) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @input_bucket_project_number = args[:input_bucket_project_number] if args.key?(:input_bucket_project_number) @output_bucket_project_number = args[:output_bucket_project_number] if args.key?(:output_bucket_project_number) @veo_spec = args[:veo_spec] if args.key?(:veo_spec) end |