Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProcessDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProcessDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for GenAiTuningService.ProcessData.
Instance Attribute Summary collapse
-
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource
The Google Cloud Storage location for the input content.
-
#input_bucket_project_number ⇒ Fixnum
Optional.
-
#output_bucket_project_number ⇒ Fixnum
Optional.
-
#veo_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProcessDataRequestVeoSpec
Spec for Veo data processing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProcessDataRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1ProcessDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProcessDataRequest
Returns a new instance of GoogleCloudAiplatformV1beta1ProcessDataRequest.
43710 43711 43712 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43710 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcsDestination
43680 43681 43682 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43680 def gcs_destination @gcs_destination end |
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
43685 43686 43687 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43685 def gcs_source @gcs_source end |
#input_bucket_project_number ⇒ Fixnum
Optional. The project number of the project that the user expects to own the
input Cloud Storage bucket referenced by gcs_source. The service verifies that
the bucket is actually owned by this project before reading from it, in order
to prevent bucket squatting. If unset, the bucket is verified to be owned by
the project the request is made for (parent).
Corresponds to the JSON property inputBucketProjectNumber
43694 43695 43696 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43694 def input_bucket_project_number @input_bucket_project_number end |
#output_bucket_project_number ⇒ Fixnum
Optional. The project number of the project that the user expects to own the
output Cloud Storage bucket referenced by gcs_destination. The service
verifies that the bucket is actually owned by this project before writing to
it, in order to prevent bucket squatting. If unset, the bucket is verified to
be owned by the project the request is made for (parent).
Corresponds to the JSON property outputBucketProjectNumber
43703 43704 43705 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43703 def output_bucket_project_number @output_bucket_project_number end |
#veo_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProcessDataRequestVeoSpec
Spec for Veo data processing.
Corresponds to the JSON property veoSpec
43708 43709 43710 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43708 def veo_spec @veo_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43715 43716 43717 43718 43719 43720 43721 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43715 def update!(**args) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @input_bucket_project_number = args[:input_bucket_project_number] if args.key?(:input_bucket_project_number) @output_bucket_project_number = args[:output_bucket_project_number] if args.key?(:output_bucket_project_number) @veo_spec = args[:veo_spec] if args.key?(:veo_spec) end |