Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProcessDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for GenAiTuningService.ProcessData.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProcessDataRequest

Returns a new instance of GoogleCloudAiplatformV1beta1ProcessDataRequest.



42544
42545
42546
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcsDestination



42514
42515
42516
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42514

def gcs_destination
  @gcs_destination
end

#gcs_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



42519
42520
42521
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42519

def gcs_source
  @gcs_source
end

#input_bucket_project_numberFixnum

Optional. The project number of the project that the user expects to own the input Cloud Storage bucket referenced by gcs_source. The service verifies that the bucket is actually owned by this project before reading from it, in order to prevent bucket squatting. If unset, the bucket is verified to be owned by the project the request is made for (parent). Corresponds to the JSON property inputBucketProjectNumber

Returns:

  • (Fixnum)


42528
42529
42530
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42528

def input_bucket_project_number
  @input_bucket_project_number
end

#output_bucket_project_numberFixnum

Optional. The project number of the project that the user expects to own the output Cloud Storage bucket referenced by gcs_destination. The service verifies that the bucket is actually owned by this project before writing to it, in order to prevent bucket squatting. If unset, the bucket is verified to be owned by the project the request is made for (parent). Corresponds to the JSON property outputBucketProjectNumber

Returns:

  • (Fixnum)


42537
42538
42539
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42537

def output_bucket_project_number
  @output_bucket_project_number
end

#veo_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProcessDataRequestVeoSpec

Spec for Veo data processing. Corresponds to the JSON property veoSpec



42542
42543
42544
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42542

def veo_spec
  @veo_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42549
42550
42551
42552
42553
42554
42555
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42549

def update!(**args)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @input_bucket_project_number = args[:input_bucket_project_number] if args.key?(:input_bucket_project_number)
  @output_bucket_project_number = args[:output_bucket_project_number] if args.key?(:output_bucket_project_number)
  @veo_spec = args[:veo_spec] if args.key?(:veo_spec)
end