Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProcessDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for GenAiTuningService.ProcessData.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ProcessDataRequest

Returns a new instance of GoogleCloudAiplatformV1beta1ProcessDataRequest.



41840
41841
41842
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_destinationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcsDestination



41828
41829
41830
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41828

def gcs_destination
  @gcs_destination
end

#gcs_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



41833
41834
41835
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41833

def gcs_source
  @gcs_source
end

#veo_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ProcessDataRequestVeoSpec

Spec for Veo data processing. Corresponds to the JSON property veoSpec



41838
41839
41840
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41838

def veo_spec
  @veo_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41845
41846
41847
41848
41849
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41845

def update!(**args)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @veo_spec = args[:veo_spec] if args.key?(:veo_spec)
end