Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A Model Garden Publisher Model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PublisherModel

Returns a new instance of GoogleCloudAiplatformV1beta1PublisherModel.



41994
41995
41996
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#frameworksArray<String>

Optional. Additional information about the model's Frameworks. Corresponds to the JSON property frameworks

Returns:

  • (Array<String>)


41943
41944
41945
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41943

def frameworks
  @frameworks
end

#launch_stageString

Optional. Indicates the launch stage of the model. Corresponds to the JSON property launchStage

Returns:

  • (String)


41948
41949
41950
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41948

def launch_stage
  @launch_stage
end

#nameString

Output only. Identifier. The resource name of the PublisherModel. Corresponds to the JSON property name

Returns:

  • (String)


41953
41954
41955
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41953

def name
  @name
end

#open_source_categoryString

Required. Indicates the open source category of the publisher model. Corresponds to the JSON property openSourceCategory

Returns:

  • (String)


41958
41959
41960
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41958

def open_source_category
  @open_source_category
end

#parentGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelParent

The information about the parent of a model. Corresponds to the JSON property parent



41963
41964
41965
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41963

def parent
  @parent
end

#predict_schemataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictSchemata

Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob. Corresponds to the JSON property predictSchemata



41969
41970
41971
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41969

def predict_schemata
  @predict_schemata
end

#publisher_model_templateString

Optional. Output only. Immutable. Used to indicate this model has a publisher model and provide the template of the publisher model resource name. Corresponds to the JSON property publisherModelTemplate

Returns:

  • (String)


41975
41976
41977
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41975

def publisher_model_template
  @publisher_model_template
end

#supported_actionsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelCallToAction

Actions could take on this Publisher Model. Corresponds to the JSON property supportedActions



41980
41981
41982
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41980

def supported_actions
  @supported_actions
end

#version_idString

Output only. Immutable. The version ID of the PublisherModel. A new version is committed when a new model version is uploaded under an existing model id. It is an auto-incrementing decimal number in string representation. Corresponds to the JSON property versionId

Returns:

  • (String)


41987
41988
41989
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41987

def version_id
  @version_id
end

#version_stateString

Optional. Indicates the state of the model version. Corresponds to the JSON property versionState

Returns:

  • (String)


41992
41993
41994
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41992

def version_state
  @version_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41999
42000
42001
42002
42003
42004
42005
42006
42007
42008
42009
42010
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41999

def update!(**args)
  @frameworks = args[:frameworks] if args.key?(:frameworks)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @name = args[:name] if args.key?(:name)
  @open_source_category = args[:open_source_category] if args.key?(:open_source_category)
  @parent = args[:parent] if args.key?(:parent)
  @predict_schemata = args[:predict_schemata] if args.key?(:predict_schemata)
  @publisher_model_template = args[:publisher_model_template] if args.key?(:publisher_model_template)
  @supported_actions = args[:supported_actions] if args.key?(:supported_actions)
  @version_id = args[:version_id] if args.key?(:version_id)
  @version_state = args[:version_state] if args.key?(:version_state)
end