Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModel
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A Model Garden Publisher Model.
Instance Attribute Summary collapse
-
#frameworks ⇒ Array<String>
Optional.
-
#launch_stage ⇒ String
Optional.
-
#name ⇒ String
Output only.
-
#open_source_category ⇒ String
Required.
-
#parent ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelParent
The information about the parent of a model.
-
#predict_schemata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictSchemata
Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
-
#publisher_model_template ⇒ String
Optional.
-
#supported_actions ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelCallToAction
Actions could take on this Publisher Model.
-
#version_id ⇒ String
Output only.
-
#version_state ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PublisherModel
constructor
A new instance of GoogleCloudAiplatformV1beta1PublisherModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PublisherModel
Returns a new instance of GoogleCloudAiplatformV1beta1PublisherModel.
42172 42173 42174 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42172 def initialize(**args) update!(**args) end |
Instance Attribute Details
#frameworks ⇒ Array<String>
Optional. Additional information about the model's Frameworks.
Corresponds to the JSON property frameworks
42121 42122 42123 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42121 def frameworks @frameworks end |
#launch_stage ⇒ String
Optional. Indicates the launch stage of the model.
Corresponds to the JSON property launchStage
42126 42127 42128 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42126 def launch_stage @launch_stage end |
#name ⇒ String
Output only. Identifier. The resource name of the PublisherModel.
Corresponds to the JSON property name
42131 42132 42133 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42131 def name @name end |
#open_source_category ⇒ String
Required. Indicates the open source category of the publisher model.
Corresponds to the JSON property openSourceCategory
42136 42137 42138 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42136 def open_source_category @open_source_category end |
#parent ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelParent
The information about the parent of a model.
Corresponds to the JSON property parent
42141 42142 42143 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42141 def parent @parent end |
#predict_schemata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictSchemata
Contains the schemata used in Model's predictions and explanations via
PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
Corresponds to the JSON property predictSchemata
42147 42148 42149 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42147 def predict_schemata @predict_schemata end |
#publisher_model_template ⇒ String
Optional. Output only. Immutable. Used to indicate this model has a publisher
model and provide the template of the publisher model resource name.
Corresponds to the JSON property publisherModelTemplate
42153 42154 42155 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42153 def publisher_model_template @publisher_model_template end |
#supported_actions ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelCallToAction
Actions could take on this Publisher Model.
Corresponds to the JSON property supportedActions
42158 42159 42160 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42158 def supported_actions @supported_actions end |
#version_id ⇒ String
Output only. Immutable. The version ID of the PublisherModel. A new version is
committed when a new model version is uploaded under an existing model id. It
is an auto-incrementing decimal number in string representation.
Corresponds to the JSON property versionId
42165 42166 42167 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42165 def version_id @version_id end |
#version_state ⇒ String
Optional. Indicates the state of the model version.
Corresponds to the JSON property versionState
42170 42171 42172 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42170 def version_state @version_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42177 42178 42179 42180 42181 42182 42183 42184 42185 42186 42187 42188 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42177 def update!(**args) @frameworks = args[:frameworks] if args.key?(:frameworks) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @name = args[:name] if args.key?(:name) @open_source_category = args[:open_source_category] if args.key?(:open_source_category) @parent = args[:parent] if args.key?(:parent) @predict_schemata = args[:predict_schemata] if args.key?(:predict_schemata) @publisher_model_template = args[:publisher_model_template] if args.key?(:publisher_model_template) @supported_actions = args[:supported_actions] if args.key?(:supported_actions) @version_id = args[:version_id] if args.key?(:version_id) @version_state = args[:version_state] if args.key?(:version_state) end |