Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A Model Garden Publisher Model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PublisherModel

Returns a new instance of GoogleCloudAiplatformV1beta1PublisherModel.



40698
40699
40700
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#frameworksArray<String>

Optional. Additional information about the model's Frameworks. Corresponds to the JSON property frameworks

Returns:

  • (Array<String>)


40647
40648
40649
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40647

def frameworks
  @frameworks
end

#launch_stageString

Optional. Indicates the launch stage of the model. Corresponds to the JSON property launchStage

Returns:

  • (String)


40652
40653
40654
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40652

def launch_stage
  @launch_stage
end

#nameString

Output only. Identifier. The resource name of the PublisherModel. Corresponds to the JSON property name

Returns:

  • (String)


40657
40658
40659
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40657

def name
  @name
end

#open_source_categoryString

Required. Indicates the open source category of the publisher model. Corresponds to the JSON property openSourceCategory

Returns:

  • (String)


40662
40663
40664
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40662

def open_source_category
  @open_source_category
end

#parentGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelParent

The information about the parent of a model. Corresponds to the JSON property parent



40667
40668
40669
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40667

def parent
  @parent
end

#predict_schemataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictSchemata

Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob. Corresponds to the JSON property predictSchemata



40673
40674
40675
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40673

def predict_schemata
  @predict_schemata
end

#publisher_model_templateString

Optional. Output only. Immutable. Used to indicate this model has a publisher model and provide the template of the publisher model resource name. Corresponds to the JSON property publisherModelTemplate

Returns:

  • (String)


40679
40680
40681
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40679

def publisher_model_template
  @publisher_model_template
end

#supported_actionsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelCallToAction

Actions could take on this Publisher Model. Corresponds to the JSON property supportedActions



40684
40685
40686
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40684

def supported_actions
  @supported_actions
end

#version_idString

Output only. Immutable. The version ID of the PublisherModel. A new version is committed when a new model version is uploaded under an existing model id. It is an auto-incrementing decimal number in string representation. Corresponds to the JSON property versionId

Returns:

  • (String)


40691
40692
40693
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40691

def version_id
  @version_id
end

#version_stateString

Optional. Indicates the state of the model version. Corresponds to the JSON property versionState

Returns:

  • (String)


40696
40697
40698
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40696

def version_state
  @version_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40703
40704
40705
40706
40707
40708
40709
40710
40711
40712
40713
40714
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40703

def update!(**args)
  @frameworks = args[:frameworks] if args.key?(:frameworks)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @name = args[:name] if args.key?(:name)
  @open_source_category = args[:open_source_category] if args.key?(:open_source_category)
  @parent = args[:parent] if args.key?(:parent)
  @predict_schemata = args[:predict_schemata] if args.key?(:predict_schemata)
  @publisher_model_template = args[:publisher_model_template] if args.key?(:publisher_model_template)
  @supported_actions = args[:supported_actions] if args.key?(:supported_actions)
  @version_id = args[:version_id] if args.key?(:version_id)
  @version_state = args[:version_state] if args.key?(:version_state)
end