Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeploy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Model metadata that is needed for UploadModel or DeployModel/CreateEndpoint requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeploy

Returns a new instance of GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeploy.



44599
44600
44601
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_uriString

Optional. The path to the directory containing the Model artifact and any of its supporting files. Corresponds to the JSON property artifactUri

Returns:

  • (String)


44539
44540
44541
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44539

def artifact_uri
  @artifact_uri
end

#automatic_resourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AutomaticResources

A description of resources that to large degree are decided by Agent Platform, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines. Corresponds to the JSON property automaticResources



44546
44547
44548
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44546

def automatic_resources
  @automatic_resources
end

#container_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelContainerSpec

Specification of a container for serving predictions. Some fields in this message correspond to fields in the Kubernetes Container v1 core specification. Corresponds to the JSON property containerSpec



44554
44555
44556
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44554

def container_spec
  @container_spec
end

#dedicated_resourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DedicatedResources

A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



44560
44561
44562
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44560

def dedicated_resources
  @dedicated_resources
end

#deploy_metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeployDeployMetadata

Metadata information about the deployment for managing deployment config. Corresponds to the JSON property deployMetadata



44565
44566
44567
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44565

def 
  @deploy_metadata
end

#deploy_task_nameString

Optional. The name of the deploy task (e.g., "text to image generation"). Corresponds to the JSON property deployTaskName

Returns:

  • (String)


44570
44571
44572
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44570

def deploy_task_name
  @deploy_task_name
end

#large_model_referenceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LargeModelReference

Contains information about the Large Model. Corresponds to the JSON property largeModelReference



44575
44576
44577
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44575

def large_model_reference
  @large_model_reference
end

#model_display_nameString

Optional. Default model display name. Corresponds to the JSON property modelDisplayName

Returns:

  • (String)


44580
44581
44582
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44580

def model_display_name
  @model_display_name
end

#public_artifact_uriString

Optional. The signed URI for ephemeral Cloud Storage access to model artifact. Corresponds to the JSON property publicArtifactUri

Returns:

  • (String)


44585
44586
44587
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44585

def public_artifact_uri
  @public_artifact_uri
end

#shared_resourcesString

The resource name of the shared DeploymentResourcePool to deploy on. Format: projects/project/locations/location/deploymentResourcePools/ deployment_resource_pool` Corresponds to the JSON propertysharedResources`

Returns:

  • (String)


44592
44593
44594
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44592

def shared_resources
  @shared_resources
end

#titleString

Required. The title of the regional resource reference. Corresponds to the JSON property title

Returns:

  • (String)


44597
44598
44599
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44597

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44604
44605
44606
44607
44608
44609
44610
44611
44612
44613
44614
44615
44616
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44604

def update!(**args)
  @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri)
  @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @deploy_metadata = args[:deploy_metadata] if args.key?(:deploy_metadata)
  @deploy_task_name = args[:deploy_task_name] if args.key?(:deploy_task_name)
  @large_model_reference = args[:large_model_reference] if args.key?(:large_model_reference)
  @model_display_name = args[:model_display_name] if args.key?(:model_display_name)
  @public_artifact_uri = args[:public_artifact_uri] if args.key?(:public_artifact_uri)
  @shared_resources = args[:shared_resources] if args.key?(:shared_resources)
  @title = args[:title] if args.key?(:title)
end