Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeploy
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeploy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Model metadata that is needed for UploadModel or DeployModel/CreateEndpoint requests.
Instance Attribute Summary collapse
-
#artifact_uri ⇒ String
Optional.
-
#automatic_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AutomaticResources
A description of resources that to large degree are decided by Agent Platform, and require only a modest additional configuration.
-
#container_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelContainerSpec
Specification of a container for serving predictions.
-
#dedicated_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DedicatedResources
A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration.
-
#deploy_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeployDeployMetadata
Metadata information about the deployment for managing deployment config.
-
#deploy_task_name ⇒ String
Optional.
-
#large_model_reference ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LargeModelReference
Contains information about the Large Model.
-
#model_display_name ⇒ String
Optional.
-
#public_artifact_uri ⇒ String
Optional.
-
#shared_resources ⇒ String
The resource name of the shared DeploymentResourcePool to deploy on.
-
#title ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeploy
constructor
A new instance of GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeploy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeploy
Returns a new instance of GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeploy.
40892 40893 40894 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40892 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_uri ⇒ String
Optional. The path to the directory containing the Model artifact and any of
its supporting files.
Corresponds to the JSON property artifactUri
40832 40833 40834 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40832 def artifact_uri @artifact_uri end |
#automatic_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1AutomaticResources
A description of resources that to large degree are decided by Agent Platform,
and require only a modest additional configuration. Each Model supporting
these resources documents its specific guidelines.
Corresponds to the JSON property automaticResources
40839 40840 40841 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40839 def automatic_resources @automatic_resources end |
#container_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelContainerSpec
Specification of a container for serving predictions. Some fields in this
message correspond to fields in the Kubernetes Container v1 core
specification.
Corresponds to the JSON property containerSpec
40847 40848 40849 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40847 def container_spec @container_spec end |
#dedicated_resources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DedicatedResources
A description of resources that are dedicated to a DeployedModel or
DeployedIndex, and that need a higher degree of manual configuration.
Corresponds to the JSON property dedicatedResources
40853 40854 40855 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40853 def dedicated_resources @dedicated_resources end |
#deploy_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeployDeployMetadata
Metadata information about the deployment for managing deployment config.
Corresponds to the JSON property deployMetadata
40858 40859 40860 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40858 def @deploy_metadata end |
#deploy_task_name ⇒ String
Optional. The name of the deploy task (e.g., "text to image generation").
Corresponds to the JSON property deployTaskName
40863 40864 40865 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40863 def deploy_task_name @deploy_task_name end |
#large_model_reference ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LargeModelReference
Contains information about the Large Model.
Corresponds to the JSON property largeModelReference
40868 40869 40870 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40868 def large_model_reference @large_model_reference end |
#model_display_name ⇒ String
Optional. Default model display name.
Corresponds to the JSON property modelDisplayName
40873 40874 40875 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40873 def model_display_name @model_display_name end |
#public_artifact_uri ⇒ String
Optional. The signed URI for ephemeral Cloud Storage access to model artifact.
Corresponds to the JSON property publicArtifactUri
40878 40879 40880 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40878 def public_artifact_uri @public_artifact_uri end |
#shared_resources ⇒ String
The resource name of the shared DeploymentResourcePool to deploy on. Format:
projects/project/locations/location/deploymentResourcePools/
deployment_resource_pool`
Corresponds to the JSON propertysharedResources`
40885 40886 40887 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40885 def shared_resources @shared_resources end |
#title ⇒ String
Required. The title of the regional resource reference.
Corresponds to the JSON property title
40890 40891 40892 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40890 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40897 40898 40899 40900 40901 40902 40903 40904 40905 40906 40907 40908 40909 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40897 def update!(**args) @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri) @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources) @container_spec = args[:container_spec] if args.key?(:container_spec) @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources) @deploy_metadata = args[:deploy_metadata] if args.key?(:deploy_metadata) @deploy_task_name = args[:deploy_task_name] if args.key?(:deploy_task_name) @large_model_reference = args[:large_model_reference] if args.key?(:large_model_reference) @model_display_name = args[:model_display_name] if args.key?(:model_display_name) @public_artifact_uri = args[:public_artifact_uri] if args.key?(:public_artifact_uri) @shared_resources = args[:shared_resources] if args.key?(:shared_resources) @title = args[:title] if args.key?(:title) end |