Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeployDeployMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Metadata information about the deployment for managing deployment config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeployDeployMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1PublisherModelCallToActionDeployDeployMetadata.



35348
35349
35350
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Optional. Labels for the deployment config. For managing deployment config like verifying, source of deployment config, etc. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


35341
35342
35343
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35341

def labels
  @labels
end

#sample_requestString

Optional. Sample request for deployed endpoint. Corresponds to the JSON property sampleRequest

Returns:

  • (String)


35346
35347
35348
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35346

def sample_request
  @sample_request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35353
35354
35355
35356
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35353

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @sample_request = args[:sample_request] if args.key?(:sample_request)
end