Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PublisherModelConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
This message contains configs of a publisher model.
Instance Attribute Summary collapse
-
#data_sharing_enabled_provider ⇒ String
Optional.
-
#logging_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictRequestResponseLoggingConfig
Configuration for logging request-response to a BigQuery table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PublisherModelConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1PublisherModelConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PublisherModelConfig
Returns a new instance of GoogleCloudAiplatformV1beta1PublisherModelConfig.
41115 41116 41117 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_sharing_enabled_provider ⇒ String
Optional. The model provider (publisher) for which the customer has enabled
data sharing. For publisher models that are configured to require data sharing,
a prediction request is only allowed when the model's publisher matches this
provider. Otherwise, the request is rejected.
Corresponds to the JSON property dataSharingEnabledProvider
41108 41109 41110 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41108 def data_sharing_enabled_provider @data_sharing_enabled_provider end |
#logging_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictRequestResponseLoggingConfig
Configuration for logging request-response to a BigQuery table.
Corresponds to the JSON property loggingConfig
41113 41114 41115 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41113 def logging_config @logging_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41120 41121 41122 41123 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41120 def update!(**args) @data_sharing_enabled_provider = args[:data_sharing_enabled_provider] if args.key?(:data_sharing_enabled_provider) @logging_config = args[:logging_config] if args.key?(:logging_config) end |