Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PurgeExecutionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for MetadataService.PurgeExecutions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PurgeExecutionsRequest

Returns a new instance of GoogleCloudAiplatformV1beta1PurgeExecutionsRequest.



35846
35847
35848
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35846

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Required. A required filter matching the Executions to be purged. E.g., update_time <= 2020-11-19T11:30:00-04:00. Corresponds to the JSON property filter

Returns:

  • (String)


35836
35837
35838
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35836

def filter
  @filter
end

#forceBoolean Also known as: force?

Optional. Flag to indicate to actually perform the purge. If force is set to false, the method will return a sample of Execution names that would be deleted. Corresponds to the JSON property force

Returns:

  • (Boolean)


35843
35844
35845
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35843

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35851
35852
35853
35854
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35851

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
end