Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PurgeMemoriesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for MemoryBankService.PurgeMemories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PurgeMemoriesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1PurgeMemoriesRequest.



40852
40853
40854
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40852

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Required. The standard list filter to determine which memories to purge. More detail in AIP-160. Corresponds to the JSON property filter

Returns:

  • (String)


40832
40833
40834
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40832

def filter
  @filter
end

#filter_groupsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryConjunctionFilter>

Optional. Metadata filters that will be applied to the memories to be purged. Filters are defined using disjunctive normal form (OR of ANDs). For example: filter_groups: [filters: [key: "author", value:string_value: "agent 123", op: EQUAL],filters: [key: "label", value:string_value: "travel", op: EQUAL, key: "author", value:string_value: "agent 321", op: EQUAL]] would be equivalent to the logical expression: (metadata.author = "agent 123" OR (metadata.label = "travel" AND metadata.author = "agent 321")). Corresponds to the JSON property filterGroups



40843
40844
40845
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40843

def filter_groups
  @filter_groups
end

#forceBoolean Also known as: force?

Optional. If true, the memories will actually be purged. If false, the purge request will be validated but not executed. Corresponds to the JSON property force

Returns:

  • (Boolean)


40849
40850
40851
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40849

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40857
40858
40859
40860
40861
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40857

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @filter_groups = args[:filter_groups] if args.key?(:filter_groups)
  @force = args[:force] if args.key?(:force)
end