Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PurgeMemoriesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PurgeMemoriesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for MemoryBankService.PurgeMemories.
Instance Attribute Summary collapse
-
#filter ⇒ String
Required.
-
#filter_groups ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryConjunctionFilter>
Optional.
-
#force ⇒ Boolean
(also: #force?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PurgeMemoriesRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1PurgeMemoriesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PurgeMemoriesRequest
Returns a new instance of GoogleCloudAiplatformV1beta1PurgeMemoriesRequest.
35913 35914 35915 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35913 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Required. The standard list filter to determine which memories to purge. More
detail in AIP-160.
Corresponds to the JSON property filter
35893 35894 35895 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35893 def filter @filter end |
#filter_groups ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryConjunctionFilter>
Optional. Metadata filters that will be applied to the memories to be purged.
Filters are defined using disjunctive normal form (OR of ANDs). For example:
filter_groups: [filters: [key: "author", value:string_value: "agent 123",
op: EQUAL],filters: [key: "label", value:string_value: "travel", op:
EQUAL, key: "author", value:string_value: "agent 321", op: EQUAL]]
would be equivalent to the logical expression: (metadata.author = "agent 123"
OR (metadata.label = "travel" AND metadata.author = "agent 321")).
Corresponds to the JSON property filterGroups
35904 35905 35906 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35904 def filter_groups @filter_groups end |
#force ⇒ Boolean Also known as: force?
Optional. If true, the memories will actually be purged. If false, the purge
request will be validated but not executed.
Corresponds to the JSON property force
35910 35911 35912 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35910 def force @force end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35918 35919 35920 35921 35922 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 35918 def update!(**args) @filter = args[:filter] if args.key?(:filter) @filter_groups = args[:filter_groups] if args.key?(:filter_groups) @force = args[:force] if args.key?(:force) end |