Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PythonPackageSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The spec of a Python packaged code.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PythonPackageSpec

Returns a new instance of GoogleCloudAiplatformV1beta1PythonPackageSpec.



44761
44762
44763
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44761

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

Command line arguments to be passed to the Python task. Corresponds to the JSON property args

Returns:

  • (Array<String>)


44733
44734
44735
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44733

def args
  @args
end

#envArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EnvVar>

Environment variables to be passed to the python module. Maximum limit is 100. Corresponds to the JSON property env



44738
44739
44740
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44738

def env
  @env
end

#executor_image_uriString

Required. The URI of a container image in Artifact Registry that will run the provided Python package. Vertex AI provides a wide range of executor images with pre-installed packages to meet users' various use cases. See the list of pre-built containers for training. You must use an image from this list. Corresponds to the JSON property executorImageUri

Returns:

  • (String)


44747
44748
44749
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44747

def executor_image_uri
  @executor_image_uri
end

#package_urisArray<String>

Required. The Google Cloud Storage location of the Python package files which are the training program and its dependent packages. The maximum number of package URIs is 100. Corresponds to the JSON property packageUris

Returns:

  • (Array<String>)


44754
44755
44756
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44754

def package_uris
  @package_uris
end

#python_moduleString

Required. The Python module name to run after installing the packages. Corresponds to the JSON property pythonModule

Returns:

  • (String)


44759
44760
44761
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44759

def python_module
  @python_module
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44766
44767
44768
44769
44770
44771
44772
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44766

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @env = args[:env] if args.key?(:env)
  @executor_image_uri = args[:executor_image_uri] if args.key?(:executor_image_uri)
  @package_uris = args[:package_uris] if args.key?(:package_uris)
  @python_module = args[:python_module] if args.key?(:python_module)
end