Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PythonPackageSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PythonPackageSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The spec of a Python packaged code.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Command line arguments to be passed to the Python task.
-
#env ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EnvVar>
Environment variables to be passed to the python module.
-
#executor_image_uri ⇒ String
Required.
-
#package_uris ⇒ Array<String>
Required.
-
#python_module ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PythonPackageSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1PythonPackageSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1PythonPackageSpec
Returns a new instance of GoogleCloudAiplatformV1beta1PythonPackageSpec.
42844 42845 42846 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42844 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Command line arguments to be passed to the Python task.
Corresponds to the JSON property args
42816 42817 42818 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42816 def args @args end |
#env ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EnvVar>
Environment variables to be passed to the python module. Maximum limit is 100.
Corresponds to the JSON property env
42821 42822 42823 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42821 def env @env end |
#executor_image_uri ⇒ String
Required. The URI of a container image in Artifact Registry that will run the
provided Python package. Vertex AI provides a wide range of executor images
with pre-installed packages to meet users' various use cases. See the list of
pre-built containers for training. You must use an image from this list.
Corresponds to the JSON property executorImageUri
42830 42831 42832 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42830 def executor_image_uri @executor_image_uri end |
#package_uris ⇒ Array<String>
Required. The Google Cloud Storage location of the Python package files which
are the training program and its dependent packages. The maximum number of
package URIs is 100.
Corresponds to the JSON property packageUris
42837 42838 42839 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42837 def package_uris @package_uris end |
#python_module ⇒ String
Required. The Python module name to run after installing the packages.
Corresponds to the JSON property pythonModule
42842 42843 42844 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42842 def python_module @python_module end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42849 42850 42851 42852 42853 42854 42855 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42849 def update!(**args) @args = args[:args] if args.key?(:args) @env = args[:env] if args.key?(:env) @executor_image_uri = args[:executor_image_uri] if args.key?(:executor_image_uri) @package_uris = args[:package_uris] if args.key?(:package_uris) @python_module = args[:python_module] if args.key?(:python_module) end |