Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QueryExtensionResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QueryExtensionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for ExtensionExecutionService.QueryExtension.
Instance Attribute Summary collapse
-
#failure_message ⇒ String
Failure message if any.
-
#steps ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Steps of extension or LLM interaction, can contain function call, function response, or text response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1QueryExtensionResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1QueryExtensionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1QueryExtensionResponse
Returns a new instance of GoogleCloudAiplatformV1beta1QueryExtensionResponse.
45582 45583 45584 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure_message ⇒ String
Failure message if any.
Corresponds to the JSON property failureMessage
45573 45574 45575 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45573 def @failure_message end |
#steps ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Steps of extension or LLM interaction, can contain function call, function
response, or text response. The last step contains the final response to the
query.
Corresponds to the JSON property steps
45580 45581 45582 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45580 def steps @steps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45587 45588 45589 45590 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45587 def update!(**args) @failure_message = args[:failure_message] if args.key?(:failure_message) @steps = args[:steps] if args.key?(:steps) end |