Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1QueryExtensionResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for ExtensionExecutionService.QueryExtension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1QueryExtensionResponse

Returns a new instance of GoogleCloudAiplatformV1beta1QueryExtensionResponse.



43119
43120
43121
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43119

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failure_messageString

Failure message if any. Corresponds to the JSON property failureMessage

Returns:

  • (String)


43110
43111
43112
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43110

def failure_message
  @failure_message
end

#stepsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>

Steps of extension or LLM interaction, can contain function call, function response, or text response. The last step contains the final response to the query. Corresponds to the JSON property steps



43117
43118
43119
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43117

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43124
43125
43126
43127
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43124

def update!(**args)
  @failure_message = args[:failure_message] if args.key?(:failure_message)
  @steps = args[:steps] if args.key?(:steps)
end