Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
Instance Attribute Summary collapse
-
#chunk_id ⇒ String
The ID of the chunk.
-
#file_id ⇒ String
The ID of the file that the chunk belongs to.
-
#page_span ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunkPageSpan
Represents where the chunk starts and ends in the document.
-
#text ⇒ String
The content of the chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagChunk
constructor
A new instance of GoogleCloudAiplatformV1beta1RagChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagChunk
Returns a new instance of GoogleCloudAiplatformV1beta1RagChunk.
43681 43682 43683 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_id ⇒ String
The ID of the chunk.
Corresponds to the JSON property chunkId
43664 43665 43666 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43664 def chunk_id @chunk_id end |
#file_id ⇒ String
The ID of the file that the chunk belongs to.
Corresponds to the JSON property fileId
43669 43670 43671 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43669 def file_id @file_id end |
#page_span ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunkPageSpan
Represents where the chunk starts and ends in the document.
Corresponds to the JSON property pageSpan
43674 43675 43676 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43674 def page_span @page_span end |
#text ⇒ String
The content of the chunk.
Corresponds to the JSON property text
43679 43680 43681 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43679 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43686 43687 43688 43689 43690 43691 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43686 def update!(**args) @chunk_id = args[:chunk_id] if args.key?(:chunk_id) @file_id = args[:file_id] if args.key?(:file_id) @page_span = args[:page_span] if args.key?(:page_span) @text = args[:text] if args.key?(:text) end |