Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A RagChunk includes the content of a chunk of a RagFile, and associated metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagChunk

Returns a new instance of GoogleCloudAiplatformV1beta1RagChunk.



42207
42208
42209
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_idString

The ID of the chunk. Corresponds to the JSON property chunkId

Returns:

  • (String)


42190
42191
42192
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42190

def chunk_id
  @chunk_id
end

#file_idString

The ID of the file that the chunk belongs to. Corresponds to the JSON property fileId

Returns:

  • (String)


42195
42196
42197
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42195

def file_id
  @file_id
end

#page_spanGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunkPageSpan

Represents where the chunk starts and ends in the document. Corresponds to the JSON property pageSpan



42200
42201
42202
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42200

def page_span
  @page_span
end

#textString

The content of the chunk. Corresponds to the JSON property text

Returns:

  • (String)


42205
42206
42207
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42205

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42212
42213
42214
42215
42216
42217
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42212

def update!(**args)
  @chunk_id = args[:chunk_id] if args.key?(:chunk_id)
  @file_id = args[:file_id] if args.key?(:file_id)
  @page_span = args[:page_span] if args.key?(:page_span)
  @text = args[:text] if args.key?(:text)
end