Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
Instance Attribute Summary collapse
-
#chunk_id ⇒ String
The ID of the chunk.
-
#file_id ⇒ String
The ID of the file that the chunk belongs to.
-
#page_span ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunkPageSpan
Represents where the chunk starts and ends in the document.
-
#text ⇒ String
The content of the chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagChunk
constructor
A new instance of GoogleCloudAiplatformV1beta1RagChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagChunk
Returns a new instance of GoogleCloudAiplatformV1beta1RagChunk.
41558 41559 41560 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_id ⇒ String
The ID of the chunk.
Corresponds to the JSON property chunkId
41541 41542 41543 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41541 def chunk_id @chunk_id end |
#file_id ⇒ String
The ID of the file that the chunk belongs to.
Corresponds to the JSON property fileId
41546 41547 41548 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41546 def file_id @file_id end |
#page_span ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunkPageSpan
Represents where the chunk starts and ends in the document.
Corresponds to the JSON property pageSpan
41551 41552 41553 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41551 def page_span @page_span end |
#text ⇒ String
The content of the chunk.
Corresponds to the JSON property text
41556 41557 41558 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41556 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41563 41564 41565 41566 41567 41568 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41563 def update!(**args) @chunk_id = args[:chunk_id] if args.key?(:chunk_id) @file_id = args[:file_id] if args.key?(:file_id) @page_span = args[:page_span] if args.key?(:page_span) @text = args[:text] if args.key?(:text) end |