Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagContextsContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A context of the query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagContextsContext

Returns a new instance of GoogleCloudAiplatformV1beta1RagContextsContext.



44361
44362
44363
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44361

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunkGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk

A RagChunk includes the content of a chunk of a RagFile, and associated metadata. Corresponds to the JSON property chunk



44319
44320
44321
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44319

def chunk
  @chunk
end

#distanceFloat

The distance between the query dense embedding vector and the context text vector. Corresponds to the JSON property distance

Returns:

  • (Float)


44325
44326
44327
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44325

def distance
  @distance
end

#scoreFloat

According to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the context and its range depends on the metric type. For example, if the metric type is COSINE_DISTANCE, it represents the distance between the query and the context. The larger the distance, the less relevant the context is to the query. The range is [0, 2], while 0 means the most relevant and 2 means the least relevant. Corresponds to the JSON property score

Returns:

  • (Float)


44336
44337
44338
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44336

def score
  @score
end

#source_display_nameString

The file display name. Corresponds to the JSON property sourceDisplayName

Returns:

  • (String)


44341
44342
44343
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44341

def source_display_name
  @source_display_name
end

#source_uriString

If the file is imported from Cloud Storage or Google Drive, source_uri will be original file URI in Cloud Storage or Google Drive; if file is uploaded, source_uri will be file display name. Corresponds to the JSON property sourceUri

Returns:

  • (String)


44348
44349
44350
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44348

def source_uri
  @source_uri
end

#sparse_distanceFloat

The distance between the query sparse embedding vector and the context text vector. Corresponds to the JSON property sparseDistance

Returns:

  • (Float)


44354
44355
44356
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44354

def sparse_distance
  @sparse_distance
end

#textString

The text chunk. Corresponds to the JSON property text

Returns:

  • (String)


44359
44360
44361
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44359

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44366
44367
44368
44369
44370
44371
44372
44373
44374
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44366

def update!(**args)
  @chunk = args[:chunk] if args.key?(:chunk)
  @distance = args[:distance] if args.key?(:distance)
  @score = args[:score] if args.key?(:score)
  @source_display_name = args[:source_display_name] if args.key?(:source_display_name)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @sparse_distance = args[:sparse_distance] if args.key?(:sparse_distance)
  @text = args[:text] if args.key?(:text)
end