Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagContextsContext
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagContextsContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A context of the query.
Instance Attribute Summary collapse
-
#chunk ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
-
#distance ⇒ Float
The distance between the query dense embedding vector and the context text vector.
-
#score ⇒ Float
According to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the context and its range depends on the metric type.
-
#source_display_name ⇒ String
The file display name.
-
#source_uri ⇒ String
If the file is imported from Cloud Storage or Google Drive, source_uri will be original file URI in Cloud Storage or Google Drive; if file is uploaded, source_uri will be file display name.
-
#sparse_distance ⇒ Float
The distance between the query sparse embedding vector and the context text vector.
-
#text ⇒ String
The text chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagContextsContext
constructor
A new instance of GoogleCloudAiplatformV1beta1RagContextsContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagContextsContext
Returns a new instance of GoogleCloudAiplatformV1beta1RagContextsContext.
36793 36794 36795 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36793 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated
metadata.
Corresponds to the JSON property chunk
36751 36752 36753 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36751 def chunk @chunk end |
#distance ⇒ Float
The distance between the query dense embedding vector and the context text
vector.
Corresponds to the JSON property distance
36757 36758 36759 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36757 def distance @distance end |
#score ⇒ Float
According to the underlying Vector DB and the selected metric type, the score
can be either the distance or the similarity between the query and the context
and its range depends on the metric type. For example, if the metric type is
COSINE_DISTANCE, it represents the distance between the query and the context.
The larger the distance, the less relevant the context is to the query. The
range is [0, 2], while 0 means the most relevant and 2 means the least
relevant.
Corresponds to the JSON property score
36768 36769 36770 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36768 def score @score end |
#source_display_name ⇒ String
The file display name.
Corresponds to the JSON property sourceDisplayName
36773 36774 36775 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36773 def source_display_name @source_display_name end |
#source_uri ⇒ String
If the file is imported from Cloud Storage or Google Drive, source_uri will be
original file URI in Cloud Storage or Google Drive; if file is uploaded,
source_uri will be file display name.
Corresponds to the JSON property sourceUri
36780 36781 36782 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36780 def source_uri @source_uri end |
#sparse_distance ⇒ Float
The distance between the query sparse embedding vector and the context text
vector.
Corresponds to the JSON property sparseDistance
36786 36787 36788 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36786 def sparse_distance @sparse_distance end |
#text ⇒ String
The text chunk.
Corresponds to the JSON property text
36791 36792 36793 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36791 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36798 36799 36800 36801 36802 36803 36804 36805 36806 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36798 def update!(**args) @chunk = args[:chunk] if args.key?(:chunk) @distance = args[:distance] if args.key?(:distance) @score = args[:score] if args.key?(:score) @source_display_name = args[:source_display_name] if args.key?(:source_display_name) @source_uri = args[:source_uri] if args.key?(:source_uri) @sparse_distance = args[:sparse_distance] if args.key?(:sparse_distance) @text = args[:text] if args.key?(:text) end |