Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagCorpus
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagCorpus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A RagCorpus is a RagFile container and a project can have multiple RagCorpora.
Instance Attribute Summary collapse
-
#corpus_status ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CorpusStatus
RagCorpus status.
-
#corpus_type_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagCorpusCorpusTypeConfig
The config for the corpus type of the RagCorpus.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#name ⇒ String
Output only.
-
#rag_embedding_model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfig
Config for the embedding model to use for RAG.
-
#rag_files_count ⇒ Fixnum
Output only.
-
#rag_vector_db_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig
Config for the Vector DB to use for RAG.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#update_time ⇒ String
Output only.
-
#vector_db_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig
Config for the Vector DB to use for RAG.
-
#vertex_ai_search_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexAiSearchConfig
Config for the Vertex AI Search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagCorpus
constructor
A new instance of GoogleCloudAiplatformV1beta1RagCorpus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagCorpus
Returns a new instance of GoogleCloudAiplatformV1beta1RagCorpus.
46166 46167 46168 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46166 def initialize(**args) update!(**args) end |
Instance Attribute Details
#corpus_status ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CorpusStatus
RagCorpus status.
Corresponds to the JSON property corpusStatus
46089 46090 46091 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46089 def corpus_status @corpus_status end |
#corpus_type_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagCorpusCorpusTypeConfig
The config for the corpus type of the RagCorpus.
Corresponds to the JSON property corpusTypeConfig
46094 46095 46096 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46094 def corpus_type_config @corpus_type_config end |
#create_time ⇒ String
Output only. Timestamp when this RagCorpus was created.
Corresponds to the JSON property createTime
46099 46100 46101 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46099 def create_time @create_time end |
#description ⇒ String
Optional. The description of the RagCorpus.
Corresponds to the JSON property description
46104 46105 46106 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46104 def description @description end |
#display_name ⇒ String
Required. The display name of the RagCorpus. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
46110 46111 46112 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46110 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
46116 46117 46118 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46116 def encryption_spec @encryption_spec end |
#name ⇒ String
Output only. The resource name of the RagCorpus.
Corresponds to the JSON property name
46121 46122 46123 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46121 def name @name end |
#rag_embedding_model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfig
Config for the embedding model to use for RAG.
Corresponds to the JSON property ragEmbeddingModelConfig
46126 46127 46128 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46126 def @rag_embedding_model_config end |
#rag_files_count ⇒ Fixnum
Output only. Number of RagFiles in the RagCorpus. NOTE: This field is not
populated in the response of VertexRagDataService.ListRagCorpora.
Corresponds to the JSON property ragFilesCount
46132 46133 46134 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46132 def rag_files_count @rag_files_count end |
#rag_vector_db_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig
Config for the Vector DB to use for RAG.
Corresponds to the JSON property ragVectorDbConfig
46137 46138 46139 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46137 def rag_vector_db_config @rag_vector_db_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
46142 46143 46144 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46142 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
46148 46149 46150 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46148 def satisfies_pzs @satisfies_pzs end |
#update_time ⇒ String
Output only. Timestamp when this RagCorpus was last updated.
Corresponds to the JSON property updateTime
46154 46155 46156 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46154 def update_time @update_time end |
#vector_db_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig
Config for the Vector DB to use for RAG.
Corresponds to the JSON property vectorDbConfig
46159 46160 46161 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46159 def vector_db_config @vector_db_config end |
#vertex_ai_search_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexAiSearchConfig
Config for the Vertex AI Search.
Corresponds to the JSON property vertexAiSearchConfig
46164 46165 46166 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46164 def vertex_ai_search_config @vertex_ai_search_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46171 46172 46173 46174 46175 46176 46177 46178 46179 46180 46181 46182 46183 46184 46185 46186 46187 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46171 def update!(**args) @corpus_status = args[:corpus_status] if args.key?(:corpus_status) @corpus_type_config = args[:corpus_type_config] if args.key?(:corpus_type_config) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @rag_embedding_model_config = args[:rag_embedding_model_config] if args.key?(:rag_embedding_model_config) @rag_files_count = args[:rag_files_count] if args.key?(:rag_files_count) @rag_vector_db_config = args[:rag_vector_db_config] if args.key?(:rag_vector_db_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @update_time = args[:update_time] if args.key?(:update_time) @vector_db_config = args[:vector_db_config] if args.key?(:vector_db_config) @vertex_ai_search_config = args[:vertex_ai_search_config] if args.key?(:vertex_ai_search_config) end |