Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagCorpus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A RagCorpus is a RagFile container and a project can have multiple RagCorpora.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagCorpus

Returns a new instance of GoogleCloudAiplatformV1beta1RagCorpus.



45627
45628
45629
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45627

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#corpus_statusGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CorpusStatus

RagCorpus status. Corresponds to the JSON property corpusStatus



45550
45551
45552
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45550

def corpus_status
  @corpus_status
end

#corpus_type_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagCorpusCorpusTypeConfig

The config for the corpus type of the RagCorpus. Corresponds to the JSON property corpusTypeConfig



45555
45556
45557
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45555

def corpus_type_config
  @corpus_type_config
end

#create_timeString

Output only. Timestamp when this RagCorpus was created. Corresponds to the JSON property createTime

Returns:

  • (String)


45560
45561
45562
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45560

def create_time
  @create_time
end

#descriptionString

Optional. The description of the RagCorpus. Corresponds to the JSON property description

Returns:

  • (String)


45565
45566
45567
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45565

def description
  @description
end

#display_nameString

Required. The display name of the RagCorpus. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


45571
45572
45573
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45571

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



45577
45578
45579
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45577

def encryption_spec
  @encryption_spec
end

#nameString

Output only. The resource name of the RagCorpus. Corresponds to the JSON property name

Returns:

  • (String)


45582
45583
45584
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45582

def name
  @name
end

#rag_embedding_model_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfig

Config for the embedding model to use for RAG. Corresponds to the JSON property ragEmbeddingModelConfig



45587
45588
45589
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45587

def rag_embedding_model_config
  @rag_embedding_model_config
end

#rag_files_countFixnum

Output only. Number of RagFiles in the RagCorpus. NOTE: This field is not populated in the response of VertexRagDataService.ListRagCorpora. Corresponds to the JSON property ragFilesCount

Returns:

  • (Fixnum)


45593
45594
45595
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45593

def rag_files_count
  @rag_files_count
end

#rag_vector_db_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig

Config for the Vector DB to use for RAG. Corresponds to the JSON property ragVectorDbConfig



45598
45599
45600
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45598

def rag_vector_db_config
  @rag_vector_db_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


45603
45604
45605
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45603

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


45609
45610
45611
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45609

def satisfies_pzs
  @satisfies_pzs
end

#update_timeString

Output only. Timestamp when this RagCorpus was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


45615
45616
45617
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45615

def update_time
  @update_time
end

#vector_db_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig

Config for the Vector DB to use for RAG. Corresponds to the JSON property vectorDbConfig



45620
45621
45622
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45620

def vector_db_config
  @vector_db_config
end

#vertex_ai_search_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexAiSearchConfig

Config for the Vertex AI Search. Corresponds to the JSON property vertexAiSearchConfig



45625
45626
45627
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45625

def vertex_ai_search_config
  @vertex_ai_search_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45632
45633
45634
45635
45636
45637
45638
45639
45640
45641
45642
45643
45644
45645
45646
45647
45648
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45632

def update!(**args)
  @corpus_status = args[:corpus_status] if args.key?(:corpus_status)
  @corpus_type_config = args[:corpus_type_config] if args.key?(:corpus_type_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @rag_embedding_model_config = args[:rag_embedding_model_config] if args.key?(:rag_embedding_model_config)
  @rag_files_count = args[:rag_files_count] if args.key?(:rag_files_count)
  @rag_vector_db_config = args[:rag_vector_db_config] if args.key?(:rag_vector_db_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vector_db_config = args[:vector_db_config] if args.key?(:vector_db_config)
  @vertex_ai_search_config = args[:vertex_ai_search_config] if args.key?(:vertex_ai_search_config)
end