Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagCorpus
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagCorpus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A RagCorpus is a RagFile container and a project can have multiple RagCorpora.
Instance Attribute Summary collapse
-
#corpus_status ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CorpusStatus
RagCorpus status.
-
#corpus_type_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagCorpusCorpusTypeConfig
The config for the corpus type of the RagCorpus.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#name ⇒ String
Output only.
-
#rag_embedding_model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfig
Config for the embedding model to use for RAG.
-
#rag_files_count ⇒ Fixnum
Output only.
-
#rag_vector_db_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig
Config for the Vector DB to use for RAG.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#update_time ⇒ String
Output only.
-
#vector_db_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig
Config for the Vector DB to use for RAG.
-
#vertex_ai_search_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexAiSearchConfig
Config for the Vertex AI Search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagCorpus
constructor
A new instance of GoogleCloudAiplatformV1beta1RagCorpus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagCorpus
Returns a new instance of GoogleCloudAiplatformV1beta1RagCorpus.
42414 42415 42416 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42414 def initialize(**args) update!(**args) end |
Instance Attribute Details
#corpus_status ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CorpusStatus
RagCorpus status.
Corresponds to the JSON property corpusStatus
42337 42338 42339 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42337 def corpus_status @corpus_status end |
#corpus_type_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagCorpusCorpusTypeConfig
The config for the corpus type of the RagCorpus.
Corresponds to the JSON property corpusTypeConfig
42342 42343 42344 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42342 def corpus_type_config @corpus_type_config end |
#create_time ⇒ String
Output only. Timestamp when this RagCorpus was created.
Corresponds to the JSON property createTime
42347 42348 42349 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42347 def create_time @create_time end |
#description ⇒ String
Optional. The description of the RagCorpus.
Corresponds to the JSON property description
42352 42353 42354 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42352 def description @description end |
#display_name ⇒ String
Required. The display name of the RagCorpus. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
42358 42359 42360 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42358 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
42364 42365 42366 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42364 def encryption_spec @encryption_spec end |
#name ⇒ String
Output only. The resource name of the RagCorpus.
Corresponds to the JSON property name
42369 42370 42371 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42369 def name @name end |
#rag_embedding_model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfig
Config for the embedding model to use for RAG.
Corresponds to the JSON property ragEmbeddingModelConfig
42374 42375 42376 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42374 def @rag_embedding_model_config end |
#rag_files_count ⇒ Fixnum
Output only. Number of RagFiles in the RagCorpus. NOTE: This field is not
populated in the response of VertexRagDataService.ListRagCorpora.
Corresponds to the JSON property ragFilesCount
42380 42381 42382 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42380 def rag_files_count @rag_files_count end |
#rag_vector_db_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig
Config for the Vector DB to use for RAG.
Corresponds to the JSON property ragVectorDbConfig
42385 42386 42387 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42385 def rag_vector_db_config @rag_vector_db_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
42390 42391 42392 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42390 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
42396 42397 42398 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42396 def satisfies_pzs @satisfies_pzs end |
#update_time ⇒ String
Output only. Timestamp when this RagCorpus was last updated.
Corresponds to the JSON property updateTime
42402 42403 42404 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42402 def update_time @update_time end |
#vector_db_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig
Config for the Vector DB to use for RAG.
Corresponds to the JSON property vectorDbConfig
42407 42408 42409 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42407 def vector_db_config @vector_db_config end |
#vertex_ai_search_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexAiSearchConfig
Config for the Vertex AI Search.
Corresponds to the JSON property vertexAiSearchConfig
42412 42413 42414 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42412 def vertex_ai_search_config @vertex_ai_search_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42419 42420 42421 42422 42423 42424 42425 42426 42427 42428 42429 42430 42431 42432 42433 42434 42435 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42419 def update!(**args) @corpus_status = args[:corpus_status] if args.key?(:corpus_status) @corpus_type_config = args[:corpus_type_config] if args.key?(:corpus_type_config) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @rag_embedding_model_config = args[:rag_embedding_model_config] if args.key?(:rag_embedding_model_config) @rag_files_count = args[:rag_files_count] if args.key?(:rag_files_count) @rag_vector_db_config = args[:rag_vector_db_config] if args.key?(:rag_vector_db_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @update_time = args[:update_time] if args.key?(:update_time) @vector_db_config = args[:vector_db_config] if args.key?(:vector_db_config) @vertex_ai_search_config = args[:vertex_ai_search_config] if args.key?(:vertex_ai_search_config) end |