Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagCorpus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A RagCorpus is a RagFile container and a project can have multiple RagCorpora.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagCorpus

Returns a new instance of GoogleCloudAiplatformV1beta1RagCorpus.



36893
36894
36895
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#corpus_statusGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CorpusStatus

RagCorpus status. Corresponds to the JSON property corpusStatus



36816
36817
36818
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36816

def corpus_status
  @corpus_status
end

#corpus_type_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagCorpusCorpusTypeConfig

The config for the corpus type of the RagCorpus. Corresponds to the JSON property corpusTypeConfig



36821
36822
36823
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36821

def corpus_type_config
  @corpus_type_config
end

#create_timeString

Output only. Timestamp when this RagCorpus was created. Corresponds to the JSON property createTime

Returns:

  • (String)


36826
36827
36828
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36826

def create_time
  @create_time
end

#descriptionString

Optional. The description of the RagCorpus. Corresponds to the JSON property description

Returns:

  • (String)


36831
36832
36833
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36831

def description
  @description
end

#display_nameString

Required. The display name of the RagCorpus. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


36837
36838
36839
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36837

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



36843
36844
36845
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36843

def encryption_spec
  @encryption_spec
end

#nameString

Output only. The resource name of the RagCorpus. Corresponds to the JSON property name

Returns:

  • (String)


36848
36849
36850
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36848

def name
  @name
end

#rag_embedding_model_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfig

Config for the embedding model to use for RAG. Corresponds to the JSON property ragEmbeddingModelConfig



36853
36854
36855
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36853

def rag_embedding_model_config
  @rag_embedding_model_config
end

#rag_files_countFixnum

Output only. Number of RagFiles in the RagCorpus. NOTE: This field is not populated in the response of VertexRagDataService.ListRagCorpora. Corresponds to the JSON property ragFilesCount

Returns:

  • (Fixnum)


36859
36860
36861
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36859

def rag_files_count
  @rag_files_count
end

#rag_vector_db_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig

Config for the Vector DB to use for RAG. Corresponds to the JSON property ragVectorDbConfig



36864
36865
36866
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36864

def rag_vector_db_config
  @rag_vector_db_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


36869
36870
36871
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36869

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


36875
36876
36877
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36875

def satisfies_pzs
  @satisfies_pzs
end

#update_timeString

Output only. Timestamp when this RagCorpus was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


36881
36882
36883
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36881

def update_time
  @update_time
end

#vector_db_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig

Config for the Vector DB to use for RAG. Corresponds to the JSON property vectorDbConfig



36886
36887
36888
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36886

def vector_db_config
  @vector_db_config
end

#vertex_ai_search_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexAiSearchConfig

Config for the Vertex AI Search. Corresponds to the JSON property vertexAiSearchConfig



36891
36892
36893
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36891

def vertex_ai_search_config
  @vertex_ai_search_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36898
36899
36900
36901
36902
36903
36904
36905
36906
36907
36908
36909
36910
36911
36912
36913
36914
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36898

def update!(**args)
  @corpus_status = args[:corpus_status] if args.key?(:corpus_status)
  @corpus_type_config = args[:corpus_type_config] if args.key?(:corpus_type_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @rag_embedding_model_config = args[:rag_embedding_model_config] if args.key?(:rag_embedding_model_config)
  @rag_files_count = args[:rag_files_count] if args.key?(:rag_files_count)
  @rag_vector_db_config = args[:rag_vector_db_config] if args.key?(:rag_vector_db_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vector_db_config = args[:vector_db_config] if args.key?(:vector_db_config)
  @vertex_ai_search_config = args[:vertex_ai_search_config] if args.key?(:vertex_ai_search_config)
end