Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagDataSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The schema of the user specified metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagDataSchema

Returns a new instance of GoogleCloudAiplatformV1beta1RagDataSchema.



44568
44569
44570
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Required. The key of this data schema. This key should be matching the key of user specified metadata and unique inside corpus. This value can be up to 63 characters, and valid characters are /a-z-/. The first character must be a letter, the last could be a letter or a number. Corresponds to the JSON property key

Returns:

  • (String)


44552
44553
44554
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44552

def key
  @key
end

#nameString

Identifier. Resource name of the data schema in the form of: projects/ project_number/locations/location/ragCorpora/rag_corpus/ragDataSchemas/ rag_data_schema`where therag_data_schemapart should be the same as the keyfield below. Corresponds to the JSON propertyname`

Returns:

  • (String)


44560
44561
44562
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44560

def name
  @name
end

#schema_detailsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails

Data schema details indicates the data type and the data struct corresponding to the key of user specified metadata. Corresponds to the JSON property schemaDetails



44566
44567
44568
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44566

def schema_details
  @schema_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44573
44574
44575
44576
44577
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44573

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @name = args[:name] if args.key?(:name)
  @schema_details = args[:schema_details] if args.key?(:schema_details)
end