Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagDataSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The schema of the user specified metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagDataSchema

Returns a new instance of GoogleCloudAiplatformV1beta1RagDataSchema.



42521
42522
42523
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Required. The key of this data schema. This key should be matching the key of user specified metadata and unique inside corpus. This value can be up to 63 characters, and valid characters are /a-z-/. The first character must be a letter, the last could be a letter or a number. Corresponds to the JSON property key

Returns:

  • (String)


42505
42506
42507
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42505

def key
  @key
end

#nameString

Identifier. Resource name of the data schema in the form of: projects/ project_number/locations/location/ragCorpora/rag_corpus/ragDataSchemas/ rag_data_schema`where therag_data_schemapart should be the same as the keyfield below. Corresponds to the JSON propertyname`

Returns:

  • (String)


42513
42514
42515
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42513

def name
  @name
end

#schema_detailsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails

Data schema details indicates the data type and the data struct corresponding to the key of user specified metadata. Corresponds to the JSON property schemaDetails



42519
42520
42521
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42519

def schema_details
  @schema_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42526
42527
42528
42529
42530
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42526

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @name = args[:name] if args.key?(:name)
  @schema_details = args[:schema_details] if args.key?(:schema_details)
end