Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagDataSchema
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagDataSchema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The schema of the user specified metadata.
Instance Attribute Summary collapse
-
#key ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#schema_details ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails
Data schema details indicates the data type and the data struct corresponding to the key of user specified metadata.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagDataSchema
constructor
A new instance of GoogleCloudAiplatformV1beta1RagDataSchema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagDataSchema
Returns a new instance of GoogleCloudAiplatformV1beta1RagDataSchema.
37000 37001 37002 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37000 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Required. The key of this data schema. This key should be matching the key of
user specified metadata and unique inside corpus. This value can be up to 63
characters, and valid characters are /a-z-/. The first character must be a
letter, the last could be a letter or a number.
Corresponds to the JSON property key
36984 36985 36986 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36984 def key @key end |
#name ⇒ String
Identifier. Resource name of the data schema in the form of: projects/
project_number/locations/location/ragCorpora/rag_corpus/ragDataSchemas/
rag_data_schema`where therag_data_schemapart should be the same as the
keyfield below.
Corresponds to the JSON propertyname`
36992 36993 36994 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36992 def name @name end |
#schema_details ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails
Data schema details indicates the data type and the data struct corresponding
to the key of user specified metadata.
Corresponds to the JSON property schemaDetails
36998 36999 37000 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 36998 def schema_details @schema_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37005 37006 37007 37008 37009 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37005 def update!(**args) @key = args[:key] if args.key?(:key) @name = args[:name] if args.key?(:name) @schema_details = args[:schema_details] if args.key?(:schema_details) end |