Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigSparseEmbeddingConfigBm25

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Message for BM25 parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigSparseEmbeddingConfigBm25

Returns a new instance of GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigSparseEmbeddingConfigBm25.



41977
41978
41979
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41977

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bFloat

Optional. The parameter to control document length normalization. It determines how much the document length affects the final score. b is in the range of [0, 1]. The default value is 0.75. Corresponds to the JSON property b

Returns:

  • (Float)


41962
41963
41964
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41962

def b
  @b
end

#k1Float

Optional. The parameter to control term frequency saturation. It determines the scaling between the matching term frequency and final score. k1 is in the range of [1.2, 3]. The default value is 1.2. Corresponds to the JSON property k1

Returns:

  • (Float)


41969
41970
41971
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41969

def k1
  @k1
end

#multilingualBoolean Also known as: multilingual?

Optional. Use multilingual tokenizer if set to true. Corresponds to the JSON property multilingual

Returns:

  • (Boolean)


41974
41975
41976
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41974

def multilingual
  @multilingual
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41982
41983
41984
41985
41986
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41982

def update!(**args)
  @b = args[:b] if args.key?(:b)
  @k1 = args[:k1] if args.key?(:k1)
  @multilingual = args[:multilingual] if args.key?(:multilingual)
end