Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigSparseEmbeddingConfigBm25

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Message for BM25 parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigSparseEmbeddingConfigBm25

Returns a new instance of GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigSparseEmbeddingConfigBm25.



37105
37106
37107
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bFloat

Optional. The parameter to control document length normalization. It determines how much the document length affects the final score. b is in the range of [0, 1]. The default value is 0.75. Corresponds to the JSON property b

Returns:

  • (Float)


37090
37091
37092
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37090

def b
  @b
end

#k1Float

Optional. The parameter to control term frequency saturation. It determines the scaling between the matching term frequency and final score. k1 is in the range of [1.2, 3]. The default value is 1.2. Corresponds to the JSON property k1

Returns:

  • (Float)


37097
37098
37099
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37097

def k1
  @k1
end

#multilingualBoolean Also known as: multilingual?

Optional. Use multilingual tokenizer if set to true. Corresponds to the JSON property multilingual

Returns:

  • (Boolean)


37102
37103
37104
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37102

def multilingual
  @multilingual
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37110
37111
37112
37113
37114
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37110

def update!(**args)
  @b = args[:b] if args.key?(:b)
  @k1 = args[:k1] if args.key?(:k1)
  @multilingual = args[:multilingual] if args.key?(:multilingual)
end