Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigVertexPredictionEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigVertexPredictionEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Config representing a model hosted on Vertex Prediction Endpoint.
Instance Attribute Summary collapse
-
#endpoint ⇒ String
Required.
-
#model ⇒ String
Output only.
-
#model_version_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigVertexPredictionEndpoint
constructor
A new instance of GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigVertexPredictionEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigVertexPredictionEndpoint
Returns a new instance of GoogleCloudAiplatformV1beta1RagEmbeddingModelConfigVertexPredictionEndpoint.
37074 37075 37076 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37074 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint ⇒ String
Required. The endpoint resource name. Format: projects/project/locations/
location/publishers/publisher/models/modelor `projects/`project`/
locations/`location`/endpoints/`endpoint
Corresponds to the JSON property endpoint
37059 37060 37061 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37059 def endpoint @endpoint end |
#model ⇒ String
Output only. The resource name of the model that is deployed on the endpoint.
Present only when the endpoint is not a publisher model. Pattern: projects/
project/locations/location/models/model`
Corresponds to the JSON propertymodel`
37066 37067 37068 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37066 def model @model end |
#model_version_id ⇒ String
Output only. Version ID of the model that is deployed on the endpoint. Present
only when the endpoint is not a publisher model.
Corresponds to the JSON property modelVersionId
37072 37073 37074 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37072 def model_version_id @model_version_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37079 37080 37081 37082 37083 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37079 def update!(**args) @endpoint = args[:endpoint] if args.key?(:endpoint) @model = args[:model] if args.key?(:model) @model_version_id = args[:model_version_id] if args.key?(:model_version_id) end |