Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagFile
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagFile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A RagFile contains user data for chunking, embedding and indexing.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#direct_upload_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DirectUploadSource
The input content is encapsulated and uploaded in the request.
-
#display_name ⇒ String
Required.
-
#file_status ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FileStatus
RagFile status.
-
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource
The Google Cloud Storage location for the input content.
-
#google_drive_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GoogleDriveSource
The Google Drive location for the input content.
-
#jira_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1JiraSource
The Jira source for the ImportRagFilesRequest.
-
#name ⇒ String
Output only.
-
#rag_file_type ⇒ String
Output only.
-
#share_point_sources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SharePointSources
The SharePointSources to pass to ImportRagFiles.
-
#size_bytes ⇒ Fixnum
Output only.
-
#slack_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SlackSource
The Slack source for the ImportRagFilesRequest.
-
#update_time ⇒ String
Output only.
-
#user_metadata ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagFile
constructor
A new instance of GoogleCloudAiplatformV1beta1RagFile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagFile
Returns a new instance of GoogleCloudAiplatformV1beta1RagFile.
45994 45995 45996 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this RagFile was created.
Corresponds to the JSON property createTime
45920 45921 45922 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45920 def create_time @create_time end |
#description ⇒ String
Optional. The description of the RagFile.
Corresponds to the JSON property description
45925 45926 45927 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45925 def description @description end |
#direct_upload_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DirectUploadSource
The input content is encapsulated and uploaded in the request.
Corresponds to the JSON property directUploadSource
45930 45931 45932 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45930 def direct_upload_source @direct_upload_source end |
#display_name ⇒ String
Required. The display name of the RagFile. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
45936 45937 45938 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45936 def display_name @display_name end |
#file_status ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FileStatus
RagFile status.
Corresponds to the JSON property fileStatus
45941 45942 45943 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45941 def file_status @file_status end |
#gcs_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
45946 45947 45948 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45946 def gcs_source @gcs_source end |
#google_drive_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GoogleDriveSource
The Google Drive location for the input content.
Corresponds to the JSON property googleDriveSource
45951 45952 45953 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45951 def google_drive_source @google_drive_source end |
#jira_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1JiraSource
The Jira source for the ImportRagFilesRequest.
Corresponds to the JSON property jiraSource
45956 45957 45958 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45956 def jira_source @jira_source end |
#name ⇒ String
Output only. The resource name of the RagFile.
Corresponds to the JSON property name
45961 45962 45963 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45961 def name @name end |
#rag_file_type ⇒ String
Output only. The type of the RagFile.
Corresponds to the JSON property ragFileType
45966 45967 45968 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45966 def rag_file_type @rag_file_type end |
#share_point_sources ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SharePointSources
The SharePointSources to pass to ImportRagFiles.
Corresponds to the JSON property sharePointSources
45971 45972 45973 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45971 def share_point_sources @share_point_sources end |
#size_bytes ⇒ Fixnum
Output only. The size of the RagFile in bytes.
Corresponds to the JSON property sizeBytes
45976 45977 45978 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45976 def size_bytes @size_bytes end |
#slack_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SlackSource
The Slack source for the ImportRagFilesRequest.
Corresponds to the JSON property slackSource
45981 45982 45983 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45981 def slack_source @slack_source end |
#update_time ⇒ String
Output only. Timestamp when this RagFile was last updated.
Corresponds to the JSON property updateTime
45986 45987 45988 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45986 def update_time @update_time end |
#user_metadata ⇒ String
Output only. The metadata for metadata search. The user_metadata Needs to be
in JSON format.
Corresponds to the JSON property userMetadata
45992 45993 45994 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45992 def @user_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45999 46000 46001 46002 46003 46004 46005 46006 46007 46008 46009 46010 46011 46012 46013 46014 46015 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45999 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @direct_upload_source = args[:direct_upload_source] if args.key?(:direct_upload_source) @display_name = args[:display_name] if args.key?(:display_name) @file_status = args[:file_status] if args.key?(:file_status) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source) @jira_source = args[:jira_source] if args.key?(:jira_source) @name = args[:name] if args.key?(:name) @rag_file_type = args[:rag_file_type] if args.key?(:rag_file_type) @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources) @size_bytes = args[:size_bytes] if args.key?(:size_bytes) @slack_source = args[:slack_source] if args.key?(:slack_source) @update_time = args[:update_time] if args.key?(:update_time) @user_metadata = args[:user_metadata] if args.key?(:user_metadata) end |