Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A RagFile contains user data for chunking, embedding and indexing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagFile

Returns a new instance of GoogleCloudAiplatformV1beta1RagFile.



42132
42133
42134
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42132

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this RagFile was created. Corresponds to the JSON property createTime

Returns:

  • (String)


42058
42059
42060
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42058

def create_time
  @create_time
end

#descriptionString

Optional. The description of the RagFile. Corresponds to the JSON property description

Returns:

  • (String)


42063
42064
42065
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42063

def description
  @description
end

#direct_upload_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DirectUploadSource

The input content is encapsulated and uploaded in the request. Corresponds to the JSON property directUploadSource



42068
42069
42070
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42068

def direct_upload_source
  @direct_upload_source
end

#display_nameString

Required. The display name of the RagFile. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


42074
42075
42076
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42074

def display_name
  @display_name
end

#file_statusGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FileStatus

RagFile status. Corresponds to the JSON property fileStatus



42079
42080
42081
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42079

def file_status
  @file_status
end

#gcs_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



42084
42085
42086
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42084

def gcs_source
  @gcs_source
end

#google_drive_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GoogleDriveSource

The Google Drive location for the input content. Corresponds to the JSON property googleDriveSource



42089
42090
42091
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42089

def google_drive_source
  @google_drive_source
end

#jira_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1JiraSource

The Jira source for the ImportRagFilesRequest. Corresponds to the JSON property jiraSource



42094
42095
42096
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42094

def jira_source
  @jira_source
end

#nameString

Output only. The resource name of the RagFile. Corresponds to the JSON property name

Returns:

  • (String)


42099
42100
42101
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42099

def name
  @name
end

#rag_file_typeString

Output only. The type of the RagFile. Corresponds to the JSON property ragFileType

Returns:

  • (String)


42104
42105
42106
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42104

def rag_file_type
  @rag_file_type
end

#share_point_sourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SharePointSources

The SharePointSources to pass to ImportRagFiles. Corresponds to the JSON property sharePointSources



42109
42110
42111
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42109

def share_point_sources
  @share_point_sources
end

#size_bytesFixnum

Output only. The size of the RagFile in bytes. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


42114
42115
42116
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42114

def size_bytes
  @size_bytes
end

#slack_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SlackSource

The Slack source for the ImportRagFilesRequest. Corresponds to the JSON property slackSource



42119
42120
42121
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42119

def slack_source
  @slack_source
end

#update_timeString

Output only. Timestamp when this RagFile was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


42124
42125
42126
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42124

def update_time
  @update_time
end

#user_metadataString

Output only. The metadata for metadata search. The user_metadata Needs to be in JSON format. Corresponds to the JSON property userMetadata

Returns:

  • (String)


42130
42131
42132
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42130

def 
  @user_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42137
42138
42139
42140
42141
42142
42143
42144
42145
42146
42147
42148
42149
42150
42151
42152
42153
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42137

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @direct_upload_source = args[:direct_upload_source] if args.key?(:direct_upload_source)
  @display_name = args[:display_name] if args.key?(:display_name)
  @file_status = args[:file_status] if args.key?(:file_status)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source)
  @jira_source = args[:jira_source] if args.key?(:jira_source)
  @name = args[:name] if args.key?(:name)
  @rag_file_type = args[:rag_file_type] if args.key?(:rag_file_type)
  @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
  @slack_source = args[:slack_source] if args.key?(:slack_source)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_metadata = args[:user_metadata] if args.key?(:user_metadata)
end