Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A RagFile contains user data for chunking, embedding and indexing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagFile

Returns a new instance of GoogleCloudAiplatformV1beta1RagFile.



37193
37194
37195
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this RagFile was created. Corresponds to the JSON property createTime

Returns:

  • (String)


37119
37120
37121
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37119

def create_time
  @create_time
end

#descriptionString

Optional. The description of the RagFile. Corresponds to the JSON property description

Returns:

  • (String)


37124
37125
37126
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37124

def description
  @description
end

#direct_upload_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DirectUploadSource

The input content is encapsulated and uploaded in the request. Corresponds to the JSON property directUploadSource



37129
37130
37131
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37129

def direct_upload_source
  @direct_upload_source
end

#display_nameString

Required. The display name of the RagFile. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


37135
37136
37137
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37135

def display_name
  @display_name
end

#file_statusGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FileStatus

RagFile status. Corresponds to the JSON property fileStatus



37140
37141
37142
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37140

def file_status
  @file_status
end

#gcs_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



37145
37146
37147
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37145

def gcs_source
  @gcs_source
end

#google_drive_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GoogleDriveSource

The Google Drive location for the input content. Corresponds to the JSON property googleDriveSource



37150
37151
37152
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37150

def google_drive_source
  @google_drive_source
end

#jira_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1JiraSource

The Jira source for the ImportRagFilesRequest. Corresponds to the JSON property jiraSource



37155
37156
37157
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37155

def jira_source
  @jira_source
end

#nameString

Output only. The resource name of the RagFile. Corresponds to the JSON property name

Returns:

  • (String)


37160
37161
37162
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37160

def name
  @name
end

#rag_file_typeString

Output only. The type of the RagFile. Corresponds to the JSON property ragFileType

Returns:

  • (String)


37165
37166
37167
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37165

def rag_file_type
  @rag_file_type
end

#share_point_sourcesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SharePointSources

The SharePointSources to pass to ImportRagFiles. Corresponds to the JSON property sharePointSources



37170
37171
37172
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37170

def share_point_sources
  @share_point_sources
end

#size_bytesFixnum

Output only. The size of the RagFile in bytes. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


37175
37176
37177
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37175

def size_bytes
  @size_bytes
end

#slack_sourceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SlackSource

The Slack source for the ImportRagFilesRequest. Corresponds to the JSON property slackSource



37180
37181
37182
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37180

def slack_source
  @slack_source
end

#update_timeString

Output only. Timestamp when this RagFile was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


37185
37186
37187
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37185

def update_time
  @update_time
end

#user_metadataString

Output only. The metadata for metadata search. The user_metadata Needs to be in JSON format. Corresponds to the JSON property userMetadata

Returns:

  • (String)


37191
37192
37193
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37191

def 
  @user_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37198
37199
37200
37201
37202
37203
37204
37205
37206
37207
37208
37209
37210
37211
37212
37213
37214
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37198

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @direct_upload_source = args[:direct_upload_source] if args.key?(:direct_upload_source)
  @display_name = args[:display_name] if args.key?(:display_name)
  @file_status = args[:file_status] if args.key?(:file_status)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source)
  @jira_source = args[:jira_source] if args.key?(:jira_source)
  @name = args[:name] if args.key?(:name)
  @rag_file_type = args[:rag_file_type] if args.key?(:rag_file_type)
  @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
  @slack_source = args[:slack_source] if args.key?(:slack_source)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_metadata = args[:user_metadata] if args.key?(:user_metadata)
end