Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagFileParsingConfigLlmParser
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagFileParsingConfigLlmParser
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Specifies the LLM parsing for RagFiles.
Instance Attribute Summary collapse
-
#custom_parsing_prompt ⇒ String
The prompt to use for parsing.
-
#global_max_parsing_requests_per_min ⇒ Fixnum
The maximum number of requests the job is allowed to make to the LLM model per minute in this project.
-
#max_parsing_requests_per_min ⇒ Fixnum
The maximum number of requests the job is allowed to make to the LLM model per minute.
-
#model_name ⇒ String
The name of a LLM model used for parsing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagFileParsingConfigLlmParser
constructor
A new instance of GoogleCloudAiplatformV1beta1RagFileParsingConfigLlmParser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagFileParsingConfigLlmParser
Returns a new instance of GoogleCloudAiplatformV1beta1RagFileParsingConfigLlmParser.
37522 37523 37524 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37522 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_parsing_prompt ⇒ String
The prompt to use for parsing. If not specified, a default prompt will be used.
Corresponds to the JSON property customParsingPrompt
37497 37498 37499 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37497 def custom_parsing_prompt @custom_parsing_prompt end |
#global_max_parsing_requests_per_min ⇒ Fixnum
The maximum number of requests the job is allowed to make to the LLM model per
minute in this project. Consult https://cloud.google.com/vertex-ai/generative-
ai/docs/quotas and your document size to set an appropriate value here. If
this value is not specified, max_parsing_requests_per_min will be used by
indexing pipeline job as the global limit.
Corresponds to the JSON property globalMaxParsingRequestsPerMin
37506 37507 37508 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37506 def global_max_parsing_requests_per_min @global_max_parsing_requests_per_min end |
#max_parsing_requests_per_min ⇒ Fixnum
The maximum number of requests the job is allowed to make to the LLM model per
minute. Consult https://cloud.google.com/vertex-ai/generative-ai/docs/quotas
and your document size to set an appropriate value here. If unspecified, a
default value of 5000 QPM would be used.
Corresponds to the JSON property maxParsingRequestsPerMin
37514 37515 37516 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37514 def max_parsing_requests_per_min @max_parsing_requests_per_min end |
#model_name ⇒ String
The name of a LLM model used for parsing. Format: * projects/project_id/
locations/location/publishers/publisher/models/model`
Corresponds to the JSON propertymodelName`
37520 37521 37522 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37520 def model_name @model_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37527 37528 37529 37530 37531 37532 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37527 def update!(**args) @custom_parsing_prompt = args[:custom_parsing_prompt] if args.key?(:custom_parsing_prompt) @global_max_parsing_requests_per_min = args[:global_max_parsing_requests_per_min] if args.key?(:global_max_parsing_requests_per_min) @max_parsing_requests_per_min = args[:max_parsing_requests_per_min] if args.key?(:max_parsing_requests_per_min) @model_name = args[:model_name] if args.key?(:model_name) end |