Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration message for RagManagedDb used by RagEngine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagManagedDbConfig

Returns a new instance of GoogleCloudAiplatformV1beta1RagManagedDbConfig.



46871
46872
46873
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46871

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#basicGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigBasic

Basic tier is a cost-effective and low compute tier suitable for the following cases: * Experimenting with RagManagedDb. * Small data size. * Latency insensitive workload. * Only using RAG Engine with external vector DBs. NOTE: This is the default tier under Spanner mode if not explicitly chosen. Corresponds to the JSON property basic



46837
46838
46839
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46837

def basic
  @basic
end

#enterpriseGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigEnterprise

Enterprise tier offers production grade performance along with autoscaling functionality. It is suitable for customers with large amounts of data or performance sensitive workloads. Corresponds to the JSON property enterprise



46844
46845
46846
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46844

def enterprise
  @enterprise
end

#scaledGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigScaled

Scaled tier offers production grade performance along with autoscaling functionality. It is suitable for customers with large amounts of data or performance sensitive workloads. Corresponds to the JSON property scaled



46851
46852
46853
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46851

def scaled
  @scaled
end

#serverlessGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigServerless

Message to configure the serverless mode offered by RAG Engine. Corresponds to the JSON property serverless



46856
46857
46858
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46856

def serverless
  @serverless
end

#spannerGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigSpanner

Message to configure the Spanner database used by RagManagedDb. Corresponds to the JSON property spanner



46861
46862
46863
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46861

def spanner
  @spanner
end

#unprovisionedGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigUnprovisioned

Disables the RAG Engine service and deletes all your data held within this service. This will halt the billing of the service. NOTE: Once deleted the data cannot be recovered. To start using RAG Engine again, you will need to update the tier by calling the UpdateRagEngineConfig API. Corresponds to the JSON property unprovisioned



46869
46870
46871
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46869

def unprovisioned
  @unprovisioned
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46876
46877
46878
46879
46880
46881
46882
46883
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46876

def update!(**args)
  @basic = args[:basic] if args.key?(:basic)
  @enterprise = args[:enterprise] if args.key?(:enterprise)
  @scaled = args[:scaled] if args.key?(:scaled)
  @serverless = args[:serverless] if args.key?(:serverless)
  @spanner = args[:spanner] if args.key?(:spanner)
  @unprovisioned = args[:unprovisioned] if args.key?(:unprovisioned)
end