Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration message for RagManagedDb used by RagEngine.
Instance Attribute Summary collapse
-
#basic ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigBasic
Basic tier is a cost-effective and low compute tier suitable for the following cases: * Experimenting with RagManagedDb.
-
#enterprise ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigEnterprise
Enterprise tier offers production grade performance along with autoscaling functionality.
-
#scaled ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigScaled
Scaled tier offers production grade performance along with autoscaling functionality.
-
#serverless ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigServerless
Message to configure the serverless mode offered by RAG Engine.
-
#spanner ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigSpanner
Message to configure the Spanner database used by RagManagedDb.
-
#unprovisioned ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigUnprovisioned
Disables the RAG Engine service and deletes all your data held within this service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagManagedDbConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1RagManagedDbConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagManagedDbConfig
Returns a new instance of GoogleCloudAiplatformV1beta1RagManagedDbConfig.
43119 43120 43121 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#basic ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigBasic
Basic tier is a cost-effective and low compute tier suitable for the following
cases: * Experimenting with RagManagedDb. * Small data size. * Latency
insensitive workload. * Only using RAG Engine with external vector DBs. NOTE:
This is the default tier under Spanner mode if not explicitly chosen.
Corresponds to the JSON property basic
43085 43086 43087 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43085 def basic @basic end |
#enterprise ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigEnterprise
Enterprise tier offers production grade performance along with autoscaling
functionality. It is suitable for customers with large amounts of data or
performance sensitive workloads.
Corresponds to the JSON property enterprise
43092 43093 43094 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43092 def enterprise @enterprise end |
#scaled ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigScaled
Scaled tier offers production grade performance along with autoscaling
functionality. It is suitable for customers with large amounts of data or
performance sensitive workloads.
Corresponds to the JSON property scaled
43099 43100 43101 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43099 def scaled @scaled end |
#serverless ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigServerless
Message to configure the serverless mode offered by RAG Engine.
Corresponds to the JSON property serverless
43104 43105 43106 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43104 def serverless @serverless end |
#spanner ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigSpanner
Message to configure the Spanner database used by RagManagedDb.
Corresponds to the JSON property spanner
43109 43110 43111 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43109 def spanner @spanner end |
#unprovisioned ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigUnprovisioned
Disables the RAG Engine service and deletes all your data held within this
service. This will halt the billing of the service. NOTE: Once deleted the
data cannot be recovered. To start using RAG Engine again, you will need to
update the tier by calling the UpdateRagEngineConfig API.
Corresponds to the JSON property unprovisioned
43117 43118 43119 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43117 def unprovisioned @unprovisioned end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43124 43125 43126 43127 43128 43129 43130 43131 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43124 def update!(**args) @basic = args[:basic] if args.key?(:basic) @enterprise = args[:enterprise] if args.key?(:enterprise) @scaled = args[:scaled] if args.key?(:scaled) @serverless = args[:serverless] if args.key?(:serverless) @spanner = args[:spanner] if args.key?(:spanner) @unprovisioned = args[:unprovisioned] if args.key?(:unprovisioned) end |