Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration message for RagManagedDb used by RagEngine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagManagedDbConfig

Returns a new instance of GoogleCloudAiplatformV1beta1RagManagedDbConfig.



37531
37532
37533
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#basicGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigBasic

Basic tier is a cost-effective and low compute tier suitable for the following cases: * Experimenting with RagManagedDb. * Small data size. * Latency insensitive workload. * Only using RAG Engine with external vector DBs. NOTE: This is the default tier under Spanner mode if not explicitly chosen. Corresponds to the JSON property basic



37497
37498
37499
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37497

def basic
  @basic
end

#enterpriseGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigEnterprise

Enterprise tier offers production grade performance along with autoscaling functionality. It is suitable for customers with large amounts of data or performance sensitive workloads. Corresponds to the JSON property enterprise



37504
37505
37506
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37504

def enterprise
  @enterprise
end

#scaledGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigScaled

Scaled tier offers production grade performance along with autoscaling functionality. It is suitable for customers with large amounts of data or performance sensitive workloads. Corresponds to the JSON property scaled



37511
37512
37513
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37511

def scaled
  @scaled
end

#serverlessGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigServerless

Message to configure the serverless mode offered by RAG Engine. Corresponds to the JSON property serverless



37516
37517
37518
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37516

def serverless
  @serverless
end

#spannerGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigSpanner

Message to configure the Spanner database used by RagManagedDb. Corresponds to the JSON property spanner



37521
37522
37523
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37521

def spanner
  @spanner
end

#unprovisionedGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigUnprovisioned

Disables the RAG Engine service and deletes all your data held within this service. This will halt the billing of the service. NOTE: Once deleted the data cannot be recovered. To start using RAG Engine again, you will need to update the tier by calling the UpdateRagEngineConfig API. Corresponds to the JSON property unprovisioned



37529
37530
37531
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37529

def unprovisioned
  @unprovisioned
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37536
37537
37538
37539
37540
37541
37542
37543
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37536

def update!(**args)
  @basic = args[:basic] if args.key?(:basic)
  @enterprise = args[:enterprise] if args.key?(:enterprise)
  @scaled = args[:scaled] if args.key?(:scaled)
  @serverless = args[:serverless] if args.key?(:serverless)
  @spanner = args[:spanner] if args.key?(:spanner)
  @unprovisioned = args[:unprovisioned] if args.key?(:unprovisioned)
end