Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigEnterprise

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Enterprise tier offers production grade performance along with autoscaling functionality. It is suitable for customers with large amounts of data or performance sensitive workloads.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagManagedDbConfigEnterprise

Returns a new instance of GoogleCloudAiplatformV1beta1RagManagedDbConfigEnterprise.



43156
43157
43158
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43156

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43161
43162
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43161

def update!(**args)
end