Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagManagedDbConfigScaled

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Scaled tier offers production grade performance along with autoscaling functionality. It is suitable for customers with large amounts of data or performance sensitive workloads.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagManagedDbConfigScaled

Returns a new instance of GoogleCloudAiplatformV1beta1RagManagedDbConfigScaled.



44467
44468
44469
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44467

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44472
44473
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44472

def update!(**args)
end