Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Data schema details indicates the data type and the data struct corresponding to the key of user specified metadata.
Instance Attribute Summary collapse
-
#granularity ⇒ String
The granularity associated with this RagMetadataSchema.
-
#list_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsListConfig
Config for List data type.
-
#search_strategy ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy
The search strategy for the metadata value of the
key. -
#type ⇒ String
Type of the metadata.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails
constructor
A new instance of GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails
Returns a new instance of GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails.
44596 44597 44598 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44596 def initialize(**args) update!(**args) end |
Instance Attribute Details
#granularity ⇒ String
The granularity associated with this RagMetadataSchema.
Corresponds to the JSON property granularity
44579 44580 44581 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44579 def granularity @granularity end |
#list_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsListConfig
Config for List data type.
Corresponds to the JSON property listConfig
44584 44585 44586 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44584 def list_config @list_config end |
#search_strategy ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy
The search strategy for the metadata value of the key.
Corresponds to the JSON property searchStrategy
44589 44590 44591 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44589 def search_strategy @search_strategy end |
#type ⇒ String
Type of the metadata.
Corresponds to the JSON property type
44594 44595 44596 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44594 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44601 44602 44603 44604 44605 44606 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44601 def update!(**args) @granularity = args[:granularity] if args.key?(:granularity) @list_config = args[:list_config] if args.key?(:list_config) @search_strategy = args[:search_strategy] if args.key?(:search_strategy) @type = args[:type] if args.key?(:type) end |