Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Data schema details indicates the data type and the data struct corresponding to the key of user specified metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails

Returns a new instance of GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails.



43300
43301
43302
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43300

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#granularityString

The granularity associated with this RagMetadataSchema. Corresponds to the JSON property granularity

Returns:

  • (String)


43283
43284
43285
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43283

def granularity
  @granularity
end

#list_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsListConfig

Config for List data type. Corresponds to the JSON property listConfig



43288
43289
43290
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43288

def list_config
  @list_config
end

#search_strategyGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy

The search strategy for the metadata value of the key. Corresponds to the JSON property searchStrategy



43293
43294
43295
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43293

def search_strategy
  @search_strategy
end

#typeString

Type of the metadata. Corresponds to the JSON property type

Returns:

  • (String)


43298
43299
43300
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43298

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43305
43306
43307
43308
43309
43310
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43305

def update!(**args)
  @granularity = args[:granularity] if args.key?(:granularity)
  @list_config = args[:list_config] if args.key?(:list_config)
  @search_strategy = args[:search_strategy] if args.key?(:search_strategy)
  @type = args[:type] if args.key?(:type)
end