Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsListConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsListConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Config for List data type.
Instance Attribute Summary collapse
-
#value_schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails
Data schema details indicates the data type and the data struct corresponding to the key of user specified metadata.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsListConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsListConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsListConfig
Returns a new instance of GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsListConfig.
37735 37736 37737 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37735 def initialize(**args) update!(**args) end |
Instance Attribute Details
#value_schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetails
Data schema details indicates the data type and the data struct corresponding
to the key of user specified metadata.
Corresponds to the JSON property valueSchema
37733 37734 37735 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37733 def value_schema @value_schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37740 37741 37742 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37740 def update!(**args) @value_schema = args[:value_schema] if args.key?(:value_schema) end |