Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The search strategy for the metadata value of the key.
Instance Attribute Summary collapse
-
#search_strategy_type ⇒ String
The search strategy type to be applied on the metadata key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy
constructor
A new instance of GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy
Returns a new instance of GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy.
37821 37822 37823 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37821 def initialize(**args) update!(**args) end |
Instance Attribute Details
#search_strategy_type ⇒ String
The search strategy type to be applied on the metadata key.
Corresponds to the JSON property searchStrategyType
37819 37820 37821 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37819 def search_strategy_type @search_strategy_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37826 37827 37828 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37826 def update!(**args) @search_strategy_type = args[:search_strategy_type] if args.key?(:search_strategy_type) end |