Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The search strategy for the metadata value of the key.
Instance Attribute Summary collapse
-
#search_strategy_type ⇒ String
The search strategy type to be applied on the metadata key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy
constructor
A new instance of GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy
Returns a new instance of GoogleCloudAiplatformV1beta1RagMetadataSchemaDetailsSearchStrategy.
37754 37755 37756 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37754 def initialize(**args) update!(**args) end |
Instance Attribute Details
#search_strategy_type ⇒ String
The search strategy type to be applied on the metadata key.
Corresponds to the JSON property searchStrategyType
37752 37753 37754 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37752 def search_strategy_type @search_strategy_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37759 37760 37761 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37759 def update!(**args) @search_strategy_type = args[:search_strategy_type] if args.key?(:search_strategy_type) end |