Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Config for the Vector DB to use for RAG.
Instance Attribute Summary collapse
-
#api_auth ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ApiAuth
The generic reusable api auth config.
-
#pinecone ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigPinecone
The config for the Pinecone.
-
#rag_embedding_model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfig
Config for the embedding model to use for RAG.
-
#rag_managed_db ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigRagManagedDb
The config for the default RAG-managed Vector DB.
-
#rag_managed_vertex_vector_search ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigRagManagedVertexVectorSearch
The config for the RAG-managed Vertex Vector Search 2.0.
-
#vertex_feature_store ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigVertexFeatureStore
The config for the Vertex Feature Store.
-
#vertex_vector_search ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigVertexVectorSearch
The config for the Vertex Vector Search.
-
#weaviate ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigWeaviate
The config for the Weaviate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagVectorDbConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1RagVectorDbConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagVectorDbConfig
Returns a new instance of GoogleCloudAiplatformV1beta1RagVectorDbConfig.
38026 38027 38028 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_auth ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ApiAuth
The generic reusable api auth config. Deprecated. Please use AuthConfig (
google/cloud/aiplatform/master/auth.proto) instead.
Corresponds to the JSON property apiAuth
37989 37990 37991 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37989 def api_auth @api_auth end |
#pinecone ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigPinecone
The config for the Pinecone.
Corresponds to the JSON property pinecone
37994 37995 37996 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37994 def pinecone @pinecone end |
#rag_embedding_model_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagEmbeddingModelConfig
Config for the embedding model to use for RAG.
Corresponds to the JSON property ragEmbeddingModelConfig
37999 38000 38001 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 37999 def @rag_embedding_model_config end |
#rag_managed_db ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigRagManagedDb
The config for the default RAG-managed Vector DB.
Corresponds to the JSON property ragManagedDb
38004 38005 38006 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38004 def rag_managed_db @rag_managed_db end |
#rag_managed_vertex_vector_search ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigRagManagedVertexVectorSearch
The config for the RAG-managed Vertex Vector Search 2.0.
Corresponds to the JSON property ragManagedVertexVectorSearch
38009 38010 38011 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38009 def rag_managed_vertex_vector_search @rag_managed_vertex_vector_search end |
#vertex_feature_store ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigVertexFeatureStore
The config for the Vertex Feature Store.
Corresponds to the JSON property vertexFeatureStore
38014 38015 38016 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38014 def vertex_feature_store @vertex_feature_store end |
#vertex_vector_search ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigVertexVectorSearch
The config for the Vertex Vector Search.
Corresponds to the JSON property vertexVectorSearch
38019 38020 38021 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38019 def vertex_vector_search @vertex_vector_search end |
#weaviate ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigWeaviate
The config for the Weaviate.
Corresponds to the JSON property weaviate
38024 38025 38026 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38024 def weaviate @weaviate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38031 38032 38033 38034 38035 38036 38037 38038 38039 38040 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38031 def update!(**args) @api_auth = args[:api_auth] if args.key?(:api_auth) @pinecone = args[:pinecone] if args.key?(:pinecone) @rag_embedding_model_config = args[:rag_embedding_model_config] if args.key?(:rag_embedding_model_config) @rag_managed_db = args[:rag_managed_db] if args.key?(:rag_managed_db) @rag_managed_vertex_vector_search = args[:rag_managed_vertex_vector_search] if args.key?(:rag_managed_vertex_vector_search) @vertex_feature_store = args[:vertex_feature_store] if args.key?(:vertex_feature_store) @vertex_vector_search = args[:vertex_vector_search] if args.key?(:vertex_vector_search) @weaviate = args[:weaviate] if args.key?(:weaviate) end |