Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigRagManagedDb

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The config for the default RAG-managed Vector DB.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagVectorDbConfigRagManagedDb

Returns a new instance of GoogleCloudAiplatformV1beta1RagVectorDbConfigRagManagedDb.



38079
38080
38081
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigRagManagedDbAnn

Config for ANN search. RagManagedDb uses a tree-based structure to partition data and facilitate faster searches. As a tradeoff, it requires longer indexing time and manual triggering of index rebuild via the ImportRagFiles and UpdateRagCorpus API. Corresponds to the JSON property ann



38072
38073
38074
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38072

def ann
  @ann
end

#knnGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagVectorDbConfigRagManagedDbKnn

Config for KNN search. Corresponds to the JSON property knn



38077
38078
38079
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38077

def knn
  @knn
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38084
38085
38086
38087
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38084

def update!(**args)
  @ann = args[:ann] if args.key?(:ann)
  @knn = args[:knn] if args.key?(:knn)
end