Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RayClusterAutoscalingSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RayClusterAutoscalingSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Ray cluster level autoscaling configuration.
Instance Attribute Summary collapse
-
#idle_timeout_minutes ⇒ Fixnum
Optional.
-
#upscaling_speed ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RayClusterAutoscalingSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1RayClusterAutoscalingSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RayClusterAutoscalingSpec
Returns a new instance of GoogleCloudAiplatformV1beta1RayClusterAutoscalingSpec.
47830 47831 47832 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#idle_timeout_minutes ⇒ Fixnum
Optional. The number of minutes that need to pass before an idle worker node
is removed by the autoscaler. Default is 5 mins.
Corresponds to the JSON property idleTimeoutMinutes
47820 47821 47822 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47820 def idle_timeout_minutes @idle_timeout_minutes end |
#upscaling_speed ⇒ Fixnum
Optional. The number of nodes allowed to be pending as a multiple of the
current number of nodes. OSS Ray reference
Corresponds to the JSON property upscalingSpeed
47828 47829 47830 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47828 def upscaling_speed @upscaling_speed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47835 47836 47837 47838 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47835 def update!(**args) @idle_timeout_minutes = args[:idle_timeout_minutes] if args.key?(:idle_timeout_minutes) @upscaling_speed = args[:upscaling_speed] if args.key?(:upscaling_speed) end |