Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RaySpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RaySpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration information for the Ray cluster. For experimental launch, Ray cluster creation and Persistent cluster creation are 1:1 mapping: We will provision all the nodes within the Persistent cluster as Ray nodes.
Instance Attribute Summary collapse
-
#head_node_resource_pool_id ⇒ String
Optional.
-
#image_uri ⇒ String
Optional.
-
#nfs_mounts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NfsMount>
Optional.
-
#ray_cluster_autoscaling_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RayClusterAutoscalingSpec
Ray cluster level autoscaling configuration.
-
#ray_logs_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RayLogsSpec
Configuration for the Ray OSS Logs.
-
#ray_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RayMetricSpec
Configuration for the Ray metrics.
-
#resource_pool_images ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RaySpec
constructor
A new instance of GoogleCloudAiplatformV1beta1RaySpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RaySpec
Returns a new instance of GoogleCloudAiplatformV1beta1RaySpec.
47942 47943 47944 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47942 def initialize(**args) update!(**args) end |
Instance Attribute Details
#head_node_resource_pool_id ⇒ String
Optional. This will be used to indicate which resource pool will serve as the
Ray head node(the first node within that pool). Will use the machine from the
first workerpool as the head node by default if this field isn't set.
Corresponds to the JSON property headNodeResourcePoolId
47901 47902 47903 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47901 def head_node_resource_pool_id @head_node_resource_pool_id end |
#image_uri ⇒ String
Optional. Default image for user to choose a preferred ML framework (for
example, TensorFlow or Pytorch) by choosing from Vertex prebuilt images. Either
this or the resource_pool_images is required. Use this field if you need all
the resource pools to have the same Ray image. Otherwise, use the @code
resource_pool_images field.
Corresponds to the JSON property imageUri
47911 47912 47913 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47911 def image_uri @image_uri end |
#nfs_mounts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NfsMount>
Optional. Use if you want to mount to any NFS storages.
Corresponds to the JSON property nfsMounts
47916 47917 47918 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47916 def nfs_mounts @nfs_mounts end |
#ray_cluster_autoscaling_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RayClusterAutoscalingSpec
Ray cluster level autoscaling configuration.
Corresponds to the JSON property rayClusterAutoscalingSpec
47921 47922 47923 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47921 def ray_cluster_autoscaling_spec @ray_cluster_autoscaling_spec end |
#ray_logs_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RayLogsSpec
Configuration for the Ray OSS Logs.
Corresponds to the JSON property rayLogsSpec
47926 47927 47928 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47926 def ray_logs_spec @ray_logs_spec end |
#ray_metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RayMetricSpec
Configuration for the Ray metrics.
Corresponds to the JSON property rayMetricSpec
47931 47932 47933 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47931 def ray_metric_spec @ray_metric_spec end |
#resource_pool_images ⇒ Hash<String,String>
Optional. Required if image_uri isn't set. A map of resource_pool_id to
prebuild Ray image if user need to use different images for different head/
worker pools. This map needs to cover all the resource pool ids. Example: "
ray_head_node_pool": "head image" "ray_worker_node_pool1": "worker image" "
ray_worker_node_pool2": "another worker image"
Corresponds to the JSON property resourcePoolImages
47940 47941 47942 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47940 def resource_pool_images @resource_pool_images end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47947 47948 47949 47950 47951 47952 47953 47954 47955 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47947 def update!(**args) @head_node_resource_pool_id = args[:head_node_resource_pool_id] if args.key?(:head_node_resource_pool_id) @image_uri = args[:image_uri] if args.key?(:image_uri) @nfs_mounts = args[:nfs_mounts] if args.key?(:nfs_mounts) @ray_cluster_autoscaling_spec = args[:ray_cluster_autoscaling_spec] if args.key?(:ray_cluster_autoscaling_spec) @ray_logs_spec = args[:ray_logs_spec] if args.key?(:ray_logs_spec) @ray_metric_spec = args[:ray_metric_spec] if args.key?(:ray_metric_spec) @resource_pool_images = args[:resource_pool_images] if args.key?(:resource_pool_images) end |