Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RaySpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration information for the Ray cluster. For experimental launch, Ray cluster creation and Persistent cluster creation are 1:1 mapping: We will provision all the nodes within the Persistent cluster as Ray nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RaySpec

Returns a new instance of GoogleCloudAiplatformV1beta1RaySpec.



45258
45259
45260
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45258

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#head_node_resource_pool_idString

Optional. This will be used to indicate which resource pool will serve as the Ray head node(the first node within that pool). Will use the machine from the first workerpool as the head node by default if this field isn't set. Corresponds to the JSON property headNodeResourcePoolId

Returns:

  • (String)


45222
45223
45224
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45222

def head_node_resource_pool_id
  @head_node_resource_pool_id
end

#image_uriString

Optional. Default image for user to choose a preferred ML framework (for example, TensorFlow or Pytorch) by choosing from Vertex prebuilt images. Either this or the resource_pool_images is required. Use this field if you need all the resource pools to have the same Ray image. Otherwise, use the @code resource_pool_images field. Corresponds to the JSON property imageUri

Returns:

  • (String)


45232
45233
45234
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45232

def image_uri
  @image_uri
end

#nfs_mountsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NfsMount>

Optional. Use if you want to mount to any NFS storages. Corresponds to the JSON property nfsMounts



45237
45238
45239
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45237

def nfs_mounts
  @nfs_mounts
end

#ray_logs_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RayLogsSpec

Configuration for the Ray OSS Logs. Corresponds to the JSON property rayLogsSpec



45242
45243
45244
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45242

def ray_logs_spec
  @ray_logs_spec
end

#ray_metric_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RayMetricSpec

Configuration for the Ray metrics. Corresponds to the JSON property rayMetricSpec



45247
45248
45249
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45247

def ray_metric_spec
  @ray_metric_spec
end

#resource_pool_imagesHash<String,String>

Optional. Required if image_uri isn't set. A map of resource_pool_id to prebuild Ray image if user need to use different images for different head/ worker pools. This map needs to cover all the resource pool ids. Example: " ray_head_node_pool": "head image" "ray_worker_node_pool1": "worker image" " ray_worker_node_pool2": "another worker image" Corresponds to the JSON property resourcePoolImages

Returns:

  • (Hash<String,String>)


45256
45257
45258
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45256

def resource_pool_images
  @resource_pool_images
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45263
45264
45265
45266
45267
45268
45269
45270
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45263

def update!(**args)
  @head_node_resource_pool_id = args[:head_node_resource_pool_id] if args.key?(:head_node_resource_pool_id)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @nfs_mounts = args[:nfs_mounts] if args.key?(:nfs_mounts)
  @ray_logs_spec = args[:ray_logs_spec] if args.key?(:ray_logs_spec)
  @ray_metric_spec = args[:ray_metric_spec] if args.key?(:ray_metric_spec)
  @resource_pool_images = args[:resource_pool_images] if args.key?(:resource_pool_images)
end