Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityView
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Entity view with Feature values.
Instance Attribute Summary collapse
-
#data ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityViewData>
Each piece of data holds the k requested values for one requested Feature.
-
#entity_id ⇒ String
ID of the requested entity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityView
constructor
A new instance of GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityView
Returns a new instance of GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityView.
38525 38526 38527 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38525 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReadFeatureValuesResponseEntityViewData>
Each piece of data holds the k requested values for one requested Feature. If
no values for the requested Feature exist, the corresponding cell will be
empty. This has the same size and is in the same order as the features from
the header ReadFeatureValuesResponse.header.
Corresponds to the JSON property data
38518 38519 38520 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38518 def data @data end |
#entity_id ⇒ String
ID of the requested entity.
Corresponds to the JSON property entityId
38523 38524 38525 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38523 def entity_id @entity_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38530 38531 38532 38533 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38530 def update!(**args) @data = args[:data] if args.key?(:data) @entity_id = args[:entity_id] if args.key?(:entity_id) end |