Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngine
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngine
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.
Instance Attribute Summary collapse
-
#context_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpec
Configuration for how Agent Engine sub-resources should manage context.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Labels for the ReasoningEngine.
-
#name ⇒ String
Identifier.
-
#spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec
ReasoningEngine configurations Corresponds to the JSON property
spec. -
#traffic_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineTrafficConfig
Traffic distribution configuration.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngine
constructor
A new instance of GoogleCloudAiplatformV1beta1ReasoningEngine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngine
Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngine.
47571 47572 47573 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47571 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpec
Configuration for how Agent Engine sub-resources should manage context.
Corresponds to the JSON property contextSpec
47516 47517 47518 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47516 def context_spec @context_spec end |
#create_time ⇒ String
Output only. Timestamp when this ReasoningEngine was created.
Corresponds to the JSON property createTime
47521 47522 47523 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47521 def create_time @create_time end |
#description ⇒ String
Optional. The description of the ReasoningEngine.
Corresponds to the JSON property description
47526 47527 47528 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47526 def description @description end |
#display_name ⇒ String
Required. The display name of the ReasoningEngine.
Corresponds to the JSON property displayName
47531 47532 47533 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47531 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
47537 47538 47539 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47537 def encryption_spec @encryption_spec end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
47543 47544 47545 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47543 def etag @etag end |
#labels ⇒ Hash<String,String>
Labels for the ReasoningEngine.
Corresponds to the JSON property labels
47548 47549 47550 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47548 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the ReasoningEngine. Format: projects/
project/locations/location/reasoningEngines/reasoning_engine`
Corresponds to the JSON propertyname`
47554 47555 47556 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47554 def name @name end |
#spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec
ReasoningEngine configurations
Corresponds to the JSON property spec
47559 47560 47561 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47559 def spec @spec end |
#traffic_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineTrafficConfig
Traffic distribution configuration.
Corresponds to the JSON property trafficConfig
47564 47565 47566 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47564 def traffic_config @traffic_config end |
#update_time ⇒ String
Output only. Timestamp when this ReasoningEngine was most recently updated.
Corresponds to the JSON property updateTime
47569 47570 47571 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47569 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47576 47577 47578 47579 47580 47581 47582 47583 47584 47585 47586 47587 47588 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47576 def update!(**args) @context_spec = args[:context_spec] if args.key?(:context_spec) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @spec = args[:spec] if args.key?(:spec) @traffic_config = args[:traffic_config] if args.key?(:traffic_config) @update_time = args[:update_time] if args.key?(:update_time) end |