Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngine

Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngine.



44358
44359
44360
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#context_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpec

Configuration for how Agent Engine sub-resources should manage context. Corresponds to the JSON property contextSpec



44303
44304
44305
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44303

def context_spec
  @context_spec
end

#create_timeString

Output only. Timestamp when this ReasoningEngine was created. Corresponds to the JSON property createTime

Returns:

  • (String)


44308
44309
44310
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44308

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ReasoningEngine. Corresponds to the JSON property description

Returns:

  • (String)


44313
44314
44315
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44313

def description
  @description
end

#display_nameString

Required. The display name of the ReasoningEngine. Corresponds to the JSON property displayName

Returns:

  • (String)


44318
44319
44320
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44318

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



44324
44325
44326
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44324

def encryption_spec
  @encryption_spec
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


44330
44331
44332
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44330

def etag
  @etag
end

#labelsHash<String,String>

Labels for the ReasoningEngine. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


44335
44336
44337
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44335

def labels
  @labels
end

#nameString

Identifier. The resource name of the ReasoningEngine. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine` Corresponds to the JSON propertyname`

Returns:

  • (String)


44341
44342
44343
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44341

def name
  @name
end

#specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec

ReasoningEngine configurations Corresponds to the JSON property spec



44346
44347
44348
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44346

def spec
  @spec
end

#traffic_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineTrafficConfig

Traffic distribution configuration. Corresponds to the JSON property trafficConfig



44351
44352
44353
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44351

def traffic_config
  @traffic_config
end

#update_timeString

Output only. Timestamp when this ReasoningEngine was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


44356
44357
44358
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44356

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44363
44364
44365
44366
44367
44368
44369
44370
44371
44372
44373
44374
44375
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44363

def update!(**args)
  @context_spec = args[:context_spec] if args.key?(:context_spec)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @spec = args[:spec] if args.key?(:spec)
  @traffic_config = args[:traffic_config] if args.key?(:traffic_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end