Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngine
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngine
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.
Instance Attribute Summary collapse
-
#context_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpec
Configuration for how Agent Engine sub-resources should manage context.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Labels for the ReasoningEngine.
-
#name ⇒ String
Identifier.
-
#spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec
ReasoningEngine configurations Corresponds to the JSON property
spec. -
#traffic_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineTrafficConfig
Traffic distribution configuration.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngine
constructor
A new instance of GoogleCloudAiplatformV1beta1ReasoningEngine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngine
Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngine.
43709 43710 43711 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43709 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpec
Configuration for how Agent Engine sub-resources should manage context.
Corresponds to the JSON property contextSpec
43654 43655 43656 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43654 def context_spec @context_spec end |
#create_time ⇒ String
Output only. Timestamp when this ReasoningEngine was created.
Corresponds to the JSON property createTime
43659 43660 43661 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43659 def create_time @create_time end |
#description ⇒ String
Optional. The description of the ReasoningEngine.
Corresponds to the JSON property description
43664 43665 43666 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43664 def description @description end |
#display_name ⇒ String
Required. The display name of the ReasoningEngine.
Corresponds to the JSON property displayName
43669 43670 43671 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43669 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
43675 43676 43677 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43675 def encryption_spec @encryption_spec end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
43681 43682 43683 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43681 def etag @etag end |
#labels ⇒ Hash<String,String>
Labels for the ReasoningEngine.
Corresponds to the JSON property labels
43686 43687 43688 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43686 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the ReasoningEngine. Format: projects/
project/locations/location/reasoningEngines/reasoning_engine`
Corresponds to the JSON propertyname`
43692 43693 43694 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43692 def name @name end |
#spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec
ReasoningEngine configurations
Corresponds to the JSON property spec
43697 43698 43699 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43697 def spec @spec end |
#traffic_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineTrafficConfig
Traffic distribution configuration.
Corresponds to the JSON property trafficConfig
43702 43703 43704 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43702 def traffic_config @traffic_config end |
#update_time ⇒ String
Output only. Timestamp when this ReasoningEngine was most recently updated.
Corresponds to the JSON property updateTime
43707 43708 43709 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43707 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43714 43715 43716 43717 43718 43719 43720 43721 43722 43723 43724 43725 43726 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43714 def update!(**args) @context_spec = args[:context_spec] if args.key?(:context_spec) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @spec = args[:spec] if args.key?(:spec) @traffic_config = args[:traffic_config] if args.key?(:traffic_config) @update_time = args[:update_time] if args.key?(:update_time) end |