Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngine
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngine
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.
Instance Attribute Summary collapse
-
#context_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpec
Configuration for how Agent Engine sub-resources should manage context.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Labels for the ReasoningEngine.
-
#name ⇒ String
Identifier.
-
#spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec
ReasoningEngine configurations Corresponds to the JSON property
spec. -
#traffic_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineTrafficConfig
Traffic distribution configuration.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngine
constructor
A new instance of GoogleCloudAiplatformV1beta1ReasoningEngine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngine
Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngine.
38837 38838 38839 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpec
Configuration for how Agent Engine sub-resources should manage context.
Corresponds to the JSON property contextSpec
38782 38783 38784 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38782 def context_spec @context_spec end |
#create_time ⇒ String
Output only. Timestamp when this ReasoningEngine was created.
Corresponds to the JSON property createTime
38787 38788 38789 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38787 def create_time @create_time end |
#description ⇒ String
Optional. The description of the ReasoningEngine.
Corresponds to the JSON property description
38792 38793 38794 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38792 def description @description end |
#display_name ⇒ String
Required. The display name of the ReasoningEngine.
Corresponds to the JSON property displayName
38797 38798 38799 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38797 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
38803 38804 38805 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38803 def encryption_spec @encryption_spec end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
38809 38810 38811 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38809 def etag @etag end |
#labels ⇒ Hash<String,String>
Labels for the ReasoningEngine.
Corresponds to the JSON property labels
38814 38815 38816 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38814 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the ReasoningEngine. Format: projects/
project/locations/location/reasoningEngines/reasoning_engine`
Corresponds to the JSON propertyname`
38820 38821 38822 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38820 def name @name end |
#spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec
ReasoningEngine configurations
Corresponds to the JSON property spec
38825 38826 38827 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38825 def spec @spec end |
#traffic_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineTrafficConfig
Traffic distribution configuration.
Corresponds to the JSON property trafficConfig
38830 38831 38832 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38830 def traffic_config @traffic_config end |
#update_time ⇒ String
Output only. Timestamp when this ReasoningEngine was most recently updated.
Corresponds to the JSON property updateTime
38835 38836 38837 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38835 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38842 38843 38844 38845 38846 38847 38848 38849 38850 38851 38852 38853 38854 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38842 def update!(**args) @context_spec = args[:context_spec] if args.key?(:context_spec) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @spec = args[:spec] if args.key?(:spec) @traffic_config = args[:traffic_config] if args.key?(:traffic_config) @update_time = args[:update_time] if args.key?(:update_time) end |