Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngine

Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngine.



38770
38771
38772
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38770

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#context_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpec

Configuration for how Agent Engine sub-resources should manage context. Corresponds to the JSON property contextSpec



38715
38716
38717
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38715

def context_spec
  @context_spec
end

#create_timeString

Output only. Timestamp when this ReasoningEngine was created. Corresponds to the JSON property createTime

Returns:

  • (String)


38720
38721
38722
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38720

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ReasoningEngine. Corresponds to the JSON property description

Returns:

  • (String)


38725
38726
38727
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38725

def description
  @description
end

#display_nameString

Required. The display name of the ReasoningEngine. Corresponds to the JSON property displayName

Returns:

  • (String)


38730
38731
38732
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38730

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



38736
38737
38738
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38736

def encryption_spec
  @encryption_spec
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


38742
38743
38744
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38742

def etag
  @etag
end

#labelsHash<String,String>

Labels for the ReasoningEngine. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


38747
38748
38749
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38747

def labels
  @labels
end

#nameString

Identifier. The resource name of the ReasoningEngine. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine` Corresponds to the JSON propertyname`

Returns:

  • (String)


38753
38754
38755
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38753

def name
  @name
end

#specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec

ReasoningEngine configurations Corresponds to the JSON property spec



38758
38759
38760
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38758

def spec
  @spec
end

#traffic_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineTrafficConfig

Traffic distribution configuration. Corresponds to the JSON property trafficConfig



38763
38764
38765
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38763

def traffic_config
  @traffic_config
end

#update_timeString

Output only. Timestamp when this ReasoningEngine was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


38768
38769
38770
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38768

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38775
38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 38775

def update!(**args)
  @context_spec = args[:context_spec] if args.key?(:context_spec)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @spec = args[:spec] if args.key?(:spec)
  @traffic_config = args[:traffic_config] if args.key?(:traffic_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end