Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for automatically setting the TTL ("time-to-live") of the memories in the Memory Bank.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfig

Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfig.



45996
45997
45998
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_ttlString

Optional. The default TTL duration of the memories in the Memory Bank. This applies to all operations that create or update a memory. Corresponds to the JSON property defaultTtl

Returns:

  • (String)


45981
45982
45983
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45981

def default_ttl
  @default_ttl
end

#granular_ttl_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig

Configuration for TTL of the memories in the Memory Bank based on the action that created or updated the memory. Corresponds to the JSON property granularTtlConfig



45987
45988
45989
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45987

def granular_ttl_config
  @granular_ttl_config
end

#memory_revision_default_ttlString

Optional. The default TTL duration of the memory revisions in the Memory Bank. This applies to all operations that create a memory revision. If not set, a default TTL of 365 days will be used. Corresponds to the JSON property memoryRevisionDefaultTtl

Returns:

  • (String)


45994
45995
45996
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45994

def memory_revision_default_ttl
  @memory_revision_default_ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46001
46002
46003
46004
46005
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46001

def update!(**args)
  @default_ttl = args[:default_ttl] if args.key?(:default_ttl)
  @granular_ttl_config = args[:granular_ttl_config] if args.key?(:granular_ttl_config)
  @memory_revision_default_ttl = args[:memory_revision_default_ttl] if args.key?(:memory_revision_default_ttl)
end