Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for TTL of the memories in the Memory Bank based on the action that created or updated the memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig

Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig.



45854
45855
45856
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_ttlString

Optional. The TTL duration for memories uploaded via CreateMemory. Corresponds to the JSON property createTtl

Returns:

  • (String)


45838
45839
45840
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45838

def create_ttl
  @create_ttl
end

#generate_created_ttlString

Optional. The TTL duration for memories newly generated via GenerateMemories ( GenerateMemoriesResponse.GeneratedMemory.Action.CREATED). Corresponds to the JSON property generateCreatedTtl

Returns:

  • (String)


45844
45845
45846
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45844

def generate_created_ttl
  @generate_created_ttl
end

#generate_updated_ttlString

Optional. The TTL duration for memories updated via GenerateMemories ( GenerateMemoriesResponse.GeneratedMemory.Action.UPDATED). In the case of an UPDATE action, the expire_time of the existing memory will be updated to the new value (now + TTL). Corresponds to the JSON property generateUpdatedTtl

Returns:

  • (String)


45852
45853
45854
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45852

def generate_updated_ttl
  @generate_updated_ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45859
45860
45861
45862
45863
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45859

def update!(**args)
  @create_ttl = args[:create_ttl] if args.key?(:create_ttl)
  @generate_created_ttl = args[:generate_created_ttl] if args.key?(:generate_created_ttl)
  @generate_updated_ttl = args[:generate_updated_ttl] if args.key?(:generate_updated_ttl)
end