Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for TTL of the memories in the Memory Bank based on the action that created or updated the memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig

Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig.



43909
43910
43911
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43909

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_ttlString

Optional. The TTL duration for memories uploaded via CreateMemory. Corresponds to the JSON property createTtl

Returns:

  • (String)


43893
43894
43895
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43893

def create_ttl
  @create_ttl
end

#generate_created_ttlString

Optional. The TTL duration for memories newly generated via GenerateMemories ( GenerateMemoriesResponse.GeneratedMemory.Action.CREATED). Corresponds to the JSON property generateCreatedTtl

Returns:

  • (String)


43899
43900
43901
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43899

def generate_created_ttl
  @generate_created_ttl
end

#generate_updated_ttlString

Optional. The TTL duration for memories updated via GenerateMemories ( GenerateMemoriesResponse.GeneratedMemory.Action.UPDATED). In the case of an UPDATE action, the expire_time of the existing memory will be updated to the new value (now + TTL). Corresponds to the JSON property generateUpdatedTtl

Returns:

  • (String)


43907
43908
43909
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43907

def generate_updated_ttl
  @generate_updated_ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43914
43915
43916
43917
43918
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43914

def update!(**args)
  @create_ttl = args[:create_ttl] if args.key?(:create_ttl)
  @generate_created_ttl = args[:generate_created_ttl] if args.key?(:generate_created_ttl)
  @generate_updated_ttl = args[:generate_updated_ttl] if args.key?(:generate_updated_ttl)
end