Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for TTL of the memories in the Memory Bank based on the action that created or updated the memory.
Instance Attribute Summary collapse
-
#create_ttl ⇒ String
Optional.
-
#generate_created_ttl ⇒ String
Optional.
-
#generate_updated_ttl ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig
Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig.
39037 39038 39039 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39037 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_ttl ⇒ String
Optional. The TTL duration for memories uploaded via CreateMemory.
Corresponds to the JSON property createTtl
39021 39022 39023 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39021 def create_ttl @create_ttl end |
#generate_created_ttl ⇒ String
Optional. The TTL duration for memories newly generated via GenerateMemories (
GenerateMemoriesResponse.GeneratedMemory.Action.CREATED).
Corresponds to the JSON property generateCreatedTtl
39027 39028 39029 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39027 def generate_created_ttl @generate_created_ttl end |
#generate_updated_ttl ⇒ String
Optional. The TTL duration for memories updated via GenerateMemories (
GenerateMemoriesResponse.GeneratedMemory.Action.UPDATED). In the case of an
UPDATE action, the expire_time of the existing memory will be updated to the
new value (now + TTL).
Corresponds to the JSON property generateUpdatedTtl
39035 39036 39037 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39035 def generate_updated_ttl @generate_updated_ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39042 39043 39044 39045 39046 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39042 def update!(**args) @create_ttl = args[:create_ttl] if args.key?(:create_ttl) @generate_created_ttl = args[:generate_created_ttl] if args.key?(:generate_created_ttl) @generate_updated_ttl = args[:generate_updated_ttl] if args.key?(:generate_updated_ttl) end |