Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
ReasoningEngine configurations
Instance Attribute Summary collapse
-
#agent_card ⇒ Hash<String,Object>
Optional.
-
#agent_framework ⇒ String
Optional.
-
#build_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecBuildSpec
Specification for building container image.
-
#class_methods ⇒ Array<Hash<String,Object>>
Optional.
-
#container_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecContainerSpec
Specification for deploying from a container image.
-
#deployment_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
-
#effective_identity ⇒ String
Output only.
-
#identity_type ⇒ String
Optional.
-
#package_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecPackageSpec
User-provided package specification, containing pickled object and package requirements.
-
#service_account ⇒ String
Optional.
-
#source_code_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec
Specification for deploying from source code.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpec
Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpec.
46733 46734 46735 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46733 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_card ⇒ Hash<String,Object>
Optional. The A2A Agent Card for the agent (if available). It follows the
specification at https://a2a-protocol.org/latest/specification/#5-agent-
discovery-the-agent-card.
Corresponds to the JSON property agentCard
46666 46667 46668 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46666 def agent_card @agent_card end |
#agent_framework ⇒ String
Optional. The OSS agent framework used to develop the agent. Currently
supported values: "google-adk", "langchain", "langgraph", "ag2", "llama-index",
"custom".
Corresponds to the JSON property agentFramework
46673 46674 46675 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46673 def agent_framework @agent_framework end |
#build_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecBuildSpec
Specification for building container image.
Corresponds to the JSON property buildSpec
46678 46679 46680 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46678 def build_spec @build_spec end |
#class_methods ⇒ Array<Hash<String,Object>>
Optional. Declarations for object class methods in OpenAPI specification
format.
Corresponds to the JSON property classMethods
46684 46685 46686 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46684 def class_methods @class_methods end |
#container_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecContainerSpec
Specification for deploying from a container image.
Corresponds to the JSON property containerSpec
46689 46690 46691 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46689 def container_spec @container_spec end |
#deployment_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
Corresponds to the JSON property deploymentSpec
46694 46695 46696 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46694 def deployment_spec @deployment_spec end |
#effective_identity ⇒ String
Output only. The identity to use for the Reasoning Engine. It can contain one
of the following values: * service-project@gcp-sa-aiplatform-re.googleapis.
com (for SERVICE_AGENT identity type) * name@project.gserviceaccount.com (
for SERVICE_ACCOUNT identity type) * agents.global.org.system.id.goog/
resources/aiplatform/projects/project/locations/location/reasoningEngines/
reasoning_engine (for AGENT_IDENTITY identity type)
Corresponds to the JSON property effectiveIdentity
46704 46705 46706 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46704 def effective_identity @effective_identity end |
#identity_type ⇒ String
Optional. The identity type to use for the Reasoning Engine. If not specified,
the service_account field will be used if set, otherwise the default Vertex
AI Reasoning Engine Service Agent in the project will be used.
Corresponds to the JSON property identityType
46711 46712 46713 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46711 def identity_type @identity_type end |
#package_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecPackageSpec
User-provided package specification, containing pickled object and package
requirements.
Corresponds to the JSON property packageSpec
46717 46718 46719 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46717 def package_spec @package_spec end |
#service_account ⇒ String
Optional. The service account that the Reasoning Engine artifact runs as. It
should have "roles/storage.objectViewer" for reading the user project's Cloud
Storage and "roles/aiplatform.user" for using Vertex extensions. If not
specified, the Vertex AI Reasoning Engine Service Agent in the project will be
used.
Corresponds to the JSON property serviceAccount
46726 46727 46728 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46726 def service_account @service_account end |
#source_code_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec
Specification for deploying from source code.
Corresponds to the JSON property sourceCodeSpec
46731 46732 46733 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46731 def source_code_spec @source_code_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46738 46739 46740 46741 46742 46743 46744 46745 46746 46747 46748 46749 46750 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46738 def update!(**args) @agent_card = args[:agent_card] if args.key?(:agent_card) @agent_framework = args[:agent_framework] if args.key?(:agent_framework) @build_spec = args[:build_spec] if args.key?(:build_spec) @class_methods = args[:class_methods] if args.key?(:class_methods) @container_spec = args[:container_spec] if args.key?(:container_spec) @deployment_spec = args[:deployment_spec] if args.key?(:deployment_spec) @effective_identity = args[:effective_identity] if args.key?(:effective_identity) @identity_type = args[:identity_type] if args.key?(:identity_type) @package_spec = args[:package_spec] if args.key?(:package_spec) @service_account = args[:service_account] if args.key?(:service_account) @source_code_spec = args[:source_code_spec] if args.key?(:source_code_spec) end |