Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

ReasoningEngine configurations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpec

Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpec.



39093
39094
39095
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_cardHash<String,Object>

Optional. The A2A Agent Card for the agent (if available). It follows the specification at https://a2a-protocol.org/latest/specification/#5-agent- discovery-the-agent-card. Corresponds to the JSON property agentCard

Returns:

  • (Hash<String,Object>)


39031
39032
39033
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39031

def agent_card
  @agent_card
end

#agent_frameworkString

Optional. The OSS agent framework used to develop the agent. Currently supported values: "google-adk", "langchain", "langgraph", "ag2", "llama-index", "custom". Corresponds to the JSON property agentFramework

Returns:

  • (String)


39038
39039
39040
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39038

def agent_framework
  @agent_framework
end

#class_methodsArray<Hash<String,Object>>

Optional. Declarations for object class methods in OpenAPI specification format. Corresponds to the JSON property classMethods

Returns:

  • (Array<Hash<String,Object>>)


39044
39045
39046
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39044

def class_methods
  @class_methods
end

#container_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecContainerSpec

Specification for deploying from a container image. Corresponds to the JSON property containerSpec



39049
39050
39051
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39049

def container_spec
  @container_spec
end

#deployment_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecDeploymentSpec

The specification of a Reasoning Engine deployment. Corresponds to the JSON property deploymentSpec



39054
39055
39056
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39054

def deployment_spec
  @deployment_spec
end

#effective_identityString

Output only. The identity to use for the Reasoning Engine. It can contain one of the following values: * service-project@gcp-sa-aiplatform-re.googleapis. com (for SERVICE_AGENT identity type) * name@project.gserviceaccount.com ( for SERVICE_ACCOUNT identity type) * agents.global.org.system.id.goog/ resources/aiplatform/projects/project/locations/location/reasoningEngines/ reasoning_engine (for AGENT_IDENTITY identity type) Corresponds to the JSON property effectiveIdentity

Returns:

  • (String)


39064
39065
39066
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39064

def effective_identity
  @effective_identity
end

#identity_typeString

Optional. The identity type to use for the Reasoning Engine. If not specified, the service_account field will be used if set, otherwise the default Vertex AI Reasoning Engine Service Agent in the project will be used. Corresponds to the JSON property identityType

Returns:

  • (String)


39071
39072
39073
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39071

def identity_type
  @identity_type
end

#package_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecPackageSpec

User-provided package specification, containing pickled object and package requirements. Corresponds to the JSON property packageSpec



39077
39078
39079
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39077

def package_spec
  @package_spec
end

#service_accountString

Optional. The service account that the Reasoning Engine artifact runs as. It should have "roles/storage.objectViewer" for reading the user project's Cloud Storage and "roles/aiplatform.user" for using Vertex extensions. If not specified, the Vertex AI Reasoning Engine Service Agent in the project will be used. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


39086
39087
39088
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39086

def 
  @service_account
end

#source_code_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec

Specification for deploying from source code. Corresponds to the JSON property sourceCodeSpec



39091
39092
39093
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39091

def source_code_spec
  @source_code_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39098
39099
39100
39101
39102
39103
39104
39105
39106
39107
39108
39109
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39098

def update!(**args)
  @agent_card = args[:agent_card] if args.key?(:agent_card)
  @agent_framework = args[:agent_framework] if args.key?(:agent_framework)
  @class_methods = args[:class_methods] if args.key?(:class_methods)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @deployment_spec = args[:deployment_spec] if args.key?(:deployment_spec)
  @effective_identity = args[:effective_identity] if args.key?(:effective_identity)
  @identity_type = args[:identity_type] if args.key?(:identity_type)
  @package_spec = args[:package_spec] if args.key?(:package_spec)
  @service_account = args[:service_account] if args.key?(:service_account)
  @source_code_spec = args[:source_code_spec] if args.key?(:source_code_spec)
end