Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecDeploymentSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The specification of a Reasoning Engine deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpecDeploymentSpec

Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpecDeploymentSpec.



39203
39204
39205
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_gateway_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecDeploymentSpecAgentGatewayConfig

Agent Gateway configuration for a Reasoning Engine deployment. Corresponds to the JSON property agentGatewayConfig



39140
39141
39142
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39140

def agent_gateway_config
  @agent_gateway_config
end

#agent_server_modeString

The agent server mode. Corresponds to the JSON property agentServerMode

Returns:

  • (String)


39145
39146
39147
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39145

def agent_server_mode
  @agent_server_mode
end

#container_concurrencyFixnum

Optional. Concurrency for each container and agent server. Recommended value: 2 * cpu + 1. Defaults to 9. Corresponds to the JSON property containerConcurrency

Returns:

  • (Fixnum)


39151
39152
39153
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39151

def container_concurrency
  @container_concurrency
end

#envArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EnvVar>

Optional. Environment variables to be set with the Reasoning Engine deployment. The environment variables can be updated through the UpdateReasoningEngine API. Corresponds to the JSON property env



39158
39159
39160
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39158

def env
  @env
end

#keep_alive_probeGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1KeepAliveProbe

Represents the configuration for keep-alive probe. Contains configuration on a specified endpoint that a deployment host should use to keep the container alive based on the probe settings. Corresponds to the JSON property keepAliveProbe



39165
39166
39167
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39165

def keep_alive_probe
  @keep_alive_probe
end

#max_instancesFixnum

Optional. The maximum number of application instances that can be launched to handle increased traffic. Defaults to 100. Range: [1, 1000]. If VPC-SC or PSC- I is enabled, the acceptable range is [1, 100]. Corresponds to the JSON property maxInstances

Returns:

  • (Fixnum)


39172
39173
39174
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39172

def max_instances
  @max_instances
end

#min_instancesFixnum

Optional. The minimum number of application instances that will be kept running at all times. Defaults to 1. Range: [0, 75]. Corresponds to the JSON property minInstances

Returns:

  • (Fixnum)


39178
39179
39180
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39178

def min_instances
  @min_instances
end

#psc_interface_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PscInterfaceConfig

Configuration for PSC-I. Corresponds to the JSON property pscInterfaceConfig



39183
39184
39185
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39183

def psc_interface_config
  @psc_interface_config
end

#resource_limitsHash<String,String>

Optional. Resource limits for each container. Only 'cpu' and 'memory' keys are supported. Defaults to "cpu": "4", "memory": "4Gi". * The only supported values for CPU are '1', '2', '4', '6' and '8'. For more information, go to https://cloud.google.com/run/docs/configuring/cpu. * The only supported values for memory are '1Gi', '2Gi', ... '32 Gi'. * For required cpu on different memory values, go to https://cloud.google.com/run/docs/configuring/memory- limits Corresponds to the JSON property resourceLimits

Returns:

  • (Hash<String,String>)


39194
39195
39196
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39194

def resource_limits
  @resource_limits
end

#secret_envArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SecretEnvVar>

Optional. Environment variables where the value is a secret in Cloud Secret Manager. To use this feature, add 'Secret Manager Secret Accessor' role (roles/ secretmanager.secretAccessor) to AI Platform Reasoning Engine Service Agent. Corresponds to the JSON property secretEnv



39201
39202
39203
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39201

def secret_env
  @secret_env
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39208
39209
39210
39211
39212
39213
39214
39215
39216
39217
39218
39219
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39208

def update!(**args)
  @agent_gateway_config = args[:agent_gateway_config] if args.key?(:agent_gateway_config)
  @agent_server_mode = args[:agent_server_mode] if args.key?(:agent_server_mode)
  @container_concurrency = args[:container_concurrency] if args.key?(:container_concurrency)
  @env = args[:env] if args.key?(:env)
  @keep_alive_probe = args[:keep_alive_probe] if args.key?(:keep_alive_probe)
  @max_instances = args[:max_instances] if args.key?(:max_instances)
  @min_instances = args[:min_instances] if args.key?(:min_instances)
  @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config)
  @resource_limits = args[:resource_limits] if args.key?(:resource_limits)
  @secret_env = args[:secret_env] if args.key?(:secret_env)
end