Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Specification for deploying from source code.
Instance Attribute Summary collapse
-
#agent_config_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecAgentConfigSource
Specification for the deploying from agent config.
-
#developer_connect_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
Specifies source code to be fetched from a Git repository managed through the Developer Connect service.
-
#image_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecImageSpec
The image spec for building an image (within a single build step), based on the config file (i.e. Dockerfile) in the source directory.
-
#inline_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecInlineSource
Specifies source code provided as a byte stream.
-
#python_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecPythonSpec
Specification for running a Python application from source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec
Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec.
47023 47024 47025 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47023 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_config_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecAgentConfigSource
Specification for the deploying from agent config.
Corresponds to the JSON property agentConfigSource
46999 47000 47001 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46999 def agent_config_source @agent_config_source end |
#developer_connect_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
Specifies source code to be fetched from a Git repository managed through the
Developer Connect service.
Corresponds to the JSON property developerConnectSource
47005 47006 47007 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47005 def developer_connect_source @developer_connect_source end |
#image_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecImageSpec
The image spec for building an image (within a single build step), based on
the config file (i.e. Dockerfile) in the source directory.
Corresponds to the JSON property imageSpec
47011 47012 47013 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47011 def image_spec @image_spec end |
#inline_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecInlineSource
Specifies source code provided as a byte stream.
Corresponds to the JSON property inlineSource
47016 47017 47018 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47016 def inline_source @inline_source end |
#python_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecPythonSpec
Specification for running a Python application from source.
Corresponds to the JSON property pythonSpec
47021 47022 47023 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47021 def python_spec @python_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47028 47029 47030 47031 47032 47033 47034 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47028 def update!(**args) @agent_config_source = args[:agent_config_source] if args.key?(:agent_config_source) @developer_connect_source = args[:developer_connect_source] if args.key?(:developer_connect_source) @image_spec = args[:image_spec] if args.key?(:image_spec) @inline_source = args[:inline_source] if args.key?(:inline_source) @python_spec = args[:python_spec] if args.key?(:python_spec) end |