Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Specification for deploying from source code.
Instance Attribute Summary collapse
-
#agent_config_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecAgentConfigSource
Specification for the deploying from agent config.
-
#developer_connect_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
Specifies source code to be fetched from a Git repository managed through the Developer Connect service.
-
#image_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecImageSpec
The image spec for building an image (within a single build step), based on the config file (i.e. Dockerfile) in the source directory.
-
#inline_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecInlineSource
Specifies source code provided as a byte stream.
-
#python_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecPythonSpec
Specification for running a Python application from source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec
Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpec.
39361 39362 39363 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39361 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_config_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecAgentConfigSource
Specification for the deploying from agent config.
Corresponds to the JSON property agentConfigSource
39337 39338 39339 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39337 def agent_config_source @agent_config_source end |
#developer_connect_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
Specifies source code to be fetched from a Git repository managed through the
Developer Connect service.
Corresponds to the JSON property developerConnectSource
39343 39344 39345 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39343 def developer_connect_source @developer_connect_source end |
#image_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecImageSpec
The image spec for building an image (within a single build step), based on
the config file (i.e. Dockerfile) in the source directory.
Corresponds to the JSON property imageSpec
39349 39350 39351 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39349 def image_spec @image_spec end |
#inline_source ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecInlineSource
Specifies source code provided as a byte stream.
Corresponds to the JSON property inlineSource
39354 39355 39356 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39354 def inline_source @inline_source end |
#python_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecPythonSpec
Specification for running a Python application from source.
Corresponds to the JSON property pythonSpec
39359 39360 39361 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39359 def python_spec @python_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39366 39367 39368 39369 39370 39371 39372 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39366 def update!(**args) @agent_config_source = args[:agent_config_source] if args.key?(:agent_config_source) @developer_connect_source = args[:developer_connect_source] if args.key?(:developer_connect_source) @image_spec = args[:image_spec] if args.key?(:image_spec) @inline_source = args[:inline_source] if args.key?(:inline_source) @python_spec = args[:python_spec] if args.key?(:python_spec) end |