Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecPythonSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecPythonSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Specification for running a Python application from source.
Instance Attribute Summary collapse
-
#entrypoint_module ⇒ String
Optional.
-
#entrypoint_object ⇒ String
Optional.
-
#requirements_file ⇒ String
Optional.
-
#version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecPythonSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecPythonSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecPythonSpec
Returns a new instance of GoogleCloudAiplatformV1beta1ReasoningEngineSpecSourceCodeSpecPythonSpec.
48934 48935 48936 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48934 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entrypoint_module ⇒ String
Optional. The Python module to load as the entrypoint, specified as a fully
qualified module name. For example: path.to.agent. If not specified, defaults
to "agent". The project root will be added to Python sys.path, allowing
imports to be specified relative to the root. This field should not be set if
the source is agent_config_source.
Corresponds to the JSON property entrypointModule
48913 48914 48915 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48913 def entrypoint_module @entrypoint_module end |
#entrypoint_object ⇒ String
Optional. The name of the callable object within the entrypoint_module to
use as the application If not specified, defaults to "root_agent". This field
should not be set if the source is agent_config_source.
Corresponds to the JSON property entrypointObject
48920 48921 48922 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48920 def entrypoint_object @entrypoint_object end |
#requirements_file ⇒ String
Optional. The path to the requirements file, relative to the source root. If
not specified, defaults to "requirements.txt".
Corresponds to the JSON property requirementsFile
48926 48927 48928 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48926 def requirements_file @requirements_file end |
#version ⇒ String
Optional. The version of Python to use. Supported versions include 3.10, 3.11,
3.12, 3.13, 3.14. If not specified, default value is 3.10.
Corresponds to the JSON property version
48932 48933 48934 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48932 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48939 48940 48941 48942 48943 48944 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48939 def update!(**args) @entrypoint_module = args[:entrypoint_module] if args.key?(:entrypoint_module) @entrypoint_object = args[:entrypoint_object] if args.key?(:entrypoint_object) @requirements_file = args[:requirements_file] if args.key?(:requirements_file) @version = args[:version] if args.key?(:version) end |