Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ModelService.RecommendSpec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RecommendSpecRequest

Returns a new instance of GoogleCloudAiplatformV1beta1RecommendSpecRequest.



46640
46641
46642
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_machine_availabilityBoolean Also known as: check_machine_availability?

Optional. If true, check machine availability for the recommended regions. Only return the machine spec in regions where the machine is available. Corresponds to the JSON property checkMachineAvailability

Returns:

  • (Boolean)


46623
46624
46625
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46623

def check_machine_availability
  @check_machine_availability
end

#check_user_quotaBoolean Also known as: check_user_quota?

Optional. If true, check user quota for the recommended regions. Returns all the machine spec in regions they are available, and also the user quota state for each machine type in each region. Corresponds to the JSON property checkUserQuota

Returns:

  • (Boolean)


46631
46632
46633
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46631

def check_user_quota
  @check_user_quota
end

#gcs_uriString

Required. The Google Cloud Storage URI of the custom model, storing weights and config files (which can be used to infer the base model). Corresponds to the JSON property gcsUri

Returns:

  • (String)


46638
46639
46640
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46638

def gcs_uri
  @gcs_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46645
46646
46647
46648
46649
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46645

def update!(**args)
  @check_machine_availability = args[:check_machine_availability] if args.key?(:check_machine_availability)
  @check_user_quota = args[:check_user_quota] if args.key?(:check_user_quota)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
end