Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ModelService.RecommendSpec.
Instance Attribute Summary collapse
-
#check_machine_availability ⇒ Boolean
(also: #check_machine_availability?)
Optional.
-
#check_user_quota ⇒ Boolean
(also: #check_user_quota?)
Optional.
-
#gcs_uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RecommendSpecRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1RecommendSpecRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RecommendSpecRequest
Returns a new instance of GoogleCloudAiplatformV1beta1RecommendSpecRequest.
45344 45345 45346 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45344 def initialize(**args) update!(**args) end |
Instance Attribute Details
#check_machine_availability ⇒ Boolean Also known as: check_machine_availability?
Optional. If true, check machine availability for the recommended regions.
Only return the machine spec in regions where the machine is available.
Corresponds to the JSON property checkMachineAvailability
45327 45328 45329 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45327 def check_machine_availability @check_machine_availability end |
#check_user_quota ⇒ Boolean Also known as: check_user_quota?
Optional. If true, check user quota for the recommended regions. Returns all
the machine spec in regions they are available, and also the user quota state
for each machine type in each region.
Corresponds to the JSON property checkUserQuota
45335 45336 45337 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45335 def check_user_quota @check_user_quota end |
#gcs_uri ⇒ String
Required. The Google Cloud Storage URI of the custom model, storing weights
and config files (which can be used to infer the base model).
Corresponds to the JSON property gcsUri
45342 45343 45344 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45342 def gcs_uri @gcs_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45349 45350 45351 45352 45353 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45349 def update!(**args) @check_machine_availability = args[:check_machine_availability] if args.key?(:check_machine_availability) @check_user_quota = args[:check_user_quota] if args.key?(:check_user_quota) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) end |