Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for ModelService.RecommendSpec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RecommendSpecResponse

Returns a new instance of GoogleCloudAiplatformV1beta1RecommendSpecResponse.



45376
45377
45378
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45376

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_modelString

Output only. The base model used to finetune the custom model. Corresponds to the JSON property baseModel

Returns:

  • (String)


45363
45364
45365
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45363

def base_model
  @base_model
end

#recommendationsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation>

Output only. Recommendations of deployment options for the given custom weights model. Corresponds to the JSON property recommendations



45369
45370
45371
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45369

def recommendations
  @recommendations
end

#specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseMachineAndModelContainerSpec>

Output only. The machine and model container specs. Corresponds to the JSON property specs



45374
45375
45376
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45374

def specs
  @specs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45381
45382
45383
45384
45385
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45381

def update!(**args)
  @base_model = args[:base_model] if args.key?(:base_model)
  @recommendations = args[:recommendations] if args.key?(:recommendations)
  @specs = args[:specs] if args.key?(:specs)
end