Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for ModelService.RecommendSpec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RecommendSpecResponse

Returns a new instance of GoogleCloudAiplatformV1beta1RecommendSpecResponse.



39855
39856
39857
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_modelString

Output only. The base model used to finetune the custom model. Corresponds to the JSON property baseModel

Returns:

  • (String)


39842
39843
39844
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39842

def base_model
  @base_model
end

#recommendationsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation>

Output only. Recommendations of deployment options for the given custom weights model. Corresponds to the JSON property recommendations



39848
39849
39850
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39848

def recommendations
  @recommendations
end

#specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseMachineAndModelContainerSpec>

Output only. The machine and model container specs. Corresponds to the JSON property specs



39853
39854
39855
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39853

def specs
  @specs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39860
39861
39862
39863
39864
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39860

def update!(**args)
  @base_model = args[:base_model] if args.key?(:base_model)
  @recommendations = args[:recommendations] if args.key?(:recommendations)
  @specs = args[:specs] if args.key?(:specs)
end