Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Recommendation of one deployment option for the given custom weights model in one region. Contains the machine and container spec, and user accelerator quota state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation

Returns a new instance of GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation.



47511
47512
47513
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47511

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#regionString

The region for the deployment spec (machine). Corresponds to the JSON property region

Returns:

  • (String)


47499
47500
47501
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47499

def region
  @region
end

#specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseMachineAndModelContainerSpec

A machine and model container spec. Corresponds to the JSON property spec



47504
47505
47506
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47504

def spec
  @spec
end

#user_quota_stateString

Output only. The user accelerator quota state. Corresponds to the JSON property userQuotaState

Returns:

  • (String)


47509
47510
47511
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47509

def user_quota_state
  @user_quota_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47516
47517
47518
47519
47520
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47516

def update!(**args)
  @region = args[:region] if args.key?(:region)
  @spec = args[:spec] if args.key?(:spec)
  @user_quota_state = args[:user_quota_state] if args.key?(:user_quota_state)
end