Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Recommendation of one deployment option for the given custom weights model in one region. Contains the machine and container spec, and user accelerator quota state.
Instance Attribute Summary collapse
-
#region ⇒ String
The region for the deployment spec (machine).
-
#spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseMachineAndModelContainerSpec
A machine and model container spec.
-
#user_quota_state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation
constructor
A new instance of GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation
Returns a new instance of GoogleCloudAiplatformV1beta1RecommendSpecResponseRecommendation.
39849 39850 39851 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#region ⇒ String
The region for the deployment spec (machine).
Corresponds to the JSON property region
39837 39838 39839 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39837 def region @region end |
#spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RecommendSpecResponseMachineAndModelContainerSpec
A machine and model container spec.
Corresponds to the JSON property spec
39842 39843 39844 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39842 def spec @spec end |
#user_quota_state ⇒ String
Output only. The user accelerator quota state.
Corresponds to the JSON property userQuotaState
39847 39848 39849 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39847 def user_quota_state @user_quota_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39854 39855 39856 39857 39858 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 39854 def update!(**args) @region = args[:region] if args.key?(:region) @spec = args[:spec] if args.key?(:spec) @user_quota_state = args[:user_quota_state] if args.key?(:user_quota_state) end |