Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningExample

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

User-facing format for Gemini Reinforcement Tuning examples on Vertex.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReinforcementTuningExample

Returns a new instance of GoogleCloudAiplatformV1beta1ReinforcementTuningExample.



48944
48945
48946
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>

Multi-turn contents that represents the Prompt. Corresponds to the JSON property contents



48919
48920
48921
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48919

def contents
  @contents
end

#referencesHash<String,String>

References for the given prompt. The key is the name of the reference, and the value is the reference itself. Users can use this field together with the reward configurations to calculate rewards for reinforcement tuning. For example, users can set the following references: ` "concise_answer": "Yes", "verbose_answer": "The answer is Yes" ` Then in a ReinforcementTuningCodeExecutionRewardScorer reward function config, for example, they can define a python code snippet as follows: def evaluate( example, response) -> float: response_str = response.get("parts", [])0 references = example.get("references", ``) if response_str == references.get(" concise_answer"): return 1.0 return -1.0 In this case, references can serve the purpose of holding the ground truth of this example in the training/ validation dataset. Corresponds to the JSON property references

Returns:

  • (Hash<String,String>)


48935
48936
48937
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48935

def references
  @references
end

#system_instructionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property systemInstruction



48942
48943
48944
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48942

def system_instruction
  @system_instruction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48949
48950
48951
48952
48953
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48949

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @references = args[:references] if args.key?(:references)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
end