Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningExample

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

User-facing format for Gemini Reinforcement Tuning examples on Vertex.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReinforcementTuningExample

Returns a new instance of GoogleCloudAiplatformV1beta1ReinforcementTuningExample.



45645
45646
45647
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>

Multi-turn contents that represents the Prompt. Corresponds to the JSON property contents



45630
45631
45632
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45630

def contents
  @contents
end

#referencesHash<String,String>

References for the given prompt. The key is the name of the reference, and the value is the reference itself. Corresponds to the JSON property references

Returns:

  • (Hash<String,String>)


45636
45637
45638
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45636

def references
  @references
end

#system_instructionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property systemInstruction



45643
45644
45645
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45643

def system_instruction
  @system_instruction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45650
45651
45652
45653
45654
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45650

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @references = args[:references] if args.key?(:references)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
end