Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningHyperParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Hyperparameters for Reinforcement Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReinforcementTuningHyperParameters

Returns a new instance of GoogleCloudAiplatformV1beta1ReinforcementTuningHyperParameters.



47238
47239
47240
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adapter_sizeString

Optional. Adapter size for Reinforcement Tuning. Corresponds to the JSON property adapterSize

Returns:

  • (String)


47180
47181
47182
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47180

def adapter_size
  @adapter_size
end

#batch_sizeFixnum

Optional. Batch size for the tuning job. How many prompts to process at a train step. If not set, the batch size will be determined automatically. Corresponds to the JSON property batchSize

Returns:

  • (Fixnum)


47186
47187
47188
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47186

def batch_size
  @batch_size
end

#checkpoint_intervalFixnum

Optional. How often at steps to save checkpoints during training. If not set, one checkpoint per epoch will be set. total_steps = epoch_count * samples_per_prompt / total_prompts_in_dataset Corresponds to the JSON property checkpointInterval

Returns:

  • (Fixnum)


47193
47194
47195
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47193

def checkpoint_interval
  @checkpoint_interval
end

#epoch_countFixnum

Optional. Number of training epoches for the tuning job. Corresponds to the JSON property epochCount

Returns:

  • (Fixnum)


47198
47199
47200
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47198

def epoch_count
  @epoch_count
end

#evaluate_intervalFixnum

Optional. How often at steps to evaluate the tuning job during training. If not set, evel will be run per epoch. total_steps = epoch_count * samples_per_prompt / total_prompts_in_dataset Corresponds to the JSON property evaluateInterval

Returns:

  • (Fixnum)


47205
47206
47207
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47205

def evaluate_interval
  @evaluate_interval
end

#learning_rate_multiplierFloat

Optional. Learning rate multiplier for Reinforcement Tuning. Corresponds to the JSON property learningRateMultiplier

Returns:

  • (Float)


47210
47211
47212
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47210

def learning_rate_multiplier
  @learning_rate_multiplier
end

#max_output_tokensFixnum

Optional. The maximum number of tokens to generate per prompt. Default to 32768. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


47216
47217
47218
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47216

def max_output_tokens
  @max_output_tokens
end

#samples_per_promptFixnum

Optional. Number of different responses to generate per prompt during tuning. Corresponds to the JSON property samplesPerPrompt

Returns:

  • (Fixnum)


47221
47222
47223
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47221

def samples_per_prompt
  @samples_per_prompt
end

#thinking_budgetFixnum

Optional. The thinking budget for the tuning job to optimize for (Gemini 2.5 only). * -1 means dynamic thinking * 0 means no thinking * > 0 means thinking budget in tokens If not set, default to -1 (dynamic thinking). Corresponds to the JSON property thinkingBudget

Returns:

  • (Fixnum)


47228
47229
47230
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47228

def thinking_budget
  @thinking_budget
end

#thinking_levelString

Indicates the maximum thinking depth during tuning. Starting from Gemini 3.5 models, the old thinking_budget will no longer be supported and will result in a user error if set. Instead, users should use the thinking_level parameter to control the maximum thinking depth. Corresponds to the JSON property thinkingLevel

Returns:

  • (String)


47236
47237
47238
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47236

def thinking_level
  @thinking_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47243
47244
47245
47246
47247
47248
47249
47250
47251
47252
47253
47254
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47243

def update!(**args)
  @adapter_size = args[:adapter_size] if args.key?(:adapter_size)
  @batch_size = args[:batch_size] if args.key?(:batch_size)
  @checkpoint_interval = args[:checkpoint_interval] if args.key?(:checkpoint_interval)
  @epoch_count = args[:epoch_count] if args.key?(:epoch_count)
  @evaluate_interval = args[:evaluate_interval] if args.key?(:evaluate_interval)
  @learning_rate_multiplier = args[:learning_rate_multiplier] if args.key?(:learning_rate_multiplier)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @samples_per_prompt = args[:samples_per_prompt] if args.key?(:samples_per_prompt)
  @thinking_budget = args[:thinking_budget] if args.key?(:thinking_budget)
  @thinking_level = args[:thinking_level] if args.key?(:thinking_level)
end