Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningHyperParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Hyperparameters for Reinforcement Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReinforcementTuningHyperParameters

Returns a new instance of GoogleCloudAiplatformV1beta1ReinforcementTuningHyperParameters.



45721
45722
45723
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adapter_sizeString

Optional. Adapter size for Reinforcement Tuning. Corresponds to the JSON property adapterSize

Returns:

  • (String)


45664
45665
45666
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45664

def adapter_size
  @adapter_size
end

#batch_sizeFixnum

Optional. Batch size for the tuning job. How many prompts to process at a train step. If not set, the batch size will be determined automatically. Corresponds to the JSON property batchSize

Returns:

  • (Fixnum)


45670
45671
45672
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45670

def batch_size
  @batch_size
end

#checkpoint_intervalFixnum

Optional. How often at steps to save checkpoints during training. If not set, one checkpoint per epoch will be set. total_steps = epoch_count * samples_per_prompt/total_prompts_in_dataset. Corresponds to the JSON property checkpointInterval

Returns:

  • (Fixnum)


45677
45678
45679
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45677

def checkpoint_interval
  @checkpoint_interval
end

#epoch_countFixnum

Optional. Number of training epoches for the tuning job. Corresponds to the JSON property epochCount

Returns:

  • (Fixnum)


45682
45683
45684
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45682

def epoch_count
  @epoch_count
end

#evaluate_intervalFixnum

Optional. How often at steps to evaluate the tuning job during training. If not set, evel will be run per epoch. total_steps = epoch_count * samples_per_prompt/total_prompts_in_dataset. Corresponds to the JSON property evaluateInterval

Returns:

  • (Fixnum)


45689
45690
45691
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45689

def evaluate_interval
  @evaluate_interval
end

#learning_rate_multiplierFloat

Optional. Learning rate multiplier for Reinforcement Learning. Corresponds to the JSON property learningRateMultiplier

Returns:

  • (Float)


45694
45695
45696
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45694

def learning_rate_multiplier
  @learning_rate_multiplier
end

#max_output_tokensFixnum

Optional. The maximum number of tokens to generate per prompt. If not set, we should default to 32768. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


45700
45701
45702
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45700

def max_output_tokens
  @max_output_tokens
end

#samples_per_promptFixnum

Optional. Number of different responses to generate per prompt during tuning. Corresponds to the JSON property samplesPerPrompt

Returns:

  • (Fixnum)


45705
45706
45707
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45705

def samples_per_prompt
  @samples_per_prompt
end

#thinking_budgetFixnum

Optional. The thinking budget for the tuning job to optimize for. -1 means dynamic thinking 0 means no thinking >0 means thinking budget in tokens If not set, default to -1 (dynamic thinking). Corresponds to the JSON property thinkingBudget

Returns:

  • (Fixnum)


45712
45713
45714
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45712

def thinking_budget
  @thinking_budget
end

#thinking_levelString

Indicates the maximum thinking depth, The thinking_level parameter replaces thinking_budget for Gemini 3 models. Use with earlier models shall result in error. Corresponds to the JSON property thinkingLevel

Returns:

  • (String)


45719
45720
45721
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45719

def thinking_level
  @thinking_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45726
45727
45728
45729
45730
45731
45732
45733
45734
45735
45736
45737
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45726

def update!(**args)
  @adapter_size = args[:adapter_size] if args.key?(:adapter_size)
  @batch_size = args[:batch_size] if args.key?(:batch_size)
  @checkpoint_interval = args[:checkpoint_interval] if args.key?(:checkpoint_interval)
  @epoch_count = args[:epoch_count] if args.key?(:epoch_count)
  @evaluate_interval = args[:evaluate_interval] if args.key?(:evaluate_interval)
  @learning_rate_multiplier = args[:learning_rate_multiplier] if args.key?(:learning_rate_multiplier)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @samples_per_prompt = args[:samples_per_prompt] if args.key?(:samples_per_prompt)
  @thinking_budget = args[:thinking_budget] if args.key?(:thinking_budget)
  @thinking_level = args[:thinking_level] if args.key?(:thinking_level)
end