Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RemoveExamplesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RemoveExamplesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ExampleStoreService.RemoveExamples.
Instance Attribute Summary collapse
-
#example_ids ⇒ Array<String>
Optional.
-
#stored_contents_example_filter ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleFilter
The metadata filters that will be used to remove or fetch StoredContentsExamples.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RemoveExamplesRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1RemoveExamplesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RemoveExamplesRequest
Returns a new instance of GoogleCloudAiplatformV1beta1RemoveExamplesRequest.
47409 47410 47411 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#example_ids ⇒ Array<String>
Optional. Example IDs to remove. If both metadata filters and Example IDs are
specified, the metadata filters will be applied to the specified examples in
order to identify which should be removed.
Corresponds to the JSON property exampleIds
47400 47401 47402 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47400 def example_ids @example_ids end |
#stored_contents_example_filter ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleFilter
The metadata filters that will be used to remove or fetch
StoredContentsExamples. If a field is unspecified, then no filtering for that
field will be applied.
Corresponds to the JSON property storedContentsExampleFilter
47407 47408 47409 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47407 def stored_contents_example_filter @stored_contents_example_filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47414 47415 47416 47417 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47414 def update!(**args) @example_ids = args[:example_ids] if args.key?(:example_ids) @stored_contents_example_filter = args[:stored_contents_example_filter] if args.key?(:stored_contents_example_filter) end |