Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RemoveExamplesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ExampleStoreService.RemoveExamples.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RemoveExamplesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1RemoveExamplesRequest.



44882
44883
44884
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44882

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#example_idsArray<String>

Optional. Example IDs to remove. If both metadata filters and Example IDs are specified, the metadata filters will be applied to the specified examples in order to identify which should be removed. Corresponds to the JSON property exampleIds

Returns:

  • (Array<String>)


44873
44874
44875
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44873

def example_ids
  @example_ids
end

#stored_contents_example_filterGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleFilter

The metadata filters that will be used to remove or fetch StoredContentsExamples. If a field is unspecified, then no filtering for that field will be applied. Corresponds to the JSON property storedContentsExampleFilter



44880
44881
44882
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44880

def stored_contents_example_filter
  @stored_contents_example_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44887
44888
44889
44890
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44887

def update!(**args)
  @example_ids = args[:example_ids] if args.key?(:example_ids)
  @stored_contents_example_filter = args[:stored_contents_example_filter] if args.key?(:stored_contents_example_filter)
end