Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReportExecutionEventRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReportExecutionEventRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for NotebookInternalService.ReportExecutionEvent.
Instance Attribute Summary collapse
-
#event_type ⇒ String
Required.
-
#status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#vm_token ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReportExecutionEventRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1ReportExecutionEventRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReportExecutionEventRequest
Returns a new instance of GoogleCloudAiplatformV1beta1ReportExecutionEventRequest.
49460 49461 49462 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49460 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_type ⇒ String
Required. The type of the event.
Corresponds to the JSON property eventType
49442 49443 49444 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49442 def event_type @event_type end |
#status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
49452 49453 49454 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49452 def status @status end |
#vm_token ⇒ String
Required. The VM identity token (a JWT) for authenticating the VM. https://
cloud.google.com/compute/docs/instances/verifying-instance-identity
Corresponds to the JSON property vmToken
49458 49459 49460 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49458 def vm_token @vm_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49465 49466 49467 49468 49469 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49465 def update!(**args) @event_type = args[:event_type] if args.key?(:event_type) @status = args[:status] if args.key?(:status) @vm_token = args[:vm_token] if args.key?(:vm_token) end |