Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReportExecutionEventRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for NotebookInternalService.ReportExecutionEvent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReportExecutionEventRequest

Returns a new instance of GoogleCloudAiplatformV1beta1ReportExecutionEventRequest.



47492
47493
47494
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_typeString

Required. The type of the event. Corresponds to the JSON property eventType

Returns:

  • (String)


47474
47475
47476
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47474

def event_type
  @event_type
end

#statusGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



47484
47485
47486
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47484

def status
  @status
end

#vm_tokenString

Required. The VM identity token (a JWT) for authenticating the VM. https:// cloud.google.com/compute/docs/instances/verifying-instance-identity Corresponds to the JSON property vmToken

Returns:

  • (String)


47490
47491
47492
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47490

def vm_token
  @vm_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47497
47498
47499
47500
47501
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47497

def update!(**args)
  @event_type = args[:event_type] if args.key?(:event_type)
  @status = args[:status] if args.key?(:status)
  @vm_token = args[:vm_token] if args.key?(:vm_token)
end