Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReportExecutionEventRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for NotebookInternalService.ReportExecutionEvent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReportExecutionEventRequest

Returns a new instance of GoogleCloudAiplatformV1beta1ReportExecutionEventRequest.



47670
47671
47672
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_typeString

Required. The type of the event. Corresponds to the JSON property eventType

Returns:

  • (String)


47652
47653
47654
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47652

def event_type
  @event_type
end

#statusGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



47662
47663
47664
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47662

def status
  @status
end

#vm_tokenString

Required. The VM identity token (a JWT) for authenticating the VM. https:// cloud.google.com/compute/docs/instances/verifying-instance-identity Corresponds to the JSON property vmToken

Returns:

  • (String)


47668
47669
47670
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47668

def vm_token
  @vm_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47675
47676
47677
47678
47679
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47675

def update!(**args)
  @event_type = args[:event_type] if args.key?(:event_type)
  @status = args[:status] if args.key?(:status)
  @vm_token = args[:vm_token] if args.key?(:vm_token)
end