Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReservationAffinity
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReservationAffinity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A ReservationAffinity can be used to configure a Vertex AI resource (e.g., a DeployedModel) to draw its Compute Engine resources from a Shared Reservation, or exclusively from on-demand capacity.
Instance Attribute Summary collapse
-
#key ⇒ String
Optional.
-
#reservation_affinity_type ⇒ String
Required.
-
#values ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReservationAffinity
constructor
A new instance of GoogleCloudAiplatformV1beta1ReservationAffinity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReservationAffinity
Returns a new instance of GoogleCloudAiplatformV1beta1ReservationAffinity.
50130 50131 50132 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50130 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Optional. Corresponds to the label key of a reservation resource. To target a
SPECIFIC_RESERVATION by name, use compute.googleapis.com/reservation-name as
the key and specify the name of your reservation as its value.
Corresponds to the JSON property key
50116 50117 50118 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50116 def key @key end |
#reservation_affinity_type ⇒ String
Required. Specifies the reservation affinity type.
Corresponds to the JSON property reservationAffinityType
50121 50122 50123 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50121 def reservation_affinity_type @reservation_affinity_type end |
#values ⇒ Array<String>
Optional. Corresponds to the label values of a reservation resource. This must
be the resource name of the reservation, reservation block, or reservation sub-
block.
Corresponds to the JSON property values
50128 50129 50130 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50128 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50135 50136 50137 50138 50139 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50135 def update!(**args) @key = args[:key] if args.key?(:key) @reservation_affinity_type = args[:reservation_affinity_type] if args.key?(:reservation_affinity_type) @values = args[:values] if args.key?(:values) end |