Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReservationAffinity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A ReservationAffinity can be used to configure a Vertex AI resource (e.g., a DeployedModel) to draw its Compute Engine resources from a Shared Reservation, or exclusively from on-demand capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ReservationAffinity

Returns a new instance of GoogleCloudAiplatformV1beta1ReservationAffinity.



47783
47784
47785
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47783

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Optional. Corresponds to the label key of a reservation resource. To target a SPECIFIC_RESERVATION by name, use compute.googleapis.com/reservation-name as the key and specify the name of your reservation as its value. Corresponds to the JSON property key

Returns:

  • (String)


47770
47771
47772
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47770

def key
  @key
end

#reservation_affinity_typeString

Required. Specifies the reservation affinity type. Corresponds to the JSON property reservationAffinityType

Returns:

  • (String)


47775
47776
47777
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47775

def reservation_affinity_type
  @reservation_affinity_type
end

#valuesArray<String>

Optional. Corresponds to the label values of a reservation resource. This must be the full resource name of the reservation or reservation block. Corresponds to the JSON property values

Returns:

  • (Array<String>)


47781
47782
47783
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47781

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47788
47789
47790
47791
47792
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47788

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @reservation_affinity_type = args[:reservation_affinity_type] if args.key?(:reservation_affinity_type)
  @values = args[:values] if args.key?(:values)
end