Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourcePool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents the spec of a group of resources of the same type, for example machine type, disk, and accelerators, in a PersistentResource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ResourcePool

Returns a new instance of GoogleCloudAiplatformV1beta1ResourcePool.



46304
46305
46306
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46304

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscaling_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourcePoolAutoscalingSpec

The min/max number of replicas allowed if enabling autoscaling Corresponds to the JSON property autoscalingSpec



46274
46275
46276
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46274

def autoscaling_spec
  @autoscaling_spec
end

#disk_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DiskSpec

Represents the spec of disk options. Corresponds to the JSON property diskSpec



46279
46280
46281
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46279

def disk_spec
  @disk_spec
end

#idString

Immutable. The unique ID in a PersistentResource for referring to this resource pool. User can specify it if necessary. Otherwise, it's generated automatically. Corresponds to the JSON property id

Returns:

  • (String)


46286
46287
46288
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46286

def id
  @id
end

#machine_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



46291
46292
46293
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46291

def machine_spec
  @machine_spec
end

#replica_countFixnum

Optional. The total number of machines to use for this resource pool. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


46296
46297
46298
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46296

def replica_count
  @replica_count
end

#used_replica_countFixnum

Output only. The number of machines currently in use by training jobs for this resource pool. Will replace idle_replica_count. Corresponds to the JSON property usedReplicaCount

Returns:

  • (Fixnum)


46302
46303
46304
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46302

def used_replica_count
  @used_replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46309
46310
46311
46312
46313
46314
46315
46316
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46309

def update!(**args)
  @autoscaling_spec = args[:autoscaling_spec] if args.key?(:autoscaling_spec)
  @disk_spec = args[:disk_spec] if args.key?(:disk_spec)
  @id = args[:id] if args.key?(:id)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
  @used_replica_count = args[:used_replica_count] if args.key?(:used_replica_count)
end