Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourcePool
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourcePool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents the spec of a group of resources of the same type, for example machine type, disk, and accelerators, in a PersistentResource.
Instance Attribute Summary collapse
-
#autoscaling_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourcePoolAutoscalingSpec
The min/max number of replicas allowed if enabling autoscaling Corresponds to the JSON property
autoscalingSpec. -
#disk_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DiskSpec
Represents the spec of disk options.
-
#id ⇒ String
Immutable.
-
#machine_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec
Specification of a single machine.
-
#replica_count ⇒ Fixnum
Optional.
-
#used_replica_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ResourcePool
constructor
A new instance of GoogleCloudAiplatformV1beta1ResourcePool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ResourcePool
Returns a new instance of GoogleCloudAiplatformV1beta1ResourcePool.
45128 45129 45130 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourcePoolAutoscalingSpec
The min/max number of replicas allowed if enabling autoscaling
Corresponds to the JSON property autoscalingSpec
45098 45099 45100 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45098 def autoscaling_spec @autoscaling_spec end |
#disk_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DiskSpec
Represents the spec of disk options.
Corresponds to the JSON property diskSpec
45103 45104 45105 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45103 def disk_spec @disk_spec end |
#id ⇒ String
Immutable. The unique ID in a PersistentResource for referring to this
resource pool. User can specify it if necessary. Otherwise, it's generated
automatically.
Corresponds to the JSON property id
45110 45111 45112 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45110 def id @id end |
#machine_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
45115 45116 45117 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45115 def machine_spec @machine_spec end |
#replica_count ⇒ Fixnum
Optional. The total number of machines to use for this resource pool.
Corresponds to the JSON property replicaCount
45120 45121 45122 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45120 def replica_count @replica_count end |
#used_replica_count ⇒ Fixnum
Output only. The number of machines currently in use by training jobs for this
resource pool. Will replace idle_replica_count.
Corresponds to the JSON property usedReplicaCount
45126 45127 45128 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45126 def used_replica_count @used_replica_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45133 45134 45135 45136 45137 45138 45139 45140 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45133 def update!(**args) @autoscaling_spec = args[:autoscaling_spec] if args.key?(:autoscaling_spec) @disk_spec = args[:disk_spec] if args.key?(:disk_spec) @id = args[:id] if args.key?(:id) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @replica_count = args[:replica_count] if args.key?(:replica_count) @used_replica_count = args[:used_replica_count] if args.key?(:used_replica_count) end |