Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourcesConsumed
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourcesConsumed
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Statistics information about resource consumption.
Instance Attribute Summary collapse
-
#replica_hours ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ResourcesConsumed
constructor
A new instance of GoogleCloudAiplatformV1beta1ResourcesConsumed.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ResourcesConsumed
Returns a new instance of GoogleCloudAiplatformV1beta1ResourcesConsumed.
47772 47773 47774 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#replica_hours ⇒ Float
Output only. The number of replica hours used. Note that many replicas may run
in parallel, and additionally any given work may be queued for some time.
Therefore this value is not strictly related to wall time.
Corresponds to the JSON property replicaHours
47770 47771 47772 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47770 def replica_hours @replica_hours end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47777 47778 47779 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47777 def update!(**args) @replica_hours = args[:replica_hours] if args.key?(:replica_hours) end |