Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResourcesConsumed

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Statistics information about resource consumption.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ResourcesConsumed

Returns a new instance of GoogleCloudAiplatformV1beta1ResourcesConsumed.



40306
40307
40308
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40306

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#replica_hoursFloat

Output only. The number of replica hours used. Note that many replicas may run in parallel, and additionally any given work may be queued for some time. Therefore this value is not strictly related to wall time. Corresponds to the JSON property replicaHours

Returns:

  • (Float)


40304
40305
40306
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40304

def replica_hours
  @replica_hours
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40311
40312
40313
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40311

def update!(**args)
  @replica_hours = args[:replica_hours] if args.key?(:replica_hours)
end