Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ResumeScheduleRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ScheduleService.ResumeSchedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ResumeScheduleRequest

Returns a new instance of GoogleCloudAiplatformV1beta1ResumeScheduleRequest.



40428
40429
40430
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#catch_upBoolean Also known as: catch_up?

Optional. Whether to backfill missed runs when the schedule is resumed from PAUSED state. If set to true, all missed runs will be scheduled. New runs will be scheduled after the backfill is complete. This will also update Schedule. catch_up field. Default to false. Corresponds to the JSON property catchUp

Returns:

  • (Boolean)


40425
40426
40427
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40425

def catch_up
  @catch_up
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40433
40434
40435
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40433

def update!(**args)
  @catch_up = args[:catch_up] if args.key?(:catch_up)
end