Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Retrieval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Defines a retrieval tool that model can call to access external knowledge.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Retrieval

Returns a new instance of GoogleCloudAiplatformV1beta1Retrieval.



40466
40467
40468
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_attributionBoolean Also known as: disable_attribution?

Optional. Deprecated. This option is no longer supported. Corresponds to the JSON property disableAttribution

Returns:

  • (Boolean)


40445
40446
40447
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40445

def disable_attribution
  @disable_attribution
end

#external_apiGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExternalApi

Retrieve from data source powered by external API for grounding. The external API is not owned by Google, but need to follow the pre-defined API spec. Corresponds to the JSON property externalApi



40452
40453
40454
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40452

def external_api
  @external_api
end

#vertex_ai_searchGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexAiSearch

Retrieve from Vertex AI Search datastore or engine for grounding. datastore and engine are mutually exclusive. See https://cloud.google.com/products/agent- builder Corresponds to the JSON property vertexAiSearch



40459
40460
40461
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40459

def vertex_ai_search
  @vertex_ai_search
end

#vertex_rag_storeGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexRagStore

Retrieve from Vertex RAG Store for grounding. Corresponds to the JSON property vertexRagStore



40464
40465
40466
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40464

def vertex_rag_store
  @vertex_rag_store
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40471
40472
40473
40474
40475
40476
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40471

def update!(**args)
  @disable_attribution = args[:disable_attribution] if args.key?(:disable_attribution)
  @external_api = args[:external_api] if args.key?(:external_api)
  @vertex_ai_search = args[:vertex_ai_search] if args.key?(:vertex_ai_search)
  @vertex_rag_store = args[:vertex_rag_store] if args.key?(:vertex_rag_store)
end