Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrievalConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrievalConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Retrieval config.
Instance Attribute Summary collapse
-
#language_code ⇒ String
The language code of the user.
-
#lat_lng ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeLatLng
An object that represents a latitude/longitude pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrievalConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1RetrievalConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrievalConfig
Returns a new instance of GoogleCloudAiplatformV1beta1RetrievalConfig.
49913 49914 49915 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49913 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language_code ⇒ String
The language code of the user.
Corresponds to the JSON property languageCode
49903 49904 49905 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49903 def language_code @language_code end |
#lat_lng ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeLatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property latLng
49911 49912 49913 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49911 def lat_lng @lat_lng end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49918 49919 49920 49921 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49918 def update!(**args) @language_code = args[:language_code] if args.key?(:language_code) @lat_lng = args[:lat_lng] if args.key?(:lat_lng) end |