Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrievalConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrievalConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Retrieval config.
Instance Attribute Summary collapse
-
#language_code ⇒ String
The language code of the user.
-
#lat_lng ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeLatLng
An object that represents a latitude/longitude pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrievalConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1RetrievalConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrievalConfig
Returns a new instance of GoogleCloudAiplatformV1beta1RetrievalConfig.
48730 48731 48732 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language_code ⇒ String
The language code of the user.
Corresponds to the JSON property languageCode
48720 48721 48722 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48720 def language_code @language_code end |
#lat_lng ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeLatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property latLng
48728 48729 48730 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48728 def lat_lng @lat_lng end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48735 48736 48737 48738 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48735 def update!(**args) @language_code = args[:language_code] if args.key?(:language_code) @lat_lng = args[:lat_lng] if args.key?(:lat_lng) end |