Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrieveContextsRequestVertexRagStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The data source for Vertex RagStore.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrieveContextsRequestVertexRagStore

Returns a new instance of GoogleCloudAiplatformV1beta1RetrieveContextsRequestVertexRagStore.



48812
48813
48814
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48812

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rag_corporaArray<String>

Optional. Deprecated. Please use rag_resources to specify the data source. Corresponds to the JSON property ragCorpora

Returns:

  • (Array<String>)


48798
48799
48800
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48798

def rag_corpora
  @rag_corpora
end

#rag_resourcesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrieveContextsRequestVertexRagStoreRagResource>

Optional. The representation of the rag source. It can be used to specify corpus only or ragfiles. Currently only support one corpus or multiple files from one corpus. In the future we may open up multiple corpora support. Corresponds to the JSON property ragResources



48805
48806
48807
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48805

def rag_resources
  @rag_resources
end

#vector_distance_thresholdFloat

Optional. Only return contexts with vector distance smaller than the threshold. Corresponds to the JSON property vectorDistanceThreshold

Returns:

  • (Float)


48810
48811
48812
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48810

def vector_distance_threshold
  @vector_distance_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48817
48818
48819
48820
48821
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48817

def update!(**args)
  @rag_corpora = args[:rag_corpora] if args.key?(:rag_corpora)
  @rag_resources = args[:rag_resources] if args.key?(:rag_resources)
  @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold)
end