Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrieveContextsRequestVertexRagStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrieveContextsRequestVertexRagStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The data source for Vertex RagStore.
Instance Attribute Summary collapse
-
#rag_corpora ⇒ Array<String>
Optional.
-
#rag_resources ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrieveContextsRequestVertexRagStoreRagResource>
Optional.
-
#vector_distance_threshold ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrieveContextsRequestVertexRagStore
constructor
A new instance of GoogleCloudAiplatformV1beta1RetrieveContextsRequestVertexRagStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrieveContextsRequestVertexRagStore
Returns a new instance of GoogleCloudAiplatformV1beta1RetrieveContextsRequestVertexRagStore.
45450 45451 45452 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rag_corpora ⇒ Array<String>
Optional. Deprecated. Please use rag_resources to specify the data source.
Corresponds to the JSON property ragCorpora
45436 45437 45438 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45436 def rag_corpora @rag_corpora end |
#rag_resources ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrieveContextsRequestVertexRagStoreRagResource>
Optional. The representation of the rag source. It can be used to specify
corpus only or ragfiles. Currently only support one corpus or multiple files
from one corpus. In the future we may open up multiple corpora support.
Corresponds to the JSON property ragResources
45443 45444 45445 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45443 def rag_resources @rag_resources end |
#vector_distance_threshold ⇒ Float
Optional. Only return contexts with vector distance smaller than the threshold.
Corresponds to the JSON property vectorDistanceThreshold
45448 45449 45450 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45448 def vector_distance_threshold @vector_distance_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45455 45456 45457 45458 45459 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45455 def update!(**args) @rag_corpora = args[:rag_corpora] if args.key?(:rag_corpora) @rag_resources = args[:rag_resources] if args.key?(:rag_resources) @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold) end |