Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrieveMemoriesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for MemoryBankService.RetrieveMemories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrieveMemoriesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1RetrieveMemoriesRequest.



40619
40620
40621
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Optional. The standard list filter that will be applied to the retrieved memories. More detail in AIP-160. Supported fields: * fact * create_time * update_time * topics (i.e. topics. custom_memory_topic_label: "example topic" OR topics.managed_memory_topic: USER_PREFERENCES) Corresponds to the JSON property filter

Returns:

  • (String)


40580
40581
40582
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40580

def filter
  @filter
end

#filter_groupsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryConjunctionFilter>

Optional. Metadata filters that will be applied to the retrieved memories' metadata using OR logic. Filters are defined using disjunctive normal form ( OR of ANDs). For example: filter_groups: [filters: [key: "author", value: string_value: "agent 123", op: EQUAL],filters: [key: "label", value: string_value: "travel", op: EQUAL, key: "author", value:string_value: " agent 321", op: EQUAL]] would be equivalent to the logical expression: ( metadata.author = "agent 123" OR (metadata.label = "travel" AND metadata. author = "agent 321")). Corresponds to the JSON property filterGroups



40592
40593
40594
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40592

def filter_groups
  @filter_groups
end

#memory_typesArray<String>

Optional. Specifies the types of memories to retrieve. If this field is empty or not provided, the request will default to retrieving only memories of type NATURAL_LANGUAGE_COLLECTION. If populated, the request will retrieve memories matching any of the specified MemoryType values. Corresponds to the JSON property memoryTypes

Returns:

  • (Array<String>)


40600
40601
40602
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40600

def memory_types
  @memory_types
end

#scopeHash<String,String>

Required. The scope of the memories to retrieve. A memory must have exactly the same scope (Memory.scope) as the scope provided here to be retrieved ( same keys and values). Order does not matter, but it is case-sensitive. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


40607
40608
40609
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40607

def scope
  @scope
end

#similarity_search_paramsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrieveMemoriesRequestSimilaritySearchParams

Parameters for semantic similarity search based retrieval. Corresponds to the JSON property similaritySearchParams



40612
40613
40614
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40612

def similarity_search_params
  @similarity_search_params
end

#simple_retrieval_paramsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrieveMemoriesRequestSimpleRetrievalParams

Parameters for simple (non-similarity search) retrieval. Corresponds to the JSON property simpleRetrievalParams



40617
40618
40619
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40617

def simple_retrieval_params
  @simple_retrieval_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40624
40625
40626
40627
40628
40629
40630
40631
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40624

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @filter_groups = args[:filter_groups] if args.key?(:filter_groups)
  @memory_types = args[:memory_types] if args.key?(:memory_types)
  @scope = args[:scope] if args.key?(:scope)
  @similarity_search_params = args[:similarity_search_params] if args.key?(:similarity_search_params)
  @simple_retrieval_params = args[:simple_retrieval_params] if args.key?(:simple_retrieval_params)
end