Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrieveProfilesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrieveProfilesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for MemoryBankService.RetrieveProfiles.
Instance Attribute Summary collapse
-
#profiles ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryProfile>
The retrieved structured profiles, which match the schemas under the requested scope.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrieveProfilesResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1RetrieveProfilesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrieveProfilesResponse
Returns a new instance of GoogleCloudAiplatformV1beta1RetrieveProfilesResponse.
49096 49097 49098 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49096 def initialize(**args) update!(**args) end |
Instance Attribute Details
#profiles ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryProfile>
The retrieved structured profiles, which match the schemas under the requested
scope. The key is the ID of the schema that the profile is linked with, which
corresponds to the schema_id defined inside the SchemaConfig, under
StructuredMemoryCustomizationConfig.
Corresponds to the JSON property profiles
49094 49095 49096 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49094 def profiles @profiles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49101 49102 49103 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49101 def update!(**args) @profiles = args[:profiles] if args.key?(:profiles) end |