Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrieveProfilesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for MemoryBankService.RetrieveProfiles.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrieveProfilesResponse

Returns a new instance of GoogleCloudAiplatformV1beta1RetrieveProfilesResponse.



48311
48312
48313
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48311

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#profilesHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryProfile>

The retrieved structured profiles, which match the schemas under the requested scope. The key is the ID of the schema that the profile is linked with, which corresponds to the schema_id defined inside the SchemaConfig, under StructuredMemoryCustomizationConfig. Corresponds to the JSON property profiles



48309
48310
48311
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48309

def profiles
  @profiles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48316
48317
48318
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48316

def update!(**args)
  @profiles = args[:profiles] if args.key?(:profiles)
end