Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RetrieveProfilesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for MemoryBankService.RetrieveProfiles.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrieveProfilesResponse

Returns a new instance of GoogleCloudAiplatformV1beta1RetrieveProfilesResponse.



46910
46911
46912
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#profilesHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MemoryProfile>

The retrieved structured profiles, which match the schemas under the requested scope. The key is the ID of the schema that the profile is linked with, which corresponds to the schema_id defined inside the SchemaConfig, under StructuredMemoryCustomizationConfig. Corresponds to the JSON property profiles



46908
46909
46910
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46908

def profiles
  @profiles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46915
46916
46917
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46915

def update!(**args)
  @profiles = args[:profiles] if args.key?(:profiles)
end