Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RolloutOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for rolling deployments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RolloutOptions

Returns a new instance of GoogleCloudAiplatformV1beta1RolloutOptions.



49208
49209
49210
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_surge_percentageFixnum

Percentage of allowed additional replicas. For autoscaling deployments, this refers to the target replica count. Corresponds to the JSON property maxSurgePercentage

Returns:

  • (Fixnum)


49178
49179
49180
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49178

def max_surge_percentage
  @max_surge_percentage
end

#max_surge_replicasFixnum

Absolute count of allowed additional replicas. Corresponds to the JSON property maxSurgeReplicas

Returns:

  • (Fixnum)


49183
49184
49185
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49183

def max_surge_replicas
  @max_surge_replicas
end

#max_unavailable_percentageFixnum

Percentage of replicas allowed to be unavailable. For autoscaling deployments, this refers to the target replica count. Corresponds to the JSON property maxUnavailablePercentage

Returns:

  • (Fixnum)


49189
49190
49191
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49189

def max_unavailable_percentage
  @max_unavailable_percentage
end

#max_unavailable_replicasFixnum

Absolute count of replicas allowed to be unavailable. Corresponds to the JSON property maxUnavailableReplicas

Returns:

  • (Fixnum)


49194
49195
49196
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49194

def max_unavailable_replicas
  @max_unavailable_replicas
end

#previous_deployed_modelString

ID of the DeployedModel that this deployment should replace. Corresponds to the JSON property previousDeployedModel

Returns:

  • (String)


49199
49200
49201
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49199

def previous_deployed_model
  @previous_deployed_model
end

#revision_numberFixnum

Output only. Read-only. Revision number determines the relative priority of DeployedModels in the same rollout. The DeployedModel with the largest revision number specifies the intended state of the deployment. Corresponds to the JSON property revisionNumber

Returns:

  • (Fixnum)


49206
49207
49208
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49206

def revision_number
  @revision_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49213
49214
49215
49216
49217
49218
49219
49220
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49213

def update!(**args)
  @max_surge_percentage = args[:max_surge_percentage] if args.key?(:max_surge_percentage)
  @max_surge_replicas = args[:max_surge_replicas] if args.key?(:max_surge_replicas)
  @max_unavailable_percentage = args[:max_unavailable_percentage] if args.key?(:max_unavailable_percentage)
  @max_unavailable_replicas = args[:max_unavailable_replicas] if args.key?(:max_unavailable_replicas)
  @previous_deployed_model = args[:previous_deployed_model] if args.key?(:previous_deployed_model)
  @revision_number = args[:revision_number] if args.key?(:revision_number)
end