Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RolloutOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for rolling deployments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RolloutOptions

Returns a new instance of GoogleCloudAiplatformV1beta1RolloutOptions.



40843
40844
40845
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40843

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_surge_percentageFixnum

Percentage of allowed additional replicas. For autoscaling deployments, this refers to the target replica count. Corresponds to the JSON property maxSurgePercentage

Returns:

  • (Fixnum)


40813
40814
40815
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40813

def max_surge_percentage
  @max_surge_percentage
end

#max_surge_replicasFixnum

Absolute count of allowed additional replicas. Corresponds to the JSON property maxSurgeReplicas

Returns:

  • (Fixnum)


40818
40819
40820
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40818

def max_surge_replicas
  @max_surge_replicas
end

#max_unavailable_percentageFixnum

Percentage of replicas allowed to be unavailable. For autoscaling deployments, this refers to the target replica count. Corresponds to the JSON property maxUnavailablePercentage

Returns:

  • (Fixnum)


40824
40825
40826
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40824

def max_unavailable_percentage
  @max_unavailable_percentage
end

#max_unavailable_replicasFixnum

Absolute count of replicas allowed to be unavailable. Corresponds to the JSON property maxUnavailableReplicas

Returns:

  • (Fixnum)


40829
40830
40831
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40829

def max_unavailable_replicas
  @max_unavailable_replicas
end

#previous_deployed_modelString

ID of the DeployedModel that this deployment should replace. Corresponds to the JSON property previousDeployedModel

Returns:

  • (String)


40834
40835
40836
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40834

def previous_deployed_model
  @previous_deployed_model
end

#revision_numberFixnum

Output only. Read-only. Revision number determines the relative priority of DeployedModels in the same rollout. The DeployedModel with the largest revision number specifies the intended state of the deployment. Corresponds to the JSON property revisionNumber

Returns:

  • (Fixnum)


40841
40842
40843
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40841

def revision_number
  @revision_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40848
40849
40850
40851
40852
40853
40854
40855
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40848

def update!(**args)
  @max_surge_percentage = args[:max_surge_percentage] if args.key?(:max_surge_percentage)
  @max_surge_replicas = args[:max_surge_replicas] if args.key?(:max_surge_replicas)
  @max_unavailable_percentage = args[:max_unavailable_percentage] if args.key?(:max_unavailable_percentage)
  @max_unavailable_replicas = args[:max_unavailable_replicas] if args.key?(:max_unavailable_replicas)
  @previous_deployed_model = args[:previous_deployed_model] if args.key?(:previous_deployed_model)
  @revision_number = args[:revision_number] if args.key?(:revision_number)
end