Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Rubric
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Rubric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Message representing a single testable criterion for evaluation. One input prompt could have multiple rubrics.
Instance Attribute Summary collapse
-
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricContent
Content of the rubric, defining the testable criteria.
-
#importance ⇒ String
Optional.
-
#rubric_id ⇒ String
Unique identifier for the rubric.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Rubric
constructor
A new instance of GoogleCloudAiplatformV1beta1Rubric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Rubric
Returns a new instance of GoogleCloudAiplatformV1beta1Rubric.
41010 41011 41012 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41010 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricContent
Content of the rubric, defining the testable criteria.
Corresponds to the JSON property content
40989 40990 40991 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40989 def content @content end |
#importance ⇒ String
Optional. The relative importance of this rubric.
Corresponds to the JSON property importance
40994 40995 40996 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 40994 def importance @importance end |
#rubric_id ⇒ String
Unique identifier for the rubric. This ID is used to refer to this rubric, e.g.
, in RubricVerdict.
Corresponds to the JSON property rubricId
41000 41001 41002 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41000 def rubric_id @rubric_id end |
#type ⇒ String
Optional. A type designator for the rubric, which can inform how it's
evaluated or interpreted by systems or users. It's recommended to use
consistent, well-defined, upper snake_case strings. Examples: "
SUMMARIZATION_QUALITY", "SAFETY_HARMFUL_CONTENT", "INSTRUCTION_ADHERENCE".
Corresponds to the JSON property type
41008 41009 41010 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41008 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41015 41016 41017 41018 41019 41020 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41015 def update!(**args) @content = args[:content] if args.key?(:content) @importance = args[:importance] if args.key?(:importance) @rubric_id = args[:rubric_id] if args.key?(:rubric_id) @type = args[:type] if args.key?(:type) end |