Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricBasedInstructionFollowingInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Instance and metric spec for RubricBasedInstructionFollowing metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RubricBasedInstructionFollowingInput

Returns a new instance of GoogleCloudAiplatformV1beta1RubricBasedInstructionFollowingInput.



41125
41126
41127
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41125

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instanceGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricBasedInstructionFollowingInstance

Instance for RubricBasedInstructionFollowing metric - one instance corresponds to one row in an evaluation dataset. Corresponds to the JSON property instance



41117
41118
41119
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41117

def instance
  @instance
end

#metric_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricBasedInstructionFollowingSpec

Spec for RubricBasedInstructionFollowing metric - returns rubrics and verdicts corresponding to rubrics along with overall score. Corresponds to the JSON property metricSpec



41123
41124
41125
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41123

def metric_spec
  @metric_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41130
41131
41132
41133
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41130

def update!(**args)
  @instance = args[:instance] if args.key?(:instance)
  @metric_spec = args[:metric_spec] if args.key?(:metric_spec)
end