Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A group of rubrics, used for grouping rubrics based on a metric or a version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RubricGroup

Returns a new instance of GoogleCloudAiplatformV1beta1RubricGroup.



47418
47419
47420
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Human-readable name for the group. This should be unique within a given context if used for display or selection. Example: "Instruction Following V1", "Content Quality - Summarization Task". Corresponds to the JSON property displayName

Returns:

  • (String)


47406
47407
47408
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47406

def display_name
  @display_name
end

#group_idString

Unique identifier for the group. Corresponds to the JSON property groupId

Returns:

  • (String)


47411
47412
47413
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47411

def group_id
  @group_id
end

#rubricsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Rubric>

Rubrics that are part of this group. Corresponds to the JSON property rubrics



47416
47417
47418
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47416

def rubrics
  @rubrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47423
47424
47425
47426
47427
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47423

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @group_id = args[:group_id] if args.key?(:group_id)
  @rubrics = args[:rubrics] if args.key?(:rubrics)
end