Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A group of rubrics, used for grouping rubrics based on a metric or a version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RubricGroup

Returns a new instance of GoogleCloudAiplatformV1beta1RubricGroup.



41239
41240
41241
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Human-readable name for the group. This should be unique within a given context if used for display or selection. Example: "Instruction Following V1", "Content Quality - Summarization Task". Corresponds to the JSON property displayName

Returns:

  • (String)


41227
41228
41229
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41227

def display_name
  @display_name
end

#group_idString

Unique identifier for the group. Corresponds to the JSON property groupId

Returns:

  • (String)


41232
41233
41234
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41232

def group_id
  @group_id
end

#rubricsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Rubric>

Rubrics that are part of this group. Corresponds to the JSON property rubrics



41237
41238
41239
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41237

def rubrics
  @rubrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41244
41245
41246
41247
41248
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41244

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @group_id = args[:group_id] if args.key?(:group_id)
  @rubrics = args[:rubrics] if args.key?(:rubrics)
end