Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricVerdict
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricVerdict
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents the verdict of an evaluation against a single rubric.
Instance Attribute Summary collapse
-
#evaluated_rubric ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Rubric
Message representing a single testable criterion for evaluation.
-
#reasoning ⇒ String
Optional.
-
#verdict ⇒ Boolean
(also: #verdict?)
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RubricVerdict
constructor
A new instance of GoogleCloudAiplatformV1beta1RubricVerdict.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RubricVerdict
Returns a new instance of GoogleCloudAiplatformV1beta1RubricVerdict.
46278 46279 46280 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46278 def initialize(**args) update!(**args) end |
Instance Attribute Details
#evaluated_rubric ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Rubric
Message representing a single testable criterion for evaluation. One input
prompt could have multiple rubrics.
Corresponds to the JSON property evaluatedRubric
46262 46263 46264 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46262 def evaluated_rubric @evaluated_rubric end |
#reasoning ⇒ String
Optional. Human-readable reasoning or explanation for the verdict. This can
include specific examples or details from the evaluated content that justify
the given verdict.
Corresponds to the JSON property reasoning
46269 46270 46271 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46269 def reasoning @reasoning end |
#verdict ⇒ Boolean Also known as: verdict?
Required. Outcome of the evaluation against the rubric, represented as a
boolean. true indicates a "Pass", false indicates a "Fail".
Corresponds to the JSON property verdict
46275 46276 46277 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46275 def verdict @verdict end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46283 46284 46285 46286 46287 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46283 def update!(**args) @evaluated_rubric = args[:evaluated_rubric] if args.key?(:evaluated_rubric) @reasoning = args[:reasoning] if args.key?(:reasoning) @verdict = args[:verdict] if args.key?(:verdict) end |