Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RubricVerdict

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents the verdict of an evaluation against a single rubric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RubricVerdict

Returns a new instance of GoogleCloudAiplatformV1beta1RubricVerdict.



41275
41276
41277
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#evaluated_rubricGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Rubric

Message representing a single testable criterion for evaluation. One input prompt could have multiple rubrics. Corresponds to the JSON property evaluatedRubric



41259
41260
41261
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41259

def evaluated_rubric
  @evaluated_rubric
end

#reasoningString

Optional. Human-readable reasoning or explanation for the verdict. This can include specific examples or details from the evaluated content that justify the given verdict. Corresponds to the JSON property reasoning

Returns:

  • (String)


41266
41267
41268
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41266

def reasoning
  @reasoning
end

#verdictBoolean Also known as: verdict?

Required. Outcome of the evaluation against the rubric, represented as a boolean. true indicates a "Pass", false indicates a "Fail". Corresponds to the JSON property verdict

Returns:

  • (Boolean)


41272
41273
41274
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41272

def verdict
  @verdict
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41280
41281
41282
41283
41284
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41280

def update!(**args)
  @evaluated_rubric = args[:evaluated_rubric] if args.key?(:evaluated_rubric)
  @reasoning = args[:reasoning] if args.key?(:reasoning)
  @verdict = args[:verdict] if args.key?(:verdict)
end