Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig

Returns a new instance of GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig.



48975
48976
48977
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_input_gcs_bucketString

Optional. The Cloud Storage bucket for file input of this Extension. If specified, support input from the Cloud Storage bucket. Vertex Extension Custom Code Service Agent should be granted file reader to this bucket. If not specified, the extension will only accept file contents from request body and reject Cloud Storage file inputs. Corresponds to the JSON property fileInputGcsBucket

Returns:

  • (String)


48965
48966
48967
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48965

def file_input_gcs_bucket
  @file_input_gcs_bucket
end

#file_output_gcs_bucketString

Optional. The Cloud Storage bucket for file output of this Extension. If specified, write all output files to the Cloud Storage bucket. Vertex Extension Custom Code Service Agent should be granted file writer to this bucket. If not specified, the file content will be output in response body. Corresponds to the JSON property fileOutputGcsBucket

Returns:

  • (String)


48973
48974
48975
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48973

def file_output_gcs_bucket
  @file_output_gcs_bucket
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48980
48981
48982
48983
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48980

def update!(**args)
  @file_input_gcs_bucket = args[:file_input_gcs_bucket] if args.key?(:file_input_gcs_bucket)
  @file_output_gcs_bucket = args[:file_output_gcs_bucket] if args.key?(:file_output_gcs_bucket)
end