Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#file_input_gcs_bucket ⇒ String
Optional.
-
#file_output_gcs_bucket ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig
Returns a new instance of GoogleCloudAiplatformV1beta1RuntimeConfigCodeInterpreterRuntimeConfig.
41395 41396 41397 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_input_gcs_bucket ⇒ String
Optional. The Cloud Storage bucket for file input of this Extension. If
specified, support input from the Cloud Storage bucket. Vertex Extension
Custom Code Service Agent should be granted file reader to this bucket. If not
specified, the extension will only accept file contents from request body and
reject Cloud Storage file inputs.
Corresponds to the JSON property fileInputGcsBucket
41385 41386 41387 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41385 def file_input_gcs_bucket @file_input_gcs_bucket end |
#file_output_gcs_bucket ⇒ String
Optional. The Cloud Storage bucket for file output of this Extension. If
specified, write all output files to the Cloud Storage bucket. Vertex
Extension Custom Code Service Agent should be granted file writer to this
bucket. If not specified, the file content will be output in response body.
Corresponds to the JSON property fileOutputGcsBucket
41393 41394 41395 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41393 def file_output_gcs_bucket @file_output_gcs_bucket end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41400 41401 41402 41403 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41400 def update!(**args) @file_input_gcs_bucket = args[:file_input_gcs_bucket] if args.key?(:file_input_gcs_bucket) @file_output_gcs_bucket = args[:file_output_gcs_bucket] if args.key?(:file_output_gcs_bucket) end |