Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetyRating
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetyRating
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A safety rating for a piece of content. The safety rating contains the harm category and the harm probability level.
Instance Attribute Summary collapse
-
#blocked ⇒ Boolean
(also: #blocked?)
Output only.
-
#category ⇒ String
Output only.
-
#overwritten_threshold ⇒ String
Output only.
-
#probability ⇒ String
Output only.
-
#probability_score ⇒ Float
Output only.
-
#severity ⇒ String
Output only.
-
#severity_score ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SafetyRating
constructor
A new instance of GoogleCloudAiplatformV1beta1SafetyRating.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SafetyRating
Returns a new instance of GoogleCloudAiplatformV1beta1SafetyRating.
51857 51858 51859 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51857 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocked ⇒ Boolean Also known as: blocked?
Output only. Indicates whether the content was blocked because of this rating.
Corresponds to the JSON property blocked
51822 51823 51824 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51822 def blocked @blocked end |
#category ⇒ String
Output only. The harm category of this rating.
Corresponds to the JSON property category
51828 51829 51830 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51828 def category @category end |
#overwritten_threshold ⇒ String
Output only. The overwritten threshold for the safety category of Gemini 2.0
image out. If minors are detected in the output image, the threshold of each
safety category will be overwritten if user sets a lower threshold.
Corresponds to the JSON property overwrittenThreshold
51835 51836 51837 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51835 def overwritten_threshold @overwritten_threshold end |
#probability ⇒ String
Output only. The probability of harm for this category.
Corresponds to the JSON property probability
51840 51841 51842 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51840 def probability @probability end |
#probability_score ⇒ Float
Output only. The probability score of harm for this category.
Corresponds to the JSON property probabilityScore
51845 51846 51847 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51845 def probability_score @probability_score end |
#severity ⇒ String
Output only. The severity of harm for this category.
Corresponds to the JSON property severity
51850 51851 51852 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51850 def severity @severity end |
#severity_score ⇒ Float
Output only. The severity score of harm for this category.
Corresponds to the JSON property severityScore
51855 51856 51857 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51855 def severity_score @severity_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51862 51863 51864 51865 51866 51867 51868 51869 51870 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51862 def update!(**args) @blocked = args[:blocked] if args.key?(:blocked) @category = args[:category] if args.key?(:category) @overwritten_threshold = args[:overwritten_threshold] if args.key?(:overwritten_threshold) @probability = args[:probability] if args.key?(:probability) @probability_score = args[:probability_score] if args.key?(:probability_score) @severity = args[:severity] if args.key?(:severity) @severity_score = args[:severity_score] if args.key?(:severity_score) end |