Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetyRating
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetyRating
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A safety rating for a piece of content. The safety rating contains the harm category and the harm probability level.
Instance Attribute Summary collapse
-
#blocked ⇒ Boolean
(also: #blocked?)
Output only.
-
#category ⇒ String
Output only.
-
#overwritten_threshold ⇒ String
Output only.
-
#probability ⇒ String
Output only.
-
#probability_score ⇒ Float
Output only.
-
#severity ⇒ String
Output only.
-
#severity_score ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SafetyRating
constructor
A new instance of GoogleCloudAiplatformV1beta1SafetyRating.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SafetyRating
Returns a new instance of GoogleCloudAiplatformV1beta1SafetyRating.
49888 49889 49890 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49888 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocked ⇒ Boolean Also known as: blocked?
Output only. Indicates whether the content was blocked because of this rating.
Corresponds to the JSON property blocked
49853 49854 49855 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49853 def blocked @blocked end |
#category ⇒ String
Output only. The harm category of this rating.
Corresponds to the JSON property category
49859 49860 49861 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49859 def category @category end |
#overwritten_threshold ⇒ String
Output only. The overwritten threshold for the safety category of Gemini 2.0
image out. If minors are detected in the output image, the threshold of each
safety category will be overwritten if user sets a lower threshold.
Corresponds to the JSON property overwrittenThreshold
49866 49867 49868 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49866 def overwritten_threshold @overwritten_threshold end |
#probability ⇒ String
Output only. The probability of harm for this category.
Corresponds to the JSON property probability
49871 49872 49873 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49871 def probability @probability end |
#probability_score ⇒ Float
Output only. The probability score of harm for this category.
Corresponds to the JSON property probabilityScore
49876 49877 49878 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49876 def probability_score @probability_score end |
#severity ⇒ String
Output only. The severity of harm for this category.
Corresponds to the JSON property severity
49881 49882 49883 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49881 def severity @severity end |
#severity_score ⇒ Float
Output only. The severity score of harm for this category.
Corresponds to the JSON property severityScore
49886 49887 49888 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49886 def severity_score @severity_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49893 49894 49895 49896 49897 49898 49899 49900 49901 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49893 def update!(**args) @blocked = args[:blocked] if args.key?(:blocked) @category = args[:category] if args.key?(:category) @overwritten_threshold = args[:overwritten_threshold] if args.key?(:overwritten_threshold) @probability = args[:probability] if args.key?(:probability) @probability_score = args[:probability_score] if args.key?(:probability_score) @severity = args[:severity] if args.key?(:severity) @severity_score = args[:severity_score] if args.key?(:severity_score) end |