Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetyRating

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A safety rating for a piece of content. The safety rating contains the harm category and the harm probability level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SafetyRating

Returns a new instance of GoogleCloudAiplatformV1beta1SafetyRating.



46526
46527
46528
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46526

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockedBoolean Also known as: blocked?

Output only. Indicates whether the content was blocked because of this rating. Corresponds to the JSON property blocked

Returns:

  • (Boolean)


46491
46492
46493
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46491

def blocked
  @blocked
end

#categoryString

Output only. The harm category of this rating. Corresponds to the JSON property category

Returns:

  • (String)


46497
46498
46499
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46497

def category
  @category
end

#overwritten_thresholdString

Output only. The overwritten threshold for the safety category of Gemini 2.0 image out. If minors are detected in the output image, the threshold of each safety category will be overwritten if user sets a lower threshold. Corresponds to the JSON property overwrittenThreshold

Returns:

  • (String)


46504
46505
46506
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46504

def overwritten_threshold
  @overwritten_threshold
end

#probabilityString

Output only. The probability of harm for this category. Corresponds to the JSON property probability

Returns:

  • (String)


46509
46510
46511
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46509

def probability
  @probability
end

#probability_scoreFloat

Output only. The probability score of harm for this category. Corresponds to the JSON property probabilityScore

Returns:

  • (Float)


46514
46515
46516
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46514

def probability_score
  @probability_score
end

#severityString

Output only. The severity of harm for this category. Corresponds to the JSON property severity

Returns:

  • (String)


46519
46520
46521
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46519

def severity
  @severity
end

#severity_scoreFloat

Output only. The severity score of harm for this category. Corresponds to the JSON property severityScore

Returns:

  • (Float)


46524
46525
46526
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46524

def severity_score
  @severity_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46531
46532
46533
46534
46535
46536
46537
46538
46539
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 46531

def update!(**args)
  @blocked = args[:blocked] if args.key?(:blocked)
  @category = args[:category] if args.key?(:category)
  @overwritten_threshold = args[:overwritten_threshold] if args.key?(:overwritten_threshold)
  @probability = args[:probability] if args.key?(:probability)
  @probability_score = args[:probability_score] if args.key?(:probability_score)
  @severity = args[:severity] if args.key?(:severity)
  @severity_score = args[:severity_score] if args.key?(:severity_score)
end