Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

SandboxEnvironment is a containerized environment that provides a customizable secure execution runtime for AI agents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironment

Returns a new instance of GoogleCloudAiplatformV1beta1SandboxEnvironment.



51346
51347
51348
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_infoGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentConnectionInfo

The connection information of the SandboxEnvironment. Corresponds to the JSON property connectionInfo



51273
51274
51275
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51273

def connection_info
  @connection_info
end

#create_timeString

Output only. The timestamp when this SandboxEnvironment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


51278
51279
51280
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51278

def create_time
  @create_time
end

#display_nameString

Required. The display name of the SandboxEnvironment. Corresponds to the JSON property displayName

Returns:

  • (String)


51283
51284
51285
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51283

def display_name
  @display_name
end

#expire_timeString

Optional. Timestamp in UTC of when this SandboxEnvironment is considered expired. This is always provided on output, regardless of what expiration was sent on input. Corresponds to the JSON property expireTime

Returns:

  • (String)


51290
51291
51292
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51290

def expire_time
  @expire_time
end

#latest_sandbox_environment_snapshotString

Output only. The resource name of the latest snapshot taken for this SandboxEnvironment. Corresponds to the JSON property latestSandboxEnvironmentSnapshot

Returns:

  • (String)


51296
51297
51298
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51296

def latest_sandbox_environment_snapshot
  @latest_sandbox_environment_snapshot
end

#nameString

Identifier. The name of the SandboxEnvironment. Corresponds to the JSON property name

Returns:

  • (String)


51301
51302
51303
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51301

def name
  @name
end

#ownerString

Optional. Owner information for this sandbox environment. A Sandbox can only be restored from a snapshot that belongs to the same owner. If not set, sandbox will be created as the default owner. Corresponds to the JSON property owner

Returns:

  • (String)


51308
51309
51310
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51308

def owner
  @owner
end

#sandbox_environment_snapshotString

Optional. The resource name of the SandboxEnvironmentSnapshot to use for creating this SandboxEnvironment. Format: projects/project/locations/ location/reasoningEngines/reasoning_engine/sandboxEnvironmentSnapshots/ sandbox_environment_snapshot` Corresponds to the JSON propertysandboxEnvironmentSnapshot`

Returns:

  • (String)


51316
51317
51318
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51316

def sandbox_environment_snapshot
  @sandbox_environment_snapshot
end

#sandbox_environment_templateString

Optional. The name of the SandboxEnvironmentTemplate specified in the parent Agent Engine resource that this SandboxEnvironment is created from. Corresponds to the JSON property sandboxEnvironmentTemplate

Returns:

  • (String)


51322
51323
51324
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51322

def sandbox_environment_template
  @sandbox_environment_template
end

#specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentSpec

The specification of a SandboxEnvironment. Corresponds to the JSON property spec



51327
51328
51329
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51327

def spec
  @spec
end

#stateString

Output only. The runtime state of the SandboxEnvironment. Corresponds to the JSON property state

Returns:

  • (String)


51332
51333
51334
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51332

def state
  @state
end

#ttlString

Optional. Input only. The TTL for the sandbox environment. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


51338
51339
51340
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51338

def ttl
  @ttl
end

#update_timeString

Output only. The timestamp when this SandboxEnvironment was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


51344
51345
51346
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51344

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51351
51352
51353
51354
51355
51356
51357
51358
51359
51360
51361
51362
51363
51364
51365
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51351

def update!(**args)
  @connection_info = args[:connection_info] if args.key?(:connection_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @latest_sandbox_environment_snapshot = args[:latest_sandbox_environment_snapshot] if args.key?(:latest_sandbox_environment_snapshot)
  @name = args[:name] if args.key?(:name)
  @owner = args[:owner] if args.key?(:owner)
  @sandbox_environment_snapshot = args[:sandbox_environment_snapshot] if args.key?(:sandbox_environment_snapshot)
  @sandbox_environment_template = args[:sandbox_environment_template] if args.key?(:sandbox_environment_template)
  @spec = args[:spec] if args.key?(:spec)
  @state = args[:state] if args.key?(:state)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end