Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

SandboxEnvironment is a containerized environment that provides a customizable secure execution runtime for AI agents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironment

Returns a new instance of GoogleCloudAiplatformV1beta1SandboxEnvironment.



49378
49379
49380
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_infoGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentConnectionInfo

The connection information of the SandboxEnvironment. Corresponds to the JSON property connectionInfo



49305
49306
49307
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49305

def connection_info
  @connection_info
end

#create_timeString

Output only. The timestamp when this SandboxEnvironment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


49310
49311
49312
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49310

def create_time
  @create_time
end

#display_nameString

Required. The display name of the SandboxEnvironment. Corresponds to the JSON property displayName

Returns:

  • (String)


49315
49316
49317
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49315

def display_name
  @display_name
end

#expire_timeString

Optional. Timestamp in UTC of when this SandboxEnvironment is considered expired. This is always provided on output, regardless of what expiration was sent on input. Corresponds to the JSON property expireTime

Returns:

  • (String)


49322
49323
49324
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49322

def expire_time
  @expire_time
end

#latest_sandbox_environment_snapshotString

Output only. The resource name of the latest snapshot taken for this SandboxEnvironment. Corresponds to the JSON property latestSandboxEnvironmentSnapshot

Returns:

  • (String)


49328
49329
49330
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49328

def latest_sandbox_environment_snapshot
  @latest_sandbox_environment_snapshot
end

#nameString

Identifier. The name of the SandboxEnvironment. Corresponds to the JSON property name

Returns:

  • (String)


49333
49334
49335
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49333

def name
  @name
end

#ownerString

Optional. Owner information for this sandbox environment. A Sandbox can only be restored from a snapshot that belongs to the same owner. If not set, sandbox will be created as the default owner. Corresponds to the JSON property owner

Returns:

  • (String)


49340
49341
49342
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49340

def owner
  @owner
end

#sandbox_environment_snapshotString

Optional. The resource name of the SandboxEnvironmentSnapshot to use for creating this SandboxEnvironment. Format: projects/project/locations/ location/reasoningEngines/reasoning_engine/sandboxEnvironmentSnapshots/ sandbox_environment_snapshot` Corresponds to the JSON propertysandboxEnvironmentSnapshot`

Returns:

  • (String)


49348
49349
49350
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49348

def sandbox_environment_snapshot
  @sandbox_environment_snapshot
end

#sandbox_environment_templateString

Optional. The name of the SandboxEnvironmentTemplate specified in the parent Agent Engine resource that this SandboxEnvironment is created from. Corresponds to the JSON property sandboxEnvironmentTemplate

Returns:

  • (String)


49354
49355
49356
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49354

def sandbox_environment_template
  @sandbox_environment_template
end

#specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentSpec

The specification of a SandboxEnvironment. Corresponds to the JSON property spec



49359
49360
49361
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49359

def spec
  @spec
end

#stateString

Output only. The runtime state of the SandboxEnvironment. Corresponds to the JSON property state

Returns:

  • (String)


49364
49365
49366
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49364

def state
  @state
end

#ttlString

Optional. Input only. The TTL for the sandbox environment. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


49370
49371
49372
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49370

def ttl
  @ttl
end

#update_timeString

Output only. The timestamp when this SandboxEnvironment was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


49376
49377
49378
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49376

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49383
49384
49385
49386
49387
49388
49389
49390
49391
49392
49393
49394
49395
49396
49397
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49383

def update!(**args)
  @connection_info = args[:connection_info] if args.key?(:connection_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @latest_sandbox_environment_snapshot = args[:latest_sandbox_environment_snapshot] if args.key?(:latest_sandbox_environment_snapshot)
  @name = args[:name] if args.key?(:name)
  @owner = args[:owner] if args.key?(:owner)
  @sandbox_environment_snapshot = args[:sandbox_environment_snapshot] if args.key?(:sandbox_environment_snapshot)
  @sandbox_environment_template = args[:sandbox_environment_template] if args.key?(:sandbox_environment_template)
  @spec = args[:spec] if args.key?(:spec)
  @state = args[:state] if args.key?(:state)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end