Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironment
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
SandboxEnvironment is a containerized environment that provides a customizable secure execution runtime for AI agents.
Instance Attribute Summary collapse
-
#connection_info ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentConnectionInfo
The connection information of the SandboxEnvironment.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#expire_time ⇒ String
Optional.
-
#latest_sandbox_environment_snapshot ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#owner ⇒ String
Optional.
-
#sandbox_environment_snapshot ⇒ String
Optional.
-
#sandbox_environment_template ⇒ String
Optional.
-
#spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentSpec
The specification of a SandboxEnvironment.
-
#state ⇒ String
Output only.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironment
constructor
A new instance of GoogleCloudAiplatformV1beta1SandboxEnvironment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironment
Returns a new instance of GoogleCloudAiplatformV1beta1SandboxEnvironment.
49556 49557 49558 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49556 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_info ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentConnectionInfo
The connection information of the SandboxEnvironment.
Corresponds to the JSON property connectionInfo
49483 49484 49485 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49483 def connection_info @connection_info end |
#create_time ⇒ String
Output only. The timestamp when this SandboxEnvironment was created.
Corresponds to the JSON property createTime
49488 49489 49490 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49488 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the SandboxEnvironment.
Corresponds to the JSON property displayName
49493 49494 49495 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49493 def display_name @display_name end |
#expire_time ⇒ String
Optional. Timestamp in UTC of when this SandboxEnvironment is considered
expired. This is always provided on output, regardless of what expiration
was sent on input.
Corresponds to the JSON property expireTime
49500 49501 49502 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49500 def expire_time @expire_time end |
#latest_sandbox_environment_snapshot ⇒ String
Output only. The resource name of the latest snapshot taken for this
SandboxEnvironment.
Corresponds to the JSON property latestSandboxEnvironmentSnapshot
49506 49507 49508 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49506 def latest_sandbox_environment_snapshot @latest_sandbox_environment_snapshot end |
#name ⇒ String
Identifier. The name of the SandboxEnvironment.
Corresponds to the JSON property name
49511 49512 49513 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49511 def name @name end |
#owner ⇒ String
Optional. Owner information for this sandbox environment. A Sandbox can only
be restored from a snapshot that belongs to the same owner. If not set,
sandbox will be created as the default owner.
Corresponds to the JSON property owner
49518 49519 49520 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49518 def owner @owner end |
#sandbox_environment_snapshot ⇒ String
Optional. The resource name of the SandboxEnvironmentSnapshot to use for
creating this SandboxEnvironment. Format: projects/project/locations/
location/reasoningEngines/reasoning_engine/sandboxEnvironmentSnapshots/
sandbox_environment_snapshot`
Corresponds to the JSON propertysandboxEnvironmentSnapshot`
49526 49527 49528 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49526 def sandbox_environment_snapshot @sandbox_environment_snapshot end |
#sandbox_environment_template ⇒ String
Optional. The name of the SandboxEnvironmentTemplate specified in the parent
Agent Engine resource that this SandboxEnvironment is created from.
Corresponds to the JSON property sandboxEnvironmentTemplate
49532 49533 49534 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49532 def sandbox_environment_template @sandbox_environment_template end |
#spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentSpec
The specification of a SandboxEnvironment.
Corresponds to the JSON property spec
49537 49538 49539 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49537 def spec @spec end |
#state ⇒ String
Output only. The runtime state of the SandboxEnvironment.
Corresponds to the JSON property state
49542 49543 49544 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49542 def state @state end |
#ttl ⇒ String
Optional. Input only. The TTL for the sandbox environment. The expiration time
is computed: now + TTL.
Corresponds to the JSON property ttl
49548 49549 49550 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49548 def ttl @ttl end |
#update_time ⇒ String
Output only. The timestamp when this SandboxEnvironment was most recently
updated.
Corresponds to the JSON property updateTime
49554 49555 49556 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49554 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49561 49562 49563 49564 49565 49566 49567 49568 49569 49570 49571 49572 49573 49574 49575 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49561 def update!(**args) @connection_info = args[:connection_info] if args.key?(:connection_info) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @latest_sandbox_environment_snapshot = args[:latest_sandbox_environment_snapshot] if args.key?(:latest_sandbox_environment_snapshot) @name = args[:name] if args.key?(:name) @owner = args[:owner] if args.key?(:owner) @sandbox_environment_snapshot = args[:sandbox_environment_snapshot] if args.key?(:sandbox_environment_snapshot) @sandbox_environment_template = args[:sandbox_environment_template] if args.key?(:sandbox_environment_template) @spec = args[:spec] if args.key?(:spec) @state = args[:state] if args.key?(:state) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) end |