Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironment
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
SandboxEnvironment is a containerized environment that provides a customizable secure execution runtime for AI agents.
Instance Attribute Summary collapse
-
#connection_info ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentConnectionInfo
The connection information of the SandboxEnvironment.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#expire_time ⇒ String
Optional.
-
#latest_sandbox_environment_snapshot ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#owner ⇒ String
Optional.
-
#sandbox_environment_snapshot ⇒ String
Optional.
-
#sandbox_environment_template ⇒ String
Optional.
-
#spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentSpec
The specification of a SandboxEnvironment.
-
#state ⇒ String
Output only.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironment
constructor
A new instance of GoogleCloudAiplatformV1beta1SandboxEnvironment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironment
Returns a new instance of GoogleCloudAiplatformV1beta1SandboxEnvironment.
41799 41800 41801 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_info ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentConnectionInfo
The connection information of the SandboxEnvironment.
Corresponds to the JSON property connectionInfo
41725 41726 41727 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41725 def connection_info @connection_info end |
#create_time ⇒ String
Output only. The timestamp when this SandboxEnvironment was created.
Corresponds to the JSON property createTime
41730 41731 41732 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41730 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the SandboxEnvironment.
Corresponds to the JSON property displayName
41735 41736 41737 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41735 def display_name @display_name end |
#expire_time ⇒ String
Optional. Timestamp in UTC of when this SandboxEnvironment is considered
expired. This is always provided on output, regardless of what expiration
was sent on input.
Corresponds to the JSON property expireTime
41742 41743 41744 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41742 def expire_time @expire_time end |
#latest_sandbox_environment_snapshot ⇒ String
Output only. The resource name of the latest snapshot taken for this
SandboxEnvironment.
Corresponds to the JSON property latestSandboxEnvironmentSnapshot
41748 41749 41750 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41748 def latest_sandbox_environment_snapshot @latest_sandbox_environment_snapshot end |
#name ⇒ String
Identifier. The name of the SandboxEnvironment.
Corresponds to the JSON property name
41753 41754 41755 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41753 def name @name end |
#owner ⇒ String
Optional. Owner information for this sandbox environment. A Sandbox can only
be restored from a snapshot that belongs to the same owner. If not set,
sandbox will be created as the default owner.
Corresponds to the JSON property owner
41760 41761 41762 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41760 def owner @owner end |
#sandbox_environment_snapshot ⇒ String
Optional. The resource name of the SandboxEnvironmentSnapshot to use for
creating this SandboxEnvironment. Format: projects/project/locations/
location/reasoningEngines/reasoning_engine/sandboxEnvironmentSnapshots/
sandbox_environment_snapshot`
Corresponds to the JSON propertysandboxEnvironmentSnapshot`
41768 41769 41770 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41768 def sandbox_environment_snapshot @sandbox_environment_snapshot end |
#sandbox_environment_template ⇒ String
Optional. The name of the SandboxEnvironmentTemplate specified in the parent
Agent Engine resource that this SandboxEnvironment is created from. Only one
of sandbox_environment_template and spec should be set.
Corresponds to the JSON property sandboxEnvironmentTemplate
41775 41776 41777 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41775 def sandbox_environment_template @sandbox_environment_template end |
#spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentSpec
The specification of a SandboxEnvironment.
Corresponds to the JSON property spec
41780 41781 41782 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41780 def spec @spec end |
#state ⇒ String
Output only. The runtime state of the SandboxEnvironment.
Corresponds to the JSON property state
41785 41786 41787 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41785 def state @state end |
#ttl ⇒ String
Optional. Input only. The TTL for the sandbox environment. The expiration time
is computed: now + TTL.
Corresponds to the JSON property ttl
41791 41792 41793 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41791 def ttl @ttl end |
#update_time ⇒ String
Output only. The timestamp when this SandboxEnvironment was most recently
updated.
Corresponds to the JSON property updateTime
41797 41798 41799 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41797 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41804 41805 41806 41807 41808 41809 41810 41811 41812 41813 41814 41815 41816 41817 41818 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 41804 def update!(**args) @connection_info = args[:connection_info] if args.key?(:connection_info) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @latest_sandbox_environment_snapshot = args[:latest_sandbox_environment_snapshot] if args.key?(:latest_sandbox_environment_snapshot) @name = args[:name] if args.key?(:name) @owner = args[:owner] if args.key?(:owner) @sandbox_environment_snapshot = args[:sandbox_environment_snapshot] if args.key?(:sandbox_environment_snapshot) @sandbox_environment_template = args[:sandbox_environment_template] if args.key?(:sandbox_environment_template) @spec = args[:spec] if args.key?(:spec) @state = args[:state] if args.key?(:state) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) end |