Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentConnectionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The connection information of the SandboxEnvironment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironmentConnectionInfo

Returns a new instance of GoogleCloudAiplatformV1beta1SandboxEnvironmentConnectionInfo.



51957
51958
51959
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#load_balancer_hostnameString

Output only. The hostname of the load balancer. Corresponds to the JSON property loadBalancerHostname

Returns:

  • (String)


51932
51933
51934
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51932

def load_balancer_hostname
  @load_balancer_hostname
end

#load_balancer_ipString

Output only. The IP address of the load balancer. Corresponds to the JSON property loadBalancerIp

Returns:

  • (String)


51937
51938
51939
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51937

def load_balancer_ip
  @load_balancer_ip
end

#routing_tokenString

Output only. The routing token for the SandboxEnvironment. Corresponds to the JSON property routingToken

Returns:

  • (String)


51942
51943
51944
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51942

def routing_token
  @routing_token
end

#sandbox_internal_ipString

Output only. The internal IP address of the SandboxEnvironment. Corresponds to the JSON property sandboxInternalIp

Returns:

  • (String)


51947
51948
51949
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51947

def sandbox_internal_ip
  @sandbox_internal_ip
end

#service_attachmentString

Output only. The name of the PSC-E service attachment created for private ingress to this SandboxEnvironment. Only populated when the template enables private ingress (see SandboxEnvironmentTemplate.ingress_control_config). VPC- SC customers use this to create a PSC endpoint in their VPC. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


51955
51956
51957
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51955

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51962
51963
51964
51965
51966
51967
51968
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51962

def update!(**args)
  @load_balancer_hostname = args[:load_balancer_hostname] if args.key?(:load_balancer_hostname)
  @load_balancer_ip = args[:load_balancer_ip] if args.key?(:load_balancer_ip)
  @routing_token = args[:routing_token] if args.key?(:routing_token)
  @sandbox_internal_ip = args[:sandbox_internal_ip] if args.key?(:sandbox_internal_ip)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end