Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentSnapshot
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
SandboxEnvironmentSnapshot is a snapshot of the SandboxEnvironment.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#expire_time ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#owner ⇒ String
Optional.
-
#parent_snapshot ⇒ String
Output only.
-
#post_snapshot_action ⇒ String
Optional.
-
#size_bytes ⇒ Fixnum
Optional.
-
#source_sandbox_environment ⇒ String
Required.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironmentSnapshot
constructor
A new instance of GoogleCloudAiplatformV1beta1SandboxEnvironmentSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironmentSnapshot
Returns a new instance of GoogleCloudAiplatformV1beta1SandboxEnvironmentSnapshot.
49687 49688 49689 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49687 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when this SandboxEnvironmentSnapshot was created.
Corresponds to the JSON property createTime
49622 49623 49624 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49622 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the SandboxEnvironmentSnapshot.
Corresponds to the JSON property displayName
49627 49628 49629 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49627 def display_name @display_name end |
#expire_time ⇒ String
Optional. Timestamp in UTC of when this SandboxEnvironmentSnapshot is
considered expired. This is always provided on output, regardless of what
expiration was sent on input.
Corresponds to the JSON property expireTime
49634 49635 49636 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49634 def expire_time @expire_time end |
#name ⇒ String
Identifier. The resource name of the SandboxEnvironmentSnapshot. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
sandboxEnvironmentSnapshots/sandbox_environment_snapshot`
Corresponds to the JSON propertyname`
49641 49642 49643 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49641 def name @name end |
#owner ⇒ String
Optional. Owner information for this sandbox snapshot. Different owners will
have isolations on snapshot storage and identity. If not set, snapshot will be
created as the default owner.
Corresponds to the JSON property owner
49648 49649 49650 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49648 def owner @owner end |
#parent_snapshot ⇒ String
Output only. The resource name of the parent SandboxEnvironmentSnapshot. Empty
if this is a root Snapshot (the first snapshot from a newly created sandbox).
Can be used to reconstruct the whole ancestry tree of snapshots.
Corresponds to the JSON property parentSnapshot
49655 49656 49657 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49655 def parent_snapshot @parent_snapshot end |
#post_snapshot_action ⇒ String
Optional. Input only. Action to take on the source SandboxEnvironment after
the snapshot is taken. This field is only used in
CreateSandboxEnvironmentSnapshotRequest and it is not stored in the resource.
Corresponds to the JSON property postSnapshotAction
49662 49663 49664 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49662 def post_snapshot_action @post_snapshot_action end |
#size_bytes ⇒ Fixnum
Optional. Output only. Size of the snapshot data in bytes.
Corresponds to the JSON property sizeBytes
49667 49668 49669 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49667 def size_bytes @size_bytes end |
#source_sandbox_environment ⇒ String
Required. The resource name of the source SandboxEnvironment this snapshot was
taken from.
Corresponds to the JSON property sourceSandboxEnvironment
49673 49674 49675 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49673 def source_sandbox_environment @source_sandbox_environment end |
#ttl ⇒ String
Optional. Input only. The TTL for the sandbox environment snapshot. The
expiration time is computed: now + TTL.
Corresponds to the JSON property ttl
49679 49680 49681 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49679 def ttl @ttl end |
#update_time ⇒ String
Output only. The timestamp when this SandboxEnvironment was most recently
updated.
Corresponds to the JSON property updateTime
49685 49686 49687 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49685 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49692 49693 49694 49695 49696 49697 49698 49699 49700 49701 49702 49703 49704 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49692 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @name = args[:name] if args.key?(:name) @owner = args[:owner] if args.key?(:owner) @parent_snapshot = args[:parent_snapshot] if args.key?(:parent_snapshot) @post_snapshot_action = args[:post_snapshot_action] if args.key?(:post_snapshot_action) @size_bytes = args[:size_bytes] if args.key?(:size_bytes) @source_sandbox_environment = args[:source_sandbox_environment] if args.key?(:source_sandbox_environment) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) end |