Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentSnapshot

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

SandboxEnvironmentSnapshot is a snapshot of the SandboxEnvironment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironmentSnapshot

Returns a new instance of GoogleCloudAiplatformV1beta1SandboxEnvironmentSnapshot.



48108
48109
48110
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when this SandboxEnvironmentSnapshot was created. Corresponds to the JSON property createTime

Returns:

  • (String)


48043
48044
48045
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48043

def create_time
  @create_time
end

#display_nameString

Required. The display name of the SandboxEnvironmentSnapshot. Corresponds to the JSON property displayName

Returns:

  • (String)


48048
48049
48050
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48048

def display_name
  @display_name
end

#expire_timeString

Optional. Timestamp in UTC of when this SandboxEnvironmentSnapshot is considered expired. This is always provided on output, regardless of what expiration was sent on input. Corresponds to the JSON property expireTime

Returns:

  • (String)


48055
48056
48057
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48055

def expire_time
  @expire_time
end

#nameString

Identifier. The resource name of the SandboxEnvironmentSnapshot. Format: projects/project/locations/location/reasoningEngines/reasoning_engine/ sandboxEnvironmentSnapshots/sandbox_environment_snapshot` Corresponds to the JSON propertyname`

Returns:

  • (String)


48062
48063
48064
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48062

def name
  @name
end

#ownerString

Optional. Owner information for this sandbox snapshot. Different owners will have isolations on snapshot storage and identity. If not set, snapshot will be created as the default owner. Corresponds to the JSON property owner

Returns:

  • (String)


48069
48070
48071
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48069

def owner
  @owner
end

#parent_snapshotString

Output only. The resource name of the parent SandboxEnvironmentSnapshot. Empty if this is a root Snapshot (the first snapshot from a newly created sandbox). Can be used to reconstruct the whole ancestry tree of snapshots. Corresponds to the JSON property parentSnapshot

Returns:

  • (String)


48076
48077
48078
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48076

def parent_snapshot
  @parent_snapshot
end

#post_snapshot_actionString

Optional. Input only. Action to take on the source SandboxEnvironment after the snapshot is taken. This field is only used in CreateSandboxEnvironmentSnapshotRequest and it is not stored in the resource. Corresponds to the JSON property postSnapshotAction

Returns:

  • (String)


48083
48084
48085
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48083

def post_snapshot_action
  @post_snapshot_action
end

#size_bytesFixnum

Optional. Output only. Size of the snapshot data in bytes. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


48088
48089
48090
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48088

def size_bytes
  @size_bytes
end

#source_sandbox_environmentString

Required. The resource name of the source SandboxEnvironment this snapshot was taken from. Corresponds to the JSON property sourceSandboxEnvironment

Returns:

  • (String)


48094
48095
48096
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48094

def source_sandbox_environment
  @source_sandbox_environment
end

#ttlString

Optional. Input only. The TTL for the sandbox environment snapshot. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


48100
48101
48102
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48100

def ttl
  @ttl
end

#update_timeString

Output only. The timestamp when this SandboxEnvironment was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


48106
48107
48108
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48106

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48113
48114
48115
48116
48117
48118
48119
48120
48121
48122
48123
48124
48125
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 48113

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @owner = args[:owner] if args.key?(:owner)
  @parent_snapshot = args[:parent_snapshot] if args.key?(:parent_snapshot)
  @post_snapshot_action = args[:post_snapshot_action] if args.key?(:post_snapshot_action)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
  @source_sandbox_environment = args[:source_sandbox_environment] if args.key?(:source_sandbox_environment)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end