Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The specification of a SandboxEnvironmentTemplate. A SandboxEnvironmentTemplate defines a template for creating SandboxEnvironments.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_container_environment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateCustomContainerEnvironment
The customized sandbox runtime environment for BYOC.
-
#default_container_environment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateDefaultContainerEnvironment
The default sandbox runtime environment for default container workloads.
-
#display_name ⇒ String
Required.
-
#egress_control_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateEgressControlConfig
Configuration for egress control of sandbox instances.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate
constructor
A new instance of GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate
Returns a new instance of GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate.
42153 42154 42155 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42153 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when this SandboxEnvironmentTemplate was created.
Corresponds to the JSON property createTime
42113 42114 42115 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42113 def create_time @create_time end |
#custom_container_environment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateCustomContainerEnvironment
The customized sandbox runtime environment for BYOC.
Corresponds to the JSON property customContainerEnvironment
42118 42119 42120 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42118 def custom_container_environment @custom_container_environment end |
#default_container_environment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateDefaultContainerEnvironment
The default sandbox runtime environment for default container workloads.
Corresponds to the JSON property defaultContainerEnvironment
42123 42124 42125 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42123 def default_container_environment @default_container_environment end |
#display_name ⇒ String
Required. The display name of the SandboxEnvironmentTemplate.
Corresponds to the JSON property displayName
42128 42129 42130 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42128 def display_name @display_name end |
#egress_control_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateEgressControlConfig
Configuration for egress control of sandbox instances.
Corresponds to the JSON property egressControlConfig
42133 42134 42135 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42133 def egress_control_config @egress_control_config end |
#name ⇒ String
Identifier. The resource name of the SandboxEnvironmentTemplate. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
sandboxEnvironmentTemplates/sandbox_environment_template`
Corresponds to the JSON propertyname`
42140 42141 42142 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42140 def name @name end |
#state ⇒ String
Output only. The state of the sandbox environment template.
Corresponds to the JSON property state
42145 42146 42147 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42145 def state @state end |
#update_time ⇒ String
Output only. The timestamp when this SandboxEnvironmentTemplate was most
recently updated.
Corresponds to the JSON property updateTime
42151 42152 42153 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42151 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42158 42159 42160 42161 42162 42163 42164 42165 42166 42167 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42158 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_container_environment = args[:custom_container_environment] if args.key?(:custom_container_environment) @default_container_environment = args[:default_container_environment] if args.key?(:default_container_environment) @display_name = args[:display_name] if args.key?(:display_name) @egress_control_config = args[:egress_control_config] if args.key?(:egress_control_config) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |