Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The specification of a SandboxEnvironmentTemplate. A SandboxEnvironmentTemplate defines a template for creating SandboxEnvironments.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_container_environment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateCustomContainerEnvironment
The customized sandbox runtime environment for BYOC.
-
#default_container_environment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateDefaultContainerEnvironment
The default sandbox runtime environment for default container workloads.
-
#display_name ⇒ String
Required.
-
#egress_control_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateEgressControlConfig
Configuration for egress control of sandbox instances.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#warm_pool_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateWarmPoolConfig
Configuration for a warm pool of sandbox instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate
constructor
A new instance of GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate
Returns a new instance of GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplate.
42072 42073 42074 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42072 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when this SandboxEnvironmentTemplate was created.
Corresponds to the JSON property createTime
42027 42028 42029 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42027 def create_time @create_time end |
#custom_container_environment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateCustomContainerEnvironment
The customized sandbox runtime environment for BYOC.
Corresponds to the JSON property customContainerEnvironment
42032 42033 42034 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42032 def custom_container_environment @custom_container_environment end |
#default_container_environment ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateDefaultContainerEnvironment
The default sandbox runtime environment for default container workloads.
Corresponds to the JSON property defaultContainerEnvironment
42037 42038 42039 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42037 def default_container_environment @default_container_environment end |
#display_name ⇒ String
Required. The display name of the SandboxEnvironmentTemplate.
Corresponds to the JSON property displayName
42042 42043 42044 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42042 def display_name @display_name end |
#egress_control_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateEgressControlConfig
Configuration for egress control of sandbox instances.
Corresponds to the JSON property egressControlConfig
42047 42048 42049 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42047 def egress_control_config @egress_control_config end |
#name ⇒ String
Identifier. The resource name of the SandboxEnvironmentTemplate. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
sandboxEnvironmentTemplates/sandbox_environment_template`
Corresponds to the JSON propertyname`
42054 42055 42056 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42054 def name @name end |
#state ⇒ String
Output only. The state of the sandbox environment template.
Corresponds to the JSON property state
42059 42060 42061 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42059 def state @state end |
#update_time ⇒ String
Output only. The timestamp when this SandboxEnvironmentTemplate was most
recently updated.
Corresponds to the JSON property updateTime
42065 42066 42067 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42065 def update_time @update_time end |
#warm_pool_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateWarmPoolConfig
Configuration for a warm pool of sandbox instances.
Corresponds to the JSON property warmPoolConfig
42070 42071 42072 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42070 def warm_pool_config @warm_pool_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42077 42078 42079 42080 42081 42082 42083 42084 42085 42086 42087 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42077 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_container_environment = args[:custom_container_environment] if args.key?(:custom_container_environment) @default_container_environment = args[:default_container_environment] if args.key?(:default_container_environment) @display_name = args[:display_name] if args.key?(:display_name) @egress_control_config = args[:egress_control_config] if args.key?(:egress_control_config) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) @warm_pool_config = args[:warm_pool_config] if args.key?(:warm_pool_config) end |