Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateEgressControlConfigDnsPeeringConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateEgressControlConfigDnsPeeringConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for peering a customer's private DNS zone so that sandbox egress can resolve customer-internal domains via the customer VPC.
Instance Attribute Summary collapse
-
#domain ⇒ String
Required.
-
#target_network ⇒ String
Required.
-
#target_project ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateEgressControlConfigDnsPeeringConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateEgressControlConfigDnsPeeringConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateEgressControlConfigDnsPeeringConfig
Returns a new instance of GoogleCloudAiplatformV1beta1SandboxEnvironmentTemplateEgressControlConfigDnsPeeringConfig.
52340 52341 52342 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52340 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
Required. The DNS name suffix of the zone being peered to, e.g., "my-internal-
domain.corp.". Must end with a dot.
Corresponds to the JSON property domain
52325 52326 52327 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52325 def domain @domain end |
#target_network ⇒ String
Required. The VPC network name in the target_project where the DNS zone
specified by domain is visible.
Corresponds to the JSON property targetNetwork
52331 52332 52333 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52331 def target_network @target_network end |
#target_project ⇒ String
Required. The project ID hosting the Cloud DNS managed zone that contains the
domain. The Vertex AI Service Agent requires the dns.peer role on this
project.
Corresponds to the JSON property targetProject
52338 52339 52340 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52338 def target_project @target_project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52345 52346 52347 52348 52349 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52345 def update!(**args) @domain = args[:domain] if args.key?(:domain) @target_network = args[:target_network] if args.key?(:target_network) @target_project = args[:target_project] if args.key?(:target_project) end |