Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An instance of a Schedule periodically schedules runs to make API calls based on user specified time specification and API request type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Schedule

Returns a new instance of GoogleCloudAiplatformV1beta1Schedule.



42494
42495
42496
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_queueingBoolean Also known as: allow_queueing?

Optional. Whether new scheduled runs can be queued when max_concurrent_runs limit is reached. If set to true, new runs will be queued instead of skipped. Default to false. Corresponds to the JSON property allowQueueing

Returns:

  • (Boolean)


42366
42367
42368
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42366

def allow_queueing
  @allow_queueing
end

#catch_upBoolean Also known as: catch_up?

Output only. Whether to backfill missed runs when the schedule is resumed from PAUSED state. If set to true, all missed runs will be scheduled. New runs will be scheduled after the backfill is complete. Default to false. Corresponds to the JSON property catchUp

Returns:

  • (Boolean)


42374
42375
42376
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42374

def catch_up
  @catch_up
end

#create_model_monitoring_job_requestGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateModelMonitoringJobRequest

Request message for ModelMonitoringService.CreateModelMonitoringJob. Corresponds to the JSON property createModelMonitoringJobRequest



42380
42381
42382
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42380

def create_model_monitoring_job_request
  @create_model_monitoring_job_request
end

#create_notebook_execution_job_requestGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreateNotebookExecutionJobRequest

Request message for [NotebookService.CreateNotebookExecutionJob] Corresponds to the JSON property createNotebookExecutionJobRequest



42385
42386
42387
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42385

def create_notebook_execution_job_request
  @create_notebook_execution_job_request
end

#create_pipeline_job_requestGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CreatePipelineJobRequest

Request message for PipelineService.CreatePipelineJob. Corresponds to the JSON property createPipelineJobRequest



42390
42391
42392
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42390

def create_pipeline_job_request
  @create_pipeline_job_request
end

#create_timeString

Output only. Timestamp when this Schedule was created. Corresponds to the JSON property createTime

Returns:

  • (String)


42395
42396
42397
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42395

def create_time
  @create_time
end

#cronString

Cron schedule (https://en.wikipedia.org/wiki/Cron) to launch scheduled runs. To explicitly set a timezone to the cron tab, apply a prefix in the cron tab: " CRON_TZ=$IANA_TIME_ZONE" or "TZ=$IANA_TIME_ZONE". The $IANA_TIME_ZONE may only be a valid string from IANA time zone database. For example, "CRON_TZ= America/New_York 1 * * * *", or "TZ=America/New_York 1 * * * *". Corresponds to the JSON property cron

Returns:

  • (String)


42404
42405
42406
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42404

def cron
  @cron
end

#display_nameString

Required. User provided name of the Schedule. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


42410
42411
42412
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42410

def display_name
  @display_name
end

#end_timeString

Optional. Timestamp after which no new runs can be scheduled. If specified, The schedule will be completed when either end_time is reached or when scheduled_run_count >= max_run_count. If not specified, new runs will keep getting scheduled until this Schedule is paused or deleted. Already scheduled runs will be allowed to complete. Unset if not specified. Corresponds to the JSON property endTime

Returns:

  • (String)


42419
42420
42421
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42419

def end_time
  @end_time
end

#last_pause_timeString

Output only. Timestamp when this Schedule was last paused. Unset if never paused. Corresponds to the JSON property lastPauseTime

Returns:

  • (String)


42425
42426
42427
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42425

def last_pause_time
  @last_pause_time
end

#last_resume_timeString

Output only. Timestamp when this Schedule was last resumed. Unset if never resumed from pause. Corresponds to the JSON property lastResumeTime

Returns:

  • (String)


42431
42432
42433
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42431

def last_resume_time
  @last_resume_time
end

#last_scheduled_run_responseGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ScheduleRunResponse

Status of a scheduled run. Corresponds to the JSON property lastScheduledRunResponse



42436
42437
42438
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42436

def last_scheduled_run_response
  @last_scheduled_run_response
end

#max_concurrent_active_run_countFixnum

Optional. Specifies the maximum number of active runs that can be executed concurrently for this Schedule. This limits the number of runs that can be in a non-terminal state at the same time. Currently, this field is only supported for requests of type CreatePipelineJobRequest. Corresponds to the JSON property maxConcurrentActiveRunCount

Returns:

  • (Fixnum)


42444
42445
42446
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42444

def max_concurrent_active_run_count
  @max_concurrent_active_run_count
end

#max_concurrent_run_countFixnum

Required. Maximum number of runs that can be started concurrently for this Schedule. This is the limit for starting the scheduled requests and not the execution of the operations/jobs created by the requests (if applicable). Corresponds to the JSON property maxConcurrentRunCount

Returns:

  • (Fixnum)


42451
42452
42453
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42451

def max_concurrent_run_count
  @max_concurrent_run_count
end

#max_run_countFixnum

Optional. Maximum run count of the schedule. If specified, The schedule will be completed when either started_run_count >= max_run_count or when end_time is reached. If not specified, new runs will keep getting scheduled until this Schedule is paused or deleted. Already scheduled runs will be allowed to complete. Unset if not specified. Corresponds to the JSON property maxRunCount

Returns:

  • (Fixnum)


42460
42461
42462
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42460

def max_run_count
  @max_run_count
end

#nameString

Immutable. The resource name of the Schedule. Corresponds to the JSON property name

Returns:

  • (String)


42465
42466
42467
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42465

def name
  @name
end

#next_run_timeString

Output only. Timestamp when this Schedule should schedule the next run. Having a next_run_time in the past means the runs are being started behind schedule. Corresponds to the JSON property nextRunTime

Returns:

  • (String)


42471
42472
42473
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42471

def next_run_time
  @next_run_time
end

#start_timeString

Optional. Timestamp after which the first run can be scheduled. Default to Schedule create time if not specified. Corresponds to the JSON property startTime

Returns:

  • (String)


42477
42478
42479
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42477

def start_time
  @start_time
end

#started_run_countFixnum

Output only. The number of runs started by this schedule. Corresponds to the JSON property startedRunCount

Returns:

  • (Fixnum)


42482
42483
42484
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42482

def started_run_count
  @started_run_count
end

#stateString

Output only. The state of this Schedule. Corresponds to the JSON property state

Returns:

  • (String)


42487
42488
42489
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42487

def state
  @state
end

#update_timeString

Output only. Timestamp when this Schedule was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


42492
42493
42494
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42492

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42499
42500
42501
42502
42503
42504
42505
42506
42507
42508
42509
42510
42511
42512
42513
42514
42515
42516
42517
42518
42519
42520
42521
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42499

def update!(**args)
  @allow_queueing = args[:allow_queueing] if args.key?(:allow_queueing)
  @catch_up = args[:catch_up] if args.key?(:catch_up)
  @create_model_monitoring_job_request = args[:create_model_monitoring_job_request] if args.key?(:create_model_monitoring_job_request)
  @create_notebook_execution_job_request = args[:create_notebook_execution_job_request] if args.key?(:create_notebook_execution_job_request)
  @create_pipeline_job_request = args[:create_pipeline_job_request] if args.key?(:create_pipeline_job_request)
  @create_time = args[:create_time] if args.key?(:create_time)
  @cron = args[:cron] if args.key?(:cron)
  @display_name = args[:display_name] if args.key?(:display_name)
  @end_time = args[:end_time] if args.key?(:end_time)
  @last_pause_time = args[:last_pause_time] if args.key?(:last_pause_time)
  @last_resume_time = args[:last_resume_time] if args.key?(:last_resume_time)
  @last_scheduled_run_response = args[:last_scheduled_run_response] if args.key?(:last_scheduled_run_response)
  @max_concurrent_active_run_count = args[:max_concurrent_active_run_count] if args.key?(:max_concurrent_active_run_count)
  @max_concurrent_run_count = args[:max_concurrent_run_count] if args.key?(:max_concurrent_run_count)
  @max_run_count = args[:max_run_count] if args.key?(:max_run_count)
  @name = args[:name] if args.key?(:name)
  @next_run_time = args[:next_run_time] if args.key?(:next_run_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @started_run_count = args[:started_run_count] if args.key?(:started_run_count)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end