Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Scheduling

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

All parameters related to queuing and scheduling of custom jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Scheduling

Returns a new instance of GoogleCloudAiplatformV1beta1Scheduling.



52189
52190
52191
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_retriesBoolean Also known as: disable_retries?

Optional. Indicates if the job should retry for internal errors after the job starts running. If true, overrides Scheduling.restart_job_on_worker_restart to false. Corresponds to the JSON property disableRetries

Returns:

  • (Boolean)


52160
52161
52162
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52160

def disable_retries
  @disable_retries
end

#max_wait_durationString

Optional. This is the maximum duration that a job will wait for the requested resources to be provisioned if the scheduling strategy is set to [Strategy. DWS_FLEX_START]. If set to 0, the job will wait indefinitely. The default is 24 hours. Corresponds to the JSON property maxWaitDuration

Returns:

  • (String)


52169
52170
52171
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52169

def max_wait_duration
  @max_wait_duration
end

#restart_job_on_worker_restartBoolean Also known as: restart_job_on_worker_restart?

Optional. Restarts the entire CustomJob if a worker gets restarted. This feature can be used by distributed training jobs that are not resilient to workers leaving and joining a job. Corresponds to the JSON property restartJobOnWorkerRestart

Returns:

  • (Boolean)


52176
52177
52178
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52176

def restart_job_on_worker_restart
  @restart_job_on_worker_restart
end

#strategyString

Optional. This determines which type of scheduling strategy to use. Corresponds to the JSON property strategy

Returns:

  • (String)


52182
52183
52184
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52182

def strategy
  @strategy
end

#timeoutString

Optional. The maximum job running time. The default is 7 days. Corresponds to the JSON property timeout

Returns:

  • (String)


52187
52188
52189
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52187

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52194
52195
52196
52197
52198
52199
52200
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52194

def update!(**args)
  @disable_retries = args[:disable_retries] if args.key?(:disable_retries)
  @max_wait_duration = args[:max_wait_duration] if args.key?(:max_wait_duration)
  @restart_job_on_worker_restart = args[:restart_job_on_worker_restart] if args.key?(:restart_job_on_worker_restart)
  @strategy = args[:strategy] if args.key?(:strategy)
  @timeout = args[:timeout] if args.key?(:timeout)
end