Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Scheduling

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

All parameters related to queuing and scheduling of custom jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Scheduling

Returns a new instance of GoogleCloudAiplatformV1beta1Scheduling.



42610
42611
42612
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_retriesBoolean Also known as: disable_retries?

Optional. Indicates if the job should retry for internal errors after the job starts running. If true, overrides Scheduling.restart_job_on_worker_restart to false. Corresponds to the JSON property disableRetries

Returns:

  • (Boolean)


42581
42582
42583
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42581

def disable_retries
  @disable_retries
end

#max_wait_durationString

Optional. This is the maximum duration that a job will wait for the requested resources to be provisioned if the scheduling strategy is set to [Strategy. DWS_FLEX_START]. If set to 0, the job will wait indefinitely. The default is 24 hours. Corresponds to the JSON property maxWaitDuration

Returns:

  • (String)


42590
42591
42592
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42590

def max_wait_duration
  @max_wait_duration
end

#restart_job_on_worker_restartBoolean Also known as: restart_job_on_worker_restart?

Optional. Restarts the entire CustomJob if a worker gets restarted. This feature can be used by distributed training jobs that are not resilient to workers leaving and joining a job. Corresponds to the JSON property restartJobOnWorkerRestart

Returns:

  • (Boolean)


42597
42598
42599
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42597

def restart_job_on_worker_restart
  @restart_job_on_worker_restart
end

#strategyString

Optional. This determines which type of scheduling strategy to use. Corresponds to the JSON property strategy

Returns:

  • (String)


42603
42604
42605
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42603

def strategy
  @strategy
end

#timeoutString

Optional. The maximum job running time. The default is 7 days. Corresponds to the JSON property timeout

Returns:

  • (String)


42608
42609
42610
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42608

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42615
42616
42617
42618
42619
42620
42621
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 42615

def update!(**args)
  @disable_retries = args[:disable_retries] if args.key?(:disable_retries)
  @max_wait_duration = args[:max_wait_duration] if args.key?(:max_wait_duration)
  @restart_job_on_worker_restart = args[:restart_job_on_worker_restart] if args.key?(:restart_job_on_worker_restart)
  @strategy = args[:strategy] if args.key?(:strategy)
  @timeout = args[:timeout] if args.key?(:timeout)
end