Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaImageSegmentationAnnotationPolygonAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a polygon in image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaImageSegmentationAnnotationPolygonAnnotation

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaImageSegmentationAnnotationPolygonAnnotation.



43171
43172
43173
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43171

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_idString

The resource Id of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property annotationSpecId

Returns:

  • (String)


43158
43159
43160
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43158

def annotation_spec_id
  @annotation_spec_id
end

#display_nameString

The display name of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property displayName

Returns:

  • (String)


43163
43164
43165
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43163

def display_name
  @display_name
end

#vertexesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaVertex>

The vertexes are connected one by one and the last vertex is connected to the first one to represent a polygon. Corresponds to the JSON property vertexes



43169
43170
43171
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43169

def vertexes
  @vertexes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43176
43177
43178
43179
43180
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43176

def update!(**args)
  @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @vertexes = args[:vertexes] if args.key?(:vertexes)
end