Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Metrics for forecasting evaluation results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetrics

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetrics.



51065
51066
51067
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51065

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mean_absolute_errorFloat

Mean Absolute Error (MAE). Corresponds to the JSON property meanAbsoluteError

Returns:

  • (Float)


51022
51023
51024
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51022

def mean_absolute_error
  @mean_absolute_error
end

#mean_absolute_percentage_errorFloat

Mean absolute percentage error. Infinity when there are zeros in the ground truth. Corresponds to the JSON property meanAbsolutePercentageError

Returns:

  • (Float)


51028
51029
51030
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51028

def mean_absolute_percentage_error
  @mean_absolute_percentage_error
end

#quantile_metricsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry>

The quantile metrics entries for each quantile. Corresponds to the JSON property quantileMetrics



51033
51034
51035
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51033

def quantile_metrics
  @quantile_metrics
end

#r_squaredFloat

Coefficient of determination as Pearson correlation coefficient. Undefined when ground truth or predictions are constant or near constant. Corresponds to the JSON property rSquared

Returns:

  • (Float)


51039
51040
51041
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51039

def r_squared
  @r_squared
end

#root_mean_squared_errorFloat

Root Mean Squared Error (RMSE). Corresponds to the JSON property rootMeanSquaredError

Returns:

  • (Float)


51044
51045
51046
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51044

def root_mean_squared_error
  @root_mean_squared_error
end

#root_mean_squared_log_errorFloat

Root mean squared log error. Undefined when there are negative ground truth values or predictions. Corresponds to the JSON property rootMeanSquaredLogError

Returns:

  • (Float)


51050
51051
51052
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51050

def root_mean_squared_log_error
  @root_mean_squared_log_error
end

#root_mean_squared_percentage_errorFloat

Root Mean Square Percentage Error. Square root of MSPE. Undefined/imaginary when MSPE is negative. Corresponds to the JSON property rootMeanSquaredPercentageError

Returns:

  • (Float)


51056
51057
51058
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51056

def root_mean_squared_percentage_error
  @root_mean_squared_percentage_error
end

#weighted_absolute_percentage_errorFloat

Weighted Absolute Percentage Error. Does not use weights, this is just what the metric is called. Undefined if actual values sum to zero. Will be very large if actual values sum to a very small number. Corresponds to the JSON property weightedAbsolutePercentageError

Returns:

  • (Float)


51063
51064
51065
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51063

def weighted_absolute_percentage_error
  @weighted_absolute_percentage_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51070
51071
51072
51073
51074
51075
51076
51077
51078
51079
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51070

def update!(**args)
  @mean_absolute_error = args[:mean_absolute_error] if args.key?(:mean_absolute_error)
  @mean_absolute_percentage_error = args[:mean_absolute_percentage_error] if args.key?(:mean_absolute_percentage_error)
  @quantile_metrics = args[:quantile_metrics] if args.key?(:quantile_metrics)
  @r_squared = args[:r_squared] if args.key?(:r_squared)
  @root_mean_squared_error = args[:root_mean_squared_error] if args.key?(:root_mean_squared_error)
  @root_mean_squared_log_error = args[:root_mean_squared_log_error] if args.key?(:root_mean_squared_log_error)
  @root_mean_squared_percentage_error = args[:root_mean_squared_percentage_error] if args.key?(:root_mean_squared_percentage_error)
  @weighted_absolute_percentage_error = args[:weighted_absolute_percentage_error] if args.key?(:weighted_absolute_percentage_error)
end