Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Metrics for forecasting evaluation results.
Instance Attribute Summary collapse
-
#mean_absolute_error ⇒ Float
Mean Absolute Error (MAE).
-
#mean_absolute_percentage_error ⇒ Float
Mean absolute percentage error.
-
#quantile_metrics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry>
The quantile metrics entries for each quantile.
-
#r_squared ⇒ Float
Coefficient of determination as Pearson correlation coefficient.
-
#root_mean_squared_error ⇒ Float
Root Mean Squared Error (RMSE).
-
#root_mean_squared_log_error ⇒ Float
Root mean squared log error.
-
#root_mean_squared_percentage_error ⇒ Float
Root Mean Square Percentage Error.
-
#weighted_absolute_percentage_error ⇒ Float
Weighted Absolute Percentage Error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetrics
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetrics
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetrics.
51243 51244 51245 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mean_absolute_error ⇒ Float
Mean Absolute Error (MAE).
Corresponds to the JSON property meanAbsoluteError
51200 51201 51202 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51200 def mean_absolute_error @mean_absolute_error end |
#mean_absolute_percentage_error ⇒ Float
Mean absolute percentage error. Infinity when there are zeros in the ground
truth.
Corresponds to the JSON property meanAbsolutePercentageError
51206 51207 51208 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51206 def mean_absolute_percentage_error @mean_absolute_percentage_error end |
#quantile_metrics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry>
The quantile metrics entries for each quantile.
Corresponds to the JSON property quantileMetrics
51211 51212 51213 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51211 def quantile_metrics @quantile_metrics end |
#r_squared ⇒ Float
Coefficient of determination as Pearson correlation coefficient. Undefined
when ground truth or predictions are constant or near constant.
Corresponds to the JSON property rSquared
51217 51218 51219 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51217 def r_squared @r_squared end |
#root_mean_squared_error ⇒ Float
Root Mean Squared Error (RMSE).
Corresponds to the JSON property rootMeanSquaredError
51222 51223 51224 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51222 def root_mean_squared_error @root_mean_squared_error end |
#root_mean_squared_log_error ⇒ Float
Root mean squared log error. Undefined when there are negative ground truth
values or predictions.
Corresponds to the JSON property rootMeanSquaredLogError
51228 51229 51230 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51228 def root_mean_squared_log_error @root_mean_squared_log_error end |
#root_mean_squared_percentage_error ⇒ Float
Root Mean Square Percentage Error. Square root of MSPE. Undefined/imaginary
when MSPE is negative.
Corresponds to the JSON property rootMeanSquaredPercentageError
51234 51235 51236 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51234 def root_mean_squared_percentage_error @root_mean_squared_percentage_error end |
#weighted_absolute_percentage_error ⇒ Float
Weighted Absolute Percentage Error. Does not use weights, this is just what
the metric is called. Undefined if actual values sum to zero. Will be very
large if actual values sum to a very small number.
Corresponds to the JSON property weightedAbsolutePercentageError
51241 51242 51243 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51241 def weighted_absolute_percentage_error @weighted_absolute_percentage_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51248 51249 51250 51251 51252 51253 51254 51255 51256 51257 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51248 def update!(**args) @mean_absolute_error = args[:mean_absolute_error] if args.key?(:mean_absolute_error) @mean_absolute_percentage_error = args[:mean_absolute_percentage_error] if args.key?(:mean_absolute_percentage_error) @quantile_metrics = args[:quantile_metrics] if args.key?(:quantile_metrics) @r_squared = args[:r_squared] if args.key?(:r_squared) @root_mean_squared_error = args[:root_mean_squared_error] if args.key?(:root_mean_squared_error) @root_mean_squared_log_error = args[:root_mean_squared_log_error] if args.key?(:root_mean_squared_log_error) @root_mean_squared_percentage_error = args[:root_mean_squared_percentage_error] if args.key?(:root_mean_squared_percentage_error) @weighted_absolute_percentage_error = args[:weighted_absolute_percentage_error] if args.key?(:weighted_absolute_percentage_error) end |