Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Entry for the Quantiles loss type optimization objective.
Instance Attribute Summary collapse
-
#observed_quantile ⇒ Float
This is a custom metric that calculates the percentage of true values that were less than the predicted value for that quantile.
-
#quantile ⇒ Float
The quantile for this entry.
-
#scaled_pinball_loss ⇒ Float
The scaled pinball loss of this quantile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry.
51283 51284 51285 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51283 def initialize(**args) update!(**args) end |
Instance Attribute Details
#observed_quantile ⇒ Float
This is a custom metric that calculates the percentage of true values that
were less than the predicted value for that quantile. Only populated when
optimization_objective is minimize-quantile-loss and each entry corresponds to
an entry in quantiles The percent value can be used to compare with the
quantile value, which is the target value.
Corresponds to the JSON property observedQuantile
51271 51272 51273 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51271 def observed_quantile @observed_quantile end |
#quantile ⇒ Float
The quantile for this entry.
Corresponds to the JSON property quantile
51276 51277 51278 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51276 def quantile @quantile end |
#scaled_pinball_loss ⇒ Float
The scaled pinball loss of this quantile.
Corresponds to the JSON property scaledPinballLoss
51281 51282 51283 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51281 def scaled_pinball_loss @scaled_pinball_loss end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51288 51289 51290 51291 51292 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51288 def update!(**args) @observed_quantile = args[:observed_quantile] if args.key?(:observed_quantile) @quantile = args[:quantile] if args.key?(:quantile) @scaled_pinball_loss = args[:scaled_pinball_loss] if args.key?(:scaled_pinball_loss) end |