Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
Metrics are computed with an assumption that the Model never returns predictions with score lower than this value.
-
#f1_score ⇒ Float
The harmonic mean of recall and precision.
-
#precision ⇒ Float
Precision for the given confidence threshold.
-
#recall ⇒ Float
Recall (True Positive Rate) for the given confidence threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics.
43932 43933 43934 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
Metrics are computed with an assumption that the Model never returns
predictions with score lower than this value.
Corresponds to the JSON property confidenceThreshold
43915 43916 43917 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43915 def confidence_threshold @confidence_threshold end |
#f1_score ⇒ Float
The harmonic mean of recall and precision.
Corresponds to the JSON property f1Score
43920 43921 43922 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43920 def f1_score @f1_score end |
#precision ⇒ Float
Precision for the given confidence threshold.
Corresponds to the JSON property precision
43925 43926 43927 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43925 def precision @precision end |
#recall ⇒ Float
Recall (True Positive Rate) for the given confidence threshold.
Corresponds to the JSON property recall
43930 43931 43932 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43930 def recall @recall end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43937 43938 43939 43940 43941 43942 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 43937 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @f1_score = args[:f1_score] if args.key?(:f1_score) @precision = args[:precision] if args.key?(:precision) @recall = args[:recall] if args.key?(:recall) end |