Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

UNIMPLEMENTED. Track matching model metrics for a single track match threshold and multiple label match confidence thresholds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetrics

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetrics.



44043
44044
44045
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44043

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_metricsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics>

Metrics for each label-match confidenceThreshold from 0.05,0.10,...,0.95,0. 96,0.97,0.98,0.99. Precision-recall curve is derived from them. Corresponds to the JSON property confidenceMetrics



44020
44021
44022
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44020

def confidence_metrics
  @confidence_metrics
end

#iou_thresholdFloat

The intersection-over-union threshold value between bounding boxes across frames used to compute this metric entry. Corresponds to the JSON property iouThreshold

Returns:

  • (Float)


44026
44027
44028
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44026

def iou_threshold
  @iou_threshold
end

#mean_bounding_box_iouFloat

The mean bounding box iou over all confidence thresholds. Corresponds to the JSON property meanBoundingBoxIou

Returns:

  • (Float)


44031
44032
44033
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44031

def mean_bounding_box_iou
  @mean_bounding_box_iou
end

#mean_mismatch_rateFloat

The mean mismatch rate over all confidence thresholds. Corresponds to the JSON property meanMismatchRate

Returns:

  • (Float)


44036
44037
44038
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44036

def mean_mismatch_rate
  @mean_mismatch_rate
end

#mean_tracking_average_precisionFloat

The mean average precision over all confidence thresholds. Corresponds to the JSON property meanTrackingAveragePrecision

Returns:

  • (Float)


44041
44042
44043
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44041

def mean_tracking_average_precision
  @mean_tracking_average_precision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44048
44049
44050
44051
44052
44053
44054
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44048

def update!(**args)
  @confidence_metrics = args[:confidence_metrics] if args.key?(:confidence_metrics)
  @iou_threshold = args[:iou_threshold] if args.key?(:iou_threshold)
  @mean_bounding_box_iou = args[:mean_bounding_box_iou] if args.key?(:mean_bounding_box_iou)
  @mean_mismatch_rate = args[:mean_mismatch_rate] if args.key?(:mean_mismatch_rate)
  @mean_tracking_average_precision = args[:mean_tracking_average_precision] if args.key?(:mean_tracking_average_precision)
end