Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Metrics for a single confidence threshold.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics.



51822
51823
51824
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51822

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_box_iouFloat

Bounding box intersection-over-union precision. Measures how well the bounding boxes overlap between each other (e.g. complete overlap or just barely above iou_threshold). Corresponds to the JSON property boundingBoxIou

Returns:

  • (Float)


51799
51800
51801
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51799

def bounding_box_iou
  @bounding_box_iou
end

#confidence_thresholdFloat

The confidence threshold value used to compute the metrics. Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


51804
51805
51806
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51804

def confidence_threshold
  @confidence_threshold
end

#mismatch_rateFloat

Mismatch rate, which measures the tracking consistency, i.e. correctness of instance ID continuity. Corresponds to the JSON property mismatchRate

Returns:

  • (Float)


51810
51811
51812
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51810

def mismatch_rate
  @mismatch_rate
end

#tracking_precisionFloat

Tracking precision. Corresponds to the JSON property trackingPrecision

Returns:

  • (Float)


51815
51816
51817
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51815

def tracking_precision
  @tracking_precision
end

#tracking_recallFloat

Tracking recall. Corresponds to the JSON property trackingRecall

Returns:

  • (Float)


51820
51821
51822
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51820

def tracking_recall
  @tracking_recall
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51827
51828
51829
51830
51831
51832
51833
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51827

def update!(**args)
  @bounding_box_iou = args[:bounding_box_iou] if args.key?(:bounding_box_iou)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @mismatch_rate = args[:mismatch_rate] if args.key?(:mismatch_rate)
  @tracking_precision = args[:tracking_precision] if args.key?(:tracking_precision)
  @tracking_recall = args[:tracking_recall] if args.key?(:tracking_recall)
end