Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Metrics for a single confidence threshold.
Instance Attribute Summary collapse
-
#bounding_box_iou ⇒ Float
Bounding box intersection-over-union precision.
-
#confidence_threshold ⇒ Float
The confidence threshold value used to compute the metrics.
-
#mismatch_rate ⇒ Float
Mismatch rate, which measures the tracking consistency, i.e.
-
#tracking_precision ⇒ Float
Tracking precision.
-
#tracking_recall ⇒ Float
Tracking recall.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics.
50243 50244 50245 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounding_box_iou ⇒ Float
Bounding box intersection-over-union precision. Measures how well the bounding
boxes overlap between each other (e.g. complete overlap or just barely above
iou_threshold).
Corresponds to the JSON property boundingBoxIou
50220 50221 50222 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50220 def bounding_box_iou @bounding_box_iou end |
#confidence_threshold ⇒ Float
The confidence threshold value used to compute the metrics.
Corresponds to the JSON property confidenceThreshold
50225 50226 50227 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50225 def confidence_threshold @confidence_threshold end |
#mismatch_rate ⇒ Float
Mismatch rate, which measures the tracking consistency, i.e. correctness of
instance ID continuity.
Corresponds to the JSON property mismatchRate
50231 50232 50233 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50231 def mismatch_rate @mismatch_rate end |
#tracking_precision ⇒ Float
Tracking precision.
Corresponds to the JSON property trackingPrecision
50236 50237 50238 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50236 def tracking_precision @tracking_precision end |
#tracking_recall ⇒ Float
Tracking recall.
Corresponds to the JSON property trackingRecall
50241 50242 50243 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50241 def tracking_recall @tracking_recall end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50248 50249 50250 50251 50252 50253 50254 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50248 def update!(**args) @bounding_box_iou = args[:bounding_box_iou] if args.key?(:bounding_box_iou) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @mismatch_rate = args[:mismatch_rate] if args.key?(:mismatch_rate) @tracking_precision = args[:tracking_precision] if args.key?(:tracking_precision) @tracking_recall = args[:tracking_recall] if args.key?(:tracking_recall) end |