Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsVideoActionMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsVideoActionMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The Evaluation metrics given a specific precision_window_length.
Instance Attribute Summary collapse
-
#confidence_metrics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsVideoActionMetricsConfidenceMetrics>
Metrics for each label-match confidence_threshold from 0.05,0.10,...,0.95,0.96, 0.97,0.98,0.99.
-
#mean_average_precision ⇒ Float
The mean average precision.
-
#precision_window_length ⇒ String
This VideoActionMetrics is calculated based on this prediction window length.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsVideoActionMetrics
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsVideoActionMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsVideoActionMetrics
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsVideoActionMetrics.
44187 44188 44189 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44187 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_metrics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsVideoActionMetricsConfidenceMetrics>
Metrics for each label-match confidence_threshold from 0.05,0.10,...,0.95,0.96,
0.97,0.98,0.99.
Corresponds to the JSON property confidenceMetrics
44172 44173 44174 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44172 def confidence_metrics @confidence_metrics end |
#mean_average_precision ⇒ Float
The mean average precision.
Corresponds to the JSON property meanAveragePrecision
44177 44178 44179 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44177 def mean_average_precision @mean_average_precision end |
#precision_window_length ⇒ String
This VideoActionMetrics is calculated based on this prediction window length.
If the predicted action's timestamp is inside the time window whose center is
the ground truth action's timestamp with this specific length, the prediction
result is treated as a true positive.
Corresponds to the JSON property precisionWindowLength
44185 44186 44187 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44185 def precision_window_length @precision_window_length end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44192 44193 44194 44195 44196 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 44192 def update!(**args) @confidence_metrics = args[:confidence_metrics] if args.key?(:confidence_metrics) @mean_average_precision = args[:mean_average_precision] if args.key?(:mean_average_precision) @precision_window_length = args[:precision_window_length] if args.key?(:precision_window_length) end |