Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsVideoObjectTrackingMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Model evaluation metrics for video object tracking problems. Evaluates prediction quality of both labeled bounding boxes and labeled tracks (i.e. series of bounding boxes sharing same label and instance ID).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsVideoObjectTrackingMetrics

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsVideoObjectTrackingMetrics.



53840
53841
53842
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_box_mean_average_precisionFloat

The single metric for bounding boxes evaluation: the meanAveragePrecision averaged over all boundingBoxMetrics. Corresponds to the JSON property boundingBoxMeanAveragePrecision

Returns:

  • (Float)


53789
53790
53791
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53789

def bounding_box_mean_average_precision
  @bounding_box_mean_average_precision
end

#bounding_box_metricsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsBoundingBoxMetrics>

The bounding boxes match metrics for each intersection-over-union threshold 0. 05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05, 0.10,...,0.95,0.96,0.97,0.98,0.99 pair. Corresponds to the JSON property boundingBoxMetrics



53796
53797
53798
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53796

def bounding_box_metrics
  @bounding_box_metrics
end

#evaluated_bounding_box_countFixnum

UNIMPLEMENTED. The total number of bounding boxes (i.e. summed over all frames) the ground truth used to create this evaluation had. Corresponds to the JSON property evaluatedBoundingBoxCount

Returns:

  • (Fixnum)


53802
53803
53804
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53802

def evaluated_bounding_box_count
  @evaluated_bounding_box_count
end

#evaluated_frame_countFixnum

UNIMPLEMENTED. The number of video frames used to create this evaluation. Corresponds to the JSON property evaluatedFrameCount

Returns:

  • (Fixnum)


53807
53808
53809
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53807

def evaluated_frame_count
  @evaluated_frame_count
end

#evaluated_track_countFixnum

UNIMPLEMENTED. The total number of tracks (i.e. as seen across all frames) the ground truth used to create this evaluation had. Corresponds to the JSON property evaluatedTrackCount

Returns:

  • (Fixnum)


53813
53814
53815
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53813

def evaluated_track_count
  @evaluated_track_count
end

#track_mean_average_precisionFloat

UNIMPLEMENTED. The single metric for tracks accuracy evaluation: the meanAveragePrecision averaged over all trackMetrics. Corresponds to the JSON property trackMeanAveragePrecision

Returns:

  • (Float)


53819
53820
53821
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53819

def track_mean_average_precision
  @track_mean_average_precision
end

#track_mean_bounding_box_iouFloat

UNIMPLEMENTED. The single metric for tracks bounding box iou evaluation: the meanBoundingBoxIou averaged over all trackMetrics. Corresponds to the JSON property trackMeanBoundingBoxIou

Returns:

  • (Float)


53825
53826
53827
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53825

def track_mean_bounding_box_iou
  @track_mean_bounding_box_iou
end

#track_mean_mismatch_rateFloat

UNIMPLEMENTED. The single metric for tracking consistency evaluation: the meanMismatchRate averaged over all trackMetrics. Corresponds to the JSON property trackMeanMismatchRate

Returns:

  • (Float)


53831
53832
53833
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53831

def track_mean_mismatch_rate
  @track_mean_mismatch_rate
end

#track_metricsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaModelevaluationMetricsTrackMetrics>

UNIMPLEMENTED. The tracks match metrics for each intersection-over-union threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 pair. Corresponds to the JSON property trackMetrics



53838
53839
53840
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53838

def track_metrics
  @track_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53845
53846
53847
53848
53849
53850
53851
53852
53853
53854
53855
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53845

def update!(**args)
  @bounding_box_mean_average_precision = args[:bounding_box_mean_average_precision] if args.key?(:bounding_box_mean_average_precision)
  @bounding_box_metrics = args[:bounding_box_metrics] if args.key?(:bounding_box_metrics)
  @evaluated_bounding_box_count = args[:evaluated_bounding_box_count] if args.key?(:evaluated_bounding_box_count)
  @evaluated_frame_count = args[:evaluated_frame_count] if args.key?(:evaluated_frame_count)
  @evaluated_track_count = args[:evaluated_track_count] if args.key?(:evaluated_track_count)
  @track_mean_average_precision = args[:track_mean_average_precision] if args.key?(:track_mean_average_precision)
  @track_mean_bounding_box_iou = args[:track_mean_bounding_box_iou] if args.key?(:track_mean_bounding_box_iou)
  @track_mean_mismatch_rate = args[:track_mean_mismatch_rate] if args.key?(:track_mean_mismatch_rate)
  @track_metrics = args[:track_metrics] if args.key?(:track_metrics)
end