Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictInstanceTextExtractionPredictionInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Prediction input format for Text Extraction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictInstanceTextExtractionPredictionInstance

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictInstanceTextExtractionPredictionInstance.



54058
54059
54060
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The text snippet to make the predictions on. Corresponds to the JSON property content

Returns:

  • (String)


54041
54042
54043
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54041

def content
  @content
end

#keyString

This field is only used for batch prediction. If a key is provided, the batch prediction result will by mapped to this key. If omitted, then the batch prediction result will contain the entire input instance. Vertex AI will not check if keys in the request are duplicates, so it is up to the caller to ensure the keys are unique. Corresponds to the JSON property key

Returns:

  • (String)


54050
54051
54052
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54050

def key
  @key
end

#mime_typeString

The MIME type of the text snippet. The supported MIME types are listed below. - text/plain Corresponds to the JSON property mimeType

Returns:

  • (String)


54056
54057
54058
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54056

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54063
54064
54065
54066
54067
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54063

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @key = args[:key] if args.key?(:key)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end