Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictParamsVideoActionRecognitionPredictionParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Prediction model parameters for Video Action Recognition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictParamsVideoActionRecognitionPredictionParams

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictParamsVideoActionRecognitionPredictionParams.



53154
53155
53156
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

The Model only returns predictions with at least this confidence score. Default value is 0.0 Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


53145
53146
53147
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53145

def confidence_threshold
  @confidence_threshold
end

#max_predictionsFixnum

The model only returns up to that many top, by confidence score, predictions per frame of the video. If this number is very high, the Model may return fewer predictions per frame. Default value is 50. Corresponds to the JSON property maxPredictions

Returns:

  • (Fixnum)


53152
53153
53154
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53152

def max_predictions
  @max_predictions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53159
53160
53161
53162
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53159

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @max_predictions = args[:max_predictions] if args.key?(:max_predictions)
end