Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictParamsVideoObjectTrackingPredictionParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Prediction model parameters for Video Object Tracking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictParamsVideoObjectTrackingPredictionParams

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictParamsVideoObjectTrackingPredictionParams.



51064
51065
51066
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

The Model only returns predictions with at least this confidence score. Default value is 0.0 Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


51049
51050
51051
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51049

def confidence_threshold
  @confidence_threshold
end

#max_predictionsFixnum

The model only returns up to that many top, by confidence score, predictions per frame of the video. If this number is very high, the Model may return fewer predictions per frame. Default value is 50. Corresponds to the JSON property maxPredictions

Returns:

  • (Fixnum)


51056
51057
51058
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51056

def max_predictions
  @max_predictions
end

#min_bounding_box_sizeFloat

Only bounding boxes with shortest edge at least that long as a relative value of video frame size are returned. Default value is 0.0. Corresponds to the JSON property minBoundingBoxSize

Returns:

  • (Float)


51062
51063
51064
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51062

def min_bounding_box_size
  @min_bounding_box_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51069
51070
51071
51072
51073
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51069

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @max_predictions = args[:max_predictions] if args.key?(:max_predictions)
  @min_bounding_box_size = args[:min_bounding_box_size] if args.key?(:min_bounding_box_size)
end