Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictPredictionImageObjectDetectionPredictionResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictPredictionImageObjectDetectionPredictionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Prediction output format for Image Object Detection.
Instance Attribute Summary collapse
-
#bboxes ⇒ Array<Array<Object>>
Bounding boxes, i.e.
-
#confidences ⇒ Array<Float>
The Model's confidences in correctness of the predicted IDs, higher value means higher confidence.
-
#display_names ⇒ Array<String>
The display names of the AnnotationSpecs that had been identified, order matches the IDs.
-
#ids ⇒ Array<Fixnum>
The resource IDs of the AnnotationSpecs that had been identified, ordered by the confidence score descendingly.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictPredictionImageObjectDetectionPredictionResult
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaPredictPredictionImageObjectDetectionPredictionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictPredictionImageObjectDetectionPredictionResult
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictPredictionImageObjectDetectionPredictionResult.
52541 52542 52543 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52541 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bboxes ⇒ Array<Array<Object>>
Bounding boxes, i.e. the rectangles over the image, that pinpoint the found
AnnotationSpecs. Given in order that matches the IDs. Each bounding box is an
array of 4 numbers xMin, xMax, yMin, and yMax, which represent the
extremal coordinates of the box. They are relative to the image size, and the
point 0,0 is in the top left of the image.
Corresponds to the JSON property bboxes
52521 52522 52523 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52521 def bboxes @bboxes end |
#confidences ⇒ Array<Float>
The Model's confidences in correctness of the predicted IDs, higher value
means higher confidence. Order matches the Ids.
Corresponds to the JSON property confidences
52527 52528 52529 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52527 def confidences @confidences end |
#display_names ⇒ Array<String>
The display names of the AnnotationSpecs that had been identified, order
matches the IDs.
Corresponds to the JSON property displayNames
52533 52534 52535 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52533 def display_names @display_names end |
#ids ⇒ Array<Fixnum>
The resource IDs of the AnnotationSpecs that had been identified, ordered by
the confidence score descendingly.
Corresponds to the JSON property ids
52539 52540 52541 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52539 def ids @ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52546 52547 52548 52549 52550 52551 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52546 def update!(**args) @bboxes = args[:bboxes] if args.key?(:bboxes) @confidences = args[:confidences] if args.key?(:confidences) @display_names = args[:display_names] if args.key?(:display_names) @ids = args[:ids] if args.key?(:ids) end |