Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoActionRecognitionPredictionResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoActionRecognitionPredictionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Prediction output format for Video Action Recognition.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
The Model's confidence in correction of this prediction, higher value means higher confidence.
-
#display_name ⇒ String
The display name of the AnnotationSpec that had been identified.
-
#id ⇒ String
The resource ID of the AnnotationSpec that had been identified.
-
#time_segment_end ⇒ String
The end, exclusive, of the video's time segment in which the AnnotationSpec has been identified.
-
#time_segment_start ⇒ String
The beginning, inclusive, of the video's time segment in which the AnnotationSpec has been identified.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoActionRecognitionPredictionResult
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoActionRecognitionPredictionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoActionRecognitionPredictionResult
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoActionRecognitionPredictionResult.
51453 51454 51455 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51453 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
The Model's confidence in correction of this prediction, higher value means
higher confidence.
Corresponds to the JSON property confidence
51425 51426 51427 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51425 def confidence @confidence end |
#display_name ⇒ String
The display name of the AnnotationSpec that had been identified.
Corresponds to the JSON property displayName
51430 51431 51432 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51430 def display_name @display_name end |
#id ⇒ String
The resource ID of the AnnotationSpec that had been identified.
Corresponds to the JSON property id
51435 51436 51437 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51435 def id @id end |
#time_segment_end ⇒ String
The end, exclusive, of the video's time segment in which the AnnotationSpec
has been identified. Expressed as a number of seconds as measured from the
start of the video, with fractions up to a microsecond precision, and with "s"
appended at the end.
Corresponds to the JSON property timeSegmentEnd
51443 51444 51445 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51443 def time_segment_end @time_segment_end end |
#time_segment_start ⇒ String
The beginning, inclusive, of the video's time segment in which the
AnnotationSpec has been identified. Expressed as a number of seconds as
measured from the start of the video, with fractions up to a microsecond
precision, and with "s" appended at the end.
Corresponds to the JSON property timeSegmentStart
51451 51452 51453 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51451 def time_segment_start @time_segment_start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51458 51459 51460 51461 51462 51463 51464 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51458 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end) @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start) end |