Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Prediction output format for Video Object Tracking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResult

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResult.



51572
51573
51574
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The Model's confidence in correction of this prediction, higher value means higher confidence. Corresponds to the JSON property confidence

Returns:

  • (Float)


51538
51539
51540
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51538

def confidence
  @confidence
end

#display_nameString

The display name of the AnnotationSpec that had been identified. Corresponds to the JSON property displayName

Returns:

  • (String)


51543
51544
51545
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51543

def display_name
  @display_name
end

#framesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame>

All of the frames of the video in which a single object instance has been detected. The bounding boxes in the frames identify the same object. Corresponds to the JSON property frames



51549
51550
51551
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51549

def frames
  @frames
end

#idString

The resource ID of the AnnotationSpec that had been identified. Corresponds to the JSON property id

Returns:

  • (String)


51554
51555
51556
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51554

def id
  @id
end

#time_segment_endString

The end, inclusive, of the video's time segment in which the object instance has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeSegmentEnd

Returns:

  • (String)


51562
51563
51564
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51562

def time_segment_end
  @time_segment_end
end

#time_segment_startString

The beginning, inclusive, of the video's time segment in which the object instance has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeSegmentStart

Returns:

  • (String)


51570
51571
51572
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51570

def time_segment_start
  @time_segment_start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51577
51578
51579
51580
51581
51582
51583
51584
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51577

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @display_name = args[:display_name] if args.key?(:display_name)
  @frames = args[:frames] if args.key?(:frames)
  @id = args[:id] if args.key?(:id)
  @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end)
  @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start)
end