Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Prediction output format for Video Object Tracking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResult

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResult.



50389
50390
50391
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50389

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The Model's confidence in correction of this prediction, higher value means higher confidence. Corresponds to the JSON property confidence

Returns:

  • (Float)


50355
50356
50357
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50355

def confidence
  @confidence
end

#display_nameString

The display name of the AnnotationSpec that had been identified. Corresponds to the JSON property displayName

Returns:

  • (String)


50360
50361
50362
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50360

def display_name
  @display_name
end

#framesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame>

All of the frames of the video in which a single object instance has been detected. The bounding boxes in the frames identify the same object. Corresponds to the JSON property frames



50366
50367
50368
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50366

def frames
  @frames
end

#idString

The resource ID of the AnnotationSpec that had been identified. Corresponds to the JSON property id

Returns:

  • (String)


50371
50372
50373
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50371

def id
  @id
end

#time_segment_endString

The end, inclusive, of the video's time segment in which the object instance has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeSegmentEnd

Returns:

  • (String)


50379
50380
50381
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50379

def time_segment_end
  @time_segment_end
end

#time_segment_startString

The beginning, inclusive, of the video's time segment in which the object instance has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeSegmentStart

Returns:

  • (String)


50387
50388
50389
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50387

def time_segment_start
  @time_segment_start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50394
50395
50396
50397
50398
50399
50400
50401
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50394

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @display_name = args[:display_name] if args.key?(:display_name)
  @frames = args[:frames] if args.key?(:frames)
  @id = args[:id] if args.key?(:id)
  @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end)
  @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start)
end