Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The fields xMin, xMax, yMin, and yMax refer to a bounding box, i.e.
the rectangle over the video frame pinpointing the found AnnotationSpec. The
coordinates are relative to the frame size, and the point 0,0 is in the top
left of the frame.
Instance Attribute Summary collapse
-
#time_offset ⇒ String
A time (frame) of a video in which the object has been detected.
-
#x_max ⇒ Float
The rightmost coordinate of the bounding box.
-
#x_min ⇒ Float
The leftmost coordinate of the bounding box.
-
#y_max ⇒ Float
The bottommost coordinate of the bounding box.
-
#y_min ⇒ Float
The topmost coordinate of the bounding box.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame.
55866 55867 55868 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55866 def initialize(**args) update!(**args) end |
Instance Attribute Details
#time_offset ⇒ String
A time (frame) of a video in which the object has been detected. Expressed as
a number of seconds as measured from the start of the video, with fractions up
to a microsecond precision, and with "s" appended at the end.
Corresponds to the JSON property timeOffset
55844 55845 55846 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55844 def time_offset @time_offset end |
#x_max ⇒ Float
The rightmost coordinate of the bounding box.
Corresponds to the JSON property xMax
55849 55850 55851 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55849 def x_max @x_max end |
#x_min ⇒ Float
The leftmost coordinate of the bounding box.
Corresponds to the JSON property xMin
55854 55855 55856 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55854 def x_min @x_min end |
#y_max ⇒ Float
The bottommost coordinate of the bounding box.
Corresponds to the JSON property yMax
55859 55860 55861 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55859 def y_max @y_max end |
#y_min ⇒ Float
The topmost coordinate of the bounding box.
Corresponds to the JSON property yMin
55864 55865 55866 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55864 def y_min @y_min end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55871 55872 55873 55874 55875 55876 55877 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55871 def update!(**args) @time_offset = args[:time_offset] if args.key?(:time_offset) @x_max = args[:x_max] if args.key?(:x_max) @x_min = args[:x_min] if args.key?(:x_min) @y_max = args[:y_max] if args.key?(:y_max) @y_min = args[:y_min] if args.key?(:y_min) end |