Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The fields xMin, xMax, yMin, and yMax refer to a bounding box, i.e. the rectangle over the video frame pinpointing the found AnnotationSpec. The coordinates are relative to the frame size, and the point 0,0 is in the top left of the frame.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame.



55046
55047
55048
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#time_offsetString

A time (frame) of a video in which the object has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeOffset

Returns:

  • (String)


55024
55025
55026
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55024

def time_offset
  @time_offset
end

#x_maxFloat

The rightmost coordinate of the bounding box. Corresponds to the JSON property xMax

Returns:

  • (Float)


55029
55030
55031
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55029

def x_max
  @x_max
end

#x_minFloat

The leftmost coordinate of the bounding box. Corresponds to the JSON property xMin

Returns:

  • (Float)


55034
55035
55036
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55034

def x_min
  @x_min
end

#y_maxFloat

The bottommost coordinate of the bounding box. Corresponds to the JSON property yMax

Returns:

  • (Float)


55039
55040
55041
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55039

def y_max
  @y_max
end

#y_minFloat

The topmost coordinate of the bounding box. Corresponds to the JSON property yMin

Returns:

  • (Float)


55044
55045
55046
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55044

def y_min
  @y_min
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55051
55052
55053
55054
55055
55056
55057
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55051

def update!(**args)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
  @x_max = args[:x_max] if args.key?(:x_max)
  @x_min = args[:x_min] if args.key?(:x_min)
  @y_max = args[:y_max] if args.key?(:y_max)
  @y_min = args[:y_min] if args.key?(:y_min)
end