Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a line of JSONL in the batch prediction output file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictionResult

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictionResult.



55087
55088
55089
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictionResultError

The error result. Do not set prediction if this is set. Corresponds to the JSON property error



55067
55068
55069
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55067

def error
  @error
end

#instanceHash<String,Object>

User's input instance. Struct is used here instead of Any so that JsonFormat does not append an extra "@type" field when we convert the proto to JSON. Corresponds to the JSON property instance

Returns:

  • (Hash<String,Object>)


55073
55074
55075
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55073

def instance
  @instance
end

#keyString

Optional user-provided key from the input instance. Corresponds to the JSON property key

Returns:

  • (String)


55078
55079
55080
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55078

def key
  @key
end

#predictionObject

The prediction result. Value is used here instead of Any so that JsonFormat does not append an extra "@type" field when we convert the proto to JSON and so we can represent array of objects. Do not set error if this is set. Corresponds to the JSON property prediction

Returns:

  • (Object)


55085
55086
55087
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55085

def prediction
  @prediction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55092
55093
55094
55095
55096
55097
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55092

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @instance = args[:instance] if args.key?(:instance)
  @key = args[:key] if args.key?(:key)
  @prediction = args[:prediction] if args.key?(:prediction)
end