Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a line of JSONL in the batch prediction output file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictionResult

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictionResult.



53063
53064
53065
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictionResultError

The error result. Do not set prediction if this is set. Corresponds to the JSON property error



53043
53044
53045
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53043

def error
  @error
end

#instanceHash<String,Object>

User's input instance. Struct is used here instead of Any so that JsonFormat does not append an extra "@type" field when we convert the proto to JSON. Corresponds to the JSON property instance

Returns:

  • (Hash<String,Object>)


53049
53050
53051
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53049

def instance
  @instance
end

#keyString

Optional user-provided key from the input instance. Corresponds to the JSON property key

Returns:

  • (String)


53054
53055
53056
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53054

def key
  @key
end

#predictionObject

The prediction result. Value is used here instead of Any so that JsonFormat does not append an extra "@type" field when we convert the proto to JSON and so we can represent array of objects. Do not set error if this is set. Corresponds to the JSON property prediction

Returns:

  • (Object)


53061
53062
53063
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53061

def prediction
  @prediction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53068
53069
53070
53071
53072
53073
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53068

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @instance = args[:instance] if args.key?(:instance)
  @key = args[:key] if args.key?(:key)
  @prediction = args[:prediction] if args.key?(:prediction)
end