Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictionResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a line of JSONL in the batch prediction output file.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictionResultError
The error result.
-
#instance ⇒ Hash<String,Object>
User's input instance.
-
#key ⇒ String
Optional user-provided key from the input instance.
-
#prediction ⇒ Object
The prediction result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictionResult
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaPredictionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictionResult
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictionResult.
53241 53242 53243 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictionResultError
The error result. Do not set prediction if this is set.
Corresponds to the JSON property error
53221 53222 53223 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53221 def error @error end |
#instance ⇒ Hash<String,Object>
User's input instance. Struct is used here instead of Any so that JsonFormat
does not append an extra "@type" field when we convert the proto to JSON.
Corresponds to the JSON property instance
53227 53228 53229 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53227 def instance @instance end |
#key ⇒ String
Optional user-provided key from the input instance.
Corresponds to the JSON property key
53232 53233 53234 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53232 def key @key end |
#prediction ⇒ Object
The prediction result. Value is used here instead of Any so that JsonFormat
does not append an extra "@type" field when we convert the proto to JSON and
so we can represent array of objects. Do not set error if this is set.
Corresponds to the JSON property prediction
53239 53240 53241 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53239 def prediction @prediction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53246 53247 53248 53249 53250 53251 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53246 def update!(**args) @error = args[:error] if args.key?(:error) @instance = args[:instance] if args.key?(:instance) @key = args[:key] if args.key?(:key) @prediction = args[:prediction] if args.key?(:prediction) end |