Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictionResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a line of JSONL in the batch prediction output file.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictionResultError
The error result.
-
#instance ⇒ Hash<String,Object>
User's input instance.
-
#key ⇒ String
Optional user-provided key from the input instance.
-
#prediction ⇒ Object
The prediction result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictionResult
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaPredictionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPredictionResult
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPredictionResult.
45438 45439 45440 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45438 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictionResultError
The error result. Do not set prediction if this is set.
Corresponds to the JSON property error
45418 45419 45420 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45418 def error @error end |
#instance ⇒ Hash<String,Object>
User's input instance. Struct is used here instead of Any so that JsonFormat
does not append an extra "@type" field when we convert the proto to JSON.
Corresponds to the JSON property instance
45424 45425 45426 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45424 def instance @instance end |
#key ⇒ String
Optional user-provided key from the input instance.
Corresponds to the JSON property key
45429 45430 45431 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45429 def key @key end |
#prediction ⇒ Object
The prediction result. Value is used here instead of Any so that JsonFormat
does not append an extra "@type" field when we convert the proto to JSON and
so we can represent array of objects. Do not set error if this is set.
Corresponds to the JSON property prediction
45436 45437 45438 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45436 def prediction @prediction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45443 45444 45445 45446 45447 45448 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45443 def update!(**args) @error = args[:error] if args.key?(:error) @instance = args[:instance] if args.key?(:instance) @key = args[:key] if args.key?(:key) @prediction = args[:prediction] if args.key?(:prediction) end |