Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderData
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Defines data for an application builder.
Instance Attribute Summary collapse
-
#code_repository_state ⇒ String
Serialized state of the code repository.
-
#framework ⇒ String
Optional.
-
#linked_resources ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderDataLinkedResource>
Linked resources attached to the application by the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderData
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderData
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderData.
45710 45711 45712 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45710 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_repository_state ⇒ String
Serialized state of the code repository. This string will typically contain a
JSON representation of the UI's CodeRepositoryService state (files, folders,
content, and any metadata). The UI is responsible for serialization and
deserialization.
Corresponds to the JSON property codeRepositoryState
45698 45699 45700 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45698 def code_repository_state @code_repository_state end |
#framework ⇒ String
Optional. Framework used to build the application.
Corresponds to the JSON property framework
45703 45704 45705 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45703 def framework @framework end |
#linked_resources ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderDataLinkedResource>
Linked resources attached to the application by the user.
Corresponds to the JSON property linkedResources
45708 45709 45710 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45708 def linked_resources @linked_resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45715 45716 45717 45718 45719 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 45715 def update!(**args) @code_repository_state = args[:code_repository_state] if args.key?(:code_repository_state) @framework = args[:framework] if args.key?(:framework) @linked_resources = args[:linked_resources] if args.key?(:linked_resources) end |