Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPartList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A list of elements and information that make up a portion of prompt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecPartList

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecPartList.



53303
53304
53305
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>

A list of elements that can be part of a prompt. Corresponds to the JSON property parts



53301
53302
53303
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53301

def parts
  @parts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53308
53309
53310
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53308

def update!(**args)
  @parts = args[:parts] if args.key?(:parts)
end