Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPromptMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The prompt message that aligns with the prompt message in google.cloud. aiplatform.master.GenerateContentRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecPromptMessage

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecPromptMessage.



53363
53364
53365
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>

The content of the current conversation with the model. For single-turn queries, this is a single instance. For multi-turn queries, this is a repeated field that contains conversation history + latest request. Corresponds to the JSON property contents



53323
53324
53325
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53323

def contents
  @contents
end

#generation_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property generationConfig



53330
53331
53332
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53330

def generation_config
  @generation_config
end

#modelString

The model name. Corresponds to the JSON property model

Returns:

  • (String)


53335
53336
53337
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53335

def model
  @model
end

#safety_settingsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SafetySetting>

Per request settings for blocking unsafe content. Enforced on GenerateContentResponse.candidates. Corresponds to the JSON property safetySettings



53341
53342
53343
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53341

def safety_settings
  @safety_settings
end

#system_instructionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property systemInstruction



53348
53349
53350
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53348

def system_instruction
  @system_instruction
end

#tool_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolConfig

Tool config. This config is shared for all tools provided in the request. Corresponds to the JSON property toolConfig



53353
53354
53355
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53353

def tool_config
  @tool_config
end

#toolsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool>

A list of Tools the model may use to generate the next response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. Corresponds to the JSON property tools



53361
53362
53363
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53361

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53368
53369
53370
53371
53372
53373
53374
53375
53376
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53368

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @model = args[:model] if args.key?(:model)
  @safety_settings = args[:safety_settings] if args.key?(:safety_settings)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tool_config = args[:tool_config] if args.key?(:tool_config)
  @tools = args[:tools] if args.key?(:tools)
end