Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecStructuredPrompt
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecStructuredPrompt
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Prompt variation that stores preambles in separate fields.
Instance Attribute Summary collapse
-
#app_builder_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderData
Defines data for an application builder.
-
#context ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message.
-
#examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPartList>
Preamble: A set of examples for expected model response.
-
#infill_prefix ⇒ String
Preamble: For infill prompt, the prefix before expected model response.
-
#infill_suffix ⇒ String
Preamble: For infill prompt, the suffix after expected model response.
-
#input_prefixes ⇒ Array<String>
Preamble: The input prefixes before each example input.
-
#interaction_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecInteractionData
Defines data for an interaction prompt.
-
#output_prefixes ⇒ Array<String>
Preamble: The output prefixes before each example output.
-
#prediction_inputs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPartList>
Preamble: The input test data for prediction.
-
#prompt_message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecStructuredPrompt
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecStructuredPrompt.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecStructuredPrompt
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecStructuredPrompt.
53659 53660 53661 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_builder_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderData
Defines data for an application builder.
Corresponds to the JSON property appBuilderData
53608 53609 53610 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53608 def app_builder_data @app_builder_data end |
#context ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property context
53615 53616 53617 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53615 def context @context end |
#examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPartList>
Preamble: A set of examples for expected model response.
Corresponds to the JSON property examples
53620 53621 53622 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53620 def examples @examples end |
#infill_prefix ⇒ String
Preamble: For infill prompt, the prefix before expected model response.
Corresponds to the JSON property infillPrefix
53625 53626 53627 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53625 def infill_prefix @infill_prefix end |
#infill_suffix ⇒ String
Preamble: For infill prompt, the suffix after expected model response.
Corresponds to the JSON property infillSuffix
53630 53631 53632 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53630 def infill_suffix @infill_suffix end |
#input_prefixes ⇒ Array<String>
Preamble: The input prefixes before each example input.
Corresponds to the JSON property inputPrefixes
53635 53636 53637 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53635 def input_prefixes @input_prefixes end |
#interaction_data ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecInteractionData
Defines data for an interaction prompt.
Corresponds to the JSON property interactionData
53640 53641 53642 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53640 def interaction_data @interaction_data end |
#output_prefixes ⇒ Array<String>
Preamble: The output prefixes before each example output.
Corresponds to the JSON property outputPrefixes
53645 53646 53647 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53645 def output_prefixes @output_prefixes end |
#prediction_inputs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPartList>
Preamble: The input test data for prediction. Each PartList in this field
represents one text-only input set for a single model request.
Corresponds to the JSON property predictionInputs
53651 53652 53653 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53651 def prediction_inputs @prediction_inputs end |
#prompt_message ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
aiplatform.master.GenerateContentRequest.
Corresponds to the JSON property promptMessage
53657 53658 53659 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53657 def @prompt_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53664 53665 53666 53667 53668 53669 53670 53671 53672 53673 53674 53675 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53664 def update!(**args) @app_builder_data = args[:app_builder_data] if args.key?(:app_builder_data) @context = args[:context] if args.key?(:context) @examples = args[:examples] if args.key?(:examples) @infill_prefix = args[:infill_prefix] if args.key?(:infill_prefix) @infill_suffix = args[:infill_suffix] if args.key?(:infill_suffix) @input_prefixes = args[:input_prefixes] if args.key?(:input_prefixes) @interaction_data = args[:interaction_data] if args.key?(:interaction_data) @output_prefixes = args[:output_prefixes] if args.key?(:output_prefixes) @prediction_inputs = args[:prediction_inputs] if args.key?(:prediction_inputs) @prompt_message = args[:prompt_message] if args.key?(:prompt_message) end |