Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecStructuredPrompt

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Prompt variation that stores preambles in separate fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaPromptSpecStructuredPrompt

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaPromptSpecStructuredPrompt.



50897
50898
50899
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_builder_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecAppBuilderData

Defines data for an application builder. Corresponds to the JSON property appBuilderData



50846
50847
50848
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50846

def app_builder_data
  @app_builder_data
end

#contextGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property context



50853
50854
50855
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50853

def context
  @context
end

#examplesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPartList>

Preamble: A set of examples for expected model response. Corresponds to the JSON property examples



50858
50859
50860
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50858

def examples
  @examples
end

#infill_prefixString

Preamble: For infill prompt, the prefix before expected model response. Corresponds to the JSON property infillPrefix

Returns:

  • (String)


50863
50864
50865
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50863

def infill_prefix
  @infill_prefix
end

#infill_suffixString

Preamble: For infill prompt, the suffix after expected model response. Corresponds to the JSON property infillSuffix

Returns:

  • (String)


50868
50869
50870
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50868

def infill_suffix
  @infill_suffix
end

#input_prefixesArray<String>

Preamble: The input prefixes before each example input. Corresponds to the JSON property inputPrefixes

Returns:

  • (Array<String>)


50873
50874
50875
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50873

def input_prefixes
  @input_prefixes
end

#interaction_dataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecInteractionData

Defines data for an interaction prompt. Corresponds to the JSON property interactionData



50878
50879
50880
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50878

def interaction_data
  @interaction_data
end

#output_prefixesArray<String>

Preamble: The output prefixes before each example output. Corresponds to the JSON property outputPrefixes

Returns:

  • (Array<String>)


50883
50884
50885
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50883

def output_prefixes
  @output_prefixes
end

#prediction_inputsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPartList>

Preamble: The input test data for prediction. Each PartList in this field represents one text-only input set for a single model request. Corresponds to the JSON property predictionInputs



50889
50890
50891
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50889

def prediction_inputs
  @prediction_inputs
end

#prompt_messageGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptSpecPromptMessage

The prompt message that aligns with the prompt message in google.cloud. aiplatform.master.GenerateContentRequest. Corresponds to the JSON property promptMessage



50895
50896
50897
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50895

def prompt_message
  @prompt_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50902
50903
50904
50905
50906
50907
50908
50909
50910
50911
50912
50913
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50902

def update!(**args)
  @app_builder_data = args[:app_builder_data] if args.key?(:app_builder_data)
  @context = args[:context] if args.key?(:context)
  @examples = args[:examples] if args.key?(:examples)
  @infill_prefix = args[:infill_prefix] if args.key?(:infill_prefix)
  @infill_suffix = args[:infill_suffix] if args.key?(:infill_suffix)
  @input_prefixes = args[:input_prefixes] if args.key?(:input_prefixes)
  @interaction_data = args[:interaction_data] if args.key?(:interaction_data)
  @output_prefixes = args[:output_prefixes] if args.key?(:output_prefixes)
  @prediction_inputs = args[:prediction_inputs] if args.key?(:prediction_inputs)
  @prompt_message = args[:prompt_message] if args.key?(:prompt_message)
end