Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The metadata of Datasets that contain Text Prompt data.
Instance Attribute Summary collapse
-
#candidate_count ⇒ Fixnum
Number of candidates.
-
#gcs_uri ⇒ String
The Google Cloud Storage URI that stores the prompt data.
-
#grounding_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictParamsGroundingConfig
The configuration for grounding checking.
-
#has_prompt_variable ⇒ Boolean
(also: #has_prompt_variable?)
Whether the prompt dataset has prompt variable.
-
#logprobs ⇒ Boolean
(also: #logprobs?)
Whether or not the user has enabled logit probabilities in the model parameters.
-
#max_output_tokens ⇒ Fixnum
Value of the maximum number of tokens generated set when the dataset was saved.
-
#note ⇒ String
User-created prompt note.
-
#prompt_api_schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptApiSchema
The A2 schema of a prompt.
-
#prompt_type ⇒ String
Type of the prompt dataset.
-
#seed_enabled ⇒ Boolean
(also: #seed_enabled?)
Seeding enables model to return a deterministic response on a best effort basis.
-
#seed_value ⇒ Fixnum
The actual value of the seed.
-
#stop_sequences ⇒ Array<String>
Customized stop sequences.
-
#system_instruction ⇒ String
The content of the prompt dataset system instruction.
-
#system_instruction_gcs_uri ⇒ String
The Google Cloud Storage URI that stores the system instruction, starting with gs://.
-
#temperature ⇒ Float
Temperature value used for sampling set when the dataset was saved.
-
#text ⇒ String
The content of the prompt dataset.
-
#top_k ⇒ Fixnum
Top K value set when the dataset was saved.
-
#top_p ⇒ Float
Top P value set when the dataset was saved.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata.
54743 54744 54745 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54743 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate_count ⇒ Fixnum
Number of candidates.
Corresponds to the JSON property candidateCount
54645 54646 54647 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54645 def candidate_count @candidate_count end |
#gcs_uri ⇒ String
The Google Cloud Storage URI that stores the prompt data.
Corresponds to the JSON property gcsUri
54650 54651 54652 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54650 def gcs_uri @gcs_uri end |
#grounding_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictParamsGroundingConfig
The configuration for grounding checking.
Corresponds to the JSON property groundingConfig
54655 54656 54657 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54655 def grounding_config @grounding_config end |
#has_prompt_variable ⇒ Boolean Also known as: has_prompt_variable?
Whether the prompt dataset has prompt variable.
Corresponds to the JSON property hasPromptVariable
54660 54661 54662 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54660 def has_prompt_variable @has_prompt_variable end |
#logprobs ⇒ Boolean Also known as: logprobs?
Whether or not the user has enabled logit probabilities in the model
parameters.
Corresponds to the JSON property logprobs
54667 54668 54669 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54667 def logprobs @logprobs end |
#max_output_tokens ⇒ Fixnum
Value of the maximum number of tokens generated set when the dataset was saved.
Corresponds to the JSON property maxOutputTokens
54673 54674 54675 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54673 def max_output_tokens @max_output_tokens end |
#note ⇒ String
User-created prompt note. Note size limit is 2KB.
Corresponds to the JSON property note
54678 54679 54680 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54678 def note @note end |
#prompt_api_schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptApiSchema
The A2 schema of a prompt.
Corresponds to the JSON property promptApiSchema
54683 54684 54685 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54683 def prompt_api_schema @prompt_api_schema end |
#prompt_type ⇒ String
Type of the prompt dataset.
Corresponds to the JSON property promptType
54688 54689 54690 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54688 def prompt_type @prompt_type end |
#seed_enabled ⇒ Boolean Also known as: seed_enabled?
Seeding enables model to return a deterministic response on a best effort
basis. Determinism isn't guaranteed. This field determines whether or not
seeding is enabled.
Corresponds to the JSON property seedEnabled
54695 54696 54697 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54695 def seed_enabled @seed_enabled end |
#seed_value ⇒ Fixnum
The actual value of the seed.
Corresponds to the JSON property seedValue
54701 54702 54703 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54701 def seed_value @seed_value end |
#stop_sequences ⇒ Array<String>
Customized stop sequences.
Corresponds to the JSON property stopSequences
54706 54707 54708 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54706 def stop_sequences @stop_sequences end |
#system_instruction ⇒ String
The content of the prompt dataset system instruction.
Corresponds to the JSON property systemInstruction
54711 54712 54713 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54711 def system_instruction @system_instruction end |
#system_instruction_gcs_uri ⇒ String
The Google Cloud Storage URI that stores the system instruction, starting with
gs://.
Corresponds to the JSON property systemInstructionGcsUri
54717 54718 54719 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54717 def system_instruction_gcs_uri @system_instruction_gcs_uri end |
#temperature ⇒ Float
Temperature value used for sampling set when the dataset was saved. This value
is used to tune the degree of randomness.
Corresponds to the JSON property temperature
54723 54724 54725 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54723 def temperature @temperature end |
#text ⇒ String
The content of the prompt dataset.
Corresponds to the JSON property text
54728 54729 54730 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54728 def text @text end |
#top_k ⇒ Fixnum
Top K value set when the dataset was saved. This value determines how many
candidates with highest probability from the vocab would be selected for each
decoding step.
Corresponds to the JSON property topK
54735 54736 54737 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54735 def top_k @top_k end |
#top_p ⇒ Float
Top P value set when the dataset was saved. Given topK tokens for decoding,
top candidates will be selected until the sum of their probabilities is topP.
Corresponds to the JSON property topP
54741 54742 54743 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54741 def top_p @top_p end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54748 54749 54750 54751 54752 54753 54754 54755 54756 54757 54758 54759 54760 54761 54762 54763 54764 54765 54766 54767 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54748 def update!(**args) @candidate_count = args[:candidate_count] if args.key?(:candidate_count) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @grounding_config = args[:grounding_config] if args.key?(:grounding_config) @has_prompt_variable = args[:has_prompt_variable] if args.key?(:has_prompt_variable) @logprobs = args[:logprobs] if args.key?(:logprobs) @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens) @note = args[:note] if args.key?(:note) @prompt_api_schema = args[:prompt_api_schema] if args.key?(:prompt_api_schema) @prompt_type = args[:prompt_type] if args.key?(:prompt_type) @seed_enabled = args[:seed_enabled] if args.key?(:seed_enabled) @seed_value = args[:seed_value] if args.key?(:seed_value) @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @system_instruction_gcs_uri = args[:system_instruction_gcs_uri] if args.key?(:system_instruction_gcs_uri) @temperature = args[:temperature] if args.key?(:temperature) @text = args[:text] if args.key?(:text) @top_k = args[:top_k] if args.key?(:top_k) @top_p = args[:top_p] if args.key?(:top_p) end |