Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The metadata of Datasets that contain Text Prompt data.
Instance Attribute Summary collapse
-
#candidate_count ⇒ Fixnum
Number of candidates.
-
#gcs_uri ⇒ String
The Google Cloud Storage URI that stores the prompt data.
-
#grounding_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictParamsGroundingConfig
The configuration for grounding checking.
-
#has_prompt_variable ⇒ Boolean
(also: #has_prompt_variable?)
Whether the prompt dataset has prompt variable.
-
#logprobs ⇒ Boolean
(also: #logprobs?)
Whether or not the user has enabled logit probabilities in the model parameters.
-
#max_output_tokens ⇒ Fixnum
Value of the maximum number of tokens generated set when the dataset was saved.
-
#note ⇒ String
User-created prompt note.
-
#prompt_api_schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptApiSchema
The A2 schema of a prompt.
-
#prompt_type ⇒ String
Type of the prompt dataset.
-
#seed_enabled ⇒ Boolean
(also: #seed_enabled?)
Seeding enables model to return a deterministic response on a best effort basis.
-
#seed_value ⇒ Fixnum
The actual value of the seed.
-
#stop_sequences ⇒ Array<String>
Customized stop sequences.
-
#system_instruction ⇒ String
The content of the prompt dataset system instruction.
-
#system_instruction_gcs_uri ⇒ String
The Google Cloud Storage URI that stores the system instruction, starting with gs://.
-
#temperature ⇒ Float
Temperature value used for sampling set when the dataset was saved.
-
#text ⇒ String
The content of the prompt dataset.
-
#top_k ⇒ Fixnum
Top K value set when the dataset was saved.
-
#top_p ⇒ Float
Top P value set when the dataset was saved.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaTextPromptDatasetMetadata.
52557 52558 52559 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52557 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate_count ⇒ Fixnum
Number of candidates.
Corresponds to the JSON property candidateCount
52459 52460 52461 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52459 def candidate_count @candidate_count end |
#gcs_uri ⇒ String
The Google Cloud Storage URI that stores the prompt data.
Corresponds to the JSON property gcsUri
52464 52465 52466 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52464 def gcs_uri @gcs_uri end |
#grounding_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPredictParamsGroundingConfig
The configuration for grounding checking.
Corresponds to the JSON property groundingConfig
52469 52470 52471 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52469 def grounding_config @grounding_config end |
#has_prompt_variable ⇒ Boolean Also known as: has_prompt_variable?
Whether the prompt dataset has prompt variable.
Corresponds to the JSON property hasPromptVariable
52474 52475 52476 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52474 def has_prompt_variable @has_prompt_variable end |
#logprobs ⇒ Boolean Also known as: logprobs?
Whether or not the user has enabled logit probabilities in the model
parameters.
Corresponds to the JSON property logprobs
52481 52482 52483 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52481 def logprobs @logprobs end |
#max_output_tokens ⇒ Fixnum
Value of the maximum number of tokens generated set when the dataset was saved.
Corresponds to the JSON property maxOutputTokens
52487 52488 52489 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52487 def max_output_tokens @max_output_tokens end |
#note ⇒ String
User-created prompt note. Note size limit is 2KB.
Corresponds to the JSON property note
52492 52493 52494 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52492 def note @note end |
#prompt_api_schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaPromptApiSchema
The A2 schema of a prompt.
Corresponds to the JSON property promptApiSchema
52497 52498 52499 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52497 def prompt_api_schema @prompt_api_schema end |
#prompt_type ⇒ String
Type of the prompt dataset.
Corresponds to the JSON property promptType
52502 52503 52504 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52502 def prompt_type @prompt_type end |
#seed_enabled ⇒ Boolean Also known as: seed_enabled?
Seeding enables model to return a deterministic response on a best effort
basis. Determinism isn't guaranteed. This field determines whether or not
seeding is enabled.
Corresponds to the JSON property seedEnabled
52509 52510 52511 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52509 def seed_enabled @seed_enabled end |
#seed_value ⇒ Fixnum
The actual value of the seed.
Corresponds to the JSON property seedValue
52515 52516 52517 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52515 def seed_value @seed_value end |
#stop_sequences ⇒ Array<String>
Customized stop sequences.
Corresponds to the JSON property stopSequences
52520 52521 52522 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52520 def stop_sequences @stop_sequences end |
#system_instruction ⇒ String
The content of the prompt dataset system instruction.
Corresponds to the JSON property systemInstruction
52525 52526 52527 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52525 def system_instruction @system_instruction end |
#system_instruction_gcs_uri ⇒ String
The Google Cloud Storage URI that stores the system instruction, starting with
gs://.
Corresponds to the JSON property systemInstructionGcsUri
52531 52532 52533 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52531 def system_instruction_gcs_uri @system_instruction_gcs_uri end |
#temperature ⇒ Float
Temperature value used for sampling set when the dataset was saved. This value
is used to tune the degree of randomness.
Corresponds to the JSON property temperature
52537 52538 52539 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52537 def temperature @temperature end |
#text ⇒ String
The content of the prompt dataset.
Corresponds to the JSON property text
52542 52543 52544 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52542 def text @text end |
#top_k ⇒ Fixnum
Top K value set when the dataset was saved. This value determines how many
candidates with highest probability from the vocab would be selected for each
decoding step.
Corresponds to the JSON property topK
52549 52550 52551 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52549 def top_k @top_k end |
#top_p ⇒ Float
Top P value set when the dataset was saved. Given topK tokens for decoding,
top candidates will be selected until the sum of their probabilities is topP.
Corresponds to the JSON property topP
52555 52556 52557 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52555 def top_p @top_p end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52562 52563 52564 52565 52566 52567 52568 52569 52570 52571 52572 52573 52574 52575 52576 52577 52578 52579 52580 52581 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52562 def update!(**args) @candidate_count = args[:candidate_count] if args.key?(:candidate_count) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @grounding_config = args[:grounding_config] if args.key?(:grounding_config) @has_prompt_variable = args[:has_prompt_variable] if args.key?(:has_prompt_variable) @logprobs = args[:logprobs] if args.key?(:logprobs) @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens) @note = args[:note] if args.key?(:note) @prompt_api_schema = args[:prompt_api_schema] if args.key?(:prompt_api_schema) @prompt_type = args[:prompt_type] if args.key?(:prompt_type) @seed_enabled = args[:seed_enabled] if args.key?(:seed_enabled) @seed_value = args[:seed_value] if args.key?(:seed_value) @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @system_instruction_gcs_uri = args[:system_instruction_gcs_uri] if args.key?(:system_instruction_gcs_uri) @temperature = args[:temperature] if args.key?(:temperature) @text = args[:text] if args.key?(:text) @top_k = args[:top_k] if args.key?(:top_k) @top_p = args[:top_p] if args.key?(:top_p) end |