Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTextSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The text segment inside of DataItem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTextSegment

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaTextSegment.



52606
52607
52608
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52606

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The text content in the segment for output only. Corresponds to the JSON property content

Returns:

  • (String)


52591
52592
52593
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52591

def content
  @content
end

#end_offsetFixnum

Zero-based character index of the first character past the end of the text segment (counting character from the beginning of the text). The character at the end_offset is NOT included in the text segment. Corresponds to the JSON property endOffset

Returns:

  • (Fixnum)


52598
52599
52600
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52598

def end_offset
  @end_offset
end

#start_offsetFixnum

Zero-based character index of the first character of the text segment ( counting characters from the beginning of the text). Corresponds to the JSON property startOffset

Returns:

  • (Fixnum)


52604
52605
52606
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52604

def start_offset
  @start_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52611
52612
52613
52614
52615
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52611

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @end_offset = args[:end_offset] if args.key?(:end_offset)
  @start_offset = args[:start_offset] if args.key?(:start_offset)
end