Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#base_model_id ⇒ String
The ID of the
basemodel. -
#budget_milli_node_hours ⇒ Fixnum
The training budget of creating this model, expressed in milli node hours i.e.
-
#disable_early_stopping ⇒ Boolean
(also: #disable_early_stopping?)
Use the entire training budget.
-
#model_type ⇒ String
Corresponds to the JSON property
modelType. -
#multi_label ⇒ Boolean
(also: #multi_label?)
If false, a single-label (multi-class) Model will be trained (i.e. assuming that for each image just up to one annotation may be applicable).
-
#tunable_parameter ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
A wrapper class which contains the tunable parameters in an AutoML Image training job.
-
#uptrain_base_model_id ⇒ String
The ID of
basemodel for upTraining.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs.
47271 47272 47273 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_model_id ⇒ String
The ID of the base model. If it is specified, the new model will be trained
based on the base model. Otherwise, the new model will be trained from
scratch. The base model must be in the same Project and Location as the new
Model to train, and have the same modelType.
Corresponds to the JSON property baseModelId
47215 47216 47217 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47215 def base_model_id @base_model_id end |
#budget_milli_node_hours ⇒ Fixnum
The training budget of creating this model, expressed in milli node hours i.e.
1,000 value in this field means 1 node hour. The actual metadata.
costMilliNodeHours will be equal or less than this value. If further model
training ceases to provide any improvements, it will stop without using the
full budget and the metadata.successfulStopReason will be model-converged.
Note, node_hour = actual_hour * number_of_nodes_involved. For modelType cloud
(default), the budget must be between 8,000 and 800,000 milli node hours,
inclusive. The default value is 192,000 which represents one day in wall time,
considering 8 nodes are used. For model types mobile-tf-low-latency-1,
mobile-tf-versatile-1, mobile-tf-high-accuracy-1, the training budget must
be between 1,000 and 100,000 milli node hours, inclusive. The default value is
24,000 which represents one day in wall time on a single node that is used.
Corresponds to the JSON property budgetMilliNodeHours
47231 47232 47233 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47231 def budget_milli_node_hours @budget_milli_node_hours end |
#disable_early_stopping ⇒ Boolean Also known as: disable_early_stopping?
Use the entire training budget. This disables the early stopping feature. When
false the early stopping feature is enabled, which means that AutoML Image
Classification might stop training before the entire training budget has been
used.
Corresponds to the JSON property disableEarlyStopping
47239 47240 47241 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47239 def disable_early_stopping @disable_early_stopping end |
#model_type ⇒ String
Corresponds to the JSON property modelType
47245 47246 47247 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47245 def model_type @model_type end |
#multi_label ⇒ Boolean Also known as: multi_label?
If false, a single-label (multi-class) Model will be trained (i.e. assuming
that for each image just up to one annotation may be applicable). If true, a
multi-label Model will be trained (i.e. assuming that for each image multiple
annotations may be applicable).
Corresponds to the JSON property multiLabel
47253 47254 47255 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47253 def multi_label @multi_label end |
#tunable_parameter ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
A wrapper class which contains the tunable parameters in an AutoML Image
training job.
Corresponds to the JSON property tunableParameter
47260 47261 47262 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47260 def tunable_parameter @tunable_parameter end |
#uptrain_base_model_id ⇒ String
The ID of base model for upTraining. If it is specified, the new model will
be upTrained based on the base model for upTraining. Otherwise, the new
model will be trained from scratch. The base model for upTraining must be in
the same Project and Location as the new Model to train, and have the same
modelType.
Corresponds to the JSON property uptrainBaseModelId
47269 47270 47271 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47269 def uptrain_base_model_id @uptrain_base_model_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47276 47277 47278 47279 47280 47281 47282 47283 47284 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 47276 def update!(**args) @base_model_id = args[:base_model_id] if args.key?(:base_model_id) @budget_milli_node_hours = args[:budget_milli_node_hours] if args.key?(:budget_milli_node_hours) @disable_early_stopping = args[:disable_early_stopping] if args.key?(:disable_early_stopping) @model_type = args[:model_type] if args.key?(:model_type) @multi_label = args[:multi_label] if args.key?(:multi_label) @tunable_parameter = args[:tunable_parameter] if args.key?(:tunable_parameter) @uptrain_base_model_id = args[:uptrain_base_model_id] if args.key?(:uptrain_base_model_id) end |