Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#auto ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationAutoTransformation
Training pipeline will infer the proper transformation based on the statistic of dataset.
-
#categorical ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalTransformation
Training pipeline will perform following transformation functions.
-
#numeric ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericTransformation
Training pipeline will perform following transformation functions.
-
#repeated_categorical ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalArrayTransformation
Treats the column as categorical array and performs following transformation functions.
-
#repeated_numeric ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericArrayTransformation
Treats the column as numerical array and performs following transformation functions.
-
#repeated_text ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation
Treats the column as text array and performs following transformation functions.
-
#text ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextTransformation
Training pipeline will perform following transformation functions.
-
#timestamp ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTimestampTransformation
Training pipeline will perform following transformation functions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation.
57260 57261 57262 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57260 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationAutoTransformation
Training pipeline will infer the proper transformation based on the statistic
of dataset.
Corresponds to the JSON property auto
57191 57192 57193 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57191 def auto @auto end |
#categorical ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalTransformation
Training pipeline will perform following transformation functions. * The
categorical string as is--no change to case, punctuation, spelling, tense, and
so on. * Convert the category name to a dictionary lookup index and generate
an embedding for each index. * Categories that appear less than 5 times in the
training dataset are treated as the "unknown" category. The "unknown" category
gets its own special lookup index and resulting embedding.
Corresponds to the JSON property categorical
57201 57202 57203 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57201 def categorical @categorical end |
#numeric ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericTransformation
Training pipeline will perform following transformation functions. * The value
converted to float32. * The z_score of the value. * log(value+1) when the
value is greater than or equal to 0. Otherwise, this transformation is not
applied and the value is considered a missing value. * z_score of log(value+1)
when the value is greater than or equal to 0. Otherwise, this transformation
is not applied and the value is considered a missing value. * A boolean value
that indicates whether the value is valid.
Corresponds to the JSON property numeric
57212 57213 57214 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57212 def numeric @numeric end |
#repeated_categorical ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalArrayTransformation
Treats the column as categorical array and performs following transformation
functions. * For each element in the array, convert the category name to a
dictionary lookup index and generate an embedding for each index. Combine the
embedding of all elements into a single embedding using the mean. * Empty
arrays treated as an embedding of zeroes.
Corresponds to the JSON property repeatedCategorical
57221 57222 57223 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57221 def repeated_categorical @repeated_categorical end |
#repeated_numeric ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericArrayTransformation
Treats the column as numerical array and performs following transformation
functions. * All transformations for Numerical types applied to the average of
the all elements. * The average of empty arrays is treated as zero.
Corresponds to the JSON property repeatedNumeric
57228 57229 57230 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57228 def repeated_numeric @repeated_numeric end |
#repeated_text ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation
Treats the column as text array and performs following transformation
functions. * Concatenate all text values in the array into a single text value
using a space (" ") as a delimiter, and then treat the result as a single text
value. Apply the transformations for Text columns. * Empty arrays treated as
an empty text.
Corresponds to the JSON property repeatedText
57237 57238 57239 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57237 def repeated_text @repeated_text end |
#text ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextTransformation
Training pipeline will perform following transformation functions. * The text as is--no change to case, punctuation, spelling, tense, and so on. * Tokenize text to words. Convert each words to a dictionary lookup index and generate an embedding for each index. Combine the embedding of all elements into a single embedding using the mean. * Tokenization is based on unicode script boundaries.
- Missing values get their own lookup index and resulting embedding. * Stop-
words receive no special treatment and are not removed.
Corresponds to the JSON property
text
57248 57249 57250 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57248 def text @text end |
#timestamp ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTimestampTransformation
Training pipeline will perform following transformation functions. * Apply the transformation functions for Numerical columns. * Determine the year, month, day,and weekday. Treat each value from the * timestamp as a Categorical column.
- Invalid numerical values (for example, values that fall outside of a
typical timestamp range, or are extreme values) receive no special treatment
and are not removed.
Corresponds to the JSON property
timestamp
57258 57259 57260 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57258 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57265 57266 57267 57268 57269 57270 57271 57272 57273 57274 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57265 def update!(**args) @auto = args[:auto] if args.key?(:auto) @categorical = args[:categorical] if args.key?(:categorical) @numeric = args[:numeric] if args.key?(:numeric) @repeated_categorical = args[:repeated_categorical] if args.key?(:repeated_categorical) @repeated_numeric = args[:repeated_numeric] if args.key?(:repeated_numeric) @repeated_text = args[:repeated_text] if args.key?(:repeated_text) @text = args[:text] if args.key?(:text) @timestamp = args[:timestamp] if args.key?(:timestamp) end |