Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Configuration for exporting test set predictions to a BigQuery table.
Instance Attribute Summary collapse
-
#destination_bigquery_uri ⇒ String
URI of desired destination BigQuery table.
-
#override_existing_table ⇒ Boolean
(also: #override_existing_table?)
If true and an export destination is specified, then the contents of the destination are overwritten.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig.
57867 57868 57869 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_bigquery_uri ⇒ String
URI of desired destination BigQuery table. Expected format: bq://project_id:
dataset_id:tableIf not specified, then results are exported to the
following auto-created BigQuery table:project_id:
export_evaluated_examples_model_name_yyyy_MM_dd'T'HH_mm_ss_SSS'Z'.
evaluated_examples
Corresponds to the JSON property destinationBigqueryUri
57857 57858 57859 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57857 def destination_bigquery_uri @destination_bigquery_uri end |
#override_existing_table ⇒ Boolean Also known as: override_existing_table?
If true and an export destination is specified, then the contents of the
destination are overwritten. Otherwise, if the export destination already
exists, then the export operation fails.
Corresponds to the JSON property overrideExistingTable
57864 57865 57866 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57864 def override_existing_table @override_existing_table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57872 57873 57874 57875 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57872 def update!(**args) @destination_bigquery_uri = args[:destination_bigquery_uri] if args.key?(:destination_bigquery_uri) @override_existing_table = args[:override_existing_table] if args.key?(:override_existing_table) end |