Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#max_failed_trial_count ⇒ Fixnum
The number of failed Trials that need to be seen before failing the HyperparameterTuningJob.
-
#max_trial_count ⇒ Fixnum
The desired total number of Trials.
-
#parallel_trial_count ⇒ Fixnum
The desired number of Trials to run in parallel.
-
#study_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpec
Represents specification of a Study.
-
#trial_job_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomJobSpec
Represents the spec of a CustomJob.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec.
56137 56138 56139 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56137 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_failed_trial_count ⇒ Fixnum
The number of failed Trials that need to be seen before failing the
HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must
fail before the whole job fails.
Corresponds to the JSON property maxFailedTrialCount
56115 56116 56117 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56115 def max_failed_trial_count @max_failed_trial_count end |
#max_trial_count ⇒ Fixnum
The desired total number of Trials.
Corresponds to the JSON property maxTrialCount
56120 56121 56122 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56120 def max_trial_count @max_trial_count end |
#parallel_trial_count ⇒ Fixnum
The desired number of Trials to run in parallel.
Corresponds to the JSON property parallelTrialCount
56125 56126 56127 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56125 def parallel_trial_count @parallel_trial_count end |
#study_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpec
Represents specification of a Study.
Corresponds to the JSON property studySpec
56130 56131 56132 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56130 def study_spec @study_spec end |
#trial_job_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CustomJobSpec
Represents the spec of a CustomJob.
Corresponds to the JSON property trialJobSpec
56135 56136 56137 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56135 def trial_job_spec @trial_job_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56142 56143 56144 56145 56146 56147 56148 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56142 def update!(**args) @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count) @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count) @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count) @study_spec = args[:study_spec] if args.key?(:study_spec) @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec) end |