Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionWindowConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Config that contains the strategy used to generate sliding windows in time series training. A window is a series of rows that comprise the context up to the time of prediction, and the horizon following. The corresponding row for each window marks the start of the forecast horizon. Each window is used as an input example for training/evaluation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionWindowConfig

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaTrainingjobDefinitionWindowConfig.



49441
49442
49443
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

Name of the column that should be used to generate sliding windows. The column should contain either booleans or string booleans; if the value of the row is True, generate a sliding window with the horizon starting at that row. The column will not be used as a feature in training. Corresponds to the JSON property column

Returns:

  • (String)


49428
49429
49430
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49428

def column
  @column
end

#max_countFixnum

Maximum number of windows that should be generated across all time series. Corresponds to the JSON property maxCount

Returns:

  • (Fixnum)


49433
49434
49435
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49433

def max_count
  @max_count
end

#stride_lengthFixnum

Stride length used to generate input examples. Within one time series, every $ STRIDE_LENGTH rows will be used to generate a sliding window. Corresponds to the JSON property strideLength

Returns:

  • (Fixnum)


49439
49440
49441
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49439

def stride_length
  @stride_length
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49446
49447
49448
49449
49450
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49446

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @max_count = args[:max_count] if args.key?(:max_count)
  @stride_length = args[:stride_length] if args.key?(:stride_length)
end