Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaVertex
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaVertex
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a 2D point in the image. Vertex coordinates are normalized to be relative to the original image dimensions and range from 0 to 1. The origin of the coordinate system (0,0) is the top-left corner of the image. x increases to the right, and y increases to the bottom.
Instance Attribute Summary collapse
-
#x ⇒ Float
X coordinate of the vertex, normalized to [0.0, 1.0].
-
#y ⇒ Float
Y coordinate of the vertex, normalized to [0.0, 1.0].
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaVertex
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaVertex.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaVertex
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaVertex.
54380 54381 54382 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54380 def initialize(**args) update!(**args) end |
Instance Attribute Details
#x ⇒ Float
X coordinate of the vertex, normalized to [0.0, 1.0].
Corresponds to the JSON property x
54373 54374 54375 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54373 def x @x end |
#y ⇒ Float
Y coordinate of the vertex, normalized to [0.0, 1.0].
Corresponds to the JSON property y
54378 54379 54380 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54378 def y @y end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54385 54386 54387 54388 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54385 def update!(**args) @x = args[:x] if args.key?(:x) @y = args[:y] if args.key?(:y) end |