Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaVertex
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaVertex
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a 2D point in the image. Vertex coordinates are normalized to be relative to the original image dimensions and range from 0 to 1. The origin of the coordinate system (0,0) is the top-left corner of the image. x increases to the right, and y increases to the bottom.
Instance Attribute Summary collapse
-
#x ⇒ Float
X coordinate of the vertex, normalized to [0.0, 1.0].
-
#y ⇒ Float
Y coordinate of the vertex, normalized to [0.0, 1.0].
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaVertex
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaVertex.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaVertex
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaVertex.
49339 49340 49341 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49339 def initialize(**args) update!(**args) end |
Instance Attribute Details
#x ⇒ Float
X coordinate of the vertex, normalized to [0.0, 1.0].
Corresponds to the JSON property x
49332 49333 49334 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49332 def x @x end |
#y ⇒ Float
Y coordinate of the vertex, normalized to [0.0, 1.0].
Corresponds to the JSON property y
49337 49338 49339 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49337 def y @y end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49344 49345 49346 49347 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49344 def update!(**args) @x = args[:x] if args.key?(:x) @y = args[:y] if args.key?(:y) end |