Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Annotation details specific to video object tracking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation.



57315
57316
57317
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_idString

The resource Id of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property annotationSpecId

Returns:

  • (String)


57276
57277
57278
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57276

def annotation_spec_id
  @annotation_spec_id
end

#display_nameString

The display name of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property displayName

Returns:

  • (String)


57281
57282
57283
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57281

def display_name
  @display_name
end

#instance_idFixnum

The instance of the object, expressed as a positive integer. Used to track the same object across different frames. Corresponds to the JSON property instanceId

Returns:

  • (Fixnum)


57287
57288
57289
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57287

def instance_id
  @instance_id
end

#time_offsetString

A time (frame) of a video to which this annotation pertains. Represented as the duration since the video's start. Corresponds to the JSON property timeOffset

Returns:

  • (String)


57293
57294
57295
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57293

def time_offset
  @time_offset
end

#x_maxFloat

The rightmost coordinate of the bounding box. Corresponds to the JSON property xMax

Returns:

  • (Float)


57298
57299
57300
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57298

def x_max
  @x_max
end

#x_minFloat

The leftmost coordinate of the bounding box. Corresponds to the JSON property xMin

Returns:

  • (Float)


57303
57304
57305
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57303

def x_min
  @x_min
end

#y_maxFloat

The bottommost coordinate of the bounding box. Corresponds to the JSON property yMax

Returns:

  • (Float)


57308
57309
57310
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57308

def y_max
  @y_max
end

#y_minFloat

The topmost coordinate of the bounding box. Corresponds to the JSON property yMin

Returns:

  • (Float)


57313
57314
57315
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57313

def y_min
  @y_min
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57320
57321
57322
57323
57324
57325
57326
57327
57328
57329
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57320

def update!(**args)
  @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
  @x_max = args[:x_max] if args.key?(:x_max)
  @x_min = args[:x_min] if args.key?(:x_min)
  @y_max = args[:y_max] if args.key?(:y_max)
  @y_min = args[:y_min] if args.key?(:y_min)
end