Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Annotation details specific to video object tracking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation

Returns a new instance of GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation.



55736
55737
55738
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_idString

The resource Id of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property annotationSpecId

Returns:

  • (String)


55697
55698
55699
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55697

def annotation_spec_id
  @annotation_spec_id
end

#display_nameString

The display name of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property displayName

Returns:

  • (String)


55702
55703
55704
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55702

def display_name
  @display_name
end

#instance_idFixnum

The instance of the object, expressed as a positive integer. Used to track the same object across different frames. Corresponds to the JSON property instanceId

Returns:

  • (Fixnum)


55708
55709
55710
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55708

def instance_id
  @instance_id
end

#time_offsetString

A time (frame) of a video to which this annotation pertains. Represented as the duration since the video's start. Corresponds to the JSON property timeOffset

Returns:

  • (String)


55714
55715
55716
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55714

def time_offset
  @time_offset
end

#x_maxFloat

The rightmost coordinate of the bounding box. Corresponds to the JSON property xMax

Returns:

  • (Float)


55719
55720
55721
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55719

def x_max
  @x_max
end

#x_minFloat

The leftmost coordinate of the bounding box. Corresponds to the JSON property xMin

Returns:

  • (Float)


55724
55725
55726
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55724

def x_min
  @x_min
end

#y_maxFloat

The bottommost coordinate of the bounding box. Corresponds to the JSON property yMax

Returns:

  • (Float)


55729
55730
55731
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55729

def y_max
  @y_max
end

#y_minFloat

The topmost coordinate of the bounding box. Corresponds to the JSON property yMin

Returns:

  • (Float)


55734
55735
55736
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55734

def y_min
  @y_min
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55741
55742
55743
55744
55745
55746
55747
55748
55749
55750
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55741

def update!(**args)
  @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
  @x_max = args[:x_max] if args.key?(:x_max)
  @x_min = args[:x_min] if args.key?(:x_min)
  @y_max = args[:y_max] if args.key?(:y_max)
  @y_min = args[:y_min] if args.key?(:y_min)
end