Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Annotation details specific to video object tracking.
Instance Attribute Summary collapse
-
#annotation_spec_id ⇒ String
The resource Id of the AnnotationSpec that this Annotation pertains to.
-
#display_name ⇒ String
The display name of the AnnotationSpec that this Annotation pertains to.
-
#instance_id ⇒ Fixnum
The instance of the object, expressed as a positive integer.
-
#time_offset ⇒ String
A time (frame) of a video to which this annotation pertains.
-
#x_max ⇒ Float
The rightmost coordinate of the bounding box.
-
#x_min ⇒ Float
The leftmost coordinate of the bounding box.
-
#y_max ⇒ Float
The bottommost coordinate of the bounding box.
-
#y_min ⇒ Float
The topmost coordinate of the bounding box.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation
constructor
A new instance of GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation
Returns a new instance of GoogleCloudAiplatformV1beta1SchemaVideoObjectTrackingAnnotation.
54553 54554 54555 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_spec_id ⇒ String
The resource Id of the AnnotationSpec that this Annotation pertains to.
Corresponds to the JSON property annotationSpecId
54514 54515 54516 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54514 def annotation_spec_id @annotation_spec_id end |
#display_name ⇒ String
The display name of the AnnotationSpec that this Annotation pertains to.
Corresponds to the JSON property displayName
54519 54520 54521 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54519 def display_name @display_name end |
#instance_id ⇒ Fixnum
The instance of the object, expressed as a positive integer. Used to track the
same object across different frames.
Corresponds to the JSON property instanceId
54525 54526 54527 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54525 def instance_id @instance_id end |
#time_offset ⇒ String
A time (frame) of a video to which this annotation pertains. Represented as
the duration since the video's start.
Corresponds to the JSON property timeOffset
54531 54532 54533 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54531 def time_offset @time_offset end |
#x_max ⇒ Float
The rightmost coordinate of the bounding box.
Corresponds to the JSON property xMax
54536 54537 54538 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54536 def x_max @x_max end |
#x_min ⇒ Float
The leftmost coordinate of the bounding box.
Corresponds to the JSON property xMin
54541 54542 54543 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54541 def x_min @x_min end |
#y_max ⇒ Float
The bottommost coordinate of the bounding box.
Corresponds to the JSON property yMax
54546 54547 54548 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54546 def y_max @y_max end |
#y_min ⇒ Float
The topmost coordinate of the bounding box.
Corresponds to the JSON property yMin
54551 54552 54553 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54551 def y_min @y_min end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54558 54559 54560 54561 54562 54563 54564 54565 54566 54567 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54558 def update!(**args) @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id) @display_name = args[:display_name] if args.key?(:display_name) @instance_id = args[:instance_id] if args.key?(:instance_id) @time_offset = args[:time_offset] if args.key?(:time_offset) @x_max = args[:x_max] if args.key?(:x_max) @x_min = args[:x_min] if args.key?(:x_min) @y_max = args[:y_max] if args.key?(:y_max) @y_min = args[:y_min] if args.key?(:y_min) end |