Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchExamplesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ExampleStoreService.SearchExamples.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchExamplesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1SearchExamplesRequest.



57439
57440
57441
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stored_contents_example_parametersGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleParameters

The metadata filters that will be used to search StoredContentsExamples. If a field is unspecified, then no filtering for that field will be applied Corresponds to the JSON property storedContentsExampleParameters



57432
57433
57434
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57432

def stored_contents_example_parameters
  @stored_contents_example_parameters
end

#top_kFixnum

Optional. The number of similar examples to return. Corresponds to the JSON property topK

Returns:

  • (Fixnum)


57437
57438
57439
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57437

def top_k
  @top_k
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57444
57445
57446
57447
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57444

def update!(**args)
  @stored_contents_example_parameters = args[:stored_contents_example_parameters] if args.key?(:stored_contents_example_parameters)
  @top_k = args[:top_k] if args.key?(:top_k)
end