Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchExamplesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchExamplesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ExampleStoreService.SearchExamples.
Instance Attribute Summary collapse
-
#stored_contents_example_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleParameters
The metadata filters that will be used to search StoredContentsExamples.
-
#top_k ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchExamplesRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1SearchExamplesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchExamplesRequest
Returns a new instance of GoogleCloudAiplatformV1beta1SearchExamplesRequest.
54677 54678 54679 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54677 def initialize(**args) update!(**args) end |
Instance Attribute Details
#stored_contents_example_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleParameters
The metadata filters that will be used to search StoredContentsExamples. If a
field is unspecified, then no filtering for that field will be applied
Corresponds to the JSON property storedContentsExampleParameters
54670 54671 54672 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54670 def stored_contents_example_parameters @stored_contents_example_parameters end |
#top_k ⇒ Fixnum
Optional. The number of similar examples to return.
Corresponds to the JSON property topK
54675 54676 54677 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54675 def top_k @top_k end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54682 54683 54684 54685 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54682 def update!(**args) @stored_contents_example_parameters = args[:stored_contents_example_parameters] if args.key?(:stored_contents_example_parameters) @top_k = args[:top_k] if args.key?(:top_k) end |