Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The result of the similar example.
Instance Attribute Summary collapse
-
#example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example
The example that is similar to the searched query.
-
#similarity_score ⇒ Float
The similarity score of this example.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample
constructor
A new instance of GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample
Returns a new instance of GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample.
54721 54722 54723 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54721 def initialize(**args) update!(**args) end |
Instance Attribute Details
#example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example
The example that is similar to the searched query.
Corresponds to the JSON property example
54714 54715 54716 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54714 def example @example end |
#similarity_score ⇒ Float
The similarity score of this example.
Corresponds to the JSON property similarityScore
54719 54720 54721 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54719 def similarity_score @similarity_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54726 54727 54728 54729 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54726 def update!(**args) @example = args[:example] if args.key?(:example) @similarity_score = args[:similarity_score] if args.key?(:similarity_score) end |