Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The result of the similar example.
Instance Attribute Summary collapse
-
#example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example
The example that is similar to the searched query.
-
#similarity_score ⇒ Float
The similarity score of this example.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample
constructor
A new instance of GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample
Returns a new instance of GoogleCloudAiplatformV1beta1SearchExamplesResponseSimilarExample.
49680 49681 49682 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49680 def initialize(**args) update!(**args) end |
Instance Attribute Details
#example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example
The example that is similar to the searched query.
Corresponds to the JSON property example
49673 49674 49675 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49673 def example @example end |
#similarity_score ⇒ Float
The similarity score of this example.
Corresponds to the JSON property similarityScore
49678 49679 49680 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49678 def similarity_score @similarity_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49685 49686 49687 49688 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 49685 def update!(**args) @example = args[:example] if args.key?(:example) @similarity_score = args[:similarity_score] if args.key?(:similarity_score) end |