Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelDeploymentMonitoringStatsAnomaliesRequestStatsAnomaliesObjective

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Stats requested for specific objective.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchModelDeploymentMonitoringStatsAnomaliesRequestStatsAnomaliesObjective

Returns a new instance of GoogleCloudAiplatformV1beta1SearchModelDeploymentMonitoringStatsAnomaliesRequestStatsAnomaliesObjective.



56087
56088
56089
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#top_feature_countFixnum

If set, all attribution scores between SearchModelDeploymentMonitoringStatsAnomaliesRequest.start_time and SearchModelDeploymentMonitoringStatsAnomaliesRequest.end_time are fetched, and page token doesn't take effect in this case. Only used to retrieve attribution score for the top Features which has the highest attribution score in the latest monitoring run. Corresponds to the JSON property topFeatureCount

Returns:

  • (Fixnum)


56080
56081
56082
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56080

def top_feature_count
  @top_feature_count
end

#typeString

Corresponds to the JSON property type

Returns:

  • (String)


56085
56086
56087
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56085

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56092
56093
56094
56095
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56092

def update!(**args)
  @top_feature_count = args[:top_feature_count] if args.key?(:top_feature_count)
  @type = args[:type] if args.key?(:type)
end