Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ModelMonitoringService.SearchModelMonitoringAlerts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest

Returns a new instance of GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest.



59590
59591
59592
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59590

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alert_time_intervalGoogle::Apis::AiplatformV1beta1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property alertTimeInterval



59561
59562
59563
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59561

def alert_time_interval
  @alert_time_interval
end

#model_monitoring_jobString

If non-empty, returns the alerts of this model monitoring job. Corresponds to the JSON property modelMonitoringJob

Returns:

  • (String)


59566
59567
59568
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59566

def model_monitoring_job
  @model_monitoring_job
end

#objective_typeString

If non-empty, returns the alerts of this objective type. Supported monitoring objectives: raw-feature-drift prediction-output-drift feature-attribution Corresponds to the JSON property objectiveType

Returns:

  • (String)


59572
59573
59574
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59572

def objective_type
  @objective_type
end

#page_sizeFixnum

The standard list page size. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


59577
59578
59579
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59577

def page_size
  @page_size
end

#page_tokenString

A page token received from a previous ModelMonitoringService. SearchModelMonitoringAlerts call. Corresponds to the JSON property pageToken

Returns:

  • (String)


59583
59584
59585
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59583

def page_token
  @page_token
end

#stats_nameString

If non-empty, returns the alerts of this stats_name. Corresponds to the JSON property statsName

Returns:

  • (String)


59588
59589
59590
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59588

def stats_name
  @stats_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59595
59596
59597
59598
59599
59600
59601
59602
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59595

def update!(**args)
  @alert_time_interval = args[:alert_time_interval] if args.key?(:alert_time_interval)
  @model_monitoring_job = args[:model_monitoring_job] if args.key?(:model_monitoring_job)
  @objective_type = args[:objective_type] if args.key?(:objective_type)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @stats_name = args[:stats_name] if args.key?(:stats_name)
end