Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ModelMonitoringService.SearchModelMonitoringAlerts.
Instance Attribute Summary collapse
-
#alert_time_interval ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#model_monitoring_job ⇒ String
If non-empty, returns the alerts of this model monitoring job.
-
#objective_type ⇒ String
If non-empty, returns the alerts of this objective type.
-
#page_size ⇒ Fixnum
The standard list page size.
-
#page_token ⇒ String
A page token received from a previous ModelMonitoringService.
-
#stats_name ⇒ String
If non-empty, returns the alerts of this stats_name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest
Returns a new instance of GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest.
58351 58352 58353 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58351 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alert_time_interval ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property alertTimeInterval
58322 58323 58324 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58322 def alert_time_interval @alert_time_interval end |
#model_monitoring_job ⇒ String
If non-empty, returns the alerts of this model monitoring job.
Corresponds to the JSON property modelMonitoringJob
58327 58328 58329 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58327 def model_monitoring_job @model_monitoring_job end |
#objective_type ⇒ String
If non-empty, returns the alerts of this objective type. Supported monitoring
objectives: raw-feature-drift prediction-output-drift feature-attribution
Corresponds to the JSON property objectiveType
58333 58334 58335 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58333 def objective_type @objective_type end |
#page_size ⇒ Fixnum
The standard list page size.
Corresponds to the JSON property pageSize
58338 58339 58340 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58338 def page_size @page_size end |
#page_token ⇒ String
A page token received from a previous ModelMonitoringService.
SearchModelMonitoringAlerts call.
Corresponds to the JSON property pageToken
58344 58345 58346 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58344 def page_token @page_token end |
#stats_name ⇒ String
If non-empty, returns the alerts of this stats_name.
Corresponds to the JSON property statsName
58349 58350 58351 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58349 def stats_name @stats_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58356 58357 58358 58359 58360 58361 58362 58363 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58356 def update!(**args) @alert_time_interval = args[:alert_time_interval] if args.key?(:alert_time_interval) @model_monitoring_job = args[:model_monitoring_job] if args.key?(:model_monitoring_job) @objective_type = args[:objective_type] if args.key?(:objective_type) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @stats_name = args[:stats_name] if args.key?(:stats_name) end |