Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ModelMonitoringService.SearchModelMonitoringAlerts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest

Returns a new instance of GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsRequest.



57566
57567
57568
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alert_time_intervalGoogle::Apis::AiplatformV1beta1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property alertTimeInterval



57537
57538
57539
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57537

def alert_time_interval
  @alert_time_interval
end

#model_monitoring_jobString

If non-empty, returns the alerts of this model monitoring job. Corresponds to the JSON property modelMonitoringJob

Returns:

  • (String)


57542
57543
57544
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57542

def model_monitoring_job
  @model_monitoring_job
end

#objective_typeString

If non-empty, returns the alerts of this objective type. Supported monitoring objectives: raw-feature-drift prediction-output-drift feature-attribution Corresponds to the JSON property objectiveType

Returns:

  • (String)


57548
57549
57550
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57548

def objective_type
  @objective_type
end

#page_sizeFixnum

The standard list page size. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


57553
57554
57555
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57553

def page_size
  @page_size
end

#page_tokenString

A page token received from a previous ModelMonitoringService. SearchModelMonitoringAlerts call. Corresponds to the JSON property pageToken

Returns:

  • (String)


57559
57560
57561
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57559

def page_token
  @page_token
end

#stats_nameString

If non-empty, returns the alerts of this stats_name. Corresponds to the JSON property statsName

Returns:

  • (String)


57564
57565
57566
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57564

def stats_name
  @stats_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57571
57572
57573
57574
57575
57576
57577
57578
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57571

def update!(**args)
  @alert_time_interval = args[:alert_time_interval] if args.key?(:alert_time_interval)
  @model_monitoring_job = args[:model_monitoring_job] if args.key?(:model_monitoring_job)
  @objective_type = args[:objective_type] if args.key?(:objective_type)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @stats_name = args[:stats_name] if args.key?(:stats_name)
end