Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for ModelMonitoringService.SearchModelMonitoringAlerts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsResponse

Returns a new instance of GoogleCloudAiplatformV1beta1SearchModelMonitoringAlertsResponse.



56201
56202
56203
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#model_monitoring_alertsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelMonitoringAlert>

Alerts retrieved for the requested objectives. Sorted by alert time descendingly. Corresponds to the JSON property modelMonitoringAlerts



56188
56189
56190
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56188

def model_monitoring_alerts
  @model_monitoring_alerts
end

#next_page_tokenString

The page token that can be used by the next ModelMonitoringService. SearchModelMonitoringAlerts call. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56194
56195
56196
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56194

def next_page_token
  @next_page_token
end

#total_number_alertsFixnum

The total number of alerts retrieved by the requested objectives. Corresponds to the JSON property totalNumberAlerts

Returns:

  • (Fixnum)


56199
56200
56201
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56199

def total_number_alerts
  @total_number_alerts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56206
56207
56208
56209
56210
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56206

def update!(**args)
  @model_monitoring_alerts = args[:model_monitoring_alerts] if args.key?(:model_monitoring_alerts)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @total_number_alerts = args[:total_number_alerts] if args.key?(:total_number_alerts)
end