Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ModelMonitoringService.SearchModelMonitoringStats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsRequest

Returns a new instance of GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsRequest.



59730
59731
59732
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59730

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_sizeFixnum

The standard list page size. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


59709
59710
59711
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59709

def page_size
  @page_size
end

#page_tokenString

A page token received from a previous ModelMonitoringService. SearchModelMonitoringStats call. Corresponds to the JSON property pageToken

Returns:

  • (String)


59715
59716
59717
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59715

def page_token
  @page_token
end

#stats_filterGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsFilter

Filter for searching ModelMonitoringStats. Corresponds to the JSON property statsFilter



59720
59721
59722
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59720

def stats_filter
  @stats_filter
end

#time_intervalGoogle::Apis::AiplatformV1beta1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property timeInterval



59728
59729
59730
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59728

def time_interval
  @time_interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59735
59736
59737
59738
59739
59740
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59735

def update!(**args)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @stats_filter = args[:stats_filter] if args.key?(:stats_filter)
  @time_interval = args[:time_interval] if args.key?(:time_interval)
end