Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ModelMonitoringService.SearchModelMonitoringStats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsRequest

Returns a new instance of GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsRequest.



56305
56306
56307
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_sizeFixnum

The standard list page size. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


56284
56285
56286
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56284

def page_size
  @page_size
end

#page_tokenString

A page token received from a previous ModelMonitoringService. SearchModelMonitoringStats call. Corresponds to the JSON property pageToken

Returns:

  • (String)


56290
56291
56292
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56290

def page_token
  @page_token
end

#stats_filterGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsFilter

Filter for searching ModelMonitoringStats. Corresponds to the JSON property statsFilter



56295
56296
56297
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56295

def stats_filter
  @stats_filter
end

#time_intervalGoogle::Apis::AiplatformV1beta1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property timeInterval



56303
56304
56305
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56303

def time_interval
  @time_interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56310
56311
56312
56313
56314
56315
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56310

def update!(**args)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @stats_filter = args[:stats_filter] if args.key?(:stats_filter)
  @time_interval = args[:time_interval] if args.key?(:time_interval)
end