Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ModelMonitoringService.SearchModelMonitoringStats.
Instance Attribute Summary collapse
-
#page_size ⇒ Fixnum
The standard list page size.
-
#page_token ⇒ String
A page token received from a previous ModelMonitoringService.
-
#stats_filter ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsFilter
Filter for searching ModelMonitoringStats.
-
#time_interval ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsRequest
Returns a new instance of GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsRequest.
55122 55123 55124 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55122 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_size ⇒ Fixnum
The standard list page size.
Corresponds to the JSON property pageSize
55101 55102 55103 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55101 def page_size @page_size end |
#page_token ⇒ String
A page token received from a previous ModelMonitoringService.
SearchModelMonitoringStats call.
Corresponds to the JSON property pageToken
55107 55108 55109 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55107 def page_token @page_token end |
#stats_filter ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchModelMonitoringStatsFilter
Filter for searching ModelMonitoringStats.
Corresponds to the JSON property statsFilter
55112 55113 55114 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55112 def stats_filter @stats_filter end |
#time_interval ⇒ Google::Apis::AiplatformV1beta1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property timeInterval
55120 55121 55122 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55120 def time_interval @time_interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55127 55128 55129 55130 55131 55132 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55127 def update!(**args) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @stats_filter = args[:stats_filter] if args.key?(:stats_filter) @time_interval = args[:time_interval] if args.key?(:time_interval) end |