Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SearchNearestEntitiesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The request message for FeatureOnlineStoreService.SearchNearestEntities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SearchNearestEntitiesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1SearchNearestEntitiesRequest.



56362
56363
56364
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#queryGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NearestNeighborQuery

A query to find a number of similar entities. Corresponds to the JSON property query



56351
56352
56353
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56351

def query
  @query
end

#return_full_entityBoolean Also known as: return_full_entity?

Optional. If set to true, the full entities (including all vector values and metadata) of the nearest neighbors are returned; otherwise only entity id of the nearest neighbors will be returned. Note that returning full entities will significantly increase the latency and cost of the query. Corresponds to the JSON property returnFullEntity

Returns:

  • (Boolean)


56359
56360
56361
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56359

def return_full_entity
  @return_full_entity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56367
56368
56369
56370
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56367

def update!(**args)
  @query = args[:query] if args.key?(:query)
  @return_full_entity = args[:return_full_entity] if args.key?(:return_full_entity)
end