Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SecretEnvVar

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents an environment variable where the value is a secret in Cloud Secret Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SecretEnvVar

Returns a new instance of GoogleCloudAiplatformV1beta1SecretEnvVar.



58594
58595
58596
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58594

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. Name of the secret environment variable. Corresponds to the JSON property name

Returns:

  • (String)


58586
58587
58588
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58586

def name
  @name
end

#secret_refGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SecretRef

Reference to a secret stored in the Cloud Secret Manager that will provide the value for this environment variable. Corresponds to the JSON property secretRef



58592
58593
58594
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58592

def secret_ref
  @secret_ref
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58599
58600
58601
58602
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58599

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @secret_ref = args[:secret_ref] if args.key?(:secret_ref)
end