Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SecretEnvVar
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SecretEnvVar
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents an environment variable where the value is a secret in Cloud Secret Manager.
Instance Attribute Summary collapse
-
#name ⇒ String
Required.
-
#secret_ref ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SecretRef
Reference to a secret stored in the Cloud Secret Manager that will provide the value for this environment variable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SecretEnvVar
constructor
A new instance of GoogleCloudAiplatformV1beta1SecretEnvVar.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SecretEnvVar
Returns a new instance of GoogleCloudAiplatformV1beta1SecretEnvVar.
50184 50185 50186 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50184 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Required. Name of the secret environment variable.
Corresponds to the JSON property name
50176 50177 50178 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50176 def name @name end |
#secret_ref ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SecretRef
Reference to a secret stored in the Cloud Secret Manager that will provide the
value for this environment variable.
Corresponds to the JSON property secretRef
50182 50183 50184 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50182 def secret_ref @secret_ref end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50189 50190 50191 50192 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50189 def update!(**args) @name = args[:name] if args.key?(:name) @secret_ref = args[:secret_ref] if args.key?(:secret_ref) end |