Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SecretRef
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SecretRef
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Reference to a secret stored in the Cloud Secret Manager that will provide the value for this environment variable.
Instance Attribute Summary collapse
-
#secret ⇒ String
Required.
-
#version ⇒ String
The Cloud Secret Manager secret version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SecretRef
constructor
A new instance of GoogleCloudAiplatformV1beta1SecretRef.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SecretRef
Returns a new instance of GoogleCloudAiplatformV1beta1SecretRef.
50212 50213 50214 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50212 def initialize(**args) update!(**args) end |
Instance Attribute Details
#secret ⇒ String
Required. The name of the secret in Cloud Secret Manager. Format: secret_name
.
Corresponds to the JSON property secret
50204 50205 50206 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50204 def secret @secret end |
#version ⇒ String
The Cloud Secret Manager secret version. Can be 'latest' for the latest
version, an integer for a specific version, or a version alias.
Corresponds to the JSON property version
50210 50211 50212 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50210 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50217 50218 50219 50220 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50217 def update!(**args) @secret = args[:secret] if args.key?(:secret) @version = args[:version] if args.key?(:version) end |