Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Segment
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Segment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A segment of the content.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
Output only.
-
#part_index ⇒ Fixnum
Output only.
-
#start_index ⇒ Fixnum
Output only.
-
#text ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Segment
constructor
A new instance of GoogleCloudAiplatformV1beta1Segment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Segment
Returns a new instance of GoogleCloudAiplatformV1beta1Segment.
60473 60474 60475 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60473 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
Output only. The end index of the segment in the Part, measured in bytes.
This marks the end of the segment and is exclusive, meaning the segment
includes content up to, but not including, the byte at this index.
Corresponds to the JSON property endIndex
60453 60454 60455 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60453 def end_index @end_index end |
#part_index ⇒ Fixnum
Output only. The index of the Part object that this segment belongs to. This
is useful for associating the segment with a specific part of the content.
Corresponds to the JSON property partIndex
60459 60460 60461 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60459 def part_index @part_index end |
#start_index ⇒ Fixnum
Output only. The start index of the segment in the Part, measured in bytes.
This marks the beginning of the segment and is inclusive, meaning the byte at
this index is the first byte of the segment.
Corresponds to the JSON property startIndex
60466 60467 60468 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60466 def start_index @start_index end |
#text ⇒ String
Output only. The text of the segment.
Corresponds to the JSON property text
60471 60472 60473 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60471 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60478 60479 60480 60481 60482 60483 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60478 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @part_index = args[:part_index] if args.key?(:part_index) @start_index = args[:start_index] if args.key?(:start_index) @text = args[:text] if args.key?(:text) end |