Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SemanticGovernancePolicy
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SemanticGovernancePolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a governance policy applied to a specific Agent and optionally a specific Tool within that Agent.
Instance Attribute Summary collapse
-
#agent ⇒ String
Required.
-
#agent_identity ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#mcp_tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SemanticGovernancePolicyMcpTool>
Optional.
-
#name ⇒ String
Identifier.
-
#natural_language_constraint ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SemanticGovernancePolicy
constructor
A new instance of GoogleCloudAiplatformV1beta1SemanticGovernancePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SemanticGovernancePolicy
Returns a new instance of GoogleCloudAiplatformV1beta1SemanticGovernancePolicy.
60549 60550 60551 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60549 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent ⇒ String
Required. The name of the agent in Agent Registry that is affected by this
policy.
Corresponds to the JSON property agent
60495 60496 60497 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60495 def agent @agent end |
#agent_identity ⇒ String
Output only. Represents the principal of the agent, used by the Policy
Decision Point (PDP) for governance checks. For more information, see https://
docs.cloud.google.com/agent-builder/agent-engine/agent-identity Format:
principal://TRUST_DOMAIN/NAMESPACE/AGENT_NAME Example: principal://agents.
global.org-ORGANIZATION_ID.system.id.goog/resources/aiplatform/projects/
PROJECT_NUMBER/locations/LOCATION/reasoningEngines/AGENT_ENGINE_ID
Corresponds to the JSON property agentIdentity
60505 60506 60507 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60505 def agent_identity @agent_identity end |
#create_time ⇒ String
Output only. Timestamp when this SemanticGovernancePolicy was created.
Corresponds to the JSON property createTime
60510 60511 60512 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60510 def create_time @create_time end |
#description ⇒ String
Optional. The description of the SemanticGovernancePolicy.
Corresponds to the JSON property description
60515 60516 60517 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60515 def description @description end |
#display_name ⇒ String
Optional. The user-defined name of the SemanticGovernancePolicy.
Corresponds to the JSON property displayName
60520 60521 60522 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60520 def display_name @display_name end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write transactions. If
provided, the request will only succeed if the etag matches the current value.
Otherwise, an ABORTED error will be returned.
Corresponds to the JSON property etag
60527 60528 60529 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60527 def etag @etag end |
#mcp_tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SemanticGovernancePolicyMcpTool>
Optional. The McpTools that are affected by this policy.
Corresponds to the JSON property mcpTools
60532 60533 60534 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60532 def mcp_tools @mcp_tools end |
#name ⇒ String
Identifier. Resource name of the SemanticGovernancePolicy.
Corresponds to the JSON property name
60537 60538 60539 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60537 def name @name end |
#natural_language_constraint ⇒ String
Required. The natural language constraint of the SemanticGovernancePolicy.
Corresponds to the JSON property naturalLanguageConstraint
60542 60543 60544 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60542 def natural_language_constraint @natural_language_constraint end |
#update_time ⇒ String
Output only. Timestamp when this SemanticGovernancePolicy was last updated.
Corresponds to the JSON property updateTime
60547 60548 60549 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60547 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60554 60555 60556 60557 60558 60559 60560 60561 60562 60563 60564 60565 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60554 def update!(**args) @agent = args[:agent] if args.key?(:agent) @agent_identity = args[:agent_identity] if args.key?(:agent_identity) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @mcp_tools = args[:mcp_tools] if args.key?(:mcp_tools) @name = args[:name] if args.key?(:name) @natural_language_constraint = args[:natural_language_constraint] if args.key?(:natural_language_constraint) @update_time = args[:update_time] if args.key?(:update_time) end |