Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SemanticGovernancePolicy
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SemanticGovernancePolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a governance policy applied to a specific Agent and optionally a specific Tool within that Agent.
Instance Attribute Summary collapse
-
#agent ⇒ String
Required.
-
#agent_identity ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#mcp_tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SemanticGovernancePolicyMcpTool>
Optional.
-
#name ⇒ String
Identifier.
-
#natural_language_constraint ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SemanticGovernancePolicy
constructor
A new instance of GoogleCloudAiplatformV1beta1SemanticGovernancePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SemanticGovernancePolicy
Returns a new instance of GoogleCloudAiplatformV1beta1SemanticGovernancePolicy.
58131 58132 58133 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58131 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent ⇒ String
Required. The name of the agent in Agent Registry that is affected by this
policy.
Corresponds to the JSON property agent
58077 58078 58079 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58077 def agent @agent end |
#agent_identity ⇒ String
Output only. Represents the principal of the agent, used by the Policy
Decision Point (PDP) for governance checks. For more information, see https://
docs.cloud.google.com/agent-builder/agent-engine/agent-identity Format:
principal://TRUST_DOMAIN/NAMESPACE/AGENT_NAME Example: principal://agents.
global.org-ORGANIZATION_ID.system.id.goog/resources/aiplatform/projects/
PROJECT_NUMBER/locations/LOCATION/reasoningEngines/AGENT_ENGINE_ID
Corresponds to the JSON property agentIdentity
58087 58088 58089 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58087 def agent_identity @agent_identity end |
#create_time ⇒ String
Output only. Timestamp when this SemanticGovernancePolicy was created.
Corresponds to the JSON property createTime
58092 58093 58094 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58092 def create_time @create_time end |
#description ⇒ String
Optional. The description of the SemanticGovernancePolicy.
Corresponds to the JSON property description
58097 58098 58099 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58097 def description @description end |
#display_name ⇒ String
Optional. The user-defined name of the SemanticGovernancePolicy.
Corresponds to the JSON property displayName
58102 58103 58104 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58102 def display_name @display_name end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write transactions. If
provided, the request will only succeed if the etag matches the current value.
Otherwise, an ABORTED error will be returned.
Corresponds to the JSON property etag
58109 58110 58111 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58109 def etag @etag end |
#mcp_tools ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SemanticGovernancePolicyMcpTool>
Optional. The McpTools that are affected by this policy.
Corresponds to the JSON property mcpTools
58114 58115 58116 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58114 def mcp_tools @mcp_tools end |
#name ⇒ String
Identifier. Resource name of the SemanticGovernancePolicy.
Corresponds to the JSON property name
58119 58120 58121 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58119 def name @name end |
#natural_language_constraint ⇒ String
Required. The natural language constraint of the SemanticGovernancePolicy.
Corresponds to the JSON property naturalLanguageConstraint
58124 58125 58126 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58124 def natural_language_constraint @natural_language_constraint end |
#update_time ⇒ String
Output only. Timestamp when this SemanticGovernancePolicy was last updated.
Corresponds to the JSON property updateTime
58129 58130 58131 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58129 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58136 58137 58138 58139 58140 58141 58142 58143 58144 58145 58146 58147 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58136 def update!(**args) @agent = args[:agent] if args.key?(:agent) @agent_identity = args[:agent_identity] if args.key?(:agent_identity) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @mcp_tools = args[:mcp_tools] if args.key?(:mcp_tools) @name = args[:name] if args.key?(:name) @natural_language_constraint = args[:natural_language_constraint] if args.key?(:natural_language_constraint) @update_time = args[:update_time] if args.key?(:update_time) end |