Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SemanticGovernancePolicyEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Define a singleton SemanticGovernancePolicyEngine resource under a project and location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SemanticGovernancePolicyEngine

Returns a new instance of GoogleCloudAiplatformV1beta1SemanticGovernancePolicyEngine.



56630
56631
56632
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56630

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this SemanticGovernancePolicyEngine was created. Corresponds to the JSON property createTime

Returns:

  • (String)


56579
56580
56581
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56579

def create_time
  @create_time
end

#gateway_configsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GatewayConfig>

Optional. Configurations for gateways. The keys are user-defined names for each gateway. Corresponds to the JSON property gatewayConfigs



56585
56586
56587
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56585

def gateway_configs
  @gateway_configs
end

#ip_addressString

Output only. The private IPv4 address of the PSC endpoint. Corresponds to the JSON property ipAddress

Returns:

  • (String)


56590
56591
56592
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56590

def ip_address
  @ip_address
end

#nameString

Identifier. The resource name of the SemanticGovernancePolicyEngine. Format: projects/project/locations/location/semanticGovernancePolicyEngine Corresponds to the JSON property name

Returns:

  • (String)


56596
56597
56598
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56596

def name
  @name
end

#psc_forwarding_ruleString

Output only. The URI of the PSC endpoint resource created in customer project. Format: projects/project/regions/region/forwardingRules/forwarding_rule Corresponds to the JSON property pscForwardingRule

Returns:

  • (String)


56602
56603
56604
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56602

def psc_forwarding_rule
  @psc_forwarding_rule
end

#psc_service_attachmentString

Output only. URI of the PSC attachment resource provided by SGP. Format: projects/project/regions/region/serviceAttachments/service_attachment Corresponds to the JSON property pscServiceAttachment

Returns:

  • (String)


56608
56609
56610
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56608

def psc_service_attachment
  @psc_service_attachment
end

#stateString

Output only. The state of the SemanticGovernancePolicyEngine. Corresponds to the JSON property state

Returns:

  • (String)


56613
56614
56615
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56613

def state
  @state
end

#target_projectString

Optional. The project where network, subnetwork and dns resources are located. If not provided, it is assumed to be the same project of SemanticGovernancePolicyEngine. This field is for Shared VPC scenarios, where network resources may be in a target project and SGP engine in a service project. Corresponds to the JSON property targetProject

Returns:

  • (String)


56622
56623
56624
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56622

def target_project
  @target_project
end

#update_timeString

Output only. Timestamp when this SemanticGovernancePolicyEngine was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


56628
56629
56630
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56628

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56635
56636
56637
56638
56639
56640
56641
56642
56643
56644
56645
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56635

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @gateway_configs = args[:gateway_configs] if args.key?(:gateway_configs)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @name = args[:name] if args.key?(:name)
  @psc_forwarding_rule = args[:psc_forwarding_rule] if args.key?(:psc_forwarding_rule)
  @psc_service_attachment = args[:psc_service_attachment] if args.key?(:psc_service_attachment)
  @state = args[:state] if args.key?(:state)
  @target_project = args[:target_project] if args.key?(:target_project)
  @update_time = args[:update_time] if args.key?(:update_time)
end