Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SemanticGovernancePolicyMcpTool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a governance policy applied to MCP tools used by an Agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SemanticGovernancePolicyMcpTool

Returns a new instance of GoogleCloudAiplatformV1beta1SemanticGovernancePolicyMcpTool.



58057
58058
58059
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mcp_serverString

Required. The resource name of the McpServer in Agent Registry that is affected by this policy. Format: projects/project/locations/location/ mcpServers/mcp_server` Corresponds to the JSON propertymcpServer`

Returns:

  • (String)


58048
58049
58050
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58048

def mcp_server
  @mcp_server
end

#toolsArray<String>

Optional. The resource names of the McpTools used by the Agent that is affected by this policy. If not specified, the policy applies to all McpTools in the McpServer. Corresponds to the JSON property tools

Returns:

  • (Array<String>)


58055
58056
58057
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58055

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58062
58063
58064
58065
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58062

def update!(**args)
  @mcp_server = args[:mcp_server] if args.key?(:mcp_server)
  @tools = args[:tools] if args.key?(:tools)
end