Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ServiceAccountSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for the use of custom service account to run the workloads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ServiceAccountSpec

Returns a new instance of GoogleCloudAiplatformV1beta1ServiceAccountSpec.



50420
50421
50422
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50420

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_custom_service_accountBoolean Also known as: enable_custom_service_account?

Required. If true, custom user-managed service account is enforced to run any workloads (for example, Vertex Jobs) on the resource. Otherwise, uses the Vertex AI Custom Code Service Agent. Corresponds to the JSON property enableCustomServiceAccount

Returns:

  • (Boolean)


50406
50407
50408
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50406

def 
  @enable_custom_service_account
end

#service_accountString

Optional. Required when all below conditions are met * enable_custom_service_account is true; * any runtime is specified via ResourceRuntimeSpec on creation time, for example, Ray The users must have iam.serviceAccounts.actAs permission on this service account and then the specified runtime containers will run as it. Do not set this field if you want to submit jobs using custom service account to this PersistentResource after creation, but only specify the service_account inside the job. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


50418
50419
50420
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50418

def 
  @service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50425
50426
50427
50428
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50425

def update!(**args)
  @enable_custom_service_account = args[:enable_custom_service_account] if args.key?(:enable_custom_service_account)
  @service_account = args[:service_account] if args.key?(:service_account)
end