Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Session

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A session contains a set of actions between users and Vertex agents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Session

Returns a new instance of GoogleCloudAiplatformV1beta1Session.



60831
60832
60833
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60831

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the session was created. Corresponds to the JSON property createTime

Returns:

  • (String)


60782
60783
60784
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60782

def create_time
  @create_time
end

#display_nameString

Optional. The display name of the session. Corresponds to the JSON property displayName

Returns:

  • (String)


60787
60788
60789
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60787

def display_name
  @display_name
end

#expire_timeString

Optional. Timestamp of when this session is considered expired. This is * always* provided on output, regardless of what was sent on input. The minimum value is 24 hours from the time of creation. Corresponds to the JSON property expireTime

Returns:

  • (String)


60794
60795
60796
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60794

def expire_time
  @expire_time
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Sessions. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


60803
60804
60805
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60803

def labels
  @labels
end

#nameString

Identifier. The resource name of the session. Format: 'projects/project/ locations/location/reasoningEngines/reasoning_engine/sessions/session'. Corresponds to the JSON property name

Returns:

  • (String)


60809
60810
60811
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60809

def name
  @name
end

#session_stateHash<String,Object>

Optional. Session specific memory which stores key conversation points. Corresponds to the JSON property sessionState

Returns:

  • (Hash<String,Object>)


60814
60815
60816
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60814

def session_state
  @session_state
end

#ttlString

Optional. Input only. The TTL for this session. The minimum value is 24 hours. Corresponds to the JSON property ttl

Returns:

  • (String)


60819
60820
60821
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60819

def ttl
  @ttl
end

#update_timeString

Output only. Timestamp when the session was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


60824
60825
60826
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60824

def update_time
  @update_time
end

#user_idString

Required. Immutable. String id provided by the user Corresponds to the JSON property userId

Returns:

  • (String)


60829
60830
60831
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60829

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60836
60837
60838
60839
60840
60841
60842
60843
60844
60845
60846
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60836

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @session_state = args[:session_state] if args.key?(:session_state)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_id = args[:user_id] if args.key?(:user_id)
end