Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Session
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Session
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A session contains a set of actions between users and Vertex agents.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#expire_time ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Sessions.
-
#name ⇒ String
Identifier.
-
#session_state ⇒ Hash<String,Object>
Optional.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#user_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Session
constructor
A new instance of GoogleCloudAiplatformV1beta1Session.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Session
Returns a new instance of GoogleCloudAiplatformV1beta1Session.
58944 58945 58946 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58944 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when the session was created.
Corresponds to the JSON property createTime
58895 58896 58897 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58895 def create_time @create_time end |
#display_name ⇒ String
Optional. The display name of the session.
Corresponds to the JSON property displayName
58900 58901 58902 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58900 def display_name @display_name end |
#expire_time ⇒ String
Optional. Timestamp of when this session is considered expired. This is *
always* provided on output, regardless of what was sent on input. The minimum
value is 24 hours from the time of creation.
Corresponds to the JSON property expireTime
58907 58908 58909 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58907 def expire_time @expire_time end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Sessions. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
58916 58917 58918 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58916 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the session. Format: 'projects/project/
locations/location/reasoningEngines/reasoning_engine/sessions/session'.
Corresponds to the JSON property name
58922 58923 58924 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58922 def name @name end |
#session_state ⇒ Hash<String,Object>
Optional. Session specific memory which stores key conversation points.
Corresponds to the JSON property sessionState
58927 58928 58929 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58927 def session_state @session_state end |
#ttl ⇒ String
Optional. Input only. The TTL for this session. The minimum value is 24 hours.
Corresponds to the JSON property ttl
58932 58933 58934 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58932 def ttl @ttl end |
#update_time ⇒ String
Output only. Timestamp when the session was updated.
Corresponds to the JSON property updateTime
58937 58938 58939 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58937 def update_time @update_time end |
#user_id ⇒ String
Required. Immutable. String id provided by the user
Corresponds to the JSON property userId
58942 58943 58944 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58942 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58949 58950 58951 58952 58953 58954 58955 58956 58957 58958 58959 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58949 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @session_state = args[:session_state] if args.key?(:session_state) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) @user_id = args[:user_id] if args.key?(:user_id) end |