Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Session

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A session contains a set of actions between users and Vertex agents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Session

Returns a new instance of GoogleCloudAiplatformV1beta1Session.



50487
50488
50489
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the session was created. Corresponds to the JSON property createTime

Returns:

  • (String)


50438
50439
50440
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50438

def create_time
  @create_time
end

#display_nameString

Optional. The display name of the session. Corresponds to the JSON property displayName

Returns:

  • (String)


50443
50444
50445
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50443

def display_name
  @display_name
end

#expire_timeString

Optional. Timestamp of when this session is considered expired. This is * always* provided on output, regardless of what was sent on input. The minimum value is 24 hours from the time of creation. Corresponds to the JSON property expireTime

Returns:

  • (String)


50450
50451
50452
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50450

def expire_time
  @expire_time
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Sessions. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


50459
50460
50461
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50459

def labels
  @labels
end

#nameString

Identifier. The resource name of the session. Format: 'projects/project/ locations/location/reasoningEngines/reasoning_engine/sessions/session'. Corresponds to the JSON property name

Returns:

  • (String)


50465
50466
50467
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50465

def name
  @name
end

#session_stateHash<String,Object>

Optional. Session specific memory which stores key conversation points. Corresponds to the JSON property sessionState

Returns:

  • (Hash<String,Object>)


50470
50471
50472
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50470

def session_state
  @session_state
end

#ttlString

Optional. Input only. The TTL for this session. The minimum value is 24 hours. Corresponds to the JSON property ttl

Returns:

  • (String)


50475
50476
50477
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50475

def ttl
  @ttl
end

#update_timeString

Output only. Timestamp when the session was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


50480
50481
50482
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50480

def update_time
  @update_time
end

#user_idString

Required. Immutable. String id provided by the user Corresponds to the JSON property userId

Returns:

  • (String)


50485
50486
50487
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50485

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50492
50493
50494
50495
50496
50497
50498
50499
50500
50501
50502
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50492

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @session_state = args[:session_state] if args.key?(:session_state)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_id = args[:user_id] if args.key?(:user_id)
end