Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SessionEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SessionEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An event represents a message from either the user or agent.
Instance Attribute Summary collapse
-
#actions ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EventActions
Actions are parts of events that are executed by the agent.
-
#author ⇒ String
Required.
-
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message.
-
#error_code ⇒ String
Optional.
-
#error_message ⇒ String
Optional.
-
#event_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EventMetadata
Metadata relating to a LLM response event.
-
#invocation_id ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#raw_event ⇒ Hash<String,Object>
Optional.
-
#timestamp ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SessionEvent
constructor
A new instance of GoogleCloudAiplatformV1beta1SessionEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SessionEvent
Returns a new instance of GoogleCloudAiplatformV1beta1SessionEvent.
58236 58237 58238 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EventActions
Actions are parts of events that are executed by the agent.
Corresponds to the JSON property actions
58184 58185 58186 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58184 def actions @actions end |
#author ⇒ String
Required. The name of the agent that sent the event, or user.
Corresponds to the JSON property author
58189 58190 58191 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58189 def @author end |
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
58196 58197 58198 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58196 def content @content end |
#error_code ⇒ String
Optional. Error code if the response is an error. Code varies by model.
Corresponds to the JSON property errorCode
58201 58202 58203 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58201 def error_code @error_code end |
#error_message ⇒ String
Optional. Error message if the response is an error.
Corresponds to the JSON property errorMessage
58206 58207 58208 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58206 def @error_message end |
#event_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EventMetadata
Metadata relating to a LLM response event.
Corresponds to the JSON property eventMetadata
58211 58212 58213 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58211 def @event_metadata end |
#invocation_id ⇒ String
Required. The invocation id of the event, multiple events can have the same
invocation id.
Corresponds to the JSON property invocationId
58217 58218 58219 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58217 def invocation_id @invocation_id end |
#name ⇒ String
Identifier. The resource name of the event. Format:projects/project/
locations/location/reasoningEngines/reasoning_engine/sessions/session/
events/event`.
Corresponds to the JSON propertyname`
58224 58225 58226 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58224 def name @name end |
#raw_event ⇒ Hash<String,Object>
Optional. Weakly typed raw event data in proto struct format.
Corresponds to the JSON property rawEvent
58229 58230 58231 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58229 def raw_event @raw_event end |
#timestamp ⇒ String
Required. Timestamp when the event was created on client side.
Corresponds to the JSON property timestamp
58234 58235 58236 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58234 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58241 58242 58243 58244 58245 58246 58247 58248 58249 58250 58251 58252 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58241 def update!(**args) @actions = args[:actions] if args.key?(:actions) @author = args[:author] if args.key?(:author) @content = args[:content] if args.key?(:content) @error_code = args[:error_code] if args.key?(:error_code) @error_message = args[:error_message] if args.key?(:error_message) @event_metadata = args[:event_metadata] if args.key?(:event_metadata) @invocation_id = args[:invocation_id] if args.key?(:invocation_id) @name = args[:name] if args.key?(:name) @raw_event = args[:raw_event] if args.key?(:raw_event) @timestamp = args[:timestamp] if args.key?(:timestamp) end |