Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An individual SharePointSource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource

Returns a new instance of GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource.



61026
61027
61028
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

The Application ID for the app registered in Microsoft Azure Portal. The application must also be configured with MS Graph permissions "Files.ReadAll", "Sites.ReadAll" and BrowserSiteLists.Read.All. Corresponds to the JSON property clientId

Returns:

  • (String)


60983
60984
60985
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60983

def client_id
  @client_id
end

#client_secretGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ApiAuthApiKeyConfig

The API secret. Corresponds to the JSON property clientSecret



60988
60989
60990
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60988

def client_secret
  @client_secret
end

#drive_idString

The ID of the drive to download from. Corresponds to the JSON property driveId

Returns:

  • (String)


60993
60994
60995
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60993

def drive_id
  @drive_id
end

#drive_nameString

The name of the drive to download from. Corresponds to the JSON property driveName

Returns:

  • (String)


60998
60999
61000
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60998

def drive_name
  @drive_name
end

#file_idString

Output only. The SharePoint file id. Output only. Corresponds to the JSON property fileId

Returns:

  • (String)


61003
61004
61005
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61003

def file_id
  @file_id
end

#sharepoint_folder_idString

The ID of the SharePoint folder to download from. Corresponds to the JSON property sharepointFolderId

Returns:

  • (String)


61008
61009
61010
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61008

def sharepoint_folder_id
  @sharepoint_folder_id
end

#sharepoint_folder_pathString

The path of the SharePoint folder to download from. Corresponds to the JSON property sharepointFolderPath

Returns:

  • (String)


61013
61014
61015
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61013

def sharepoint_folder_path
  @sharepoint_folder_path
end

#sharepoint_site_nameString

The name of the SharePoint site to download from. This can be the site name or the site id. Corresponds to the JSON property sharepointSiteName

Returns:

  • (String)


61019
61020
61021
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61019

def sharepoint_site_name
  @sharepoint_site_name
end

#tenant_idString

Unique identifier of the Azure Active Directory Instance. Corresponds to the JSON property tenantId

Returns:

  • (String)


61024
61025
61026
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61024

def tenant_id
  @tenant_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61031
61032
61033
61034
61035
61036
61037
61038
61039
61040
61041
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61031

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @drive_id = args[:drive_id] if args.key?(:drive_id)
  @drive_name = args[:drive_name] if args.key?(:drive_name)
  @file_id = args[:file_id] if args.key?(:file_id)
  @sharepoint_folder_id = args[:sharepoint_folder_id] if args.key?(:sharepoint_folder_id)
  @sharepoint_folder_path = args[:sharepoint_folder_path] if args.key?(:sharepoint_folder_path)
  @sharepoint_site_name = args[:sharepoint_site_name] if args.key?(:sharepoint_site_name)
  @tenant_id = args[:tenant_id] if args.key?(:tenant_id)
end