Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An individual SharePointSource.
Instance Attribute Summary collapse
-
#client_id ⇒ String
The Application ID for the app registered in Microsoft Azure Portal.
-
#client_secret ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ApiAuthApiKeyConfig
The API secret.
-
#drive_id ⇒ String
The ID of the drive to download from.
-
#drive_name ⇒ String
The name of the drive to download from.
-
#file_id ⇒ String
Output only.
-
#sharepoint_folder_id ⇒ String
The ID of the SharePoint folder to download from.
-
#sharepoint_folder_path ⇒ String
The path of the SharePoint folder to download from.
-
#sharepoint_site_name ⇒ String
The name of the SharePoint site to download from.
-
#tenant_id ⇒ String
Unique identifier of the Azure Active Directory Instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource
constructor
A new instance of GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource
Returns a new instance of GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource.
60454 60455 60456 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60454 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_id ⇒ String
The Application ID for the app registered in Microsoft Azure Portal. The
application must also be configured with MS Graph permissions "Files.ReadAll",
"Sites.ReadAll" and BrowserSiteLists.Read.All.
Corresponds to the JSON property clientId
60411 60412 60413 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60411 def client_id @client_id end |
#client_secret ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ApiAuthApiKeyConfig
The API secret.
Corresponds to the JSON property clientSecret
60416 60417 60418 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60416 def client_secret @client_secret end |
#drive_id ⇒ String
The ID of the drive to download from.
Corresponds to the JSON property driveId
60421 60422 60423 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60421 def drive_id @drive_id end |
#drive_name ⇒ String
The name of the drive to download from.
Corresponds to the JSON property driveName
60426 60427 60428 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60426 def drive_name @drive_name end |
#file_id ⇒ String
Output only. The SharePoint file id. Output only.
Corresponds to the JSON property fileId
60431 60432 60433 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60431 def file_id @file_id end |
#sharepoint_folder_id ⇒ String
The ID of the SharePoint folder to download from.
Corresponds to the JSON property sharepointFolderId
60436 60437 60438 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60436 def sharepoint_folder_id @sharepoint_folder_id end |
#sharepoint_folder_path ⇒ String
The path of the SharePoint folder to download from.
Corresponds to the JSON property sharepointFolderPath
60441 60442 60443 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60441 def sharepoint_folder_path @sharepoint_folder_path end |
#sharepoint_site_name ⇒ String
The name of the SharePoint site to download from. This can be the site name or
the site id.
Corresponds to the JSON property sharepointSiteName
60447 60448 60449 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60447 def sharepoint_site_name @sharepoint_site_name end |
#tenant_id ⇒ String
Unique identifier of the Azure Active Directory Instance.
Corresponds to the JSON property tenantId
60452 60453 60454 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60452 def tenant_id @tenant_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60459 60460 60461 60462 60463 60464 60465 60466 60467 60468 60469 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60459 def update!(**args) @client_id = args[:client_id] if args.key?(:client_id) @client_secret = args[:client_secret] if args.key?(:client_secret) @drive_id = args[:drive_id] if args.key?(:drive_id) @drive_name = args[:drive_name] if args.key?(:drive_name) @file_id = args[:file_id] if args.key?(:file_id) @sharepoint_folder_id = args[:sharepoint_folder_id] if args.key?(:sharepoint_folder_id) @sharepoint_folder_path = args[:sharepoint_folder_path] if args.key?(:sharepoint_folder_path) @sharepoint_site_name = args[:sharepoint_site_name] if args.key?(:sharepoint_site_name) @tenant_id = args[:tenant_id] if args.key?(:tenant_id) end |