Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An individual SharePointSource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource

Returns a new instance of GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource.



55583
55584
55585
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

The Application ID for the app registered in Microsoft Azure Portal. The application must also be configured with MS Graph permissions "Files.ReadAll", "Sites.ReadAll" and BrowserSiteLists.Read.All. Corresponds to the JSON property clientId

Returns:

  • (String)


55540
55541
55542
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55540

def client_id
  @client_id
end

#client_secretGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ApiAuthApiKeyConfig

The API secret. Corresponds to the JSON property clientSecret



55545
55546
55547
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55545

def client_secret
  @client_secret
end

#drive_idString

The ID of the drive to download from. Corresponds to the JSON property driveId

Returns:

  • (String)


55550
55551
55552
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55550

def drive_id
  @drive_id
end

#drive_nameString

The name of the drive to download from. Corresponds to the JSON property driveName

Returns:

  • (String)


55555
55556
55557
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55555

def drive_name
  @drive_name
end

#file_idString

Output only. The SharePoint file id. Output only. Corresponds to the JSON property fileId

Returns:

  • (String)


55560
55561
55562
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55560

def file_id
  @file_id
end

#sharepoint_folder_idString

The ID of the SharePoint folder to download from. Corresponds to the JSON property sharepointFolderId

Returns:

  • (String)


55565
55566
55567
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55565

def sharepoint_folder_id
  @sharepoint_folder_id
end

#sharepoint_folder_pathString

The path of the SharePoint folder to download from. Corresponds to the JSON property sharepointFolderPath

Returns:

  • (String)


55570
55571
55572
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55570

def sharepoint_folder_path
  @sharepoint_folder_path
end

#sharepoint_site_nameString

The name of the SharePoint site to download from. This can be the site name or the site id. Corresponds to the JSON property sharepointSiteName

Returns:

  • (String)


55576
55577
55578
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55576

def sharepoint_site_name
  @sharepoint_site_name
end

#tenant_idString

Unique identifier of the Azure Active Directory Instance. Corresponds to the JSON property tenantId

Returns:

  • (String)


55581
55582
55583
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55581

def tenant_id
  @tenant_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55588
55589
55590
55591
55592
55593
55594
55595
55596
55597
55598
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55588

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @drive_id = args[:drive_id] if args.key?(:drive_id)
  @drive_name = args[:drive_name] if args.key?(:drive_name)
  @file_id = args[:file_id] if args.key?(:file_id)
  @sharepoint_folder_id = args[:sharepoint_folder_id] if args.key?(:sharepoint_folder_id)
  @sharepoint_folder_path = args[:sharepoint_folder_path] if args.key?(:sharepoint_folder_path)
  @sharepoint_site_name = args[:sharepoint_site_name] if args.key?(:sharepoint_site_name)
  @tenant_id = args[:tenant_id] if args.key?(:tenant_id)
end