Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

An individual SharePointSource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource

Returns a new instance of GoogleCloudAiplatformV1beta1SharePointSourcesSharePointSource.



50542
50543
50544
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50542

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

The Application ID for the app registered in Microsoft Azure Portal. The application must also be configured with MS Graph permissions "Files.ReadAll", "Sites.ReadAll" and BrowserSiteLists.Read.All. Corresponds to the JSON property clientId

Returns:

  • (String)


50499
50500
50501
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50499

def client_id
  @client_id
end

#client_secretGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ApiAuthApiKeyConfig

The API secret. Corresponds to the JSON property clientSecret



50504
50505
50506
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50504

def client_secret
  @client_secret
end

#drive_idString

The ID of the drive to download from. Corresponds to the JSON property driveId

Returns:

  • (String)


50509
50510
50511
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50509

def drive_id
  @drive_id
end

#drive_nameString

The name of the drive to download from. Corresponds to the JSON property driveName

Returns:

  • (String)


50514
50515
50516
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50514

def drive_name
  @drive_name
end

#file_idString

Output only. The SharePoint file id. Output only. Corresponds to the JSON property fileId

Returns:

  • (String)


50519
50520
50521
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50519

def file_id
  @file_id
end

#sharepoint_folder_idString

The ID of the SharePoint folder to download from. Corresponds to the JSON property sharepointFolderId

Returns:

  • (String)


50524
50525
50526
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50524

def sharepoint_folder_id
  @sharepoint_folder_id
end

#sharepoint_folder_pathString

The path of the SharePoint folder to download from. Corresponds to the JSON property sharepointFolderPath

Returns:

  • (String)


50529
50530
50531
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50529

def sharepoint_folder_path
  @sharepoint_folder_path
end

#sharepoint_site_nameString

The name of the SharePoint site to download from. This can be the site name or the site id. Corresponds to the JSON property sharepointSiteName

Returns:

  • (String)


50535
50536
50537
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50535

def sharepoint_site_name
  @sharepoint_site_name
end

#tenant_idString

Unique identifier of the Azure Active Directory Instance. Corresponds to the JSON property tenantId

Returns:

  • (String)


50540
50541
50542
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50540

def tenant_id
  @tenant_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50547
50548
50549
50550
50551
50552
50553
50554
50555
50556
50557
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 50547

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @drive_id = args[:drive_id] if args.key?(:drive_id)
  @drive_name = args[:drive_name] if args.key?(:drive_name)
  @file_id = args[:file_id] if args.key?(:file_id)
  @sharepoint_folder_id = args[:sharepoint_folder_id] if args.key?(:sharepoint_folder_id)
  @sharepoint_folder_path = args[:sharepoint_folder_path] if args.key?(:sharepoint_folder_path)
  @sharepoint_site_name = args[:sharepoint_site_name] if args.key?(:sharepoint_site_name)
  @tenant_id = args[:tenant_id] if args.key?(:tenant_id)
end