Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ShieldedVmConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ShieldedVmConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A set of Shielded Instance options. See Images using supported Shielded VM features.
Instance Attribute Summary collapse
-
#enable_secure_boot ⇒ Boolean
(also: #enable_secure_boot?)
Defines whether the instance has Secure Boot enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ShieldedVmConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1ShieldedVmConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ShieldedVmConfig
Returns a new instance of GoogleCloudAiplatformV1beta1ShieldedVmConfig.
60488 60489 60490 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60488 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_secure_boot ⇒ Boolean Also known as: enable_secure_boot?
Defines whether the instance has Secure Boot enabled. Secure Boot helps
ensure that the system only runs authentic software by verifying the digital
signature of all boot components, and halting the boot process if signature
verification fails.
Corresponds to the JSON property enableSecureBoot
60485 60486 60487 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60485 def enable_secure_boot @enable_secure_boot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60493 60494 60495 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60493 def update!(**args) @enable_secure_boot = args[:enable_secure_boot] if args.key?(:enable_secure_boot) end |