Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Skill

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A skill.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Skill

Returns a new instance of GoogleCloudAiplatformV1beta1Skill.



60716
60717
60718
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compatibilityString

Optional. Specifies the compatibility of the Skill. Indicates environment requirements (intended product, system packages, network access, etc.). This should align with compatibility in the SKILL.md file. Corresponds to the JSON property compatibility

Returns:

  • (String)


60649
60650
60651
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60649

def compatibility
  @compatibility
end

#create_timeString

Output only. Timestamp when this Skill was created. Corresponds to the JSON property createTime

Returns:

  • (String)


60654
60655
60656
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60654

def create_time
  @create_time
end

#descriptionString

Required. Describes the Skill. Should describe both what the skill does and when to use it. Should include specific keywords that help agents identify relevant tasks. This should align with description in the SKILL.md file. Corresponds to the JSON property description

Returns:

  • (String)


60661
60662
60663
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60661

def description
  @description
end

#display_nameString

Required. Provides the display name of the Skill. This should align with name in the SKILL.md file. Corresponds to the JSON property displayName

Returns:

  • (String)


60667
60668
60669
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60667

def display_name
  @display_name
end

#labelsHash<String,String>

The labels with user-defined metadata to organize Skills. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


60672
60673
60674
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60672

def labels
  @labels
end

#licenseString

Optional. Specifies the license of the Skill. This should be an SPDX license identifier (e.g., "MIT", "Apache-2.0"). See https://spdx.org/licenses/. This should align with license in the SKILL.md file. Corresponds to the JSON property license

Returns:

  • (String)


60679
60680
60681
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60679

def license
  @license
end

#nameString

Identifier. The resource name of the Skill. Format: projects/project/ locations/location/skills/skill` Corresponds to the JSON propertyname`

Returns:

  • (String)


60685
60686
60687
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60685

def name
  @name
end

#sha256String

Output only. The SHA256 checksum of the zipped filesystem. Corresponds to the JSON property sha256

Returns:

  • (String)


60690
60691
60692
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60690

def sha256
  @sha256
end

#skill_sourceString

Output only. The source of the Skill. Corresponds to the JSON property skillSource

Returns:

  • (String)


60695
60696
60697
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60695

def skill_source
  @skill_source
end

#stateString

Output only. The state of the Skill. Corresponds to the JSON property state

Returns:

  • (String)


60700
60701
60702
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60700

def state
  @state
end

#update_timeString

Output only. Timestamp when this Skill was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


60705
60706
60707
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60705

def update_time
  @update_time
end

#zipped_filesystemString

Required. Provides the zipped filesystem of the Skill. This should contain the SKILL.md file at the root of the zip and optional directories for scripts, references, and assets. Directory should align with the directory structure specified at https://agentskills.io/specification#directory-structure. Corresponds to the JSON property zippedFilesystem NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


60714
60715
60716
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60714

def zipped_filesystem
  @zipped_filesystem
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60721
60722
60723
60724
60725
60726
60727
60728
60729
60730
60731
60732
60733
60734
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60721

def update!(**args)
  @compatibility = args[:compatibility] if args.key?(:compatibility)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @license = args[:license] if args.key?(:license)
  @name = args[:name] if args.key?(:name)
  @sha256 = args[:sha256] if args.key?(:sha256)
  @skill_source = args[:skill_source] if args.key?(:skill_source)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
  @zipped_filesystem = args[:zipped_filesystem] if args.key?(:zipped_filesystem)
end