Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SpecialistPool
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SpecialistPool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
SpecialistPool represents customers' own workforce to work on their data labeling jobs. It includes a group of specialist managers and workers. Managers are responsible for managing the workers in this pool as well as customers' data labeling jobs associated with this pool. Customers create specialist pool as well as start data labeling jobs on Cloud, managers and workers handle the jobs using CrowdCompute console.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#name ⇒ String
Required.
-
#pending_data_labeling_jobs ⇒ Array<String>
Output only.
-
#specialist_manager_emails ⇒ Array<String>
The email addresses of the managers in the SpecialistPool.
-
#specialist_managers_count ⇒ Fixnum
Output only.
-
#specialist_worker_emails ⇒ Array<String>
The email addresses of workers in the SpecialistPool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SpecialistPool
constructor
A new instance of GoogleCloudAiplatformV1beta1SpecialistPool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SpecialistPool
Returns a new instance of GoogleCloudAiplatformV1beta1SpecialistPool.
60964 60965 60966 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60964 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. The user-defined name of the SpecialistPool. The name can be up to
128 characters long and can consist of any UTF-8 characters. This field should
be unique on project-level.
Corresponds to the JSON property displayName
60937 60938 60939 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60937 def display_name @display_name end |
#name ⇒ String
Required. The resource name of the SpecialistPool.
Corresponds to the JSON property name
60942 60943 60944 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60942 def name @name end |
#pending_data_labeling_jobs ⇒ Array<String>
Output only. The resource name of the pending data labeling jobs.
Corresponds to the JSON property pendingDataLabelingJobs
60947 60948 60949 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60947 def pending_data_labeling_jobs @pending_data_labeling_jobs end |
#specialist_manager_emails ⇒ Array<String>
The email addresses of the managers in the SpecialistPool.
Corresponds to the JSON property specialistManagerEmails
60952 60953 60954 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60952 def specialist_manager_emails @specialist_manager_emails end |
#specialist_managers_count ⇒ Fixnum
Output only. The number of managers in this SpecialistPool.
Corresponds to the JSON property specialistManagersCount
60957 60958 60959 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60957 def specialist_managers_count @specialist_managers_count end |
#specialist_worker_emails ⇒ Array<String>
The email addresses of workers in the SpecialistPool.
Corresponds to the JSON property specialistWorkerEmails
60962 60963 60964 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60962 def specialist_worker_emails @specialist_worker_emails end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60969 60970 60971 60972 60973 60974 60975 60976 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60969 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @pending_data_labeling_jobs = args[:pending_data_labeling_jobs] if args.key?(:pending_data_labeling_jobs) @specialist_manager_emails = args[:specialist_manager_emails] if args.key?(:specialist_manager_emails) @specialist_managers_count = args[:specialist_managers_count] if args.key?(:specialist_managers_count) @specialist_worker_emails = args[:specialist_worker_emails] if args.key?(:specialist_worker_emails) end |