Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SpeculativeDecodingSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Configuration for Speculative Decoding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SpeculativeDecodingSpec

Returns a new instance of GoogleCloudAiplatformV1beta1SpeculativeDecodingSpec.



59685
59686
59687
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#draft_model_speculationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SpeculativeDecodingSpecDraftModelSpeculation

Draft model speculation works by using the smaller model to generate candidate tokens for speculative decoding. Corresponds to the JSON property draftModelSpeculation



59672
59673
59674
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59672

def draft_model_speculation
  @draft_model_speculation
end

#ngram_speculationGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SpeculativeDecodingSpecNgramSpeculation

N-Gram speculation works by trying to find matching tokens in the previous prompt sequence and use those as speculation for generating new tokens. Corresponds to the JSON property ngramSpeculation



59678
59679
59680
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59678

def ngram_speculation
  @ngram_speculation
end

#speculative_token_countFixnum

The number of speculative tokens to generate at each step. Corresponds to the JSON property speculativeTokenCount

Returns:

  • (Fixnum)


59683
59684
59685
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59683

def speculative_token_count
  @speculative_token_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59690
59691
59692
59693
59694
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59690

def update!(**args)
  @draft_model_speculation = args[:draft_model_speculation] if args.key?(:draft_model_speculation)
  @ngram_speculation = args[:ngram_speculation] if args.key?(:ngram_speculation)
  @speculative_token_count = args[:speculative_token_count] if args.key?(:speculative_token_count)
end