Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExample

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A ContentsExample to be used with GenerateContent alongside information required for storage and retrieval with Example Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StoredContentsExample

Returns a new instance of GoogleCloudAiplatformV1beta1StoredContentsExample.



57650
57651
57652
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contents_exampleGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContentsExample

A single example of a conversation with the model. Corresponds to the JSON property contentsExample



57635
57636
57637
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57635

def contents_example
  @contents_example
end

#search_keyString

Optional. (Optional) the search key used for retrieval. If not provided at upload-time, the search key will be generated from contents_example.contents using the method provided by search_key_generation_method. The generated search key will be included in retrieved examples. Corresponds to the JSON property searchKey

Returns:

  • (String)


57643
57644
57645
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57643

def search_key
  @search_key
end

#search_key_generation_methodGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod

Options for generating the search key from the conversation history. Corresponds to the JSON property searchKeyGenerationMethod



57648
57649
57650
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57648

def search_key_generation_method
  @search_key_generation_method
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57655
57656
57657
57658
57659
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57655

def update!(**args)
  @contents_example = args[:contents_example] if args.key?(:contents_example)
  @search_key = args[:search_key] if args.key?(:search_key)
  @search_key_generation_method = args[:search_key_generation_method] if args.key?(:search_key_generation_method)
end