Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExample
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A ContentsExample to be used with GenerateContent alongside information required for storage and retrieval with Example Store.
Instance Attribute Summary collapse
-
#contents_example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContentsExample
A single example of a conversation with the model.
-
#search_key ⇒ String
Optional.
-
#search_key_generation_method ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod
Options for generating the search key from the conversation history.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StoredContentsExample
constructor
A new instance of GoogleCloudAiplatformV1beta1StoredContentsExample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StoredContentsExample
Returns a new instance of GoogleCloudAiplatformV1beta1StoredContentsExample.
51148 51149 51150 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51148 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents_example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContentsExample
A single example of a conversation with the model.
Corresponds to the JSON property contentsExample
51133 51134 51135 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51133 def contents_example @contents_example end |
#search_key ⇒ String
Optional. (Optional) the search key used for retrieval. If not provided at
upload-time, the search key will be generated from contents_example.contents
using the method provided by search_key_generation_method. The generated
search key will be included in retrieved examples.
Corresponds to the JSON property searchKey
51141 51142 51143 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51141 def search_key @search_key end |
#search_key_generation_method ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod
Options for generating the search key from the conversation history.
Corresponds to the JSON property searchKeyGenerationMethod
51146 51147 51148 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51146 def search_key_generation_method @search_key_generation_method end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51153 51154 51155 51156 51157 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51153 def update!(**args) @contents_example = args[:contents_example] if args.key?(:contents_example) @search_key = args[:search_key] if args.key?(:search_key) @search_key_generation_method = args[:search_key_generation_method] if args.key?(:search_key_generation_method) end |