Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The metadata filters that will be used to search StoredContentsExamples. If a field is unspecified, then no filtering for that field will be applied

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StoredContentsExampleParameters

Returns a new instance of GoogleCloudAiplatformV1beta1StoredContentsExampleParameters.



51047
51048
51049
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_search_keyGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey

The chat history to use to generate the search key for retrieval. Corresponds to the JSON property contentSearchKey



51034
51035
51036
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51034

def content_search_key
  @content_search_key
end

#function_namesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ExamplesArrayFilter

Filters for examples' array metadata fields. An array field is example metadata where multiple values are attributed to a single example. Corresponds to the JSON property functionNames



51040
51041
51042
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51040

def function_names
  @function_names
end

#search_keyString

The exact search key to use for retrieval. Corresponds to the JSON property searchKey

Returns:

  • (String)


51045
51046
51047
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51045

def search_key
  @search_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51052
51053
51054
51055
51056
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51052

def update!(**args)
  @content_search_key = args[:content_search_key] if args.key?(:content_search_key)
  @function_names = args[:function_names] if args.key?(:function_names)
  @search_key = args[:search_key] if args.key?(:search_key)
end