Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The chat history to use to generate the search key for retrieval.
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Required.
-
#search_key_generation_method ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod
Options for generating the search key from the conversation history.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey
constructor
A new instance of GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey
Returns a new instance of GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey.
59341 59342 59343 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>
Required. The conversation for generating a search key.
Corresponds to the JSON property contents
59334 59335 59336 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59334 def contents @contents end |
#search_key_generation_method ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod
Options for generating the search key from the conversation history.
Corresponds to the JSON property searchKeyGenerationMethod
59339 59340 59341 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59339 def search_key_generation_method @search_key_generation_method end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59346 59347 59348 59349 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59346 def update!(**args) @contents = args[:contents] if args.key?(:contents) @search_key_generation_method = args[:search_key_generation_method] if args.key?(:search_key_generation_method) end |