Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The chat history to use to generate the search key for retrieval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey

Returns a new instance of GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey.



56282
56283
56284
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>

Required. The conversation for generating a search key. Corresponds to the JSON property contents



56275
56276
56277
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56275

def contents
  @contents
end

#search_key_generation_methodGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod

Options for generating the search key from the conversation history. Corresponds to the JSON property searchKeyGenerationMethod



56280
56281
56282
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56280

def search_key_generation_method
  @search_key_generation_method
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56287
56288
56289
56290
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56287

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @search_key_generation_method = args[:search_key_generation_method] if args.key?(:search_key_generation_method)
end