Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The chat history to use to generate the search key for retrieval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey

Returns a new instance of GoogleCloudAiplatformV1beta1StoredContentsExampleParametersContentSearchKey.



51073
51074
51075
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51073

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content>

Required. The conversation for generating a search key. Corresponds to the JSON property contents



51066
51067
51068
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51066

def contents
  @contents
end

#search_key_generation_methodGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod

Options for generating the search key from the conversation history. Corresponds to the JSON property searchKeyGenerationMethod



51071
51072
51073
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51071

def search_key_generation_method
  @search_key_generation_method
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51078
51079
51080
51081
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51078

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @search_key_generation_method = args[:search_key_generation_method] if args.key?(:search_key_generation_method)
end