Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Options for generating the search key from the conversation history.
Instance Attribute Summary collapse
-
#last_entry ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethodLastEntry
Configuration for using only the last entry of the conversation history as the search key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod
constructor
A new instance of GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod
Returns a new instance of GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethod.
51094 51095 51096 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51094 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_entry ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StoredContentsExampleSearchKeyGenerationMethodLastEntry
Configuration for using only the last entry of the conversation history as the
search key.
Corresponds to the JSON property lastEntry
51092 51093 51094 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51092 def last_entry @last_entry end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51099 51100 51101 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51099 def update!(**args) @last_entry = args[:last_entry] if args.key?(:last_entry) end |