Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StreamingFetchFeatureValuesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StreamingFetchFeatureValuesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for FeatureOnlineStoreService.StreamingFetchFeatureValues.
Instance Attribute Summary collapse
-
#data ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FetchFeatureValuesResponse>
Corresponds to the JSON property
data. -
#data_keys_with_error ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewDataKey>
Corresponds to the JSON property
dataKeysWithError. -
#status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StreamingFetchFeatureValuesResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1StreamingFetchFeatureValuesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StreamingFetchFeatureValuesResponse
Returns a new instance of GoogleCloudAiplatformV1beta1StreamingFetchFeatureValuesResponse.
60153 60154 60155 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60153 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FetchFeatureValuesResponse>
Corresponds to the JSON property data
60136 60137 60138 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60136 def data @data end |
#data_keys_with_error ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FeatureViewDataKey>
Corresponds to the JSON property dataKeysWithError
60141 60142 60143 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60141 def data_keys_with_error @data_keys_with_error end |
#status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
60151 60152 60153 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60151 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60158 60159 60160 60161 60162 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60158 def update!(**args) @data = args[:data] if args.key?(:data) @data_keys_with_error = args[:data_keys_with_error] if args.key?(:data_keys_with_error) @status = args[:status] if args.key?(:status) end |