Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StructuredMemoryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents configuration for organizing structured memories for a particular scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StructuredMemoryConfig

Returns a new instance of GoogleCloudAiplatformV1beta1StructuredMemoryConfig.



58119
58120
58121
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58119

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#schema_configsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig>

Optional. Represents configuration of the structured memories' schemas. Corresponds to the JSON property schemaConfigs



58108
58109
58110
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58108

def schema_configs
  @schema_configs
end

#scope_keysArray<String>

Optional. Represents the scope keys (i.e. 'user_id') for which to use this config. A request's scope must include all of the provided keys for the config to be used (order does not matter). If empty, then the config will be used for all requests that do not have a more specific config. Only one default config is allowed per Memory Bank. Corresponds to the JSON property scopeKeys

Returns:

  • (Array<String>)


58117
58118
58119
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58117

def scope_keys
  @scope_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58124
58125
58126
58127
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58124

def update!(**args)
  @schema_configs = args[:schema_configs] if args.key?(:schema_configs)
  @scope_keys = args[:scope_keys] if args.key?(:scope_keys)
end