Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StructuredMemoryConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StructuredMemoryConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents configuration for organizing structured memories for a particular scope.
Instance Attribute Summary collapse
-
#schema_configs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig>
Optional.
-
#scope_keys ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StructuredMemoryConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1StructuredMemoryConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StructuredMemoryConfig
Returns a new instance of GoogleCloudAiplatformV1beta1StructuredMemoryConfig.
51453 51454 51455 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51453 def initialize(**args) update!(**args) end |
Instance Attribute Details
#schema_configs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig>
Optional. Represents configuration of the structured memories' schemas.
Corresponds to the JSON property schemaConfigs
51442 51443 51444 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51442 def schema_configs @schema_configs end |
#scope_keys ⇒ Array<String>
Optional. Represents the scope keys (i.e. 'user_id') for which to use this
config. A request's scope must include all of the provided keys for the config
to be used (order does not matter). If empty, then the config will be used for
all requests that do not have a more specific config. Only one default config
is allowed per Memory Bank.
Corresponds to the JSON property scopeKeys
51451 51452 51453 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51451 def scope_keys @scope_keys end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51458 51459 51460 51461 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51458 def update!(**args) @schema_configs = args[:schema_configs] if args.key?(:schema_configs) @scope_keys = args[:scope_keys] if args.key?(:scope_keys) end |