Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Schema configuration for structured memories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig

Returns a new instance of GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig.



62252
62253
62254
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62252

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Required. Represents the ID of the schema. Must be 1-63 characters, start with a lowercase letter, and consist of lowercase letters, numbers, and hyphens. Corresponds to the JSON property id

Returns:

  • (String)


62233
62234
62235
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62233

def id
  @id
end

#json_schemaObject

Optional. Represents the JSON Schema of the structured memories. Corresponds to the JSON property jsonSchema

Returns:

  • (Object)


62238
62239
62240
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62238

def json_schema
  @json_schema
end

#memory_typeString

Optional. Represents the type of the structured memories associated with the schema. If not set, then STRUCTURED_PROFILE will be used. Corresponds to the JSON property memoryType

Returns:

  • (String)


62244
62245
62246
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62244

def memory_type
  @memory_type
end

#schemaGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema

Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object. Corresponds to the JSON property schema



62250
62251
62252
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62250

def schema
  @schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62257
62258
62259
62260
62261
62262
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62257

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @json_schema = args[:json_schema] if args.key?(:json_schema)
  @memory_type = args[:memory_type] if args.key?(:memory_type)
  @schema = args[:schema] if args.key?(:schema)
end