Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Schema configuration for structured memories.
Instance Attribute Summary collapse
-
#id ⇒ String
Required.
-
#json_schema ⇒ Object
Optional.
-
#memory_type ⇒ String
Optional.
-
#schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema
Defines the schema of input and output data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig
Returns a new instance of GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig.
60365 60366 60367 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Required. Represents the ID of the schema. Must be 1-63 characters, start with
a lowercase letter, and consist of lowercase letters, numbers, and hyphens.
Corresponds to the JSON property id
60346 60347 60348 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60346 def id @id end |
#json_schema ⇒ Object
Optional. Represents the JSON Schema of the structured memories.
Corresponds to the JSON property jsonSchema
60351 60352 60353 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60351 def json_schema @json_schema end |
#memory_type ⇒ String
Optional. Represents the type of the structured memories associated with the
schema. If not set, then STRUCTURED_PROFILE will be used.
Corresponds to the JSON property memoryType
60357 60358 60359 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60357 def memory_type @memory_type end |
#schema ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema
Defines the schema of input and output data. This is a subset of the OpenAPI
3.0 Schema Object.
Corresponds to the JSON property schema
60363 60364 60365 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60363 def schema @schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60370 60371 60372 60373 60374 60375 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60370 def update!(**args) @id = args[:id] if args.key?(:id) @json_schema = args[:json_schema] if args.key?(:json_schema) @memory_type = args[:memory_type] if args.key?(:memory_type) @schema = args[:schema] if args.key?(:schema) end |