Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Schema configuration for structured memories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig

Returns a new instance of GoogleCloudAiplatformV1beta1StructuredMemoryConfigSchemaConfig.



51650
51651
51652
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Required. Represents the ID of the schema. Must be 1-63 characters, start with a lowercase letter, and consist of lowercase letters, numbers, and hyphens. Corresponds to the JSON property id

Returns:

  • (String)


51636
51637
51638
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51636

def id
  @id
end

#memory_typeString

Optional. Represents the type of the structured memories associated with the schema. If not set, then STRUCTURED_PROFILE will be used. Corresponds to the JSON property memoryType

Returns:

  • (String)


51642
51643
51644
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51642

def memory_type
  @memory_type
end

#schemaGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Schema

Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object. Corresponds to the JSON property schema



51648
51649
51650
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51648

def schema
  @schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51655
51656
51657
51658
51659
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51655

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @memory_type = args[:memory_type] if args.key?(:memory_type)
  @schema = args[:schema] if args.key?(:schema)
end