Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Study

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A message representing a Study.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Study

Returns a new instance of GoogleCloudAiplatformV1beta1Study.



51534
51535
51536
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51534

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time at which the study was created. Corresponds to the JSON property createTime

Returns:

  • (String)


51505
51506
51507
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51505

def create_time
  @create_time
end

#display_nameString

Required. Describes the Study, default value is empty string. Corresponds to the JSON property displayName

Returns:

  • (String)


51510
51511
51512
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51510

def display_name
  @display_name
end

#inactive_reasonString

Output only. A human readable reason why the Study is inactive. This should be empty if a study is ACTIVE or COMPLETED. Corresponds to the JSON property inactiveReason

Returns:

  • (String)


51516
51517
51518
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51516

def inactive_reason
  @inactive_reason
end

#nameString

Output only. The name of a study. The study's globally unique identifier. Format: projects/project/locations/location/studies/study` Corresponds to the JSON propertyname`

Returns:

  • (String)


51522
51523
51524
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51522

def name
  @name
end

#stateString

Output only. The detailed state of a Study. Corresponds to the JSON property state

Returns:

  • (String)


51527
51528
51529
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51527

def state
  @state
end

#study_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



51532
51533
51534
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51532

def study_spec
  @study_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51539
51540
51541
51542
51543
51544
51545
51546
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51539

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @inactive_reason = args[:inactive_reason] if args.key?(:inactive_reason)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
end