Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents specification of a Study.
Instance Attribute Summary collapse
-
#algorithm ⇒ String
The search algorithm specified for the Study.
-
#convex_automated_stopping_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecConvexAutomatedStoppingSpec
Configuration for ConvexAutomatedStoppingSpec.
-
#convex_stop_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecConvexStopConfig
Configuration for ConvexStopPolicy.
-
#decay_curve_stopping_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecDecayCurveAutomatedStoppingSpec
The decay curve automated stopping rule builds a Gaussian Process Regressor to predict the final objective value of a Trial based on the already completed Trials and the intermediate measurements of the current Trial.
-
#measurement_selection_type ⇒ String
Describe which measurement selection type will be used Corresponds to the JSON property
measurementSelectionType. -
#median_automated_stopping_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecMedianAutomatedStoppingSpec
The median automated stopping rule stops a pending Trial if the Trial's best objective_value is strictly below the median 'performance' of all completed Trials reported up to the Trial's last measurement.
-
#metrics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecMetricSpec>
Required.
-
#observation_noise ⇒ String
The observation noise level of the study.
-
#parameters ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpec>
Required.
-
#study_stopping_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecStudyStoppingConfig
The configuration (stopping conditions) for automated stopping of a Study.
-
#transfer_learning_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecTransferLearningConfig
This contains flag for manually disabling transfer learning for a study.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpec
constructor
A new instance of GoogleCloudAiplatformV1beta1StudySpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpec
Returns a new instance of GoogleCloudAiplatformV1beta1StudySpec.
61824 61825 61826 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61824 def initialize(**args) update!(**args) end |
Instance Attribute Details
#algorithm ⇒ String
The search algorithm specified for the Study.
Corresponds to the JSON property algorithm
61751 61752 61753 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61751 def algorithm @algorithm end |
#convex_automated_stopping_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecConvexAutomatedStoppingSpec
Configuration for ConvexAutomatedStoppingSpec. When there are enough completed
trials (configured by min_measurement_count), for pending trials with enough
measurements and steps, the policy first computes an overestimate of the
objective value at max_num_steps according to the slope of the incomplete
objective value curve. No prediction can be made if the curve is completely
flat. If the overestimation is worse than the best objective value of the
completed trials, this pending trial will be early-stopped, but a last
measurement will be added to the pending trial with max_num_steps and
predicted objective value from the autoregression model.
Corresponds to the JSON property convexAutomatedStoppingSpec
61764 61765 61766 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61764 def convex_automated_stopping_spec @convex_automated_stopping_spec end |
#convex_stop_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecConvexStopConfig
Configuration for ConvexStopPolicy.
Corresponds to the JSON property convexStopConfig
61769 61770 61771 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61769 def convex_stop_config @convex_stop_config end |
#decay_curve_stopping_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecDecayCurveAutomatedStoppingSpec
The decay curve automated stopping rule builds a Gaussian Process Regressor to
predict the final objective value of a Trial based on the already completed
Trials and the intermediate measurements of the current Trial. Early stopping
is requested for the current Trial if there is very low probability to exceed
the optimal value found so far.
Corresponds to the JSON property decayCurveStoppingSpec
61778 61779 61780 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61778 def decay_curve_stopping_spec @decay_curve_stopping_spec end |
#measurement_selection_type ⇒ String
Describe which measurement selection type will be used
Corresponds to the JSON property measurementSelectionType
61783 61784 61785 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61783 def measurement_selection_type @measurement_selection_type end |
#median_automated_stopping_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecMedianAutomatedStoppingSpec
The median automated stopping rule stops a pending Trial if the Trial's best
objective_value is strictly below the median 'performance' of all completed
Trials reported up to the Trial's last measurement. Currently, 'performance'
refers to the running average of the objective values reported by the Trial in
each measurement.
Corresponds to the JSON property medianAutomatedStoppingSpec
61792 61793 61794 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61792 def median_automated_stopping_spec @median_automated_stopping_spec end |
#metrics ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecMetricSpec>
Required. Metric specs for the Study.
Corresponds to the JSON property metrics
61797 61798 61799 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61797 def metrics @metrics end |
#observation_noise ⇒ String
The observation noise level of the study. Currently only supported by the
Vertex AI Vizier service. Not supported by HyperparameterTuningJob or
TrainingPipeline.
Corresponds to the JSON property observationNoise
61804 61805 61806 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61804 def observation_noise @observation_noise end |
#parameters ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpec>
Required. The set of parameters to tune.
Corresponds to the JSON property parameters
61809 61810 61811 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61809 def parameters @parameters end |
#study_stopping_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecStudyStoppingConfig
The configuration (stopping conditions) for automated stopping of a Study.
Conditions include trial budgets, time budgets, and convergence detection.
Corresponds to the JSON property studyStoppingConfig
61815 61816 61817 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61815 def study_stopping_config @study_stopping_config end |
#transfer_learning_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecTransferLearningConfig
This contains flag for manually disabling transfer learning for a study. The
names of prior studies being used for transfer learning (if any) are also
listed here.
Corresponds to the JSON property transferLearningConfig
61822 61823 61824 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61822 def transfer_learning_config @transfer_learning_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61829 61830 61831 61832 61833 61834 61835 61836 61837 61838 61839 61840 61841 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61829 def update!(**args) @algorithm = args[:algorithm] if args.key?(:algorithm) @convex_automated_stopping_spec = args[:convex_automated_stopping_spec] if args.key?(:convex_automated_stopping_spec) @convex_stop_config = args[:convex_stop_config] if args.key?(:convex_stop_config) @decay_curve_stopping_spec = args[:decay_curve_stopping_spec] if args.key?(:decay_curve_stopping_spec) @measurement_selection_type = args[:measurement_selection_type] if args.key?(:measurement_selection_type) @median_automated_stopping_spec = args[:median_automated_stopping_spec] if args.key?(:median_automated_stopping_spec) @metrics = args[:metrics] if args.key?(:metrics) @observation_noise = args[:observation_noise] if args.key?(:observation_noise) @parameters = args[:parameters] if args.key?(:parameters) @study_stopping_config = args[:study_stopping_config] if args.key?(:study_stopping_config) @transfer_learning_config = args[:transfer_learning_config] if args.key?(:transfer_learning_config) end |