Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecDecayCurveAutomatedStoppingSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecDecayCurveAutomatedStoppingSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The decay curve automated stopping rule builds a Gaussian Process Regressor to predict the final objective value of a Trial based on the already completed Trials and the intermediate measurements of the current Trial. Early stopping is requested for the current Trial if there is very low probability to exceed the optimal value found so far.
Instance Attribute Summary collapse
-
#use_elapsed_duration ⇒ Boolean
(also: #use_elapsed_duration?)
True if Measurement.elapsed_duration is used as the x-axis of each Trials Decay Curve.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecDecayCurveAutomatedStoppingSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1StudySpecDecayCurveAutomatedStoppingSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecDecayCurveAutomatedStoppingSpec
Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecDecayCurveAutomatedStoppingSpec.
58471 58472 58473 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58471 def initialize(**args) update!(**args) end |
Instance Attribute Details
#use_elapsed_duration ⇒ Boolean Also known as: use_elapsed_duration?
True if Measurement.elapsed_duration is used as the x-axis of each Trials
Decay Curve. Otherwise, Measurement.step_count will be used as the x-axis.
Corresponds to the JSON property useElapsedDuration
58468 58469 58470 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58468 def use_elapsed_duration @use_elapsed_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58476 58477 58478 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58476 def update!(**args) @use_elapsed_duration = args[:use_elapsed_duration] if args.key?(:use_elapsed_duration) end |