Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecMetricSpecSafetyMetricConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecMetricSpecSafetyMetricConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Used in safe optimization to specify threshold levels and risk tolerance.
Instance Attribute Summary collapse
-
#desired_min_safe_trials_fraction ⇒ Float
Desired minimum fraction of safe trials (over total number of trials) that should be targeted by the algorithm at any time during the study (best effort).
-
#safety_threshold ⇒ Float
Safety threshold (boundary value between safe and unsafe).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecMetricSpecSafetyMetricConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1StudySpecMetricSpecSafetyMetricConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecMetricSpecSafetyMetricConfig
Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecMetricSpecSafetyMetricConfig.
59972 59973 59974 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59972 def initialize(**args) update!(**args) end |
Instance Attribute Details
#desired_min_safe_trials_fraction ⇒ Float
Desired minimum fraction of safe trials (over total number of trials) that
should be targeted by the algorithm at any time during the study (best effort).
This should be between 0.0 and 1.0 and a value of 0.0 means that there is no
minimum and an algorithm proceeds without targeting any specific fraction. A
value of 1.0 means that the algorithm attempts to only Suggest safe Trials.
Corresponds to the JSON property desiredMinSafeTrialsFraction
59964 59965 59966 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59964 def desired_min_safe_trials_fraction @desired_min_safe_trials_fraction end |
#safety_threshold ⇒ Float
Safety threshold (boundary value between safe and unsafe). NOTE that if you
leave SafetyMetricConfig unset, a default value of 0 will be used.
Corresponds to the JSON property safetyThreshold
59970 59971 59972 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59970 def safety_threshold @safety_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59977 59978 59979 59980 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59977 def update!(**args) @desired_min_safe_trials_fraction = args[:desired_min_safe_trials_fraction] if args.key?(:desired_min_safe_trials_fraction) @safety_threshold = args[:safety_threshold] if args.key?(:safety_threshold) end |