Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a single parameter to optimize.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpec

Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpec.



58612
58613
58614
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categorical_value_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecCategoricalValueSpec

Value specification for a parameter in CATEGORICAL type. Corresponds to the JSON property categoricalValueSpec



58576
58577
58578
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58576

def categorical_value_spec
  @categorical_value_spec
end

#conditional_parameter_specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec>

A conditional parameter node is active if the parameter's value matches the conditional node's parent_value_condition. If two items in conditional_parameter_specs have the same name, they must have disjoint parent_value_condition. Corresponds to the JSON property conditionalParameterSpecs



58584
58585
58586
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58584

def conditional_parameter_specs
  @conditional_parameter_specs
end

#discrete_value_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecDiscreteValueSpec

Value specification for a parameter in DISCRETE type. Corresponds to the JSON property discreteValueSpec



58589
58590
58591
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58589

def discrete_value_spec
  @discrete_value_spec
end

#double_value_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecDoubleValueSpec

Value specification for a parameter in DOUBLE type. Corresponds to the JSON property doubleValueSpec



58594
58595
58596
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58594

def double_value_spec
  @double_value_spec
end

#integer_value_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec

Value specification for a parameter in INTEGER type. Corresponds to the JSON property integerValueSpec



58599
58600
58601
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58599

def integer_value_spec
  @integer_value_spec
end

#parameter_idString

Required. The ID of the parameter. Must not contain whitespaces and must be unique amongst all ParameterSpecs. Corresponds to the JSON property parameterId

Returns:

  • (String)


58605
58606
58607
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58605

def parameter_id
  @parameter_id
end

#scale_typeString

How the parameter should be scaled. Leave unset for CATEGORICAL parameters. Corresponds to the JSON property scaleType

Returns:

  • (String)


58610
58611
58612
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58610

def scale_type
  @scale_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58617
58618
58619
58620
58621
58622
58623
58624
58625
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58617

def update!(**args)
  @categorical_value_spec = args[:categorical_value_spec] if args.key?(:categorical_value_spec)
  @conditional_parameter_specs = args[:conditional_parameter_specs] if args.key?(:conditional_parameter_specs)
  @discrete_value_spec = args[:discrete_value_spec] if args.key?(:discrete_value_spec)
  @double_value_spec = args[:double_value_spec] if args.key?(:double_value_spec)
  @integer_value_spec = args[:integer_value_spec] if args.key?(:integer_value_spec)
  @parameter_id = args[:parameter_id] if args.key?(:parameter_id)
  @scale_type = args[:scale_type] if args.key?(:scale_type)
end