Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecCategoricalValueSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Value specification for a parameter in CATEGORICAL type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpecCategoricalValueSpec

Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpecCategoricalValueSpec.



60247
60248
60249
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueString

A default value for a CATEGORICAL parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline. Corresponds to the JSON property defaultValue

Returns:

  • (String)


60240
60241
60242
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60240

def default_value
  @default_value
end

#valuesArray<String>

Required. The list of possible categories. Corresponds to the JSON property values

Returns:

  • (Array<String>)


60245
60246
60247
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60245

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60252
60253
60254
60255
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60252

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @values = args[:values] if args.key?(:values)
end