Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a parameter spec with condition from its parent parameter.
Instance Attribute Summary collapse
-
#parameter_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpec
Represents a single parameter to optimize.
-
#parent_categorical_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecCategoricalValueCondition
Represents the spec to match categorical values from parent parameter.
-
#parent_discrete_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecDiscreteValueCondition
Represents the spec to match discrete values from parent parameter.
-
#parent_int_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecIntValueCondition
Represents the spec to match integer values from parent parameter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec
Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec.
58680 58681 58682 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58680 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parameter_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpec
Represents a single parameter to optimize.
Corresponds to the JSON property parameterSpec
58663 58664 58665 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58663 def parameter_spec @parameter_spec end |
#parent_categorical_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecCategoricalValueCondition
Represents the spec to match categorical values from parent parameter.
Corresponds to the JSON property parentCategoricalValues
58668 58669 58670 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58668 def parent_categorical_values @parent_categorical_values end |
#parent_discrete_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecDiscreteValueCondition
Represents the spec to match discrete values from parent parameter.
Corresponds to the JSON property parentDiscreteValues
58673 58674 58675 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58673 def parent_discrete_values @parent_discrete_values end |
#parent_int_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecIntValueCondition
Represents the spec to match integer values from parent parameter.
Corresponds to the JSON property parentIntValues
58678 58679 58680 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58678 def parent_int_values @parent_int_values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58685 58686 58687 58688 58689 58690 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58685 def update!(**args) @parameter_spec = args[:parameter_spec] if args.key?(:parameter_spec) @parent_categorical_values = args[:parent_categorical_values] if args.key?(:parent_categorical_values) @parent_discrete_values = args[:parent_discrete_values] if args.key?(:parent_discrete_values) @parent_int_values = args[:parent_int_values] if args.key?(:parent_int_values) end |