Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a parameter spec with condition from its parent parameter.
Instance Attribute Summary collapse
-
#parameter_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpec
Represents a single parameter to optimize.
-
#parent_categorical_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecCategoricalValueCondition
Represents the spec to match categorical values from parent parameter.
-
#parent_discrete_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecDiscreteValueCondition
Represents the spec to match discrete values from parent parameter.
-
#parent_int_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecIntValueCondition
Represents the spec to match integer values from parent parameter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec
Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpec.
52014 52015 52016 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parameter_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpec
Represents a single parameter to optimize.
Corresponds to the JSON property parameterSpec
51997 51998 51999 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 51997 def parameter_spec @parameter_spec end |
#parent_categorical_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecCategoricalValueCondition
Represents the spec to match categorical values from parent parameter.
Corresponds to the JSON property parentCategoricalValues
52002 52003 52004 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52002 def parent_categorical_values @parent_categorical_values end |
#parent_discrete_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecDiscreteValueCondition
Represents the spec to match discrete values from parent parameter.
Corresponds to the JSON property parentDiscreteValues
52007 52008 52009 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52007 def parent_discrete_values @parent_discrete_values end |
#parent_int_values ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecConditionalParameterSpecIntValueCondition
Represents the spec to match integer values from parent parameter.
Corresponds to the JSON property parentIntValues
52012 52013 52014 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52012 def parent_int_values @parent_int_values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52019 52020 52021 52022 52023 52024 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52019 def update!(**args) @parameter_spec = args[:parameter_spec] if args.key?(:parameter_spec) @parent_categorical_values = args[:parent_categorical_values] if args.key?(:parent_categorical_values) @parent_discrete_values = args[:parent_discrete_values] if args.key?(:parent_discrete_values) @parent_int_values = args[:parent_int_values] if args.key?(:parent_int_values) end |