Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecDiscreteValueSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Value specification for a parameter in DISCRETE type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpecDiscreteValueSpec

Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpecDiscreteValueSpec.



60989
60990
60991
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueFloat

A default value for a DISCRETE parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. It automatically rounds to the nearest feasible discrete point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline. Corresponds to the JSON property defaultValue

Returns:

  • (Float)


60979
60980
60981
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60979

def default_value
  @default_value
end

#valuesArray<Float>

Required. A list of possible values. The list should be in increasing order and at least 1e-10 apart. For instance, this parameter might have possible settings of 1.5, 2.5, and 4.0. This list should not contain more than 1,000 values. Corresponds to the JSON property values

Returns:

  • (Array<Float>)


60987
60988
60989
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60987

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60994
60995
60996
60997
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60994

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @values = args[:values] if args.key?(:values)
end