Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecDoubleValueSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Value specification for a parameter in DOUBLE type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpecDoubleValueSpec

Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpecDoubleValueSpec.



52142
52143
52144
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52142

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueFloat

A default value for a DOUBLE parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline. Corresponds to the JSON property defaultValue

Returns:

  • (Float)


52130
52131
52132
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52130

def default_value
  @default_value
end

#max_valueFloat

Required. Inclusive maximum value of the parameter. Corresponds to the JSON property maxValue

Returns:

  • (Float)


52135
52136
52137
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52135

def max_value
  @max_value
end

#min_valueFloat

Required. Inclusive minimum value of the parameter. Corresponds to the JSON property minValue

Returns:

  • (Float)


52140
52141
52142
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52140

def min_value
  @min_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52147
52148
52149
52150
52151
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52147

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
end