Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Value specification for a parameter in INTEGER type.
Instance Attribute Summary collapse
-
#default_value ⇒ Fixnum
A default value for an
INTEGERparameter that is assumed to be a relatively good starting point. -
#max_value ⇒ Fixnum
Required.
-
#min_value ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec
Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec.
60256 60257 60258 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60256 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_value ⇒ Fixnum
A default value for an INTEGER parameter that is assumed to be a relatively
good starting point. Unset value signals that there is no offered starting
point. Currently only supported by the Vertex AI Vizier service. Not supported
by HyperparameterTuningJob or TrainingPipeline.
Corresponds to the JSON property defaultValue
60244 60245 60246 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60244 def default_value @default_value end |
#max_value ⇒ Fixnum
Required. Inclusive maximum value of the parameter.
Corresponds to the JSON property maxValue
60249 60250 60251 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60249 def max_value @max_value end |
#min_value ⇒ Fixnum
Required. Inclusive minimum value of the parameter.
Corresponds to the JSON property minValue
60254 60255 60256 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60254 def min_value @min_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60261 60262 60263 60264 60265 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60261 def update!(**args) @default_value = args[:default_value] if args.key?(:default_value) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) end |