Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Value specification for a parameter in INTEGER type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec

Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec.



60444
60445
60446
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60444

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueFixnum

A default value for an INTEGER parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline. Corresponds to the JSON property defaultValue

Returns:

  • (Fixnum)


60432
60433
60434
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60432

def default_value
  @default_value
end

#max_valueFixnum

Required. Inclusive maximum value of the parameter. Corresponds to the JSON property maxValue

Returns:

  • (Fixnum)


60437
60438
60439
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60437

def max_value
  @max_value
end

#min_valueFixnum

Required. Inclusive minimum value of the parameter. Corresponds to the JSON property minValue

Returns:

  • (Fixnum)


60442
60443
60444
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60442

def min_value
  @min_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60449
60450
60451
60452
60453
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60449

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
end