Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Value specification for a parameter in INTEGER type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec

Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecParameterSpecIntegerValueSpec.



52176
52177
52178
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52176

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueFixnum

A default value for an INTEGER parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline. Corresponds to the JSON property defaultValue

Returns:

  • (Fixnum)


52164
52165
52166
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52164

def default_value
  @default_value
end

#max_valueFixnum

Required. Inclusive maximum value of the parameter. Corresponds to the JSON property maxValue

Returns:

  • (Fixnum)


52169
52170
52171
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52169

def max_value
  @max_value
end

#min_valueFixnum

Required. Inclusive minimum value of the parameter. Corresponds to the JSON property minValue

Returns:

  • (Fixnum)


52174
52175
52176
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52174

def min_value
  @min_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52181
52182
52183
52184
52185
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52181

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
end