Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecStudyStoppingConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudySpecStudyStoppingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The configuration (stopping conditions) for automated stopping of a Study. Conditions include trial budgets, time budgets, and convergence detection.
Instance Attribute Summary collapse
-
#max_duration_no_progress ⇒ String
If the objective value has not improved for this much time, stop the study.
-
#max_num_trials ⇒ Fixnum
If there are more than this many trials, stop the study.
-
#max_num_trials_no_progress ⇒ Fixnum
If the objective value has not improved for this many consecutive trials, stop the study.
-
#maximum_runtime_constraint ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudyTimeConstraint
Time-based Constraint for Study Corresponds to the JSON property
maximumRuntimeConstraint. -
#min_num_trials ⇒ Fixnum
If there are fewer than this many COMPLETED trials, do not stop the study.
-
#minimum_runtime_constraint ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudyTimeConstraint
Time-based Constraint for Study Corresponds to the JSON property
minimumRuntimeConstraint. -
#should_stop_asap ⇒ Boolean
(also: #should_stop_asap?)
If true, a Study enters STOPPING_ASAP whenever it would normally enters STOPPING state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecStudyStoppingConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1StudySpecStudyStoppingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1StudySpecStudyStoppingConfig
Returns a new instance of GoogleCloudAiplatformV1beta1StudySpecStudyStoppingConfig.
52234 52235 52236 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration_no_progress ⇒ String
If the objective value has not improved for this much time, stop the study.
WARNING: Effective only for single-objective studies.
Corresponds to the JSON property maxDurationNoProgress
52197 52198 52199 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52197 def max_duration_no_progress @max_duration_no_progress end |
#max_num_trials ⇒ Fixnum
If there are more than this many trials, stop the study.
Corresponds to the JSON property maxNumTrials
52202 52203 52204 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52202 def max_num_trials @max_num_trials end |
#max_num_trials_no_progress ⇒ Fixnum
If the objective value has not improved for this many consecutive trials, stop
the study. WARNING: Effective only for single-objective studies.
Corresponds to the JSON property maxNumTrialsNoProgress
52208 52209 52210 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52208 def max_num_trials_no_progress @max_num_trials_no_progress end |
#maximum_runtime_constraint ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudyTimeConstraint
Time-based Constraint for Study
Corresponds to the JSON property maximumRuntimeConstraint
52213 52214 52215 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52213 def maximum_runtime_constraint @maximum_runtime_constraint end |
#min_num_trials ⇒ Fixnum
If there are fewer than this many COMPLETED trials, do not stop the study.
Corresponds to the JSON property minNumTrials
52218 52219 52220 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52218 def min_num_trials @min_num_trials end |
#minimum_runtime_constraint ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1StudyTimeConstraint
Time-based Constraint for Study
Corresponds to the JSON property minimumRuntimeConstraint
52223 52224 52225 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52223 def minimum_runtime_constraint @minimum_runtime_constraint end |
#should_stop_asap ⇒ Boolean Also known as: should_stop_asap?
If true, a Study enters STOPPING_ASAP whenever it would normally enters
STOPPING state. The bottom line is: set to true if you want to interrupt on-
going evaluations of Trials as soon as the study stopping condition is met. (
Please see Study.State documentation for the source of truth).
Corresponds to the JSON property shouldStopAsap
52231 52232 52233 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52231 def should_stop_asap @should_stop_asap end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52239 52240 52241 52242 52243 52244 52245 52246 52247 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 52239 def update!(**args) @max_duration_no_progress = args[:max_duration_no_progress] if args.key?(:max_duration_no_progress) @max_num_trials = args[:max_num_trials] if args.key?(:max_num_trials) @max_num_trials_no_progress = args[:max_num_trials_no_progress] if args.key?(:max_num_trials_no_progress) @maximum_runtime_constraint = args[:maximum_runtime_constraint] if args.key?(:maximum_runtime_constraint) @min_num_trials = args[:min_num_trials] if args.key?(:min_num_trials) @minimum_runtime_constraint = args[:minimum_runtime_constraint] if args.key?(:minimum_runtime_constraint) @should_stop_asap = args[:should_stop_asap] if args.key?(:should_stop_asap) end |