Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution.



63771
63772
63773
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


63729
63730
63731
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63729

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



63734
63735
63736
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63734

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


63739
63740
63741
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63739

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


63744
63745
63746
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63744

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


63749
63750
63751
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63749

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


63754
63755
63756
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63754

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


63759
63760
63761
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63759

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


63764
63765
63766
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63764

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


63769
63770
63771
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63769

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63776
63777
63778
63779
63780
63781
63782
63783
63784
63785
63786
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63776

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end