Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Dataset distribution for Supervised Tuning.
Instance Attribute Summary collapse
-
#billable_sum ⇒ Fixnum
Output only.
-
#buckets ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket>
Output only.
-
#max ⇒ Float
Output only.
-
#mean ⇒ Float
Output only.
-
#median ⇒ Float
Output only.
-
#min ⇒ Float
Output only.
-
#p5 ⇒ Float
Output only.
-
#p95 ⇒ Float
Output only.
-
#sum ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution
constructor
A new instance of GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution
Returns a new instance of GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution.
61884 61885 61886 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billable_sum ⇒ Fixnum
Output only. Sum of a given population of values that are billable.
Corresponds to the JSON property billableSum
61842 61843 61844 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61842 def billable_sum @billable_sum end |
#buckets ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket>
Output only. Defines the histogram bucket.
Corresponds to the JSON property buckets
61847 61848 61849 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61847 def buckets @buckets end |
#max ⇒ Float
Output only. The maximum of the population values.
Corresponds to the JSON property max
61852 61853 61854 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61852 def max @max end |
#mean ⇒ Float
Output only. The arithmetic mean of the values in the population.
Corresponds to the JSON property mean
61857 61858 61859 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61857 def mean @mean end |
#median ⇒ Float
Output only. The median of the values in the population.
Corresponds to the JSON property median
61862 61863 61864 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61862 def median @median end |
#min ⇒ Float
Output only. The minimum of the population values.
Corresponds to the JSON property min
61867 61868 61869 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61867 def min @min end |
#p5 ⇒ Float
Output only. The 5th percentile of the values in the population.
Corresponds to the JSON property p5
61872 61873 61874 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61872 def p5 @p5 end |
#p95 ⇒ Float
Output only. The 95th percentile of the values in the population.
Corresponds to the JSON property p95
61877 61878 61879 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61877 def p95 @p95 end |
#sum ⇒ Fixnum
Output only. Sum of a given population of values.
Corresponds to the JSON property sum
61882 61883 61884 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61882 def sum @sum end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61889 61890 61891 61892 61893 61894 61895 61896 61897 61898 61899 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61889 def update!(**args) @billable_sum = args[:billable_sum] if args.key?(:billable_sum) @buckets = args[:buckets] if args.key?(:buckets) @max = args[:max] if args.key?(:max) @mean = args[:mean] if args.key?(:mean) @median = args[:median] if args.key?(:median) @min = args[:min] if args.key?(:min) @p5 = args[:p5] if args.key?(:p5) @p95 = args[:p95] if args.key?(:p95) @sum = args[:sum] if args.key?(:sum) end |