Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution.



61084
61085
61086
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61084

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


61042
61043
61044
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61042

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



61047
61048
61049
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61047

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


61052
61053
61054
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61052

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


61057
61058
61059
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61057

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


61062
61063
61064
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61062

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


61067
61068
61069
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61067

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


61072
61073
61074
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61072

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


61077
61078
61079
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61077

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


61082
61083
61084
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61082

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61089

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end