Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Dataset distribution for Supervised Tuning.
Instance Attribute Summary collapse
-
#billable_sum ⇒ Fixnum
Output only.
-
#buckets ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket>
Output only.
-
#max ⇒ Float
Output only.
-
#mean ⇒ Float
Output only.
-
#median ⇒ Float
Output only.
-
#min ⇒ Float
Output only.
-
#p5 ⇒ Float
Output only.
-
#p95 ⇒ Float
Output only.
-
#sum ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution
constructor
A new instance of GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution
Returns a new instance of GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution.
61084 61085 61086 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billable_sum ⇒ Fixnum
Output only. Sum of a given population of values that are billable.
Corresponds to the JSON property billableSum
61042 61043 61044 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61042 def billable_sum @billable_sum end |
#buckets ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket>
Output only. Defines the histogram bucket.
Corresponds to the JSON property buckets
61047 61048 61049 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61047 def buckets @buckets end |
#max ⇒ Float
Output only. The maximum of the population values.
Corresponds to the JSON property max
61052 61053 61054 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61052 def max @max end |
#mean ⇒ Float
Output only. The arithmetic mean of the values in the population.
Corresponds to the JSON property mean
61057 61058 61059 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61057 def mean @mean end |
#median ⇒ Float
Output only. The median of the values in the population.
Corresponds to the JSON property median
61062 61063 61064 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61062 def median @median end |
#min ⇒ Float
Output only. The minimum of the population values.
Corresponds to the JSON property min
61067 61068 61069 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61067 def min @min end |
#p5 ⇒ Float
Output only. The 5th percentile of the values in the population.
Corresponds to the JSON property p5
61072 61073 61074 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61072 def p5 @p5 end |
#p95 ⇒ Float
Output only. The 95th percentile of the values in the population.
Corresponds to the JSON property p95
61077 61078 61079 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61077 def p95 @p95 end |
#sum ⇒ Fixnum
Output only. Sum of a given population of values.
Corresponds to the JSON property sum
61082 61083 61084 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61082 def sum @sum end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61089 61090 61091 61092 61093 61094 61095 61096 61097 61098 61099 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61089 def update!(**args) @billable_sum = args[:billable_sum] if args.key?(:billable_sum) @buckets = args[:buckets] if args.key?(:buckets) @max = args[:max] if args.key?(:max) @mean = args[:mean] if args.key?(:mean) @median = args[:median] if args.key?(:median) @min = args[:min] if args.key?(:min) @p5 = args[:p5] if args.key?(:p5) @p95 = args[:p95] if args.key?(:p95) @sum = args[:sum] if args.key?(:sum) end |