Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Dataset distribution for Supervised Tuning.
Instance Attribute Summary collapse
-
#billable_sum ⇒ Fixnum
Output only.
-
#buckets ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket>
Output only.
-
#max ⇒ Float
Output only.
-
#mean ⇒ Float
Output only.
-
#median ⇒ Float
Output only.
-
#min ⇒ Float
Output only.
-
#p5 ⇒ Float
Output only.
-
#p95 ⇒ Float
Output only.
-
#sum ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution
constructor
A new instance of GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution
Returns a new instance of GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution.
61272 61273 61274 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billable_sum ⇒ Fixnum
Output only. Sum of a given population of values that are billable.
Corresponds to the JSON property billableSum
61230 61231 61232 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61230 def billable_sum @billable_sum end |
#buckets ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket>
Output only. Defines the histogram bucket.
Corresponds to the JSON property buckets
61235 61236 61237 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61235 def buckets @buckets end |
#max ⇒ Float
Output only. The maximum of the population values.
Corresponds to the JSON property max
61240 61241 61242 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61240 def max @max end |
#mean ⇒ Float
Output only. The arithmetic mean of the values in the population.
Corresponds to the JSON property mean
61245 61246 61247 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61245 def mean @mean end |
#median ⇒ Float
Output only. The median of the values in the population.
Corresponds to the JSON property median
61250 61251 61252 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61250 def median @median end |
#min ⇒ Float
Output only. The minimum of the population values.
Corresponds to the JSON property min
61255 61256 61257 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61255 def min @min end |
#p5 ⇒ Float
Output only. The 5th percentile of the values in the population.
Corresponds to the JSON property p5
61260 61261 61262 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61260 def p5 @p5 end |
#p95 ⇒ Float
Output only. The 95th percentile of the values in the population.
Corresponds to the JSON property p95
61265 61266 61267 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61265 def p95 @p95 end |
#sum ⇒ Fixnum
Output only. Sum of a given population of values.
Corresponds to the JSON property sum
61270 61271 61272 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61270 def sum @sum end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61277 61278 61279 61280 61281 61282 61283 61284 61285 61286 61287 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61277 def update!(**args) @billable_sum = args[:billable_sum] if args.key?(:billable_sum) @buckets = args[:buckets] if args.key?(:buckets) @max = args[:max] if args.key?(:max) @mean = args[:mean] if args.key?(:mean) @median = args[:median] if args.key?(:median) @min = args[:min] if args.key?(:min) @p5 = args[:p5] if args.key?(:p5) @p95 = args[:p95] if args.key?(:p95) @sum = args[:sum] if args.key?(:sum) end |