Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution.



59670
59671
59672
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


59628
59629
59630
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59628

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



59633
59634
59635
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59633

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


59638
59639
59640
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59638

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


59643
59644
59645
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59643

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


59648
59649
59650
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59648

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


59653
59654
59655
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59653

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


59658
59659
59660
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59658

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


59663
59664
59665
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59663

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


59668
59669
59670
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59668

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59675
59676
59677
59678
59679
59680
59681
59682
59683
59684
59685
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59675

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end