Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistribution.



58213
58214
58215
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


58171
58172
58173
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58171

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



58176
58177
58178
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58176

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


58181
58182
58183
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58181

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


58186
58187
58188
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58186

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


58191
58192
58193
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58191

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


58196
58197
58198
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58196

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


58201
58202
58203
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58201

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


58206
58207
58208
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58206

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


58211
58212
58213
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58211

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58218
58219
58220
58221
58222
58223
58224
58225
58226
58227
58228
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58218

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end