Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Tuning Spec for Supervised Tuning for first party models.
Instance Attribute Summary collapse
-
#evaluation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationConfig
Evaluation Config for Tuning Job.
-
#export_last_checkpoint_only ⇒ Boolean
(also: #export_last_checkpoint_only?)
Optional.
-
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedHyperParameters
Hyperparameters for SFT.
-
#training_dataset_uri ⇒ String
Required.
-
#tuning_mode ⇒ String
Tuning mode.
-
#validation_dataset_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1SupervisedTuningSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningSpec
Returns a new instance of GoogleCloudAiplatformV1beta1SupervisedTuningSpec.
63862 63863 63864 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63862 def initialize(**args) update!(**args) end |
Instance Attribute Details
#evaluation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationConfig
Evaluation Config for Tuning Job.
Corresponds to the JSON property evaluationConfig
63828 63829 63830 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63828 def evaluation_config @evaluation_config end |
#export_last_checkpoint_only ⇒ Boolean Also known as: export_last_checkpoint_only?
Optional. If set to true, disable intermediate checkpoints for SFT and only
the last checkpoint will be exported. Otherwise, enable intermediate
checkpoints for SFT. Default is false.
Corresponds to the JSON property exportLastCheckpointOnly
63835 63836 63837 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63835 def export_last_checkpoint_only @export_last_checkpoint_only end |
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedHyperParameters
Hyperparameters for SFT.
Corresponds to the JSON property hyperParameters
63841 63842 63843 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63841 def hyper_parameters @hyper_parameters end |
#training_dataset_uri ⇒ String
Required. Training dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property trainingDatasetUri
63848 63849 63850 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63848 def training_dataset_uri @training_dataset_uri end |
#tuning_mode ⇒ String
Tuning mode.
Corresponds to the JSON property tuningMode
63853 63854 63855 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63853 def tuning_mode @tuning_mode end |
#validation_dataset_uri ⇒ String
Optional. Validation dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property validationDatasetUri
63860 63861 63862 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63860 def validation_dataset_uri @validation_dataset_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63867 63868 63869 63870 63871 63872 63873 63874 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63867 def update!(**args) @evaluation_config = args[:evaluation_config] if args.key?(:evaluation_config) @export_last_checkpoint_only = args[:export_last_checkpoint_only] if args.key?(:export_last_checkpoint_only) @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters) @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri) @tuning_mode = args[:tuning_mode] if args.key?(:tuning_mode) @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri) end |