Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Tuning Spec for Supervised Tuning for first party models.
Instance Attribute Summary collapse
-
#evaluation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationConfig
Evaluation Config for Tuning Job.
-
#export_last_checkpoint_only ⇒ Boolean
(also: #export_last_checkpoint_only?)
Optional.
-
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedHyperParameters
Hyperparameters for SFT.
-
#training_dataset_uri ⇒ String
Required.
-
#tuning_mode ⇒ String
Tuning mode.
-
#validation_dataset_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1SupervisedTuningSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SupervisedTuningSpec
Returns a new instance of GoogleCloudAiplatformV1beta1SupervisedTuningSpec.
61363 61364 61365 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61363 def initialize(**args) update!(**args) end |
Instance Attribute Details
#evaluation_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluationConfig
Evaluation Config for Tuning Job.
Corresponds to the JSON property evaluationConfig
61329 61330 61331 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61329 def evaluation_config @evaluation_config end |
#export_last_checkpoint_only ⇒ Boolean Also known as: export_last_checkpoint_only?
Optional. If set to true, disable intermediate checkpoints for SFT and only
the last checkpoint will be exported. Otherwise, enable intermediate
checkpoints for SFT. Default is false.
Corresponds to the JSON property exportLastCheckpointOnly
61336 61337 61338 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61336 def export_last_checkpoint_only @export_last_checkpoint_only end |
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedHyperParameters
Hyperparameters for SFT.
Corresponds to the JSON property hyperParameters
61342 61343 61344 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61342 def hyper_parameters @hyper_parameters end |
#training_dataset_uri ⇒ String
Required. Training dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property trainingDatasetUri
61349 61350 61351 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61349 def training_dataset_uri @training_dataset_uri end |
#tuning_mode ⇒ String
Tuning mode.
Corresponds to the JSON property tuningMode
61354 61355 61356 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61354 def tuning_mode @tuning_mode end |
#validation_dataset_uri ⇒ String
Optional. Validation dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property validationDatasetUri
61361 61362 61363 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61361 def validation_dataset_uri @validation_dataset_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61368 61369 61370 61371 61372 61373 61374 61375 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61368 def update!(**args) @evaluation_config = args[:evaluation_config] if args.key?(:evaluation_config) @export_last_checkpoint_only = args[:export_last_checkpoint_only] if args.key?(:export_last_checkpoint_only) @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters) @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri) @tuning_mode = args[:tuning_mode] if args.key?(:tuning_mode) @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri) end |