Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SyntheticExample

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A single instance of generated synthetic data. Each example is made up of one or more named fields, as defined in OutputFieldSpec. These examples are used as few-shot examples to show the model what you want (in GenerateSyntheticDataRequest.examples) and to return generated examples in the response (in GenerateSyntheticDataResponse.synthetic_examples).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SyntheticExample

Returns a new instance of GoogleCloudAiplatformV1beta1SyntheticExample.



53353
53354
53355
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53353

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SyntheticField>

Required. A list of fields that constitute an example. Corresponds to the JSON property fields



53351
53352
53353
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53351

def fields
  @fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53358
53359
53360
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53358

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
end