Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SyntheticField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a single named field within a synthetic example, consisting of a name and the actual content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SyntheticField

Returns a new instance of GoogleCloudAiplatformV1beta1SyntheticField.



58426
58427
58428
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58426

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



58418
58419
58420
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58418

def content
  @content
end

#field_nameString

Optional. The name of the specific field, such as "product_name" or " review_text". Corresponds to the JSON property fieldName

Returns:

  • (String)


58424
58425
58426
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58424

def field_name
  @field_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58431
58432
58433
58434
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58431

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @field_name = args[:field_name] if args.key?(:field_name)
end