Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SyntheticField
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SyntheticField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a single named field within a synthetic example, consisting of a name and the actual content.
Instance Attribute Summary collapse
-
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message.
-
#field_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SyntheticField
constructor
A new instance of GoogleCloudAiplatformV1beta1SyntheticField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SyntheticField
Returns a new instance of GoogleCloudAiplatformV1beta1SyntheticField.
53217 53218 53219 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
53209 53210 53211 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53209 def content @content end |
#field_name ⇒ String
Optional. The name of the specific field, such as "product_name" or "
review_text".
Corresponds to the JSON property fieldName
53215 53216 53217 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53215 def field_name @field_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53222 53223 53224 53225 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53222 def update!(**args) @content = args[:content] if args.key?(:content) @field_name = args[:field_name] if args.key?(:field_name) end |