Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskArtifact
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskArtifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a single artifact produced by a task. sample: artifacts:
artifact_id: "image-12345" name: "Generated Sunset Image" description: "A
beautiful sunset over the mountains, generated by the user's request." parts:
inline_data: mime_type: "image/png" data: "
iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAA="
Instance Attribute Summary collapse
-
#artifact_id ⇒ String
Required.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#metadata ⇒ Hash<String,Object>
Optional.
-
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskArtifact
constructor
A new instance of GoogleCloudAiplatformV1beta1TaskArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskArtifact
Returns a new instance of GoogleCloudAiplatformV1beta1TaskArtifact.
63477 63478 63479 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63477 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_id ⇒ String
Required. The unique identifier of the artifact within the task. This id is
provided by the creator of the artifact.
Corresponds to the JSON property artifactId
63454 63455 63456 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63454 def artifact_id @artifact_id end |
#description ⇒ String
Optional. A human readable description of the artifact.
Corresponds to the JSON property description
63459 63460 63461 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63459 def description @description end |
#display_name ⇒ String
Optional. The human-readable name of the artifact provided by the creator.
Corresponds to the JSON property displayName
63464 63465 63466 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63464 def display_name @display_name end |
#metadata ⇒ Hash<String,Object>
Optional. Additional metadata for the artifact. For A2A, the URIs of the
extensions that were used to produce this artifact will be stored here.
Corresponds to the JSON property metadata
63470 63471 63472 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63470 def @metadata end |
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>
Required. The content of the artifact.
Corresponds to the JSON property parts
63475 63476 63477 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63475 def parts @parts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63482 63483 63484 63485 63486 63487 63488 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63482 def update!(**args) @artifact_id = args[:artifact_id] if args.key?(:artifact_id) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @metadata = args[:metadata] if args.key?(:metadata) @parts = args[:parts] if args.key?(:parts) end |