Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskArtifact
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskArtifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a single artifact produced by a task. sample: artifacts:
artifact_id: "image-12345" name: "Generated Sunset Image" description: "A
beautiful sunset over the mountains, generated by the user's request." parts:
inline_data: mime_type: "image/png" data: "
iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAA="
Instance Attribute Summary collapse
-
#artifact_id ⇒ String
Required.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#metadata ⇒ Hash<String,Object>
Optional.
-
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskArtifact
constructor
A new instance of GoogleCloudAiplatformV1beta1TaskArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskArtifact
Returns a new instance of GoogleCloudAiplatformV1beta1TaskArtifact.
62162 62163 62164 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_id ⇒ String
Required. The unique identifier of the artifact within the task. This id is
provided by the creator of the artifact.
Corresponds to the JSON property artifactId
62139 62140 62141 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62139 def artifact_id @artifact_id end |
#description ⇒ String
Optional. A human readable description of the artifact.
Corresponds to the JSON property description
62144 62145 62146 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62144 def description @description end |
#display_name ⇒ String
Optional. The human-readable name of the artifact provided by the creator.
Corresponds to the JSON property displayName
62149 62150 62151 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62149 def display_name @display_name end |
#metadata ⇒ Hash<String,Object>
Optional. Additional metadata for the artifact. For A2A, the URIs of the
extensions that were used to produce this artifact will be stored here.
Corresponds to the JSON property metadata
62155 62156 62157 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62155 def @metadata end |
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>
Required. The content of the artifact.
Corresponds to the JSON property parts
62160 62161 62162 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62160 def parts @parts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62167 62168 62169 62170 62171 62172 62173 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62167 def update!(**args) @artifact_id = args[:artifact_id] if args.key?(:artifact_id) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @metadata = args[:metadata] if args.key?(:metadata) @parts = args[:parts] if args.key?(:parts) end |