Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskArtifact
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskArtifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a single artifact produced by a task. sample: artifacts:
artifact_id: "image-12345" name: "Generated Sunset Image" description: "A
beautiful sunset over the mountains, generated by the user's request." parts:
inline_data: mime_type: "image/png" data: "
iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAA="
Instance Attribute Summary collapse
-
#artifact_id ⇒ String
Required.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#metadata ⇒ Hash<String,Object>
Optional.
-
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskArtifact
constructor
A new instance of GoogleCloudAiplatformV1beta1TaskArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskArtifact
Returns a new instance of GoogleCloudAiplatformV1beta1TaskArtifact.
61362 61363 61364 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_id ⇒ String
Required. The unique identifier of the artifact within the task. This id is
provided by the creator of the artifact.
Corresponds to the JSON property artifactId
61339 61340 61341 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61339 def artifact_id @artifact_id end |
#description ⇒ String
Optional. A human readable description of the artifact.
Corresponds to the JSON property description
61344 61345 61346 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61344 def description @description end |
#display_name ⇒ String
Optional. The human-readable name of the artifact provided by the creator.
Corresponds to the JSON property displayName
61349 61350 61351 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61349 def display_name @display_name end |
#metadata ⇒ Hash<String,Object>
Optional. Additional metadata for the artifact. For A2A, the URIs of the
extensions that were used to produce this artifact will be stored here.
Corresponds to the JSON property metadata
61355 61356 61357 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61355 def @metadata end |
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>
Required. The content of the artifact.
Corresponds to the JSON property parts
61360 61361 61362 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61360 def parts @parts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61367 61368 61369 61370 61371 61372 61373 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61367 def update!(**args) @artifact_id = args[:artifact_id] if args.key?(:artifact_id) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @metadata = args[:metadata] if args.key?(:metadata) @parts = args[:parts] if args.key?(:parts) end |