Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a single artifact produced by a task. sample: artifacts: artifact_id: "image-12345" name: "Generated Sunset Image" description: "A beautiful sunset over the mountains, generated by the user's request." parts: inline_data: mime_type: "image/png" data: " iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAA="

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskArtifact

Returns a new instance of GoogleCloudAiplatformV1beta1TaskArtifact.



61550
61551
61552
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_idString

Required. The unique identifier of the artifact within the task. This id is provided by the creator of the artifact. Corresponds to the JSON property artifactId

Returns:

  • (String)


61527
61528
61529
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61527

def artifact_id
  @artifact_id
end

#descriptionString

Optional. A human readable description of the artifact. Corresponds to the JSON property description

Returns:

  • (String)


61532
61533
61534
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61532

def description
  @description
end

#display_nameString

Optional. The human-readable name of the artifact provided by the creator. Corresponds to the JSON property displayName

Returns:

  • (String)


61537
61538
61539
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61537

def display_name
  @display_name
end

#metadataHash<String,Object>

Optional. Additional metadata for the artifact. For A2A, the URIs of the extensions that were used to produce this artifact will be stored here. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


61543
61544
61545
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61543

def 
  @metadata
end

#partsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>

Required. The content of the artifact. Corresponds to the JSON property parts



61548
61549
61550
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61548

def parts
  @parts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61555
61556
61557
61558
61559
61560
61561
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61555

def update!(**args)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @metadata = args[:metadata] if args.key?(:metadata)
  @parts = args[:parts] if args.key?(:parts)
end