Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents a single artifact produced by a task. sample: artifacts: artifact_id: "image-12345" name: "Generated Sunset Image" description: "A beautiful sunset over the mountains, generated by the user's request." parts: inline_data: mime_type: "image/png" data: " iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAA="

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskArtifact

Returns a new instance of GoogleCloudAiplatformV1beta1TaskArtifact.



59948
59949
59950
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_idString

Required. The unique identifier of the artifact within the task. This id is provided by the creator of the artifact. Corresponds to the JSON property artifactId

Returns:

  • (String)


59925
59926
59927
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59925

def artifact_id
  @artifact_id
end

#descriptionString

Optional. A human readable description of the artifact. Corresponds to the JSON property description

Returns:

  • (String)


59930
59931
59932
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59930

def description
  @description
end

#display_nameString

Optional. The human-readable name of the artifact provided by the creator. Corresponds to the JSON property displayName

Returns:

  • (String)


59935
59936
59937
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59935

def display_name
  @display_name
end

#metadataHash<String,Object>

Optional. Additional metadata for the artifact. For A2A, the URIs of the extensions that were used to produce this artifact will be stored here. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


59941
59942
59943
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59941

def 
  @metadata
end

#partsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>

Required. The content of the artifact. Corresponds to the JSON property parts



59946
59947
59948
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59946

def parts
  @parts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59953
59954
59955
59956
59957
59958
59959
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59953

def update!(**args)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @metadata = args[:metadata] if args.key?(:metadata)
  @parts = args[:parts] if args.key?(:parts)
end