Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskArtifact
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskArtifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a single artifact produced by a task. sample: artifacts:
artifact_id: "image-12345" name: "Generated Sunset Image" description: "A
beautiful sunset over the mountains, generated by the user's request." parts:
inline_data: mime_type: "image/png" data: "
iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAA="
Instance Attribute Summary collapse
-
#artifact_id ⇒ String
Required.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#metadata ⇒ Hash<String,Object>
Optional.
-
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskArtifact
constructor
A new instance of GoogleCloudAiplatformV1beta1TaskArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskArtifact
Returns a new instance of GoogleCloudAiplatformV1beta1TaskArtifact.
58491 58492 58493 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58491 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_id ⇒ String
Required. The unique identifier of the artifact within the task. This id is
provided by the creator of the artifact.
Corresponds to the JSON property artifactId
58468 58469 58470 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58468 def artifact_id @artifact_id end |
#description ⇒ String
Optional. A human readable description of the artifact.
Corresponds to the JSON property description
58473 58474 58475 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58473 def description @description end |
#display_name ⇒ String
Optional. The human-readable name of the artifact provided by the creator.
Corresponds to the JSON property displayName
58478 58479 58480 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58478 def display_name @display_name end |
#metadata ⇒ Hash<String,Object>
Optional. Additional metadata for the artifact. For A2A, the URIs of the
extensions that were used to produce this artifact will be stored here.
Corresponds to the JSON property metadata
58484 58485 58486 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58484 def @metadata end |
#parts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Part>
Required. The content of the artifact.
Corresponds to the JSON property parts
58489 58490 58491 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58489 def parts @parts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58496 58497 58498 58499 58500 58501 58502 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58496 def update!(**args) @artifact_id = args[:artifact_id] if args.key?(:artifact_id) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @metadata = args[:metadata] if args.key?(:metadata) @parts = args[:parts] if args.key?(:parts) end |