Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskDescriptionStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Defines a generation strategy based on a general task description.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskDescriptionStrategy

Returns a new instance of GoogleCloudAiplatformV1beta1TaskDescriptionStrategy.



58546
58547
58548
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58546

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#task_descriptionString

Required. A general description of the type of synthetic data you want to generate. For example, "Generate customer reviews for a new smartphone." Corresponds to the JSON property taskDescription

Returns:

  • (String)


58544
58545
58546
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58544

def task_description
  @task_description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58551
58552
58553
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58551

def update!(**args)
  @task_description = args[:task_description] if args.key?(:task_description)
end