Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskMetadataChange
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TaskMetadataChange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
An event representing a change to the task's top-level metadata. example:
metadata_change: new_metadata: "name": "My task", update_mask: paths: "
name"
Instance Attribute Summary collapse
-
#new_metadata ⇒ Hash<String,Object>
Required.
-
#update_mask ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskMetadataChange
constructor
A new instance of GoogleCloudAiplatformV1beta1TaskMetadataChange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TaskMetadataChange
Returns a new instance of GoogleCloudAiplatformV1beta1TaskMetadataChange.
53476 53477 53478 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53476 def initialize(**args) update!(**args) end |
Instance Attribute Details
#new_metadata ⇒ Hash<String,Object>
Required. The complete state of the metadata object after the change.
Corresponds to the JSON property newMetadata
53468 53469 53470 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53468 def @new_metadata end |
#update_mask ⇒ String
Optional. A field mask indicating which paths in the Struct were changed. If
not set, all fields will be updated. go/aip-internal/cloud-standard/2412
Corresponds to the JSON property updateMask
53474 53475 53476 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53474 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53481 53482 53483 53484 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53481 def update!(**args) @new_metadata = args[:new_metadata] if args.key?(:new_metadata) @update_mask = args[:update_mask] if args.key?(:update_mask) end |