Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tensor value type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tensor

Returns a new instance of GoogleCloudAiplatformV1beta1Tensor.



63856
63857
63858
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63856

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valArray<Boolean>

Type specific representations that make it easy to create tensor protos in all languages. Only the representation corresponding to "dtype" can be set. The values hold the flattened representation of the tensor in row major order. BOOL Corresponds to the JSON property boolVal

Returns:

  • (Array<Boolean>)


63788
63789
63790
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63788

def bool_val
  @bool_val
end

#bytes_valArray<String>

STRING Corresponds to the JSON property bytesVal

Returns:

  • (Array<String>)


63793
63794
63795
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63793

def bytes_val
  @bytes_val
end

#double_valArray<Float>

DOUBLE Corresponds to the JSON property doubleVal

Returns:

  • (Array<Float>)


63798
63799
63800
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63798

def double_val
  @double_val
end

#dtypeString

The data type of tensor. Corresponds to the JSON property dtype

Returns:

  • (String)


63803
63804
63805
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63803

def dtype
  @dtype
end

#float_valArray<Float>

FLOAT Corresponds to the JSON property floatVal

Returns:

  • (Array<Float>)


63808
63809
63810
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63808

def float_val
  @float_val
end

#int64_valArray<Fixnum>

INT64 Corresponds to the JSON property int64Val

Returns:

  • (Array<Fixnum>)


63813
63814
63815
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63813

def int64_val
  @int64_val
end

#int_valArray<Fixnum>

INT_8 INT_16 INT_32 Corresponds to the JSON property intVal

Returns:

  • (Array<Fixnum>)


63818
63819
63820
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63818

def int_val
  @int_val
end

#list_valArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>

A list of tensor values. Corresponds to the JSON property listVal



63823
63824
63825
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63823

def list_val
  @list_val
end

#shapeArray<Fixnum>

Shape of the tensor. Corresponds to the JSON property shape

Returns:

  • (Array<Fixnum>)


63828
63829
63830
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63828

def shape
  @shape
end

#string_valArray<String>

STRING Corresponds to the JSON property stringVal

Returns:

  • (Array<String>)


63833
63834
63835
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63833

def string_val
  @string_val
end

#struct_valHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>

A map of string to tensor. Corresponds to the JSON property structVal



63838
63839
63840
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63838

def struct_val
  @struct_val
end

#tensor_valString

Serialized raw tensor content. Corresponds to the JSON property tensorVal NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


63844
63845
63846
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63844

def tensor_val
  @tensor_val
end

#uint64_valArray<Fixnum>

UINT64 Corresponds to the JSON property uint64Val

Returns:

  • (Array<Fixnum>)


63849
63850
63851
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63849

def uint64_val
  @uint64_val
end

#uint_valArray<Fixnum>

UINT8 UINT16 UINT32 Corresponds to the JSON property uintVal

Returns:

  • (Array<Fixnum>)


63854
63855
63856
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63854

def uint_val
  @uint_val
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63861
63862
63863
63864
63865
63866
63867
63868
63869
63870
63871
63872
63873
63874
63875
63876
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63861

def update!(**args)
  @bool_val = args[:bool_val] if args.key?(:bool_val)
  @bytes_val = args[:bytes_val] if args.key?(:bytes_val)
  @double_val = args[:double_val] if args.key?(:double_val)
  @dtype = args[:dtype] if args.key?(:dtype)
  @float_val = args[:float_val] if args.key?(:float_val)
  @int64_val = args[:int64_val] if args.key?(:int64_val)
  @int_val = args[:int_val] if args.key?(:int_val)
  @list_val = args[:list_val] if args.key?(:list_val)
  @shape = args[:shape] if args.key?(:shape)
  @string_val = args[:string_val] if args.key?(:string_val)
  @struct_val = args[:struct_val] if args.key?(:struct_val)
  @tensor_val = args[:tensor_val] if args.key?(:tensor_val)
  @uint64_val = args[:uint64_val] if args.key?(:uint64_val)
  @uint_val = args[:uint_val] if args.key?(:uint_val)
end