Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A tensor value type.
Instance Attribute Summary collapse
-
#bool_val ⇒ Array<Boolean>
Type specific representations that make it easy to create tensor protos in all languages.
-
#bytes_val ⇒ Array<String>
STRING Corresponds to the JSON property
bytesVal. -
#double_val ⇒ Array<Float>
DOUBLE Corresponds to the JSON property
doubleVal. -
#dtype ⇒ String
The data type of tensor.
-
#float_val ⇒ Array<Float>
FLOAT Corresponds to the JSON property
floatVal. -
#int64_val ⇒ Array<Fixnum>
INT64 Corresponds to the JSON property
int64Val. -
#int_val ⇒ Array<Fixnum>
INT_8 INT_16 INT_32 Corresponds to the JSON property
intVal. -
#list_val ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>
A list of tensor values.
-
#shape ⇒ Array<Fixnum>
Shape of the tensor.
-
#string_val ⇒ Array<String>
STRING Corresponds to the JSON property
stringVal. -
#struct_val ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>
A map of string to tensor.
-
#tensor_val ⇒ String
Serialized raw tensor content.
-
#uint64_val ⇒ Array<Fixnum>
UINT64 Corresponds to the JSON property
uint64Val. -
#uint_val ⇒ Array<Fixnum>
UINT8 UINT16 UINT32 Corresponds to the JSON property
uintVal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tensor
constructor
A new instance of GoogleCloudAiplatformV1beta1Tensor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tensor
Returns a new instance of GoogleCloudAiplatformV1beta1Tensor.
60327 60328 60329 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60327 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_val ⇒ Array<Boolean>
Type specific representations that make it easy to create tensor protos in all
languages. Only the representation corresponding to "dtype" can be set. The
values hold the flattened representation of the tensor in row major order.
BOOL
Corresponds to the JSON property boolVal
60259 60260 60261 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60259 def bool_val @bool_val end |
#bytes_val ⇒ Array<String>
STRING
Corresponds to the JSON property bytesVal
60264 60265 60266 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60264 def bytes_val @bytes_val end |
#double_val ⇒ Array<Float>
DOUBLE
Corresponds to the JSON property doubleVal
60269 60270 60271 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60269 def double_val @double_val end |
#dtype ⇒ String
The data type of tensor.
Corresponds to the JSON property dtype
60274 60275 60276 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60274 def dtype @dtype end |
#float_val ⇒ Array<Float>
FLOAT
Corresponds to the JSON property floatVal
60279 60280 60281 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60279 def float_val @float_val end |
#int64_val ⇒ Array<Fixnum>
INT64
Corresponds to the JSON property int64Val
60284 60285 60286 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60284 def int64_val @int64_val end |
#int_val ⇒ Array<Fixnum>
INT_8 INT_16 INT_32
Corresponds to the JSON property intVal
60289 60290 60291 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60289 def int_val @int_val end |
#list_val ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>
A list of tensor values.
Corresponds to the JSON property listVal
60294 60295 60296 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60294 def list_val @list_val end |
#shape ⇒ Array<Fixnum>
Shape of the tensor.
Corresponds to the JSON property shape
60299 60300 60301 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60299 def shape @shape end |
#string_val ⇒ Array<String>
STRING
Corresponds to the JSON property stringVal
60304 60305 60306 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60304 def string_val @string_val end |
#struct_val ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>
A map of string to tensor.
Corresponds to the JSON property structVal
60309 60310 60311 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60309 def struct_val @struct_val end |
#tensor_val ⇒ String
Serialized raw tensor content.
Corresponds to the JSON property tensorVal
NOTE: Values are automatically base64 encoded/decoded in the client library.
60315 60316 60317 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60315 def tensor_val @tensor_val end |
#uint64_val ⇒ Array<Fixnum>
UINT64
Corresponds to the JSON property uint64Val
60320 60321 60322 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60320 def uint64_val @uint64_val end |
#uint_val ⇒ Array<Fixnum>
UINT8 UINT16 UINT32
Corresponds to the JSON property uintVal
60325 60326 60327 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60325 def uint_val @uint_val end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60332 60333 60334 60335 60336 60337 60338 60339 60340 60341 60342 60343 60344 60345 60346 60347 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 60332 def update!(**args) @bool_val = args[:bool_val] if args.key?(:bool_val) @bytes_val = args[:bytes_val] if args.key?(:bytes_val) @double_val = args[:double_val] if args.key?(:double_val) @dtype = args[:dtype] if args.key?(:dtype) @float_val = args[:float_val] if args.key?(:float_val) @int64_val = args[:int64_val] if args.key?(:int64_val) @int_val = args[:int_val] if args.key?(:int_val) @list_val = args[:list_val] if args.key?(:list_val) @shape = args[:shape] if args.key?(:shape) @string_val = args[:string_val] if args.key?(:string_val) @struct_val = args[:struct_val] if args.key?(:struct_val) @tensor_val = args[:tensor_val] if args.key?(:tensor_val) @uint64_val = args[:uint64_val] if args.key?(:uint64_val) @uint_val = args[:uint_val] if args.key?(:uint_val) end |