Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tensor value type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tensor

Returns a new instance of GoogleCloudAiplatformV1beta1Tensor.



58870
58871
58872
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58870

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valArray<Boolean>

Type specific representations that make it easy to create tensor protos in all languages. Only the representation corresponding to "dtype" can be set. The values hold the flattened representation of the tensor in row major order. BOOL Corresponds to the JSON property boolVal

Returns:

  • (Array<Boolean>)


58802
58803
58804
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58802

def bool_val
  @bool_val
end

#bytes_valArray<String>

STRING Corresponds to the JSON property bytesVal

Returns:

  • (Array<String>)


58807
58808
58809
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58807

def bytes_val
  @bytes_val
end

#double_valArray<Float>

DOUBLE Corresponds to the JSON property doubleVal

Returns:

  • (Array<Float>)


58812
58813
58814
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58812

def double_val
  @double_val
end

#dtypeString

The data type of tensor. Corresponds to the JSON property dtype

Returns:

  • (String)


58817
58818
58819
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58817

def dtype
  @dtype
end

#float_valArray<Float>

FLOAT Corresponds to the JSON property floatVal

Returns:

  • (Array<Float>)


58822
58823
58824
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58822

def float_val
  @float_val
end

#int64_valArray<Fixnum>

INT64 Corresponds to the JSON property int64Val

Returns:

  • (Array<Fixnum>)


58827
58828
58829
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58827

def int64_val
  @int64_val
end

#int_valArray<Fixnum>

INT_8 INT_16 INT_32 Corresponds to the JSON property intVal

Returns:

  • (Array<Fixnum>)


58832
58833
58834
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58832

def int_val
  @int_val
end

#list_valArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>

A list of tensor values. Corresponds to the JSON property listVal



58837
58838
58839
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58837

def list_val
  @list_val
end

#shapeArray<Fixnum>

Shape of the tensor. Corresponds to the JSON property shape

Returns:

  • (Array<Fixnum>)


58842
58843
58844
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58842

def shape
  @shape
end

#string_valArray<String>

STRING Corresponds to the JSON property stringVal

Returns:

  • (Array<String>)


58847
58848
58849
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58847

def string_val
  @string_val
end

#struct_valHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>

A map of string to tensor. Corresponds to the JSON property structVal



58852
58853
58854
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58852

def struct_val
  @struct_val
end

#tensor_valString

Serialized raw tensor content. Corresponds to the JSON property tensorVal NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


58858
58859
58860
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58858

def tensor_val
  @tensor_val
end

#uint64_valArray<Fixnum>

UINT64 Corresponds to the JSON property uint64Val

Returns:

  • (Array<Fixnum>)


58863
58864
58865
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58863

def uint64_val
  @uint64_val
end

#uint_valArray<Fixnum>

UINT8 UINT16 UINT32 Corresponds to the JSON property uintVal

Returns:

  • (Array<Fixnum>)


58868
58869
58870
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58868

def uint_val
  @uint_val
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58875
58876
58877
58878
58879
58880
58881
58882
58883
58884
58885
58886
58887
58888
58889
58890
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58875

def update!(**args)
  @bool_val = args[:bool_val] if args.key?(:bool_val)
  @bytes_val = args[:bytes_val] if args.key?(:bytes_val)
  @double_val = args[:double_val] if args.key?(:double_val)
  @dtype = args[:dtype] if args.key?(:dtype)
  @float_val = args[:float_val] if args.key?(:float_val)
  @int64_val = args[:int64_val] if args.key?(:int64_val)
  @int_val = args[:int_val] if args.key?(:int_val)
  @list_val = args[:list_val] if args.key?(:list_val)
  @shape = args[:shape] if args.key?(:shape)
  @string_val = args[:string_val] if args.key?(:string_val)
  @struct_val = args[:struct_val] if args.key?(:struct_val)
  @tensor_val = args[:tensor_val] if args.key?(:tensor_val)
  @uint64_val = args[:uint64_val] if args.key?(:uint64_val)
  @uint_val = args[:uint_val] if args.key?(:uint_val)
end