Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tensor value type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tensor

Returns a new instance of GoogleCloudAiplatformV1beta1Tensor.



53825
53826
53827
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53825

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valArray<Boolean>

Type specific representations that make it easy to create tensor protos in all languages. Only the representation corresponding to "dtype" can be set. The values hold the flattened representation of the tensor in row major order. BOOL Corresponds to the JSON property boolVal

Returns:

  • (Array<Boolean>)


53757
53758
53759
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53757

def bool_val
  @bool_val
end

#bytes_valArray<String>

STRING Corresponds to the JSON property bytesVal

Returns:

  • (Array<String>)


53762
53763
53764
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53762

def bytes_val
  @bytes_val
end

#double_valArray<Float>

DOUBLE Corresponds to the JSON property doubleVal

Returns:

  • (Array<Float>)


53767
53768
53769
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53767

def double_val
  @double_val
end

#dtypeString

The data type of tensor. Corresponds to the JSON property dtype

Returns:

  • (String)


53772
53773
53774
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53772

def dtype
  @dtype
end

#float_valArray<Float>

FLOAT Corresponds to the JSON property floatVal

Returns:

  • (Array<Float>)


53777
53778
53779
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53777

def float_val
  @float_val
end

#int64_valArray<Fixnum>

INT64 Corresponds to the JSON property int64Val

Returns:

  • (Array<Fixnum>)


53782
53783
53784
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53782

def int64_val
  @int64_val
end

#int_valArray<Fixnum>

INT_8 INT_16 INT_32 Corresponds to the JSON property intVal

Returns:

  • (Array<Fixnum>)


53787
53788
53789
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53787

def int_val
  @int_val
end

#list_valArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>

A list of tensor values. Corresponds to the JSON property listVal



53792
53793
53794
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53792

def list_val
  @list_val
end

#shapeArray<Fixnum>

Shape of the tensor. Corresponds to the JSON property shape

Returns:

  • (Array<Fixnum>)


53797
53798
53799
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53797

def shape
  @shape
end

#string_valArray<String>

STRING Corresponds to the JSON property stringVal

Returns:

  • (Array<String>)


53802
53803
53804
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53802

def string_val
  @string_val
end

#struct_valHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>

A map of string to tensor. Corresponds to the JSON property structVal



53807
53808
53809
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53807

def struct_val
  @struct_val
end

#tensor_valString

Serialized raw tensor content. Corresponds to the JSON property tensorVal NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


53813
53814
53815
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53813

def tensor_val
  @tensor_val
end

#uint64_valArray<Fixnum>

UINT64 Corresponds to the JSON property uint64Val

Returns:

  • (Array<Fixnum>)


53818
53819
53820
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53818

def uint64_val
  @uint64_val
end

#uint_valArray<Fixnum>

UINT8 UINT16 UINT32 Corresponds to the JSON property uintVal

Returns:

  • (Array<Fixnum>)


53823
53824
53825
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53823

def uint_val
  @uint_val
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53830
53831
53832
53833
53834
53835
53836
53837
53838
53839
53840
53841
53842
53843
53844
53845
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53830

def update!(**args)
  @bool_val = args[:bool_val] if args.key?(:bool_val)
  @bytes_val = args[:bytes_val] if args.key?(:bytes_val)
  @double_val = args[:double_val] if args.key?(:double_val)
  @dtype = args[:dtype] if args.key?(:dtype)
  @float_val = args[:float_val] if args.key?(:float_val)
  @int64_val = args[:int64_val] if args.key?(:int64_val)
  @int_val = args[:int_val] if args.key?(:int_val)
  @list_val = args[:list_val] if args.key?(:list_val)
  @shape = args[:shape] if args.key?(:shape)
  @string_val = args[:string_val] if args.key?(:string_val)
  @struct_val = args[:struct_val] if args.key?(:struct_val)
  @tensor_val = args[:tensor_val] if args.key?(:tensor_val)
  @uint64_val = args[:uint64_val] if args.key?(:uint64_val)
  @uint_val = args[:uint_val] if args.key?(:uint_val)
end