Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A tensor value type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tensor

Returns a new instance of GoogleCloudAiplatformV1beta1Tensor.



53661
53662
53663
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53661

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valArray<Boolean>

Type specific representations that make it easy to create tensor protos in all languages. Only the representation corresponding to "dtype" can be set. The values hold the flattened representation of the tensor in row major order. BOOL Corresponds to the JSON property boolVal

Returns:

  • (Array<Boolean>)


53593
53594
53595
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53593

def bool_val
  @bool_val
end

#bytes_valArray<String>

STRING Corresponds to the JSON property bytesVal

Returns:

  • (Array<String>)


53598
53599
53600
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53598

def bytes_val
  @bytes_val
end

#double_valArray<Float>

DOUBLE Corresponds to the JSON property doubleVal

Returns:

  • (Array<Float>)


53603
53604
53605
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53603

def double_val
  @double_val
end

#dtypeString

The data type of tensor. Corresponds to the JSON property dtype

Returns:

  • (String)


53608
53609
53610
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53608

def dtype
  @dtype
end

#float_valArray<Float>

FLOAT Corresponds to the JSON property floatVal

Returns:

  • (Array<Float>)


53613
53614
53615
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53613

def float_val
  @float_val
end

#int64_valArray<Fixnum>

INT64 Corresponds to the JSON property int64Val

Returns:

  • (Array<Fixnum>)


53618
53619
53620
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53618

def int64_val
  @int64_val
end

#int_valArray<Fixnum>

INT_8 INT_16 INT_32 Corresponds to the JSON property intVal

Returns:

  • (Array<Fixnum>)


53623
53624
53625
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53623

def int_val
  @int_val
end

#list_valArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>

A list of tensor values. Corresponds to the JSON property listVal



53628
53629
53630
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53628

def list_val
  @list_val
end

#shapeArray<Fixnum>

Shape of the tensor. Corresponds to the JSON property shape

Returns:

  • (Array<Fixnum>)


53633
53634
53635
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53633

def shape
  @shape
end

#string_valArray<String>

STRING Corresponds to the JSON property stringVal

Returns:

  • (Array<String>)


53638
53639
53640
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53638

def string_val
  @string_val
end

#struct_valHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tensor>

A map of string to tensor. Corresponds to the JSON property structVal



53643
53644
53645
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53643

def struct_val
  @struct_val
end

#tensor_valString

Serialized raw tensor content. Corresponds to the JSON property tensorVal NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


53649
53650
53651
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53649

def tensor_val
  @tensor_val
end

#uint64_valArray<Fixnum>

UINT64 Corresponds to the JSON property uint64Val

Returns:

  • (Array<Fixnum>)


53654
53655
53656
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53654

def uint64_val
  @uint64_val
end

#uint_valArray<Fixnum>

UINT8 UINT16 UINT32 Corresponds to the JSON property uintVal

Returns:

  • (Array<Fixnum>)


53659
53660
53661
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53659

def uint_val
  @uint_val
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53666
53667
53668
53669
53670
53671
53672
53673
53674
53675
53676
53677
53678
53679
53680
53681
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53666

def update!(**args)
  @bool_val = args[:bool_val] if args.key?(:bool_val)
  @bytes_val = args[:bytes_val] if args.key?(:bytes_val)
  @double_val = args[:double_val] if args.key?(:double_val)
  @dtype = args[:dtype] if args.key?(:dtype)
  @float_val = args[:float_val] if args.key?(:float_val)
  @int64_val = args[:int64_val] if args.key?(:int64_val)
  @int_val = args[:int_val] if args.key?(:int_val)
  @list_val = args[:list_val] if args.key?(:list_val)
  @shape = args[:shape] if args.key?(:shape)
  @string_val = args[:string_val] if args.key?(:string_val)
  @struct_val = args[:struct_val] if args.key?(:struct_val)
  @tensor_val = args[:tensor_val] if args.key?(:tensor_val)
  @uint64_val = args[:uint64_val] if args.key?(:uint64_val)
  @uint_val = args[:uint_val] if args.key?(:uint_val)
end