Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardExperiment
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardExperiment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A TensorboardExperiment is a group of TensorboardRuns, that are typically the results of a training job run, in a Tensorboard.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of this TensorboardExperiment.
-
#display_name ⇒ String
User provided name of this TensorboardExperiment.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardExperiment.
-
#name ⇒ String
Output only.
-
#source ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TensorboardExperiment
constructor
A new instance of GoogleCloudAiplatformV1beta1TensorboardExperiment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TensorboardExperiment
Returns a new instance of GoogleCloudAiplatformV1beta1TensorboardExperiment.
62777 62778 62779 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this TensorboardExperiment was created.
Corresponds to the JSON property createTime
62729 62730 62731 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62729 def create_time @create_time end |
#description ⇒ String
Description of this TensorboardExperiment.
Corresponds to the JSON property description
62734 62735 62736 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62734 def description @description end |
#display_name ⇒ String
User provided name of this TensorboardExperiment.
Corresponds to the JSON property displayName
62739 62740 62741 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62739 def display_name @display_name end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
62745 62746 62747 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62745 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardExperiment.
Label keys and values cannot be longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. No more than 64 user labels can
be associated with one Dataset (System labels are excluded). See https://goo.
gl/xmQnxf for more information and examples of labels. System reserved label
keys are prefixed with aiplatform.googleapis.com/ and are immutable. The
following system labels exist for each Dataset: * aiplatform.googleapis.com/
dataset_metadata_schema: output only. Its value is the metadata_schema's
title.
Corresponds to the JSON property labels
62759 62760 62761 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62759 def labels @labels end |
#name ⇒ String
Output only. Name of the TensorboardExperiment. Format: projects/project/
locations/location/tensorboards/tensorboard/experiments/experiment`
Corresponds to the JSON propertyname`
62765 62766 62767 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62765 def name @name end |
#source ⇒ String
Immutable. Source of the TensorboardExperiment. Example: a custom training job.
Corresponds to the JSON property source
62770 62771 62772 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62770 def source @source end |
#update_time ⇒ String
Output only. Timestamp when this TensorboardExperiment was last updated.
Corresponds to the JSON property updateTime
62775 62776 62777 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62775 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62782 62783 62784 62785 62786 62787 62788 62789 62790 62791 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62782 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @update_time = args[:update_time] if args.key?(:update_time) end |