Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardExperiment
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardExperiment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A TensorboardExperiment is a group of TensorboardRuns, that are typically the results of a training job run, in a Tensorboard.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of this TensorboardExperiment.
-
#display_name ⇒ String
User provided name of this TensorboardExperiment.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardExperiment.
-
#name ⇒ String
Output only.
-
#source ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TensorboardExperiment
constructor
A new instance of GoogleCloudAiplatformV1beta1TensorboardExperiment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TensorboardExperiment
Returns a new instance of GoogleCloudAiplatformV1beta1TensorboardExperiment.
62165 62166 62167 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62165 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this TensorboardExperiment was created.
Corresponds to the JSON property createTime
62117 62118 62119 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62117 def create_time @create_time end |
#description ⇒ String
Description of this TensorboardExperiment.
Corresponds to the JSON property description
62122 62123 62124 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62122 def description @description end |
#display_name ⇒ String
User provided name of this TensorboardExperiment.
Corresponds to the JSON property displayName
62127 62128 62129 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62127 def display_name @display_name end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
62133 62134 62135 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62133 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardExperiment.
Label keys and values cannot be longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. No more than 64 user labels can
be associated with one Dataset (System labels are excluded). See https://goo.
gl/xmQnxf for more information and examples of labels. System reserved label
keys are prefixed with aiplatform.googleapis.com/ and are immutable. The
following system labels exist for each Dataset: * aiplatform.googleapis.com/
dataset_metadata_schema: output only. Its value is the metadata_schema's
title.
Corresponds to the JSON property labels
62147 62148 62149 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62147 def labels @labels end |
#name ⇒ String
Output only. Name of the TensorboardExperiment. Format: projects/project/
locations/location/tensorboards/tensorboard/experiments/experiment`
Corresponds to the JSON propertyname`
62153 62154 62155 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62153 def name @name end |
#source ⇒ String
Immutable. Source of the TensorboardExperiment. Example: a custom training job.
Corresponds to the JSON property source
62158 62159 62160 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62158 def source @source end |
#update_time ⇒ String
Output only. Timestamp when this TensorboardExperiment was last updated.
Corresponds to the JSON property updateTime
62163 62164 62165 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62163 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62170 62171 62172 62173 62174 62175 62176 62177 62178 62179 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62170 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @update_time = args[:update_time] if args.key?(:update_time) end |