Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardExperiment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A TensorboardExperiment is a group of TensorboardRuns, that are typically the results of a training job run, in a Tensorboard.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TensorboardExperiment

Returns a new instance of GoogleCloudAiplatformV1beta1TensorboardExperiment.



53897
53898
53899
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this TensorboardExperiment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


53849
53850
53851
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53849

def create_time
  @create_time
end

#descriptionString

Description of this TensorboardExperiment. Corresponds to the JSON property description

Returns:

  • (String)


53854
53855
53856
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53854

def description
  @description
end

#display_nameString

User provided name of this TensorboardExperiment. Corresponds to the JSON property displayName

Returns:

  • (String)


53859
53860
53861
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53859

def display_name
  @display_name
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


53865
53866
53867
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53865

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your TensorboardExperiment. Label keys and values cannot be longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Dataset (System labels are excluded). See https://goo. gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with aiplatform.googleapis.com/ and are immutable. The following system labels exist for each Dataset: * aiplatform.googleapis.com/ dataset_metadata_schema: output only. Its value is the metadata_schema's title. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


53879
53880
53881
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53879

def labels
  @labels
end

#nameString

Output only. Name of the TensorboardExperiment. Format: projects/project/ locations/location/tensorboards/tensorboard/experiments/experiment` Corresponds to the JSON propertyname`

Returns:

  • (String)


53885
53886
53887
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53885

def name
  @name
end

#sourceString

Immutable. Source of the TensorboardExperiment. Example: a custom training job. Corresponds to the JSON property source

Returns:

  • (String)


53890
53891
53892
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53890

def source
  @source
end

#update_timeString

Output only. Timestamp when this TensorboardExperiment was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


53895
53896
53897
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53895

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53902
53903
53904
53905
53906
53907
53908
53909
53910
53911
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53902

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @source = args[:source] if args.key?(:source)
  @update_time = args[:update_time] if args.key?(:update_time)
end