Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTimeSeries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

TensorboardTimeSeries maps to times series produced in training runs

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TensorboardTimeSeries

Returns a new instance of GoogleCloudAiplatformV1beta1TensorboardTimeSeries.



64266
64267
64268
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this TensorboardTimeSeries was created. Corresponds to the JSON property createTime

Returns:

  • (String)


64214
64215
64216
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64214

def create_time
  @create_time
end

#descriptionString

Description of this TensorboardTimeSeries. Corresponds to the JSON property description

Returns:

  • (String)


64219
64220
64221
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64219

def description
  @description
end

#display_nameString

Required. User provided name of this TensorboardTimeSeries. This value should be unique among all TensorboardTimeSeries resources belonging to the same TensorboardRun resource (parent resource). Corresponds to the JSON property displayName

Returns:

  • (String)


64226
64227
64228
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64226

def display_name
  @display_name
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


64232
64233
64234
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64232

def etag
  @etag
end

#metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTimeSeriesMetadata

Describes metadata for a TensorboardTimeSeries. Corresponds to the JSON property metadata



64237
64238
64239
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64237

def 
  @metadata
end

#nameString

Output only. Name of the TensorboardTimeSeries. Corresponds to the JSON property name

Returns:

  • (String)


64242
64243
64244
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64242

def name
  @name
end

#plugin_dataString

Data of the current plugin, with the size limited to 65KB. Corresponds to the JSON property pluginData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


64248
64249
64250
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64248

def plugin_data
  @plugin_data
end

#plugin_nameString

Immutable. Name of the plugin this time series pertain to. Such as Scalar, Tensor, Blob Corresponds to the JSON property pluginName

Returns:

  • (String)


64254
64255
64256
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64254

def plugin_name
  @plugin_name
end

#update_timeString

Output only. Timestamp when this TensorboardTimeSeries was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


64259
64260
64261
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64259

def update_time
  @update_time
end

#value_typeString

Required. Immutable. Type of TensorboardTimeSeries value. Corresponds to the JSON property valueType

Returns:

  • (String)


64264
64265
64266
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64264

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64271
64272
64273
64274
64275
64276
64277
64278
64279
64280
64281
64282
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64271

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @plugin_data = args[:plugin_data] if args.key?(:plugin_data)
  @plugin_name = args[:plugin_name] if args.key?(:plugin_name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
end