Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTimeSeries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

TensorboardTimeSeries maps to times series produced in training runs

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TensorboardTimeSeries

Returns a new instance of GoogleCloudAiplatformV1beta1TensorboardTimeSeries.



62151
62152
62153
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62151

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this TensorboardTimeSeries was created. Corresponds to the JSON property createTime

Returns:

  • (String)


62099
62100
62101
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62099

def create_time
  @create_time
end

#descriptionString

Description of this TensorboardTimeSeries. Corresponds to the JSON property description

Returns:

  • (String)


62104
62105
62106
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62104

def description
  @description
end

#display_nameString

Required. User provided name of this TensorboardTimeSeries. This value should be unique among all TensorboardTimeSeries resources belonging to the same TensorboardRun resource (parent resource). Corresponds to the JSON property displayName

Returns:

  • (String)


62111
62112
62113
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62111

def display_name
  @display_name
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


62117
62118
62119
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62117

def etag
  @etag
end

#metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTimeSeriesMetadata

Describes metadata for a TensorboardTimeSeries. Corresponds to the JSON property metadata



62122
62123
62124
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62122

def 
  @metadata
end

#nameString

Output only. Name of the TensorboardTimeSeries. Corresponds to the JSON property name

Returns:

  • (String)


62127
62128
62129
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62127

def name
  @name
end

#plugin_dataString

Data of the current plugin, with the size limited to 65KB. Corresponds to the JSON property pluginData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


62133
62134
62135
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62133

def plugin_data
  @plugin_data
end

#plugin_nameString

Immutable. Name of the plugin this time series pertain to. Such as Scalar, Tensor, Blob Corresponds to the JSON property pluginName

Returns:

  • (String)


62139
62140
62141
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62139

def plugin_name
  @plugin_name
end

#update_timeString

Output only. Timestamp when this TensorboardTimeSeries was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


62144
62145
62146
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62144

def update_time
  @update_time
end

#value_typeString

Required. Immutable. Type of TensorboardTimeSeries value. Corresponds to the JSON property valueType

Returns:

  • (String)


62149
62150
62151
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62149

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62156
62157
62158
62159
62160
62161
62162
62163
62164
62165
62166
62167
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62156

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @plugin_data = args[:plugin_data] if args.key?(:plugin_data)
  @plugin_name = args[:plugin_name] if args.key?(:plugin_name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
end