Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTimeSeries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

TensorboardTimeSeries maps to times series produced in training runs

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TensorboardTimeSeries

Returns a new instance of GoogleCloudAiplatformV1beta1TensorboardTimeSeries.



62339
62340
62341
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62339

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this TensorboardTimeSeries was created. Corresponds to the JSON property createTime

Returns:

  • (String)


62287
62288
62289
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62287

def create_time
  @create_time
end

#descriptionString

Description of this TensorboardTimeSeries. Corresponds to the JSON property description

Returns:

  • (String)


62292
62293
62294
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62292

def description
  @description
end

#display_nameString

Required. User provided name of this TensorboardTimeSeries. This value should be unique among all TensorboardTimeSeries resources belonging to the same TensorboardRun resource (parent resource). Corresponds to the JSON property displayName

Returns:

  • (String)


62299
62300
62301
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62299

def display_name
  @display_name
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


62305
62306
62307
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62305

def etag
  @etag
end

#metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTimeSeriesMetadata

Describes metadata for a TensorboardTimeSeries. Corresponds to the JSON property metadata



62310
62311
62312
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62310

def 
  @metadata
end

#nameString

Output only. Name of the TensorboardTimeSeries. Corresponds to the JSON property name

Returns:

  • (String)


62315
62316
62317
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62315

def name
  @name
end

#plugin_dataString

Data of the current plugin, with the size limited to 65KB. Corresponds to the JSON property pluginData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


62321
62322
62323
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62321

def plugin_data
  @plugin_data
end

#plugin_nameString

Immutable. Name of the plugin this time series pertain to. Such as Scalar, Tensor, Blob Corresponds to the JSON property pluginName

Returns:

  • (String)


62327
62328
62329
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62327

def plugin_name
  @plugin_name
end

#update_timeString

Output only. Timestamp when this TensorboardTimeSeries was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


62332
62333
62334
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62332

def update_time
  @update_time
end

#value_typeString

Required. Immutable. Type of TensorboardTimeSeries value. Corresponds to the JSON property valueType

Returns:

  • (String)


62337
62338
62339
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62337

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62344
62345
62346
62347
62348
62349
62350
62351
62352
62353
62354
62355
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62344

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @plugin_data = args[:plugin_data] if args.key?(:plugin_data)
  @plugin_name = args[:plugin_name] if args.key?(:plugin_name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
end