Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTimeSeries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

TensorboardTimeSeries maps to times series produced in training runs

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TensorboardTimeSeries

Returns a new instance of GoogleCloudAiplatformV1beta1TensorboardTimeSeries.



59280
59281
59282
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59280

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this TensorboardTimeSeries was created. Corresponds to the JSON property createTime

Returns:

  • (String)


59228
59229
59230
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59228

def create_time
  @create_time
end

#descriptionString

Description of this TensorboardTimeSeries. Corresponds to the JSON property description

Returns:

  • (String)


59233
59234
59235
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59233

def description
  @description
end

#display_nameString

Required. User provided name of this TensorboardTimeSeries. This value should be unique among all TensorboardTimeSeries resources belonging to the same TensorboardRun resource (parent resource). Corresponds to the JSON property displayName

Returns:

  • (String)


59240
59241
59242
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59240

def display_name
  @display_name
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


59246
59247
59248
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59246

def etag
  @etag
end

#metadataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTimeSeriesMetadata

Describes metadata for a TensorboardTimeSeries. Corresponds to the JSON property metadata



59251
59252
59253
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59251

def 
  @metadata
end

#nameString

Output only. Name of the TensorboardTimeSeries. Corresponds to the JSON property name

Returns:

  • (String)


59256
59257
59258
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59256

def name
  @name
end

#plugin_dataString

Data of the current plugin, with the size limited to 65KB. Corresponds to the JSON property pluginData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


59262
59263
59264
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59262

def plugin_data
  @plugin_data
end

#plugin_nameString

Immutable. Name of the plugin this time series pertain to. Such as Scalar, Tensor, Blob Corresponds to the JSON property pluginName

Returns:

  • (String)


59268
59269
59270
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59268

def plugin_name
  @plugin_name
end

#update_timeString

Output only. Timestamp when this TensorboardTimeSeries was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


59273
59274
59275
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59273

def update_time
  @update_time
end

#value_typeString

Required. Immutable. Type of TensorboardTimeSeries value. Corresponds to the JSON property valueType

Returns:

  • (String)


59278
59279
59280
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59278

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59285
59286
59287
59288
59289
59290
59291
59292
59293
59294
59295
59296
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59285

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @plugin_data = args[:plugin_data] if args.key?(:plugin_data)
  @plugin_name = args[:plugin_name] if args.key?(:plugin_name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
end