Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTimeSeriesMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Describes metadata for a TensorboardTimeSeries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TensorboardTimeSeriesMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1TensorboardTimeSeriesMetadata.



62379
62380
62381
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_blob_sequence_lengthFixnum

Output only. The largest blob sequence length (number of blobs) of all data points in this time series, if its ValueType is BLOB_SEQUENCE. Corresponds to the JSON property maxBlobSequenceLength

Returns:

  • (Fixnum)


62366
62367
62368
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62366

def max_blob_sequence_length
  @max_blob_sequence_length
end

#max_stepFixnum

Output only. Max step index of all data points within a TensorboardTimeSeries. Corresponds to the JSON property maxStep

Returns:

  • (Fixnum)


62371
62372
62373
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62371

def max_step
  @max_step
end

#max_wall_timeString

Output only. Max wall clock timestamp of all data points within a TensorboardTimeSeries. Corresponds to the JSON property maxWallTime

Returns:

  • (String)


62377
62378
62379
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62377

def max_wall_time
  @max_wall_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62384
62385
62386
62387
62388
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62384

def update!(**args)
  @max_blob_sequence_length = args[:max_blob_sequence_length] if args.key?(:max_blob_sequence_length)
  @max_step = args[:max_step] if args.key?(:max_step)
  @max_wall_time = args[:max_wall_time] if args.key?(:max_wall_time)
end