Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TfRecordDestination
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TfRecordDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The storage details for TFRecord output content.
Instance Attribute Summary collapse
-
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TfRecordDestination
constructor
A new instance of GoogleCloudAiplatformV1beta1TfRecordDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TfRecordDestination
Returns a new instance of GoogleCloudAiplatformV1beta1TfRecordDestination.
53237 53238 53239 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53237 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_destination ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcsDestination
53235 53236 53237 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53235 def gcs_destination @gcs_destination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53242 53243 53244 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 53242 def update!(**args) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) end |