Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TimeSeriesDataPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A TensorboardTimeSeries data point.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TimeSeriesDataPoint

Returns a new instance of GoogleCloudAiplatformV1beta1TimeSeriesDataPoint.



59419
59420
59421
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blobsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardBlobSequence

One point viewable on a blob metric plot, but mostly just a wrapper message to work around repeated fields can't be used directly within oneof fields. Corresponds to the JSON property blobs



59397
59398
59399
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59397

def blobs
  @blobs
end

#scalarGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Scalar

One point viewable on a scalar metric plot. Corresponds to the JSON property scalar



59402
59403
59404
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59402

def scalar
  @scalar
end

#stepFixnum

Step index of this data point within the run. Corresponds to the JSON property step

Returns:

  • (Fixnum)


59407
59408
59409
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59407

def step
  @step
end

#tensorGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTensor

One point viewable on a tensor metric plot. Corresponds to the JSON property tensor



59412
59413
59414
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59412

def tensor
  @tensor
end

#wall_timeString

Wall clock timestamp when this data point is generated by the end user. Corresponds to the JSON property wallTime

Returns:

  • (String)


59417
59418
59419
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59417

def wall_time
  @wall_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59424
59425
59426
59427
59428
59429
59430
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 59424

def update!(**args)
  @blobs = args[:blobs] if args.key?(:blobs)
  @scalar = args[:scalar] if args.key?(:scalar)
  @step = args[:step] if args.key?(:step)
  @tensor = args[:tensor] if args.key?(:tensor)
  @wall_time = args[:wall_time] if args.key?(:wall_time)
end