Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TimeSeriesDataPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A TensorboardTimeSeries data point.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TimeSeriesDataPoint

Returns a new instance of GoogleCloudAiplatformV1beta1TimeSeriesDataPoint.



54210
54211
54212
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blobsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardBlobSequence

One point viewable on a blob metric plot, but mostly just a wrapper message to work around repeated fields can't be used directly within oneof fields. Corresponds to the JSON property blobs



54188
54189
54190
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54188

def blobs
  @blobs
end

#scalarGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Scalar

One point viewable on a scalar metric plot. Corresponds to the JSON property scalar



54193
54194
54195
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54193

def scalar
  @scalar
end

#stepFixnum

Step index of this data point within the run. Corresponds to the JSON property step

Returns:

  • (Fixnum)


54198
54199
54200
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54198

def step
  @step
end

#tensorGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TensorboardTensor

One point viewable on a tensor metric plot. Corresponds to the JSON property tensor



54203
54204
54205
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54203

def tensor
  @tensor
end

#wall_timeString

Wall clock timestamp when this data point is generated by the end user. Corresponds to the JSON property wallTime

Returns:

  • (String)


54208
54209
54210
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54208

def wall_time
  @wall_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54215
54216
54217
54218
54219
54220
54221
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54215

def update!(**args)
  @blobs = args[:blobs] if args.key?(:blobs)
  @scalar = args[:scalar] if args.key?(:scalar)
  @step = args[:step] if args.key?(:step)
  @tensor = args[:tensor] if args.key?(:tensor)
  @wall_time = args[:wall_time] if args.key?(:wall_time)
end