Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TimestampSplit
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TimestampSplit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Assigns input data to training, validation, and test sets based on a provided timestamps. The youngest data pieces are assigned to training set, next to validation set, and the oldest to the test set. Supported only for tabular Datasets.
Instance Attribute Summary collapse
-
#key ⇒ String
Required.
-
#test_fraction ⇒ Float
The fraction of the input data that is to be used to evaluate the Model.
-
#training_fraction ⇒ Float
The fraction of the input data that is to be used to train the Model.
-
#validation_fraction ⇒ Float
The fraction of the input data that is to be used to validate the Model.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TimestampSplit
constructor
A new instance of GoogleCloudAiplatformV1beta1TimestampSplit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TimestampSplit
Returns a new instance of GoogleCloudAiplatformV1beta1TimestampSplit.
54255 54256 54257 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54255 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Required. The key is a name of one of the Dataset's data columns. The values
of the key (the values in the column) must be in RFC 3339 date-time format,
where time-offset = "Z" (e.g. 1985-04-12T23:20:50.52Z). If for a piece of
data the key is not present or has an invalid value, that piece is ignored by
the pipeline.
Corresponds to the JSON property key
54238 54239 54240 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54238 def key @key end |
#test_fraction ⇒ Float
The fraction of the input data that is to be used to evaluate the Model.
Corresponds to the JSON property testFraction
54243 54244 54245 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54243 def test_fraction @test_fraction end |
#training_fraction ⇒ Float
The fraction of the input data that is to be used to train the Model.
Corresponds to the JSON property trainingFraction
54248 54249 54250 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54248 def training_fraction @training_fraction end |
#validation_fraction ⇒ Float
The fraction of the input data that is to be used to validate the Model.
Corresponds to the JSON property validationFraction
54253 54254 54255 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54253 def validation_fraction @validation_fraction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54260 54261 54262 54263 54264 54265 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54260 def update!(**args) @key = args[:key] if args.key?(:key) @test_fraction = args[:test_fraction] if args.key?(:test_fraction) @training_fraction = args[:training_fraction] if args.key?(:training_fraction) @validation_fraction = args[:validation_fraction] if args.key?(:validation_fraction) end |