Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Tool details that the model may use to generate response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. A Tool object should contain exactly one type of Tool (e.g FunctionDeclaration, Retrieval or GoogleSearchRetrieval).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tool

Returns a new instance of GoogleCloudAiplatformV1beta1Tool.



64593
64594
64595
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64593

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_executionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolCodeExecution

Tool that executes code generated by the model, and automatically returns the result to the model. See also ExecutableCode and CodeExecutionResult, which are input and output to this tool. Corresponds to the JSON property codeExecution



64533
64534
64535
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64533

def code_execution
  @code_execution
end

#computer_useGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolComputerUse

Tool to support computer use. Corresponds to the JSON property computerUse



64538
64539
64540
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64538

def computer_use
  @computer_use
end

#enterprise_web_searchGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EnterpriseWebSearch

Tool to search public web data, powered by Vertex AI Search and Sec4 compliance. Corresponds to the JSON property enterpriseWebSearch



64544
64545
64546
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64544

def enterprise_web_search
  @enterprise_web_search
end

#exa_ai_searchGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolExaAiSearch

ExaAiSearch tool type. A tool that uses the Exa.ai search engine for grounding. Corresponds to the JSON property exaAiSearch



64549
64550
64551
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64549

def exa_ai_search
  @exa_ai_search
end

#function_declarationsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionDeclaration>

Optional. Function tool type. One or more function declarations to be passed to the model along with the current user query. Model may decide to call a subset of these functions by populating FunctionCall in the response. User should provide a FunctionResponse for each function call in the next turn. Based on the function responses, Model will generate the final response back to the user. Maximum 512 function declarations can be provided. Corresponds to the JSON property functionDeclarations



64559
64560
64561
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64559

def function_declarations
  @function_declarations
end

#google_mapsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GoogleMaps

Tool to retrieve public maps data for grounding, powered by Google. Corresponds to the JSON property googleMaps



64564
64565
64566
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64564

def google_maps
  @google_maps
end

#google_searchGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolGoogleSearch

GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google. Corresponds to the JSON property googleSearch



64570
64571
64572
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64570

def google_search
  @google_search
end

#google_search_retrievalGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GoogleSearchRetrieval

Tool to retrieve public web data for grounding, powered by Google. Corresponds to the JSON property googleSearchRetrieval



64575
64576
64577
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64575

def google_search_retrieval
  @google_search_retrieval
end

#parallel_ai_searchGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParallelAiSearch

ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding. Corresponds to the JSON property parallelAiSearch



64581
64582
64583
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64581

def parallel_ai_search
  @parallel_ai_search
end

#retrievalGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Retrieval

Defines a retrieval tool that model can call to access external knowledge. Corresponds to the JSON property retrieval



64586
64587
64588
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64586

def retrieval
  @retrieval
end

#url_contextGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UrlContext

Tool to support URL context. Corresponds to the JSON property urlContext



64591
64592
64593
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64591

def url_context
  @url_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64598
64599
64600
64601
64602
64603
64604
64605
64606
64607
64608
64609
64610
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64598

def update!(**args)
  @code_execution = args[:code_execution] if args.key?(:code_execution)
  @computer_use = args[:computer_use] if args.key?(:computer_use)
  @enterprise_web_search = args[:enterprise_web_search] if args.key?(:enterprise_web_search)
  @exa_ai_search = args[:exa_ai_search] if args.key?(:exa_ai_search)
  @function_declarations = args[:function_declarations] if args.key?(:function_declarations)
  @google_maps = args[:google_maps] if args.key?(:google_maps)
  @google_search = args[:google_search] if args.key?(:google_search)
  @google_search_retrieval = args[:google_search_retrieval] if args.key?(:google_search_retrieval)
  @parallel_ai_search = args[:parallel_ai_search] if args.key?(:parallel_ai_search)
  @retrieval = args[:retrieval] if args.key?(:retrieval)
  @url_context = args[:url_context] if args.key?(:url_context)
end