Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Tool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Tool details that the model may use to generate response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. A Tool object should contain exactly one type of Tool (e.g FunctionDeclaration, Retrieval or GoogleSearchRetrieval).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tool

Returns a new instance of GoogleCloudAiplatformV1beta1Tool.



62478
62479
62480
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_executionGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolCodeExecution

Tool that executes code generated by the model, and automatically returns the result to the model. See also ExecutableCode and CodeExecutionResult, which are input and output to this tool. Corresponds to the JSON property codeExecution



62418
62419
62420
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62418

def code_execution
  @code_execution
end

#computer_useGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolComputerUse

Tool to support computer use. Corresponds to the JSON property computerUse



62423
62424
62425
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62423

def computer_use
  @computer_use
end

#enterprise_web_searchGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EnterpriseWebSearch

Tool to search public web data, powered by Vertex AI Search and Sec4 compliance. Corresponds to the JSON property enterpriseWebSearch



62429
62430
62431
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62429

def enterprise_web_search
  @enterprise_web_search
end

#exa_ai_searchGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolExaAiSearch

ExaAiSearch tool type. A tool that uses the Exa.ai search engine for grounding. Corresponds to the JSON property exaAiSearch



62434
62435
62436
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62434

def exa_ai_search
  @exa_ai_search
end

#function_declarationsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FunctionDeclaration>

Optional. Function tool type. One or more function declarations to be passed to the model along with the current user query. Model may decide to call a subset of these functions by populating FunctionCall in the response. User should provide a FunctionResponse for each function call in the next turn. Based on the function responses, Model will generate the final response back to the user. Maximum 512 function declarations can be provided. Corresponds to the JSON property functionDeclarations



62444
62445
62446
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62444

def function_declarations
  @function_declarations
end

#google_mapsGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GoogleMaps

Tool to retrieve public maps data for grounding, powered by Google. Corresponds to the JSON property googleMaps



62449
62450
62451
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62449

def google_maps
  @google_maps
end

#google_searchGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolGoogleSearch

GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google. Corresponds to the JSON property googleSearch



62455
62456
62457
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62455

def google_search
  @google_search
end

#google_search_retrievalGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1GoogleSearchRetrieval

Tool to retrieve public web data for grounding, powered by Google. Corresponds to the JSON property googleSearchRetrieval



62460
62461
62462
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62460

def google_search_retrieval
  @google_search_retrieval
end

#parallel_ai_searchGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParallelAiSearch

ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding. Corresponds to the JSON property parallelAiSearch



62466
62467
62468
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62466

def parallel_ai_search
  @parallel_ai_search
end

#retrievalGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Retrieval

Defines a retrieval tool that model can call to access external knowledge. Corresponds to the JSON property retrieval



62471
62472
62473
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62471

def retrieval
  @retrieval
end

#url_contextGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UrlContext

Tool to support URL context. Corresponds to the JSON property urlContext



62476
62477
62478
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62476

def url_context
  @url_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62483
62484
62485
62486
62487
62488
62489
62490
62491
62492
62493
62494
62495
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62483

def update!(**args)
  @code_execution = args[:code_execution] if args.key?(:code_execution)
  @computer_use = args[:computer_use] if args.key?(:computer_use)
  @enterprise_web_search = args[:enterprise_web_search] if args.key?(:enterprise_web_search)
  @exa_ai_search = args[:exa_ai_search] if args.key?(:exa_ai_search)
  @function_declarations = args[:function_declarations] if args.key?(:function_declarations)
  @google_maps = args[:google_maps] if args.key?(:google_maps)
  @google_search = args[:google_search] if args.key?(:google_search)
  @google_search_retrieval = args[:google_search_retrieval] if args.key?(:google_search_retrieval)
  @parallel_ai_search = args[:parallel_ai_search] if args.key?(:parallel_ai_search)
  @retrieval = args[:retrieval] if args.key?(:retrieval)
  @url_context = args[:url_context] if args.key?(:url_context)
end