Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolCodeExecution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolCodeExecution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Tool that executes code generated by the model, and automatically returns the result to the model. See also ExecutableCode and CodeExecutionResult, which are input and output to this tool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolCodeExecution
constructor
A new instance of GoogleCloudAiplatformV1beta1ToolCodeExecution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolCodeExecution
Returns a new instance of GoogleCloudAiplatformV1beta1ToolCodeExecution.
54682 54683 54684 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54682 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54687 54688 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54687 def update!(**args) end |