Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolGoogleSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolGoogleSearch

Returns a new instance of GoogleCloudAiplatformV1beta1ToolGoogleSearch.



62749
62750
62751
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocking_confidenceString

Optional. Sites with confidence level chosen & above this value will be blocked from the search results. Corresponds to the JSON property blockingConfidence

Returns:

  • (String)


62736
62737
62738
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62736

def blocking_confidence
  @blocking_confidence
end

#exclude_domainsArray<String>

Optional. List of domains to be excluded from the search results. The default limit is 2000 domains. Example: ["amazon.com", "facebook.com"]. Corresponds to the JSON property excludeDomains

Returns:

  • (Array<String>)


62742
62743
62744
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62742

def exclude_domains
  @exclude_domains
end

#search_typesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolGoogleSearchSearchTypes

Different types of search that can be enabled on the GoogleSearch tool. Corresponds to the JSON property searchTypes



62747
62748
62749
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62747

def search_types
  @search_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62754
62755
62756
62757
62758
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62754

def update!(**args)
  @blocking_confidence = args[:blocking_confidence] if args.key?(:blocking_confidence)
  @exclude_domains = args[:exclude_domains] if args.key?(:exclude_domains)
  @search_types = args[:search_types] if args.key?(:search_types)
end