Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolGoogleSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolGoogleSearch

Returns a new instance of GoogleCloudAiplatformV1beta1ToolGoogleSearch.



54604
54605
54606
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54604

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocking_confidenceString

Optional. Sites with confidence level chosen & above this value will be blocked from the search results. Corresponds to the JSON property blockingConfidence

Returns:

  • (String)


54591
54592
54593
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54591

def blocking_confidence
  @blocking_confidence
end

#exclude_domainsArray<String>

Optional. List of domains to be excluded from the search results. The default limit is 2000 domains. Example: ["amazon.com", "facebook.com"]. Corresponds to the JSON property excludeDomains

Returns:

  • (Array<String>)


54597
54598
54599
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54597

def exclude_domains
  @exclude_domains
end

#search_typesGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolGoogleSearchSearchTypes

Different types of search that can be enabled on the GoogleSearch tool. Corresponds to the JSON property searchTypes



54602
54603
54604
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54602

def search_types
  @search_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54609
54610
54611
54612
54613
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 54609

def update!(**args)
  @blocking_confidence = args[:blocking_confidence] if args.key?(:blocking_confidence)
  @exclude_domains = args[:exclude_domains] if args.key?(:exclude_domains)
  @search_types = args[:search_types] if args.key?(:search_types)
end