Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParallelAiSearch
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolParallelAiSearch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding.
Instance Attribute Summary collapse
-
#api_key ⇒ String
Optional.
-
#custom_configs ⇒ Hash<String,Object>
Optional.
-
#enable_data_retention ⇒ Boolean
(also: #enable_data_retention?)
Optional.
-
#enable_zero_data_retention ⇒ Boolean
(also: #enable_zero_data_retention?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolParallelAiSearch
constructor
A new instance of GoogleCloudAiplatformV1beta1ToolParallelAiSearch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolParallelAiSearch
Returns a new instance of GoogleCloudAiplatformV1beta1ToolParallelAiSearch.
63759 63760 63761 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63759 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_key ⇒ String
Optional. The API key for ParallelAiSearch. If an API key is not provided, the
system will attempt to verify access by checking for an active Parallel.ai
subscription through the Google Cloud Marketplace. See https://docs.parallel.
ai/search/search-quickstart for more details.
Corresponds to the JSON property apiKey
63726 63727 63728 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63726 def api_key @api_key end |
#custom_configs ⇒ Hash<String,Object>
Optional. Custom configs for ParallelAiSearch. This field can be used to pass
any parameter from the Parallel.ai Search API. See the Parallel.ai
documentation for the full list of available parameters and their usage: https:
//docs.parallel.ai/api-reference/search-beta/search Currently only
source_policy, excerpts, max_results, mode, fetch_policy can be set
via this field. For example: "source_policy": "include_domains": ["google.
com", "wikipedia.org"], "exclude_domains": ["example.com"] , "fetch_policy":
"max_age_seconds": 3600
Corresponds to the JSON property customConfigs
63738 63739 63740 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63738 def custom_configs @custom_configs end |
#enable_data_retention ⇒ Boolean Also known as: enable_data_retention?
Optional. Deprecated: Use enable_zero_data_retention instead. Instructs
Vertex Grounding to use Parallel's Zero Data Retention Marketplace product. If
this value is "false" or omitted, the Parallel Web Search for Grounding
standard subscription will be used. If this value is "true", the Parallel Web
Search for Grounding - ZDR subscription will be used.
Corresponds to the JSON property enableDataRetention
63747 63748 63749 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63747 def enable_data_retention @enable_data_retention end |
#enable_zero_data_retention ⇒ Boolean Also known as: enable_zero_data_retention?
Optional. Instructs Vertex Grounding to use Parallel's Zero Data Retention
Marketplace product. If this value is "false" or omitted, the Parallel Web
Search for Grounding standard subscription will be used. If this value is "
true", the Parallel Web Search for Grounding - ZDR subscription will be used.
Corresponds to the JSON property enableZeroDataRetention
63756 63757 63758 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63756 def enable_zero_data_retention @enable_zero_data_retention end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63764 63765 63766 63767 63768 63769 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63764 def update!(**args) @api_key = args[:api_key] if args.key?(:api_key) @custom_configs = args[:custom_configs] if args.key?(:custom_configs) @enable_data_retention = args[:enable_data_retention] if args.key?(:enable_data_retention) @enable_zero_data_retention = args[:enable_zero_data_retention] if args.key?(:enable_zero_data_retention) end |