Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExample
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A single example of the tool usage.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#extension_operation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExampleExtensionOperation
Identifies one operation of the extension.
-
#function_name ⇒ String
Function name to call.
-
#query ⇒ String
Required.
-
#request_params ⇒ Hash<String,Object>
Request parameters used for executing this tool.
-
#response_params ⇒ Hash<String,Object>
Response parameters generated by this tool.
-
#response_summary ⇒ String
Summary of the tool response to the user query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolUseExample
constructor
A new instance of GoogleCloudAiplatformV1beta1ToolUseExample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolUseExample
Returns a new instance of GoogleCloudAiplatformV1beta1ToolUseExample.
65907 65908 65909 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65907 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. The display name for example.
Corresponds to the JSON property displayName
65875 65876 65877 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65875 def display_name @display_name end |
#extension_operation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExampleExtensionOperation
Identifies one operation of the extension.
Corresponds to the JSON property extensionOperation
65880 65881 65882 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65880 def extension_operation @extension_operation end |
#function_name ⇒ String
Function name to call.
Corresponds to the JSON property functionName
65885 65886 65887 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65885 def function_name @function_name end |
#query ⇒ String
Required. Query that should be routed to this tool.
Corresponds to the JSON property query
65890 65891 65892 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65890 def query @query end |
#request_params ⇒ Hash<String,Object>
Request parameters used for executing this tool.
Corresponds to the JSON property requestParams
65895 65896 65897 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65895 def request_params @request_params end |
#response_params ⇒ Hash<String,Object>
Response parameters generated by this tool.
Corresponds to the JSON property responseParams
65900 65901 65902 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65900 def response_params @response_params end |
#response_summary ⇒ String
Summary of the tool response to the user query.
Corresponds to the JSON property responseSummary
65905 65906 65907 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65905 def response_summary @response_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65912 65913 65914 65915 65916 65917 65918 65919 65920 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65912 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @extension_operation = args[:extension_operation] if args.key?(:extension_operation) @function_name = args[:function_name] if args.key?(:function_name) @query = args[:query] if args.key?(:query) @request_params = args[:request_params] if args.key?(:request_params) @response_params = args[:response_params] if args.key?(:response_params) @response_summary = args[:response_summary] if args.key?(:response_summary) end |