Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExample
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A single example of the tool usage.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#extension_operation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExampleExtensionOperation
Identifies one operation of the extension.
-
#function_name ⇒ String
Function name to call.
-
#query ⇒ String
Required.
-
#request_params ⇒ Hash<String,Object>
Request parameters used for executing this tool.
-
#response_params ⇒ Hash<String,Object>
Response parameters generated by this tool.
-
#response_summary ⇒ String
Summary of the tool response to the user query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolUseExample
constructor
A new instance of GoogleCloudAiplatformV1beta1ToolUseExample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolUseExample
Returns a new instance of GoogleCloudAiplatformV1beta1ToolUseExample.
61752 61753 61754 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. The display name for example.
Corresponds to the JSON property displayName
61720 61721 61722 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61720 def display_name @display_name end |
#extension_operation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExampleExtensionOperation
Identifies one operation of the extension.
Corresponds to the JSON property extensionOperation
61725 61726 61727 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61725 def extension_operation @extension_operation end |
#function_name ⇒ String
Function name to call.
Corresponds to the JSON property functionName
61730 61731 61732 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61730 def function_name @function_name end |
#query ⇒ String
Required. Query that should be routed to this tool.
Corresponds to the JSON property query
61735 61736 61737 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61735 def query @query end |
#request_params ⇒ Hash<String,Object>
Request parameters used for executing this tool.
Corresponds to the JSON property requestParams
61740 61741 61742 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61740 def request_params @request_params end |
#response_params ⇒ Hash<String,Object>
Response parameters generated by this tool.
Corresponds to the JSON property responseParams
61745 61746 61747 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61745 def response_params @response_params end |
#response_summary ⇒ String
Summary of the tool response to the user query.
Corresponds to the JSON property responseSummary
61750 61751 61752 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61750 def response_summary @response_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61757 61758 61759 61760 61761 61762 61763 61764 61765 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61757 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @extension_operation = args[:extension_operation] if args.key?(:extension_operation) @function_name = args[:function_name] if args.key?(:function_name) @query = args[:query] if args.key?(:query) @request_params = args[:request_params] if args.key?(:request_params) @response_params = args[:response_params] if args.key?(:response_params) @response_summary = args[:response_summary] if args.key?(:response_summary) end |