Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExample
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A single example of the tool usage.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#extension_operation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExampleExtensionOperation
Identifies one operation of the extension.
-
#function_name ⇒ String
Function name to call.
-
#query ⇒ String
Required.
-
#request_params ⇒ Hash<String,Object>
Request parameters used for executing this tool.
-
#response_params ⇒ Hash<String,Object>
Response parameters generated by this tool.
-
#response_summary ⇒ String
Summary of the tool response to the user query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolUseExample
constructor
A new instance of GoogleCloudAiplatformV1beta1ToolUseExample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolUseExample
Returns a new instance of GoogleCloudAiplatformV1beta1ToolUseExample.
55218 55219 55220 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55218 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. The display name for example.
Corresponds to the JSON property displayName
55186 55187 55188 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55186 def display_name @display_name end |
#extension_operation ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ToolUseExampleExtensionOperation
Identifies one operation of the extension.
Corresponds to the JSON property extensionOperation
55191 55192 55193 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55191 def extension_operation @extension_operation end |
#function_name ⇒ String
Function name to call.
Corresponds to the JSON property functionName
55196 55197 55198 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55196 def function_name @function_name end |
#query ⇒ String
Required. Query that should be routed to this tool.
Corresponds to the JSON property query
55201 55202 55203 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55201 def query @query end |
#request_params ⇒ Hash<String,Object>
Request parameters used for executing this tool.
Corresponds to the JSON property requestParams
55206 55207 55208 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55206 def request_params @request_params end |
#response_params ⇒ Hash<String,Object>
Response parameters generated by this tool.
Corresponds to the JSON property responseParams
55211 55212 55213 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55211 def response_params @response_params end |
#response_summary ⇒ String
Summary of the tool response to the user query.
Corresponds to the JSON property responseSummary
55216 55217 55218 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55216 def response_summary @response_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55223 55224 55225 55226 55227 55228 55229 55230 55231 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55223 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @extension_operation = args[:extension_operation] if args.key?(:extension_operation) @function_name = args[:function_name] if args.key?(:function_name) @query = args[:query] if args.key?(:query) @request_params = args[:request_params] if args.key?(:request_params) @response_params = args[:response_params] if args.key?(:response_params) @response_summary = args[:response_summary] if args.key?(:response_summary) end |