Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrainingPipeline

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The TrainingPipeline orchestrates tasks associated with training a Model. It always executes the training task, and optionally may also export data from Vertex AI's Dataset which becomes the training input, upload the Model to Vertex AI, and evaluate the Model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrainingPipeline

Returns a new instance of GoogleCloudAiplatformV1beta1TrainingPipeline.



61936
61937
61938
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61936

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the TrainingPipeline was created. Corresponds to the JSON property createTime

Returns:

  • (String)


61825
61826
61827
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61825

def create_time
  @create_time
end

#display_nameString

Required. The user-defined name of this TrainingPipeline. Corresponds to the JSON property displayName

Returns:

  • (String)


61830
61831
61832
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61830

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



61836
61837
61838
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61836

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the TrainingPipeline entered any of the following states: PIPELINE_STATE_SUCCEEDED, PIPELINE_STATE_FAILED, PIPELINE_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


61843
61844
61845
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61843

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



61853
61854
61855
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61853

def error
  @error
end

#input_data_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1InputDataConfig

Specifies Vertex AI owned input data to be used for training, and possibly evaluating, the Model. Corresponds to the JSON property inputDataConfig



61859
61860
61861
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61859

def input_data_config
  @input_data_config
end

#labelsHash<String,String>

The labels with user-defined metadata to organize TrainingPipelines. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


61868
61869
61870
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61868

def labels
  @labels
end

#model_idString

Optional. The ID to use for the uploaded Model, which will become the final component of the model resource name. This value may be up to 63 characters, and valid characters are [a-z0-9_-]. The first character cannot be a number or hyphen. Corresponds to the JSON property modelId

Returns:

  • (String)


61876
61877
61878
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61876

def model_id
  @model_id
end

#model_to_uploadGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Model

A trained machine learning Model. Corresponds to the JSON property modelToUpload



61881
61882
61883
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61881

def model_to_upload
  @model_to_upload
end

#nameString

Output only. Resource name of the TrainingPipeline. Corresponds to the JSON property name

Returns:

  • (String)


61886
61887
61888
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61886

def name
  @name
end

#parent_modelString

Optional. When specify this field, the model_to_upload will not be uploaded as a new model, instead, it will become a new version of this parent_model. Corresponds to the JSON property parentModel

Returns:

  • (String)


61892
61893
61894
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61892

def parent_model
  @parent_model
end

#start_timeString

Output only. Time when the TrainingPipeline for the first time entered the PIPELINE_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


61898
61899
61900
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61898

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the pipeline. Corresponds to the JSON property state

Returns:

  • (String)


61903
61904
61905
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61903

def state
  @state
end

#training_task_definitionString

Required. A Google Cloud Storage path to the YAML file that defines the training task which is responsible for producing the model artifact, and may also include additional auxiliary work. The definition files that can be used here are found in gs://google-cloud-aiplatform/schema/trainingjob/definition/. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access. Corresponds to the JSON property trainingTaskDefinition

Returns:

  • (String)


61914
61915
61916
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61914

def training_task_definition
  @training_task_definition
end

#training_task_inputsObject

Required. The training task's parameter(s), as specified in the training_task_definition's inputs. Corresponds to the JSON property trainingTaskInputs

Returns:

  • (Object)


61920
61921
61922
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61920

def training_task_inputs
  @training_task_inputs
end

#training_task_metadataObject

Output only. The metadata information as specified in the training_task_definition's metadata. This metadata is an auxiliary runtime and final information about the training task. While the pipeline is running this information is populated only at a best effort basis. Only present if the pipeline's training_task_definition contains metadata object. Corresponds to the JSON property trainingTaskMetadata

Returns:

  • (Object)


61929
61930
61931
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61929

def 
  @training_task_metadata
end

#update_timeString

Output only. Time when the TrainingPipeline was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


61934
61935
61936
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61934

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61941
61942
61943
61944
61945
61946
61947
61948
61949
61950
61951
61952
61953
61954
61955
61956
61957
61958
61959
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61941

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @input_data_config = args[:input_data_config] if args.key?(:input_data_config)
  @labels = args[:labels] if args.key?(:labels)
  @model_id = args[:model_id] if args.key?(:model_id)
  @model_to_upload = args[:model_to_upload] if args.key?(:model_to_upload)
  @name = args[:name] if args.key?(:name)
  @parent_model = args[:parent_model] if args.key?(:parent_model)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @training_task_definition = args[:training_task_definition] if args.key?(:training_task_definition)
  @training_task_inputs = args[:training_task_inputs] if args.key?(:training_task_inputs)
  @training_task_metadata = args[:training_task_metadata] if args.key?(:training_task_metadata)
  @update_time = args[:update_time] if args.key?(:update_time)
end