Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Instances and metric spec for TrajectoryAnyOrderMatch metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInput

Returns a new instance of GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInput.



61996
61997
61998
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInstance>

Required. Repeated TrajectoryAnyOrderMatch instance. Corresponds to the JSON property instances



61988
61989
61990
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61988

def instances
  @instances
end

#metric_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchSpec

Spec for TrajectoryAnyOrderMatch metric - returns 1 if all tool calls in the reference trajectory appear in the predicted trajectory in any order, else 0. Corresponds to the JSON property metricSpec



61994
61995
61996
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61994

def metric_spec
  @metric_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62001
62002
62003
62004
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62001

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @metric_spec = args[:metric_spec] if args.key?(:metric_spec)
end