Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Instances and metric spec for TrajectoryAnyOrderMatch metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInput

Returns a new instance of GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInput.



55462
55463
55464
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInstance>

Required. Repeated TrajectoryAnyOrderMatch instance. Corresponds to the JSON property instances



55454
55455
55456
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55454

def instances
  @instances
end

#metric_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchSpec

Spec for TrajectoryAnyOrderMatch metric - returns 1 if all tool calls in the reference trajectory appear in the predicted trajectory in any order, else 0. Corresponds to the JSON property metricSpec



55460
55461
55462
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55460

def metric_spec
  @metric_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55467
55468
55469
55470
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55467

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @metric_spec = args[:metric_spec] if args.key?(:metric_spec)
end