Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInput
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInput
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Instances and metric spec for TrajectoryAnyOrderMatch metric.
Instance Attribute Summary collapse
-
#instances ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInstance>
Required.
-
#metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchSpec
Spec for TrajectoryAnyOrderMatch metric - returns 1 if all tool calls in the reference trajectory appear in the predicted trajectory in any order, else 0.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInput
constructor
A new instance of GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInput
Returns a new instance of GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInput.
55298 55299 55300 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchInstance>
Required. Repeated TrajectoryAnyOrderMatch instance.
Corresponds to the JSON property instances
55290 55291 55292 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55290 def instances @instances end |
#metric_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryAnyOrderMatchSpec
Spec for TrajectoryAnyOrderMatch metric - returns 1 if all tool calls in the
reference trajectory appear in the predicted trajectory in any order, else 0.
Corresponds to the JSON property metricSpec
55296 55297 55298 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55296 def metric_spec @metric_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55303 55304 55305 55306 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55303 def update!(**args) @instances = args[:instances] if args.key?(:instances) @metric_spec = args[:metric_spec] if args.key?(:metric_spec) end |