Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Instances and metric spec for TrajectoryInOrderMatch metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchInput

Returns a new instance of GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchInput.



55669
55670
55671
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchInstance>

Required. Repeated TrajectoryInOrderMatch instance. Corresponds to the JSON property instances



55660
55661
55662
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55660

def instances
  @instances
end

#metric_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchSpec

Spec for TrajectoryInOrderMatch metric - returns 1 if tool calls in the reference trajectory appear in the predicted trajectory in the same order, else 0. Corresponds to the JSON property metricSpec



55667
55668
55669
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55667

def metric_spec
  @metric_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55674
55675
55676
55677
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55674

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @metric_spec = args[:metric_spec] if args.key?(:metric_spec)
end