Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Spec for TrajectoryInOrderMatch metric - returns 1 if tool calls in the reference trajectory appear in the predicted trajectory in the same order, else 0.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchSpec
Returns a new instance of GoogleCloudAiplatformV1beta1TrajectoryInOrderMatchSpec.
55585 55586 55587 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55585 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55590 55591 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55590 def update!(**args) end |