Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrajectorySingleToolUseSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Spec for TrajectorySingleToolUse metric - returns 1 if tool is present in the predicted trajectory, else 0.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrajectorySingleToolUseSpec

Returns a new instance of GoogleCloudAiplatformV1beta1TrajectorySingleToolUseSpec.



55893
55894
55895
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tool_nameString

Required. Spec for tool name to be checked for in the predicted trajectory. Corresponds to the JSON property toolName

Returns:

  • (String)


55891
55892
55893
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55891

def tool_name
  @tool_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55898
55899
55900
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 55898

def update!(**args)
  @tool_name = args[:tool_name] if args.key?(:tool_name)
end