Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Trial
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Trial
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A message representing a Trial. A Trial contains a unique set of Parameters that has been or will be evaluated, along with the objective metrics got by running the Trial.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Output only.
-
#custom_job ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#final_measurement ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Measurement
A message representing a Measurement of a Trial.
-
#id ⇒ String
Output only.
-
#infeasible_reason ⇒ String
Output only.
-
#measurements ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Measurement>
Output only.
-
#name ⇒ String
Output only.
-
#parameters ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrialParameter>
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#web_access_uris ⇒ Hash<String,String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Trial
constructor
A new instance of GoogleCloudAiplatformV1beta1Trial.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Trial
Returns a new instance of GoogleCloudAiplatformV1beta1Trial.
64169 64170 64171 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64169 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_id ⇒ String
Output only. The identifier of the client that originally requested this Trial.
Each client is identified by a unique client_id. When a client asks for a
suggestion, Vertex AI Vizier will assign it a Trial. The client should
evaluate the Trial, complete it, and report back to Vertex AI Vizier. If
suggestion is asked again by same client_id before the Trial is completed, the
same Trial will be returned. Multiple clients with different client_ids can
ask for suggestions simultaneously, each of them will get their own Trial.
Corresponds to the JSON property clientId
64099 64100 64101 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64099 def client_id @client_id end |
#custom_job ⇒ String
Output only. The CustomJob name linked to the Trial. It's set for a
HyperparameterTuningJob's Trial.
Corresponds to the JSON property customJob
64105 64106 64107 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64105 def custom_job @custom_job end |
#end_time ⇒ String
Output only. Time when the Trial's status changed to SUCCEEDED or
INFEASIBLE.
Corresponds to the JSON property endTime
64111 64112 64113 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64111 def end_time @end_time end |
#final_measurement ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Measurement
A message representing a Measurement of a Trial. A Measurement contains the
Metrics got by executing a Trial using suggested hyperparameter values.
Corresponds to the JSON property finalMeasurement
64117 64118 64119 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64117 def final_measurement @final_measurement end |
#id ⇒ String
Output only. The identifier of the Trial assigned by the service.
Corresponds to the JSON property id
64122 64123 64124 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64122 def id @id end |
#infeasible_reason ⇒ String
Output only. A human readable string describing why the Trial is infeasible.
This is set only if Trial state is INFEASIBLE.
Corresponds to the JSON property infeasibleReason
64128 64129 64130 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64128 def infeasible_reason @infeasible_reason end |
#measurements ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Measurement>
Output only. A list of measurements that are strictly lexicographically
ordered by their induced tuples (steps, elapsed_duration). These are used for
early stopping computations.
Corresponds to the JSON property measurements
64135 64136 64137 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64135 def measurements @measurements end |
#name ⇒ String
Output only. Resource name of the Trial assigned by the service.
Corresponds to the JSON property name
64140 64141 64142 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64140 def name @name end |
#parameters ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrialParameter>
Output only. The parameters of the Trial.
Corresponds to the JSON property parameters
64145 64146 64147 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64145 def parameters @parameters end |
#start_time ⇒ String
Output only. Time when the Trial was started.
Corresponds to the JSON property startTime
64150 64151 64152 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64150 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the Trial.
Corresponds to the JSON property state
64155 64156 64157 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64155 def state @state end |
#web_access_uris ⇒ Hash<String,String>
Output only. URIs for accessing interactive shells (one URI for each
training node). Only available if this trial is part of a
HyperparameterTuningJob and the job's trial_job_spec.enable_web_access field
is true. The keys are names of each node used for the trial; for example,
workerpool0-0 for the primary node, workerpool1-0 for the first node in the
second worker pool, and workerpool1-1 for the second node in the second
worker pool. The values are the URIs for each node's interactive shell.
Corresponds to the JSON property webAccessUris
64167 64168 64169 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64167 def web_access_uris @web_access_uris end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64174 64175 64176 64177 64178 64179 64180 64181 64182 64183 64184 64185 64186 64187 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64174 def update!(**args) @client_id = args[:client_id] if args.key?(:client_id) @custom_job = args[:custom_job] if args.key?(:custom_job) @end_time = args[:end_time] if args.key?(:end_time) @final_measurement = args[:final_measurement] if args.key?(:final_measurement) @id = args[:id] if args.key?(:id) @infeasible_reason = args[:infeasible_reason] if args.key?(:infeasible_reason) @measurements = args[:measurements] if args.key?(:measurements) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @web_access_uris = args[:web_access_uris] if args.key?(:web_access_uris) end |