Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrialContext
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrialContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
A human-readable field which can store a description of this context.
-
#parameters ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrialParameter>
If/when a Trial is generated or selected from this Context, its Parameters will match any parameters specified here.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrialContext
constructor
A new instance of GoogleCloudAiplatformV1beta1TrialContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrialContext
Returns a new instance of GoogleCloudAiplatformV1beta1TrialContext.
66909 66910 66911 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66909 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
A human-readable field which can store a description of this context. This
will become part of the resulting Trial's description field.
Corresponds to the JSON property description
66896 66897 66898 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66896 def description @description end |
#parameters ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrialParameter>
If/when a Trial is generated or selected from this Context, its Parameters
will match any parameters specified here. (I.e. if this context specifies
parameter name:'a' int_value:3, then a resulting Trial will have int_value:3
for its parameter named 'a'.) Note that we first attempt to match existing
REQUESTED Trials with contexts, and if there are no matches, we generate
suggestions in the subspace defined by the parameters specified here. NOTE: a
Context without any Parameters matches the entire feasible search space.
Corresponds to the JSON property parameters
66907 66908 66909 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66907 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66914 66915 66916 66917 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66914 def update!(**args) @description = args[:description] if args.key?(:description) @parameters = args[:parameters] if args.key?(:parameters) end |