Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrialContext
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrialContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
A human-readable field which can store a description of this context.
-
#parameters ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrialParameter>
If/when a Trial is generated or selected from this Context, its Parameters will match any parameters specified here.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrialContext
constructor
A new instance of GoogleCloudAiplatformV1beta1TrialContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrialContext
Returns a new instance of GoogleCloudAiplatformV1beta1TrialContext.
65022 65023 65024 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
A human-readable field which can store a description of this context. This
will become part of the resulting Trial's description field.
Corresponds to the JSON property description
65009 65010 65011 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65009 def description @description end |
#parameters ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrialParameter>
If/when a Trial is generated or selected from this Context, its Parameters
will match any parameters specified here. (I.e. if this context specifies
parameter name:'a' int_value:3, then a resulting Trial will have int_value:3
for its parameter named 'a'.) Note that we first attempt to match existing
REQUESTED Trials with contexts, and if there are no matches, we generate
suggestions in the subspace defined by the parameters specified here. NOTE: a
Context without any Parameters matches the entire feasible search space.
Corresponds to the JSON property parameters
65020 65021 65022 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65020 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65027 65028 65029 65030 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65027 def update!(**args) @description = args[:description] if args.key?(:description) @parameters = args[:parameters] if args.key?(:parameters) end |