Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrialContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TrialContext

Returns a new instance of GoogleCloudAiplatformV1beta1TrialContext.



64389
64390
64391
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64389

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A human-readable field which can store a description of this context. This will become part of the resulting Trial's description field. Corresponds to the JSON property description

Returns:

  • (String)


64376
64377
64378
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64376

def description
  @description
end

#parametersArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TrialParameter>

If/when a Trial is generated or selected from this Context, its Parameters will match any parameters specified here. (I.e. if this context specifies parameter name:'a' int_value:3, then a resulting Trial will have int_value:3 for its parameter named 'a'.) Note that we first attempt to match existing REQUESTED Trials with contexts, and if there are no matches, we generate suggestions in the subspace defined by the parameters specified here. NOTE: a Context without any Parameters matches the entire feasible search space. Corresponds to the JSON property parameters



64387
64388
64389
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64387

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64394
64395
64396
64397
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64394

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @parameters = args[:parameters] if args.key?(:parameters)
end