Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The Model Registry Model and Online Prediction Endpoint associated with this TuningJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModel

Returns a new instance of GoogleCloudAiplatformV1beta1TunedModel.



61334
61335
61336
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpointsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelCheckpoint>

Output only. The checkpoints associated with this TunedModel. This field is only populated for tuning jobs that enable intermediate checkpoints. Corresponds to the JSON property checkpoints



61314
61315
61316
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61314

def checkpoints
  @checkpoints
end

#endpointString

Output only. A resource name of an Endpoint. Format: projects/project/ locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


61320
61321
61322
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61320

def endpoint
  @endpoint
end

#modelString

Output only. The resource name of the TunedModel. Format: projects/project/ locations/location/models/model@version_idWhen tuning from a base model, the version ID will be 1. For continuous tuning, if the provided tuned_model_display_name is set and different from parent model's display name, the tuned model will have a new parent model with version 1. Otherwise the version id will be incremented by 1 from the last version ID in the parent model. E.g., `projects/`project`/locations/`location`/models/`model`@` last_version_id + 1 Corresponds to the JSON property model

Returns:

  • (String)


61332
61333
61334
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61332

def model
  @model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61339
61340
61341
61342
61343
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61339

def update!(**args)
  @checkpoints = args[:checkpoints] if args.key?(:checkpoints)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @model = args[:model] if args.key?(:model)
end