Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelCheckpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

TunedModelCheckpoint for the Tuned Model of a Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelCheckpoint

Returns a new instance of GoogleCloudAiplatformV1beta1TunedModelCheckpoint.



67015
67016
67017
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

The ID of the checkpoint. Corresponds to the JSON property checkpointId

Returns:

  • (String)


66997
66998
66999
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66997

def checkpoint_id
  @checkpoint_id
end

#endpointString

The Endpoint resource name that the checkpoint is deployed to. Format: projects/project/locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


67003
67004
67005
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67003

def endpoint
  @endpoint
end

#epochFixnum

The epoch of the checkpoint. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


67008
67009
67010
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67008

def epoch
  @epoch
end

#stepFixnum

The step of the checkpoint. Corresponds to the JSON property step

Returns:

  • (Fixnum)


67013
67014
67015
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67013

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67020
67021
67022
67023
67024
67025
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67020

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @epoch = args[:epoch] if args.key?(:epoch)
  @step = args[:step] if args.key?(:step)
end