Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelCheckpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

TunedModelCheckpoint for the Tuned Model of a Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelCheckpoint

Returns a new instance of GoogleCloudAiplatformV1beta1TunedModelCheckpoint.



66443
66444
66445
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

The ID of the checkpoint. Corresponds to the JSON property checkpointId

Returns:

  • (String)


66425
66426
66427
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66425

def checkpoint_id
  @checkpoint_id
end

#endpointString

The Endpoint resource name that the checkpoint is deployed to. Format: projects/project/locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


66431
66432
66433
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66431

def endpoint
  @endpoint
end

#epochFixnum

The epoch of the checkpoint. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


66436
66437
66438
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66436

def epoch
  @epoch
end

#stepFixnum

The step of the checkpoint. Corresponds to the JSON property step

Returns:

  • (Fixnum)


66441
66442
66443
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66441

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66448
66449
66450
66451
66452
66453
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66448

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @epoch = args[:epoch] if args.key?(:epoch)
  @step = args[:step] if args.key?(:step)
end