Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelCheckpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

TunedModelCheckpoint for the Tuned Model of a Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelCheckpoint

Returns a new instance of GoogleCloudAiplatformV1beta1TunedModelCheckpoint.



64495
64496
64497
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

The ID of the checkpoint. Corresponds to the JSON property checkpointId

Returns:

  • (String)


64477
64478
64479
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64477

def checkpoint_id
  @checkpoint_id
end

#endpointString

The Endpoint resource name that the checkpoint is deployed to. Format: projects/project/locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


64483
64484
64485
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64483

def endpoint
  @endpoint
end

#epochFixnum

The epoch of the checkpoint. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


64488
64489
64490
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64488

def epoch
  @epoch
end

#stepFixnum

The step of the checkpoint. Corresponds to the JSON property step

Returns:

  • (Fixnum)


64493
64494
64495
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64493

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64500
64501
64502
64503
64504
64505
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64500

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @epoch = args[:epoch] if args.key?(:epoch)
  @step = args[:step] if args.key?(:step)
end