Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelCheckpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelCheckpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
TunedModelCheckpoint for the Tuned Model of a Tuning Job.
Instance Attribute Summary collapse
-
#checkpoint_id ⇒ String
The ID of the checkpoint.
-
#endpoint ⇒ String
The Endpoint resource name that the checkpoint is deployed to.
-
#epoch ⇒ Fixnum
The epoch of the checkpoint.
-
#step ⇒ Fixnum
The step of the checkpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelCheckpoint
constructor
A new instance of GoogleCloudAiplatformV1beta1TunedModelCheckpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelCheckpoint
Returns a new instance of GoogleCloudAiplatformV1beta1TunedModelCheckpoint.
61371 61372 61373 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61371 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoint_id ⇒ String
The ID of the checkpoint.
Corresponds to the JSON property checkpointId
61353 61354 61355 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61353 def checkpoint_id @checkpoint_id end |
#endpoint ⇒ String
The Endpoint resource name that the checkpoint is deployed to. Format:
projects/project/locations/location/endpoints/endpoint`.
Corresponds to the JSON propertyendpoint`
61359 61360 61361 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61359 def endpoint @endpoint end |
#epoch ⇒ Fixnum
The epoch of the checkpoint.
Corresponds to the JSON property epoch
61364 61365 61366 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61364 def epoch @epoch end |
#step ⇒ Fixnum
The step of the checkpoint.
Corresponds to the JSON property step
61369 61370 61371 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61369 def step @step end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61376 61377 61378 61379 61380 61381 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61376 def update!(**args) @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id) @endpoint = args[:endpoint] if args.key?(:endpoint) @epoch = args[:epoch] if args.key?(:epoch) @step = args[:step] if args.key?(:step) end |