Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelCheckpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

TunedModelCheckpoint for the Tuned Model of a Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelCheckpoint

Returns a new instance of GoogleCloudAiplatformV1beta1TunedModelCheckpoint.



56162
56163
56164
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56162

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

The ID of the checkpoint. Corresponds to the JSON property checkpointId

Returns:

  • (String)


56144
56145
56146
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56144

def checkpoint_id
  @checkpoint_id
end

#endpointString

The Endpoint resource name that the checkpoint is deployed to. Format: projects/project/locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


56150
56151
56152
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56150

def endpoint
  @endpoint
end

#epochFixnum

The epoch of the checkpoint. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


56155
56156
56157
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56155

def epoch
  @epoch
end

#stepFixnum

The step of the checkpoint. Corresponds to the JSON property step

Returns:

  • (Fixnum)


56160
56161
56162
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56160

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56167
56168
56169
56170
56171
56172
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56167

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @epoch = args[:epoch] if args.key?(:epoch)
  @step = args[:step] if args.key?(:step)
end