Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelCheckpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelCheckpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
TunedModelCheckpoint for the Tuned Model of a Tuning Job.
Instance Attribute Summary collapse
-
#checkpoint_id ⇒ String
The ID of the checkpoint.
-
#endpoint ⇒ String
The Endpoint resource name that the checkpoint is deployed to.
-
#epoch ⇒ Fixnum
The epoch of the checkpoint.
-
#step ⇒ Fixnum
The step of the checkpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelCheckpoint
constructor
A new instance of GoogleCloudAiplatformV1beta1TunedModelCheckpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelCheckpoint
Returns a new instance of GoogleCloudAiplatformV1beta1TunedModelCheckpoint.
56162 56163 56164 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoint_id ⇒ String
The ID of the checkpoint.
Corresponds to the JSON property checkpointId
56144 56145 56146 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56144 def checkpoint_id @checkpoint_id end |
#endpoint ⇒ String
The Endpoint resource name that the checkpoint is deployed to. Format:
projects/project/locations/location/endpoints/endpoint`.
Corresponds to the JSON propertyendpoint`
56150 56151 56152 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56150 def endpoint @endpoint end |
#epoch ⇒ Fixnum
The epoch of the checkpoint.
Corresponds to the JSON property epoch
56155 56156 56157 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56155 def epoch @epoch end |
#step ⇒ Fixnum
The step of the checkpoint.
Corresponds to the JSON property step
56160 56161 56162 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56160 def step @step end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56167 56168 56169 56170 56171 56172 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56167 def update!(**args) @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id) @endpoint = args[:endpoint] if args.key?(:endpoint) @epoch = args[:epoch] if args.key?(:epoch) @step = args[:step] if args.key?(:step) end |