Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelRef
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelRef
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
TunedModel Reference for legacy model migration.
Instance Attribute Summary collapse
-
#pipeline_job ⇒ String
Support migration from tuning job list page, from bison model to gemini model.
-
#tuned_model ⇒ String
Support migration from model registry.
-
#tuning_job ⇒ String
Support migration from tuning job list page, from gemini-1.0-pro-002 to 1.5 and above.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelRef
constructor
A new instance of GoogleCloudAiplatformV1beta1TunedModelRef.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelRef
Returns a new instance of GoogleCloudAiplatformV1beta1TunedModelRef.
65161 65162 65163 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65161 def initialize(**args) update!(**args) end |
Instance Attribute Details
#pipeline_job ⇒ String
Support migration from tuning job list page, from bison model to gemini model.
Corresponds to the JSON property pipelineJob
65148 65149 65150 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65148 def pipeline_job @pipeline_job end |
#tuned_model ⇒ String
Support migration from model registry.
Corresponds to the JSON property tunedModel
65153 65154 65155 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65153 def tuned_model @tuned_model end |
#tuning_job ⇒ String
Support migration from tuning job list page, from gemini-1.0-pro-002 to 1.5
and above.
Corresponds to the JSON property tuningJob
65159 65160 65161 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65159 def tuning_job @tuning_job end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65166 65167 65168 65169 65170 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65166 def update!(**args) @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job) @tuned_model = args[:tuned_model] if args.key?(:tuned_model) @tuning_job = args[:tuning_job] if args.key?(:tuning_job) end |