Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelRef

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

TunedModel Reference for legacy model migration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelRef

Returns a new instance of GoogleCloudAiplatformV1beta1TunedModelRef.



64350
64351
64352
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pipeline_jobString

Support migration from tuning job list page, from bison model to gemini model. Corresponds to the JSON property pipelineJob

Returns:

  • (String)


64337
64338
64339
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64337

def pipeline_job
  @pipeline_job
end

#tuned_modelString

Support migration from model registry. Corresponds to the JSON property tunedModel

Returns:

  • (String)


64342
64343
64344
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64342

def tuned_model
  @tuned_model
end

#tuning_jobString

Support migration from tuning job list page, from gemini-1.0-pro-002 to 1.5 and above. Corresponds to the JSON property tuningJob

Returns:

  • (String)


64348
64349
64350
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64348

def tuning_job
  @tuning_job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64355
64356
64357
64358
64359
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64355

def update!(**args)
  @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job)
  @tuned_model = args[:tuned_model] if args.key?(:tuned_model)
  @tuning_job = args[:tuning_job] if args.key?(:tuning_job)
end