Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelRef

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

TunedModel Reference for legacy model migration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelRef

Returns a new instance of GoogleCloudAiplatformV1beta1TunedModelRef.



61404
61405
61406
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61404

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pipeline_jobString

Support migration from tuning job list page, from bison model to gemini model. Corresponds to the JSON property pipelineJob

Returns:

  • (String)


61391
61392
61393
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61391

def pipeline_job
  @pipeline_job
end

#tuned_modelString

Support migration from model registry. Corresponds to the JSON property tunedModel

Returns:

  • (String)


61396
61397
61398
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61396

def tuned_model
  @tuned_model
end

#tuning_jobString

Support migration from tuning job list page, from gemini-1.0-pro-002 to 1.5 and above. Corresponds to the JSON property tuningJob

Returns:

  • (String)


61402
61403
61404
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61402

def tuning_job
  @tuning_job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61409
61410
61411
61412
61413
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61409

def update!(**args)
  @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job)
  @tuned_model = args[:tuned_model] if args.key?(:tuned_model)
  @tuning_job = args[:tuning_job] if args.key?(:tuning_job)
end