Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModelRef

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

TunedModel Reference for legacy model migration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TunedModelRef

Returns a new instance of GoogleCloudAiplatformV1beta1TunedModelRef.



56195
56196
56197
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56195

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pipeline_jobString

Support migration from tuning job list page, from bison model to gemini model. Corresponds to the JSON property pipelineJob

Returns:

  • (String)


56182
56183
56184
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56182

def pipeline_job
  @pipeline_job
end

#tuned_modelString

Support migration from model registry. Corresponds to the JSON property tunedModel

Returns:

  • (String)


56187
56188
56189
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56187

def tuned_model
  @tuned_model
end

#tuning_jobString

Support migration from tuning job list page, from gemini-1.0-pro-002 to 1.5 and above. Corresponds to the JSON property tuningJob

Returns:

  • (String)


56193
56194
56195
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56193

def tuning_job
  @tuning_job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56200
56201
56202
56203
56204
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 56200

def update!(**args)
  @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job)
  @tuned_model = args[:tuned_model] if args.key?(:tuned_model)
  @tuning_job = args[:tuning_job] if args.key?(:tuning_job)
end