Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a TuningJob that runs with Google owned models.
Instance Attribute Summary collapse
-
#base_model ⇒ String
The base model that is being tuned.
-
#create_time ⇒ String
Output only.
-
#custom_base_model ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#distillation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DistillationSpec
Tuning Spec for Distillation.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#evaluate_dataset_runs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateDatasetRun>
Output only.
-
#experiment ⇒ String
Output only.
-
#full_fine_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FullFineTuningSpec
Tuning Spec for Full Fine Tuning.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#output_uri ⇒ String
Optional.
-
#partner_model_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PartnerModelTuningSpec
Tuning spec for Partner models.
-
#pipeline_job ⇒ String
Output only.
-
#pre_tuned_model ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreTunedModel
A pre-tuned model for continuous tuning.
-
#preference_optimization_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreferenceOptimizationSpec
Tuning Spec for Preference Optimization.
-
#reinforcement_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningSpec
Tuning spec for Reinforcement Tuning.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account ⇒ String
The service account that the tuningJob workload runs as.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#supervised_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningSpec
Tuning Spec for Supervised Tuning for first party models.
-
#tuned_model ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModel
The Model Registry Model and Online Prediction Endpoint associated with this TuningJob.
-
#tuned_model_display_name ⇒ String
Optional.
-
#tuning_data_stats ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningDataStats
The tuning data statistic values for TuningJob.
-
#tuning_job_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningJobMetadata
Tuning job metadata.
-
#tuning_job_state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#veo_lora_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
Tuning Spec for Veo LoRA Model Tuning.
-
#veo_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoTuningSpec
Tuning Spec for Veo Model Tuning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TuningJob
constructor
A new instance of GoogleCloudAiplatformV1beta1TuningJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TuningJob
Returns a new instance of GoogleCloudAiplatformV1beta1TuningJob.
65417 65418 65419 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65417 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_model ⇒ String
The base model that is being tuned. See Supported models.
Corresponds to the JSON property baseModel
65220 65221 65222 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65220 def base_model @base_model end |
#create_time ⇒ String
Output only. Time when the TuningJob was created.
Corresponds to the JSON property createTime
65225 65226 65227 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65225 def create_time @create_time end |
#custom_base_model ⇒ String
Optional. The user-provided path to custom model weights. Set this field to
tune a custom model. The path must be a Cloud Storage directory that contains
the model weights in .safetensors format along with associated model metadata
files. If this field is set, the base_model field must still be set to
indicate which base model the custom model is derived from. This feature is
only available for open source models.
Corresponds to the JSON property customBaseModel
65235 65236 65237 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65235 def custom_base_model @custom_base_model end |
#description ⇒ String
Optional. The description of the TuningJob.
Corresponds to the JSON property description
65240 65241 65242 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65240 def description @description end |
#distillation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DistillationSpec
Tuning Spec for Distillation.
Corresponds to the JSON property distillationSpec
65245 65246 65247 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65245 def distillation_spec @distillation_spec end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
65251 65252 65253 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65251 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the TuningJob entered any of the following JobStates:
JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED,
JOB_STATE_EXPIRED.
Corresponds to the JSON property endTime
65258 65259 65260 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65258 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
65268 65269 65270 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65268 def error @error end |
#evaluate_dataset_runs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateDatasetRun>
Output only. Evaluation runs for the Tuning Job.
Corresponds to the JSON property evaluateDatasetRuns
65273 65274 65275 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65273 def evaluate_dataset_runs @evaluate_dataset_runs end |
#experiment ⇒ String
Output only. The Experiment associated with this TuningJob.
Corresponds to the JSON property experiment
65278 65279 65280 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65278 def experiment @experiment end |
#full_fine_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FullFineTuningSpec
Tuning Spec for Full Fine Tuning.
Corresponds to the JSON property fullFineTuningSpec
65283 65284 65285 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65283 def full_fine_tuning_spec @full_fine_tuning_spec end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize TuningJob and
generated resources such as Model and Endpoint. Label keys and values can be
no longer than 64 characters (Unicode codepoints), can only contain lowercase
letters, numeric characters, underscores and dashes. International characters
are allowed. See https://goo.gl/xmQnxf for more information and examples of
labels.
Corresponds to the JSON property labels
65293 65294 65295 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65293 def labels @labels end |
#name ⇒ String
Output only. Identifier. Resource name of a TuningJob. Format: projects/
project/locations/location/tuningJobs/tuning_job`
Corresponds to the JSON propertyname`
65299 65300 65301 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65299 def name @name end |
#output_uri ⇒ String
Optional. Cloud Storage path to the directory where tuning job outputs are
written to. This field is only available and required for open source models.
Corresponds to the JSON property outputUri
65305 65306 65307 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65305 def output_uri @output_uri end |
#partner_model_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PartnerModelTuningSpec
Tuning spec for Partner models.
Corresponds to the JSON property partnerModelTuningSpec
65310 65311 65312 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65310 def partner_model_tuning_spec @partner_model_tuning_spec end |
#pipeline_job ⇒ String
Output only. The resource name of the PipelineJob associated with the
TuningJob. Format: projects/project/locations/location/pipelineJobs/
pipeline_job`.
Corresponds to the JSON propertypipelineJob`
65317 65318 65319 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65317 def pipeline_job @pipeline_job end |
#pre_tuned_model ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreTunedModel
A pre-tuned model for continuous tuning.
Corresponds to the JSON property preTunedModel
65322 65323 65324 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65322 def pre_tuned_model @pre_tuned_model end |
#preference_optimization_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreferenceOptimizationSpec
Tuning Spec for Preference Optimization.
Corresponds to the JSON property preferenceOptimizationSpec
65327 65328 65329 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65327 def preference_optimization_spec @preference_optimization_spec end |
#reinforcement_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningSpec
Tuning spec for Reinforcement Tuning.
Corresponds to the JSON property reinforcementTuningSpec
65332 65333 65334 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65332 def reinforcement_tuning_spec @reinforcement_tuning_spec end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
65337 65338 65339 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65337 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
65343 65344 65345 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65343 def satisfies_pzs @satisfies_pzs end |
#service_account ⇒ String
The service account that the tuningJob workload runs as. If not specified, the
Vertex AI Secure Fine-Tuned Service Agent in the project will be used. See
https://cloud.google.com/iam/docs/service-agents#vertex-ai-secure-fine-tuning-
service-agent Users starting the pipeline must have the iam.serviceAccounts.
actAs permission on this service account.
Corresponds to the JSON property serviceAccount
65353 65354 65355 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65353 def service_account @service_account end |
#start_time ⇒ String
Output only. Time when the TuningJob for the first time entered the
JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
65359 65360 65361 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65359 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
65364 65365 65366 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65364 def state @state end |
#supervised_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningSpec
Tuning Spec for Supervised Tuning for first party models.
Corresponds to the JSON property supervisedTuningSpec
65369 65370 65371 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65369 def supervised_tuning_spec @supervised_tuning_spec end |
#tuned_model ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModel
The Model Registry Model and Online Prediction Endpoint associated with this
TuningJob.
Corresponds to the JSON property tunedModel
65375 65376 65377 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65375 def tuned_model @tuned_model end |
#tuned_model_display_name ⇒ String
Optional. The display name of the TunedModel. The name can be up to 128
characters long and can consist of any UTF-8 characters. For continuous tuning,
tuned_model_display_name will by default use the same display name as the pre-
tuned model. If a new display name is provided, the tuning job will create a
new model instead of a new version.
Corresponds to the JSON property tunedModelDisplayName
65384 65385 65386 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65384 def tuned_model_display_name @tuned_model_display_name end |
#tuning_data_stats ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningDataStats
The tuning data statistic values for TuningJob.
Corresponds to the JSON property tuningDataStats
65389 65390 65391 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65389 def tuning_data_stats @tuning_data_stats end |
#tuning_job_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningJobMetadata
Tuning job metadata.
Corresponds to the JSON property tuningJobMetadata
65394 65395 65396 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65394 def @tuning_job_metadata end |
#tuning_job_state ⇒ String
Output only. The detail state of the tuning job (while the overall JobState
is running).
Corresponds to the JSON property tuningJobState
65400 65401 65402 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65400 def tuning_job_state @tuning_job_state end |
#update_time ⇒ String
Output only. Time when the TuningJob was most recently updated.
Corresponds to the JSON property updateTime
65405 65406 65407 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65405 def update_time @update_time end |
#veo_lora_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
Tuning Spec for Veo LoRA Model Tuning.
Corresponds to the JSON property veoLoraTuningSpec
65410 65411 65412 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65410 def veo_lora_tuning_spec @veo_lora_tuning_spec end |
#veo_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoTuningSpec
Tuning Spec for Veo Model Tuning.
Corresponds to the JSON property veoTuningSpec
65415 65416 65417 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65415 def veo_tuning_spec @veo_tuning_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65422 65423 65424 65425 65426 65427 65428 65429 65430 65431 65432 65433 65434 65435 65436 65437 65438 65439 65440 65441 65442 65443 65444 65445 65446 65447 65448 65449 65450 65451 65452 65453 65454 65455 65456 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65422 def update!(**args) @base_model = args[:base_model] if args.key?(:base_model) @create_time = args[:create_time] if args.key?(:create_time) @custom_base_model = args[:custom_base_model] if args.key?(:custom_base_model) @description = args[:description] if args.key?(:description) @distillation_spec = args[:distillation_spec] if args.key?(:distillation_spec) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @evaluate_dataset_runs = args[:evaluate_dataset_runs] if args.key?(:evaluate_dataset_runs) @experiment = args[:experiment] if args.key?(:experiment) @full_fine_tuning_spec = args[:full_fine_tuning_spec] if args.key?(:full_fine_tuning_spec) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @output_uri = args[:output_uri] if args.key?(:output_uri) @partner_model_tuning_spec = args[:partner_model_tuning_spec] if args.key?(:partner_model_tuning_spec) @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job) @pre_tuned_model = args[:pre_tuned_model] if args.key?(:pre_tuned_model) @preference_optimization_spec = args[:preference_optimization_spec] if args.key?(:preference_optimization_spec) @reinforcement_tuning_spec = args[:reinforcement_tuning_spec] if args.key?(:reinforcement_tuning_spec) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account = args[:service_account] if args.key?(:service_account) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @supervised_tuning_spec = args[:supervised_tuning_spec] if args.key?(:supervised_tuning_spec) @tuned_model = args[:tuned_model] if args.key?(:tuned_model) @tuned_model_display_name = args[:tuned_model_display_name] if args.key?(:tuned_model_display_name) @tuning_data_stats = args[:tuning_data_stats] if args.key?(:tuning_data_stats) @tuning_job_metadata = args[:tuning_job_metadata] if args.key?(:tuning_job_metadata) @tuning_job_state = args[:tuning_job_state] if args.key?(:tuning_job_state) @update_time = args[:update_time] if args.key?(:update_time) @veo_lora_tuning_spec = args[:veo_lora_tuning_spec] if args.key?(:veo_lora_tuning_spec) @veo_tuning_spec = args[:veo_tuning_spec] if args.key?(:veo_tuning_spec) end |