Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents a TuningJob that runs with Google owned models.
Instance Attribute Summary collapse
-
#base_model ⇒ String
The base model that is being tuned.
-
#create_time ⇒ String
Output only.
-
#custom_base_model ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#distillation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DistillationSpec
Tuning Spec for Distillation.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#evaluate_dataset_runs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateDatasetRun>
Output only.
-
#experiment ⇒ String
Output only.
-
#full_fine_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FullFineTuningSpec
Tuning Spec for Full Fine Tuning.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#output_uri ⇒ String
Optional.
-
#partner_model_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PartnerModelTuningSpec
Tuning spec for Partner models.
-
#pipeline_job ⇒ String
Output only.
-
#pre_tuned_model ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreTunedModel
A pre-tuned model for continuous tuning.
-
#preference_optimization_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreferenceOptimizationSpec
Tuning Spec for Preference Optimization.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account ⇒ String
The service account that the tuningJob workload runs as.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#supervised_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningSpec
Tuning Spec for Supervised Tuning for first party models.
-
#tuned_model ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModel
The Model Registry Model and Online Prediction Endpoint associated with this TuningJob.
-
#tuned_model_display_name ⇒ String
Optional.
-
#tuning_data_stats ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningDataStats
The tuning data statistic values for TuningJob.
-
#tuning_job_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningJobMetadata
Tuning job metadata.
-
#tuning_job_state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#veo_lora_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
Tuning Spec for Veo LoRA Model Tuning.
-
#veo_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoTuningSpec
Tuning Spec for Veo Model Tuning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TuningJob
constructor
A new instance of GoogleCloudAiplatformV1beta1TuningJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1TuningJob
Returns a new instance of GoogleCloudAiplatformV1beta1TuningJob.
61649 61650 61651 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_model ⇒ String
The base model that is being tuned. See Supported models.
Corresponds to the JSON property baseModel
61457 61458 61459 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61457 def base_model @base_model end |
#create_time ⇒ String
Output only. Time when the TuningJob was created.
Corresponds to the JSON property createTime
61462 61463 61464 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61462 def create_time @create_time end |
#custom_base_model ⇒ String
Optional. The user-provided path to custom model weights. Set this field to
tune a custom model. The path must be a Cloud Storage directory that contains
the model weights in .safetensors format along with associated model metadata
files. If this field is set, the base_model field must still be set to
indicate which base model the custom model is derived from. This feature is
only available for open source models.
Corresponds to the JSON property customBaseModel
61472 61473 61474 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61472 def custom_base_model @custom_base_model end |
#description ⇒ String
Optional. The description of the TuningJob.
Corresponds to the JSON property description
61477 61478 61479 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61477 def description @description end |
#distillation_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DistillationSpec
Tuning Spec for Distillation.
Corresponds to the JSON property distillationSpec
61482 61483 61484 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61482 def distillation_spec @distillation_spec end |
#encryption_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
61488 61489 61490 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61488 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the TuningJob entered any of the following JobStates:
JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED,
JOB_STATE_EXPIRED.
Corresponds to the JSON property endTime
61495 61496 61497 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61495 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
61505 61506 61507 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61505 def error @error end |
#evaluate_dataset_runs ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1EvaluateDatasetRun>
Output only. Evaluation runs for the Tuning Job.
Corresponds to the JSON property evaluateDatasetRuns
61510 61511 61512 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61510 def evaluate_dataset_runs @evaluate_dataset_runs end |
#experiment ⇒ String
Output only. The Experiment associated with this TuningJob.
Corresponds to the JSON property experiment
61515 61516 61517 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61515 def experiment @experiment end |
#full_fine_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1FullFineTuningSpec
Tuning Spec for Full Fine Tuning.
Corresponds to the JSON property fullFineTuningSpec
61520 61521 61522 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61520 def full_fine_tuning_spec @full_fine_tuning_spec end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize TuningJob and
generated resources such as Model and Endpoint. Label keys and values can be
no longer than 64 characters (Unicode codepoints), can only contain lowercase
letters, numeric characters, underscores and dashes. International characters
are allowed. See https://goo.gl/xmQnxf for more information and examples of
labels.
Corresponds to the JSON property labels
61530 61531 61532 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61530 def labels @labels end |
#name ⇒ String
Output only. Identifier. Resource name of a TuningJob. Format: projects/
project/locations/location/tuningJobs/tuning_job`
Corresponds to the JSON propertyname`
61536 61537 61538 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61536 def name @name end |
#output_uri ⇒ String
Optional. Cloud Storage path to the directory where tuning job outputs are
written to. This field is only available and required for open source models.
Corresponds to the JSON property outputUri
61542 61543 61544 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61542 def output_uri @output_uri end |
#partner_model_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PartnerModelTuningSpec
Tuning spec for Partner models.
Corresponds to the JSON property partnerModelTuningSpec
61547 61548 61549 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61547 def partner_model_tuning_spec @partner_model_tuning_spec end |
#pipeline_job ⇒ String
Output only. The resource name of the PipelineJob associated with the
TuningJob. Format: projects/project/locations/location/pipelineJobs/
pipeline_job`.
Corresponds to the JSON propertypipelineJob`
61554 61555 61556 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61554 def pipeline_job @pipeline_job end |
#pre_tuned_model ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreTunedModel
A pre-tuned model for continuous tuning.
Corresponds to the JSON property preTunedModel
61559 61560 61561 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61559 def pre_tuned_model @pre_tuned_model end |
#preference_optimization_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PreferenceOptimizationSpec
Tuning Spec for Preference Optimization.
Corresponds to the JSON property preferenceOptimizationSpec
61564 61565 61566 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61564 def preference_optimization_spec @preference_optimization_spec end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
61569 61570 61571 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61569 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
61575 61576 61577 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61575 def satisfies_pzs @satisfies_pzs end |
#service_account ⇒ String
The service account that the tuningJob workload runs as. If not specified, the
Vertex AI Secure Fine-Tuned Service Agent in the project will be used. See
https://cloud.google.com/iam/docs/service-agents#vertex-ai-secure-fine-tuning-
service-agent Users starting the pipeline must have the iam.serviceAccounts.
actAs permission on this service account.
Corresponds to the JSON property serviceAccount
61585 61586 61587 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61585 def service_account @service_account end |
#start_time ⇒ String
Output only. Time when the TuningJob for the first time entered the
JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
61591 61592 61593 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61591 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
61596 61597 61598 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61596 def state @state end |
#supervised_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SupervisedTuningSpec
Tuning Spec for Supervised Tuning for first party models.
Corresponds to the JSON property supervisedTuningSpec
61601 61602 61603 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61601 def supervised_tuning_spec @supervised_tuning_spec end |
#tuned_model ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TunedModel
The Model Registry Model and Online Prediction Endpoint associated with this
TuningJob.
Corresponds to the JSON property tunedModel
61607 61608 61609 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61607 def tuned_model @tuned_model end |
#tuned_model_display_name ⇒ String
Optional. The display name of the TunedModel. The name can be up to 128
characters long and can consist of any UTF-8 characters. For continuous tuning,
tuned_model_display_name will by default use the same display name as the pre-
tuned model. If a new display name is provided, the tuning job will create a
new model instead of a new version.
Corresponds to the JSON property tunedModelDisplayName
61616 61617 61618 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61616 def tuned_model_display_name @tuned_model_display_name end |
#tuning_data_stats ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningDataStats
The tuning data statistic values for TuningJob.
Corresponds to the JSON property tuningDataStats
61621 61622 61623 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61621 def tuning_data_stats @tuning_data_stats end |
#tuning_job_metadata ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1TuningJobMetadata
Tuning job metadata.
Corresponds to the JSON property tuningJobMetadata
61626 61627 61628 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61626 def @tuning_job_metadata end |
#tuning_job_state ⇒ String
Output only. The detail state of the tuning job (while the overall JobState
is running).
Corresponds to the JSON property tuningJobState
61632 61633 61634 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61632 def tuning_job_state @tuning_job_state end |
#update_time ⇒ String
Output only. Time when the TuningJob was most recently updated.
Corresponds to the JSON property updateTime
61637 61638 61639 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61637 def update_time @update_time end |
#veo_lora_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
Tuning Spec for Veo LoRA Model Tuning.
Corresponds to the JSON property veoLoraTuningSpec
61642 61643 61644 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61642 def veo_lora_tuning_spec @veo_lora_tuning_spec end |
#veo_tuning_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoTuningSpec
Tuning Spec for Veo Model Tuning.
Corresponds to the JSON property veoTuningSpec
61647 61648 61649 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61647 def veo_tuning_spec @veo_tuning_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61654 61655 61656 61657 61658 61659 61660 61661 61662 61663 61664 61665 61666 61667 61668 61669 61670 61671 61672 61673 61674 61675 61676 61677 61678 61679 61680 61681 61682 61683 61684 61685 61686 61687 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61654 def update!(**args) @base_model = args[:base_model] if args.key?(:base_model) @create_time = args[:create_time] if args.key?(:create_time) @custom_base_model = args[:custom_base_model] if args.key?(:custom_base_model) @description = args[:description] if args.key?(:description) @distillation_spec = args[:distillation_spec] if args.key?(:distillation_spec) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @evaluate_dataset_runs = args[:evaluate_dataset_runs] if args.key?(:evaluate_dataset_runs) @experiment = args[:experiment] if args.key?(:experiment) @full_fine_tuning_spec = args[:full_fine_tuning_spec] if args.key?(:full_fine_tuning_spec) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @output_uri = args[:output_uri] if args.key?(:output_uri) @partner_model_tuning_spec = args[:partner_model_tuning_spec] if args.key?(:partner_model_tuning_spec) @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job) @pre_tuned_model = args[:pre_tuned_model] if args.key?(:pre_tuned_model) @preference_optimization_spec = args[:preference_optimization_spec] if args.key?(:preference_optimization_spec) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account = args[:service_account] if args.key?(:service_account) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @supervised_tuning_spec = args[:supervised_tuning_spec] if args.key?(:supervised_tuning_spec) @tuned_model = args[:tuned_model] if args.key?(:tuned_model) @tuned_model_display_name = args[:tuned_model_display_name] if args.key?(:tuned_model_display_name) @tuning_data_stats = args[:tuning_data_stats] if args.key?(:tuning_data_stats) @tuning_job_metadata = args[:tuning_job_metadata] if args.key?(:tuning_job_metadata) @tuning_job_state = args[:tuning_job_state] if args.key?(:tuning_job_state) @update_time = args[:update_time] if args.key?(:update_time) @veo_lora_tuning_spec = args[:veo_lora_tuning_spec] if args.key?(:veo_lora_tuning_spec) @veo_tuning_spec = args[:veo_tuning_spec] if args.key?(:veo_tuning_spec) end |