Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UndeployModelRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for EndpointService.UndeployModel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UndeployModelRequest

Returns a new instance of GoogleCloudAiplatformV1beta1UndeployModelRequest.



66889
66890
66891
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_model_idString

Required. The ID of the DeployedModel to be undeployed from the Endpoint. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


66877
66878
66879
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66877

def deployed_model_id
  @deployed_model_id
end

#traffic_splitHash<String,Fixnum>

If this field is provided, then the Endpoint's traffic_split will be overwritten with it. If last DeployedModel is being undeployed from the Endpoint, the [Endpoint.traffic_split] will always end up empty when this call returns. A DeployedModel will be successfully undeployed only if it doesn't have any traffic assigned to it when this method executes, or if this field unassigns any traffic to it. Corresponds to the JSON property trafficSplit

Returns:

  • (Hash<String,Fixnum>)


66887
66888
66889
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66887

def traffic_split
  @traffic_split
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66894
66895
66896
66897
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66894

def update!(**args)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @traffic_split = args[:traffic_split] if args.key?(:traffic_split)
end