Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UndeployModelRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UndeployModelRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for EndpointService.UndeployModel.
Instance Attribute Summary collapse
-
#deployed_model_id ⇒ String
Required.
-
#traffic_split ⇒ Hash<String,Fixnum>
If this field is provided, then the Endpoint's traffic_split will be overwritten with it.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UndeployModelRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1UndeployModelRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UndeployModelRequest
Returns a new instance of GoogleCloudAiplatformV1beta1UndeployModelRequest.
61805 61806 61807 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61805 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployed_model_id ⇒ String
Required. The ID of the DeployedModel to be undeployed from the Endpoint.
Corresponds to the JSON property deployedModelId
61793 61794 61795 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61793 def deployed_model_id @deployed_model_id end |
#traffic_split ⇒ Hash<String,Fixnum>
If this field is provided, then the Endpoint's traffic_split will be
overwritten with it. If last DeployedModel is being undeployed from the
Endpoint, the [Endpoint.traffic_split] will always end up empty when this call
returns. A DeployedModel will be successfully undeployed only if it doesn't
have any traffic assigned to it when this method executes, or if this field
unassigns any traffic to it.
Corresponds to the JSON property trafficSplit
61803 61804 61805 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61803 def traffic_split @traffic_split end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61810 61811 61812 61813 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61810 def update!(**args) @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id) @traffic_split = args[:traffic_split] if args.key?(:traffic_split) end |