Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UnmanagedContainerModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Contains model information necessary to perform batch prediction without requiring a full model import.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UnmanagedContainerModel

Returns a new instance of GoogleCloudAiplatformV1beta1UnmanagedContainerModel.



61873
61874
61875
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_uriString

The path to the directory containing the Model artifact and any of its supporting files. Corresponds to the JSON property artifactUri

Returns:

  • (String)


61857
61858
61859
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61857

def artifact_uri
  @artifact_uri
end

#container_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModelContainerSpec

Specification of a container for serving predictions. Some fields in this message correspond to fields in the Kubernetes Container v1 core specification. Corresponds to the JSON property containerSpec



61865
61866
61867
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61865

def container_spec
  @container_spec
end

#predict_schemataGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PredictSchemata

Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob. Corresponds to the JSON property predictSchemata



61871
61872
61873
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61871

def predict_schemata
  @predict_schemata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61878
61879
61880
61881
61882
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 61878

def update!(**args)
  @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @predict_schemata = args[:predict_schemata] if args.key?(:predict_schemata)
end