Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UploadRagFileResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for VertexRagDataService.UploadRagFile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UploadRagFileResponse

Returns a new instance of GoogleCloudAiplatformV1beta1UploadRagFileResponse.



68093
68094
68095
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



68086
68087
68088
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68086

def error
  @error
end

#rag_fileGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagFile

A RagFile contains user data for chunking, embedding and indexing. Corresponds to the JSON property ragFile



68091
68092
68093
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68091

def rag_file
  @rag_file
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68098
68099
68100
68101
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68098

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @rag_file = args[:rag_file] if args.key?(:rag_file)
end