Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UploadRagFileResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for VertexRagDataService.UploadRagFile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UploadRagFileResponse

Returns a new instance of GoogleCloudAiplatformV1beta1UploadRagFileResponse.



65395
65396
65397
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



65388
65389
65390
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65388

def error
  @error
end

#rag_fileGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagFile

A RagFile contains user data for chunking, embedding and indexing. Corresponds to the JSON property ragFile



65393
65394
65395
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65393

def rag_file
  @rag_file
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65400
65401
65402
65403
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65400

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @rag_file = args[:rag_file] if args.key?(:rag_file)
end