Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UpsertExamplesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UpsertExamplesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ExampleStoreService.UpsertExamples.
Instance Attribute Summary collapse
-
#examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example>
Required.
-
#overwrite ⇒ Boolean
(also: #overwrite?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UpsertExamplesRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1UpsertExamplesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UpsertExamplesRequest
Returns a new instance of GoogleCloudAiplatformV1beta1UpsertExamplesRequest.
65643 65644 65645 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65643 def initialize(**args) update!(**args) end |
Instance Attribute Details
#examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example>
Required. A list of examples to be created/updated.
Corresponds to the JSON property examples
65632 65633 65634 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65632 def examples @examples end |
#overwrite ⇒ Boolean Also known as: overwrite?
Optional. A flag indicating whether an example can be overwritten if it
already exists. If False (default) and the example already exists, the example
will not be updated. This does not affect behavior if the example does not
exist already.
Corresponds to the JSON property overwrite
65640 65641 65642 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65640 def overwrite @overwrite end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65648 65649 65650 65651 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65648 def update!(**args) @examples = args[:examples] if args.key?(:examples) @overwrite = args[:overwrite] if args.key?(:overwrite) end |