Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UpsertExamplesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UpsertExamplesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for ExampleStoreService.UpsertExamples.
Instance Attribute Summary collapse
-
#examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example>
Required.
-
#overwrite ⇒ Boolean
(also: #overwrite?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UpsertExamplesRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1UpsertExamplesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UpsertExamplesRequest
Returns a new instance of GoogleCloudAiplatformV1beta1UpsertExamplesRequest.
62507 62508 62509 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62507 def initialize(**args) update!(**args) end |
Instance Attribute Details
#examples ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example>
Required. A list of examples to be created/updated.
Corresponds to the JSON property examples
62496 62497 62498 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62496 def examples @examples end |
#overwrite ⇒ Boolean Also known as: overwrite?
Optional. A flag indicating whether an example can be overwritten if it
already exists. If False (default) and the example already exists, the example
will not be updated. This does not affect behavior if the example does not
exist already.
Corresponds to the JSON property overwrite
62504 62505 62506 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62504 def overwrite @overwrite end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62512 62513 62514 62515 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62512 def update!(**args) @examples = args[:examples] if args.key?(:examples) @overwrite = args[:overwrite] if args.key?(:overwrite) end |