Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UpsertExamplesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Request message for ExampleStoreService.UpsertExamples.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UpsertExamplesRequest

Returns a new instance of GoogleCloudAiplatformV1beta1UpsertExamplesRequest.



57462
57463
57464
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#examplesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example>

Required. A list of examples to be created/updated. Corresponds to the JSON property examples



57451
57452
57453
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57451

def examples
  @examples
end

#overwriteBoolean Also known as: overwrite?

Optional. A flag indicating whether an example can be overwritten if it already exists. If False (default) and the example already exists, the example will not be updated. This does not affect behavior if the example does not exist already. Corresponds to the JSON property overwrite

Returns:

  • (Boolean)


57459
57460
57461
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57459

def overwrite
  @overwrite
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57467
57468
57469
57470
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57467

def update!(**args)
  @examples = args[:examples] if args.key?(:examples)
  @overwrite = args[:overwrite] if args.key?(:overwrite)
end