Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UpsertExamplesResponseUpsertResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UpsertExamplesResponseUpsertResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The result for creating/updating a single example.
Instance Attribute Summary collapse
-
#example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example
The example created/updated successfully.
-
#status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UpsertExamplesResponseUpsertResult
constructor
A new instance of GoogleCloudAiplatformV1beta1UpsertExamplesResponseUpsertResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UpsertExamplesResponseUpsertResult
Returns a new instance of GoogleCloudAiplatformV1beta1UpsertExamplesResponseUpsertResult.
65515 65516 65517 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65515 def initialize(**args) update!(**args) end |
Instance Attribute Details
#example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example
The example created/updated successfully.
Corresponds to the JSON property example
65503 65504 65505 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65503 def example @example end |
#status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
65513 65514 65515 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65513 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65520 65521 65522 65523 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65520 def update!(**args) @example = args[:example] if args.key?(:example) @status = args[:status] if args.key?(:status) end |