Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UpsertExamplesResponseUpsertResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

The result for creating/updating a single example.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UpsertExamplesResponseUpsertResult

Returns a new instance of GoogleCloudAiplatformV1beta1UpsertExamplesResponseUpsertResult.



57342
57343
57344
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57342

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exampleGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Example

The example created/updated successfully. Corresponds to the JSON property example



57330
57331
57332
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57330

def example
  @example
end

#statusGoogle::Apis::AiplatformV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



57340
57341
57342
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57340

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57347
57348
57349
57350
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57347

def update!(**args)
  @example = args[:example] if args.key?(:example)
  @status = args[:status] if args.key?(:status)
end