Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UsageMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Usage metadata about the content generation request and response. This message provides a detailed breakdown of token usage and other relevant metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UsageMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1UsageMetadata.



67782
67783
67784
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_tokens_detailsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModalityTokenCount>

Output only. A detailed breakdown of the token count for each modality in the cached content. Corresponds to the JSON property cacheTokensDetails



67720
67721
67722
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67720

def cache_tokens_details
  @cache_tokens_details
end

#cached_content_token_countFixnum

Output only. The number of tokens in the cached content that was used for this request. Corresponds to the JSON property cachedContentTokenCount

Returns:

  • (Fixnum)


67726
67727
67728
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67726

def cached_content_token_count
  @cached_content_token_count
end

#candidates_token_countFixnum

The total number of tokens in the generated candidates. Corresponds to the JSON property candidatesTokenCount

Returns:

  • (Fixnum)


67731
67732
67733
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67731

def candidates_token_count
  @candidates_token_count
end

#candidates_tokens_detailsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModalityTokenCount>

Output only. A detailed breakdown of the token count for each modality in the generated candidates. Corresponds to the JSON property candidatesTokensDetails



67737
67738
67739
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67737

def candidates_tokens_details
  @candidates_tokens_details
end

#prompt_token_countFixnum

The total number of tokens in the prompt. This includes any text, images, or other media provided in the request. When cached_content is set, this also includes the number of tokens in the cached content. Corresponds to the JSON property promptTokenCount

Returns:

  • (Fixnum)


67744
67745
67746
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67744

def prompt_token_count
  @prompt_token_count
end

#prompt_tokens_detailsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModalityTokenCount>

Output only. A detailed breakdown of the token count for each modality in the prompt. Corresponds to the JSON property promptTokensDetails



67750
67751
67752
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67750

def prompt_tokens_details
  @prompt_tokens_details
end

#thoughts_token_countFixnum

Output only. The number of tokens that were part of the model's generated " thoughts" output, if applicable. Corresponds to the JSON property thoughtsTokenCount

Returns:

  • (Fixnum)


67756
67757
67758
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67756

def thoughts_token_count
  @thoughts_token_count
end

#tool_use_prompt_token_countFixnum

Output only. The number of tokens in the results from tool executions, which are provided back to the model as input, if applicable. Corresponds to the JSON property toolUsePromptTokenCount

Returns:

  • (Fixnum)


67762
67763
67764
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67762

def tool_use_prompt_token_count
  @tool_use_prompt_token_count
end

#tool_use_prompt_tokens_detailsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ModalityTokenCount>

Output only. A detailed breakdown by modality of the token counts from the results of tool executions, which are provided back to the model as input. Corresponds to the JSON property toolUsePromptTokensDetails



67768
67769
67770
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67768

def tool_use_prompt_tokens_details
  @tool_use_prompt_tokens_details
end

#total_token_countFixnum

The total number of tokens for the entire request. This is the sum of prompt_token_count, candidates_token_count, tool_use_prompt_token_count, and thoughts_token_count. Corresponds to the JSON property totalTokenCount

Returns:

  • (Fixnum)


67775
67776
67777
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67775

def total_token_count
  @total_token_count
end

#traffic_typeString

Output only. The traffic type for this request. Corresponds to the JSON property trafficType

Returns:

  • (String)


67780
67781
67782
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67780

def traffic_type
  @traffic_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67787
67788
67789
67790
67791
67792
67793
67794
67795
67796
67797
67798
67799
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67787

def update!(**args)
  @cache_tokens_details = args[:cache_tokens_details] if args.key?(:cache_tokens_details)
  @cached_content_token_count = args[:cached_content_token_count] if args.key?(:cached_content_token_count)
  @candidates_token_count = args[:candidates_token_count] if args.key?(:candidates_token_count)
  @candidates_tokens_details = args[:candidates_tokens_details] if args.key?(:candidates_tokens_details)
  @prompt_token_count = args[:prompt_token_count] if args.key?(:prompt_token_count)
  @prompt_tokens_details = args[:prompt_tokens_details] if args.key?(:prompt_tokens_details)
  @thoughts_token_count = args[:thoughts_token_count] if args.key?(:thoughts_token_count)
  @tool_use_prompt_token_count = args[:tool_use_prompt_token_count] if args.key?(:tool_use_prompt_token_count)
  @tool_use_prompt_tokens_details = args[:tool_use_prompt_tokens_details] if args.key?(:tool_use_prompt_tokens_details)
  @total_token_count = args[:total_token_count] if args.key?(:total_token_count)
  @traffic_type = args[:traffic_type] if args.key?(:traffic_type)
end