Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserScenario
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserScenario
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Output of user scenario generation.
Instance Attribute Summary collapse
-
#conversation_plan ⇒ String
Conversation plan to drive multi-turn agent run and get simulated agent eval dataset.
-
#starting_prompt ⇒ String
Starting prompt for the conversation between simulated user and agent under the test.
-
#test_case_title ⇒ String
Represents a short 3-5 word title for eval test case.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UserScenario
constructor
A new instance of GoogleCloudAiplatformV1beta1UserScenario.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UserScenario
Returns a new instance of GoogleCloudAiplatformV1beta1UserScenario.
57731 57732 57733 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57731 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_plan ⇒ String
Conversation plan to drive multi-turn agent run and get simulated agent eval
dataset.
Corresponds to the JSON property conversationPlan
57718 57719 57720 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57718 def conversation_plan @conversation_plan end |
#starting_prompt ⇒ String
Starting prompt for the conversation between simulated user and agent under
the test.
Corresponds to the JSON property startingPrompt
57724 57725 57726 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57724 def starting_prompt @starting_prompt end |
#test_case_title ⇒ String
Represents a short 3-5 word title for eval test case.
Corresponds to the JSON property testCaseTitle
57729 57730 57731 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57729 def test_case_title @test_case_title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57736 57737 57738 57739 57740 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57736 def update!(**args) @conversation_plan = args[:conversation_plan] if args.key?(:conversation_plan) @starting_prompt = args[:starting_prompt] if args.key?(:starting_prompt) @test_case_title = args[:test_case_title] if args.key?(:test_case_title) end |