Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserScenario

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Output of user scenario generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UserScenario

Returns a new instance of GoogleCloudAiplatformV1beta1UserScenario.



57561
57562
57563
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_planString

Conversation plan to drive multi-turn agent run and get simulated agent eval dataset. Corresponds to the JSON property conversationPlan

Returns:

  • (String)


57548
57549
57550
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57548

def conversation_plan
  @conversation_plan
end

#starting_promptString

Starting prompt for the conversation between simulated user and agent under the test. Corresponds to the JSON property startingPrompt

Returns:

  • (String)


57554
57555
57556
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57554

def starting_prompt
  @starting_prompt
end

#test_case_titleString

Represents a short 3-5 word title for eval test case. Corresponds to the JSON property testCaseTitle

Returns:

  • (String)


57559
57560
57561
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57559

def test_case_title
  @test_case_title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57566
57567
57568
57569
57570
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57566

def update!(**args)
  @conversation_plan = args[:conversation_plan] if args.key?(:conversation_plan)
  @starting_prompt = args[:starting_prompt] if args.key?(:starting_prompt)
  @test_case_title = args[:test_case_title] if args.key?(:test_case_title)
end