Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserSpecifiedMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserSpecifiedMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Metadata provided by users.
Instance Attribute Summary collapse
-
#key ⇒ String
Required.
-
#value ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataValue
Value of Metadata, including all types available in data schema.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UserSpecifiedMetadata
constructor
A new instance of GoogleCloudAiplatformV1beta1UserSpecifiedMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UserSpecifiedMetadata
Returns a new instance of GoogleCloudAiplatformV1beta1UserSpecifiedMetadata.
64346 64347 64348 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Required. Key of the metadata. The key must be set with type by
CreateRagDataSchema.
Corresponds to the JSON property key
64339 64340 64341 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64339 def key @key end |
#value ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataValue
Value of Metadata, including all types available in data schema.
Corresponds to the JSON property value
64344 64345 64346 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64344 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64351 64352 64353 64354 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64351 def update!(**args) @key = args[:key] if args.key?(:key) @value = args[:value] if args.key?(:value) end |