Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserSpecifiedMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserSpecifiedMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Metadata provided by users.
Instance Attribute Summary collapse
-
#key ⇒ String
Required.
-
#value ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataValue
Value of Metadata, including all types available in data schema.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UserSpecifiedMetadata
constructor
A new instance of GoogleCloudAiplatformV1beta1UserSpecifiedMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UserSpecifiedMetadata
Returns a new instance of GoogleCloudAiplatformV1beta1UserSpecifiedMetadata.
62845 62846 62847 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62845 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Required. Key of the metadata. The key must be set with type by
CreateRagDataSchema.
Corresponds to the JSON property key
62838 62839 62840 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62838 def key @key end |
#value ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataValue
Value of Metadata, including all types available in data schema.
Corresponds to the JSON property value
62843 62844 62845 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62843 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62850 62851 62852 62853 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62850 def update!(**args) @key = args[:key] if args.key?(:key) @value = args[:value] if args.key?(:value) end |