Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1UserSpecifiedMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Metadata provided by users.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1UserSpecifiedMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1UserSpecifiedMetadata.



57630
57631
57632
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57630

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Required. Key of the metadata. The key must be set with type by CreateRagDataSchema. Corresponds to the JSON property key

Returns:

  • (String)


57623
57624
57625
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57623

def key
  @key
end

#valueGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MetadataValue

Value of Metadata, including all types available in data schema. Corresponds to the JSON property value



57628
57629
57630
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57628

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57635
57636
57637
57638
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57635

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @value = args[:value] if args.key?(:value)
end