Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Request message for GenAiTuningService.ValidateReinforcementTuningReward.
Instance Attribute Summary collapse
-
#composite_reward_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CompositeReinforcementTuningRewardConfig
Composite reward function configuration for reinforcement tuning.
-
#example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningExample
User-facing format for Gemini Reinforcement Tuning examples on Vertex.
-
#sample_response ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message.
-
#single_reward_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SingleReinforcementTuningRewardConfig
SingleReinforcementTuningRewardConfig defines a single reward function configuration for RL tuning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardRequest
Returns a new instance of GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardRequest.
66022 66023 66024 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#composite_reward_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1CompositeReinforcementTuningRewardConfig
Composite reward function configuration for reinforcement tuning.
Corresponds to the JSON property compositeRewardConfig
65999 66000 66001 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65999 def composite_reward_config @composite_reward_config end |
#example ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningExample
User-facing format for Gemini Reinforcement Tuning examples on Vertex.
Corresponds to the JSON property example
66004 66005 66006 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66004 def example @example end |
#sample_response ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property sampleResponse
66011 66012 66013 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66011 def sample_response @sample_response end |
#single_reward_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1SingleReinforcementTuningRewardConfig
SingleReinforcementTuningRewardConfig defines a single reward function
configuration for RL tuning. Each reward calculation/evaluation consists of
two stages: 1. Stage 1: Parses the part of information important from sample
response via regex extract, or simply takes the sample response unmodified. 2.
Stage 2: Calls the configured reward scorer to compute the reward.
Corresponds to the JSON property singleRewardConfig
66020 66021 66022 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66020 def single_reward_config @single_reward_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66027 66028 66029 66030 66031 66032 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66027 def update!(**args) @composite_reward_config = args[:composite_reward_config] if args.key?(:composite_reward_config) @example = args[:example] if args.key?(:example) @sample_response = args[:sample_response] if args.key?(:sample_response) @single_reward_config = args[:single_reward_config] if args.key?(:single_reward_config) end |