Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for GenAiTuningService.ValidateReinforcementTuningReward.
Instance Attribute Summary collapse
-
#error ⇒ String
Output only.
-
#error_status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#overall_reward ⇒ Float
Output only.
-
#reward_details ⇒ Hash<String,Float>
Output only.
-
#reward_info_details ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo>
A map from reward name to reward info.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse.
68596 68597 68598 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68596 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ String
Output only. Deprecated: Use error_status instead. In case of an error, this
field will be populated with a detailed error message to help with debugging.
Corresponds to the JSON property error
68563 68564 68565 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68563 def error @error end |
#error_status ⇒ Google::Apis::AiplatformV1beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property errorStatus
68573 68574 68575 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68573 def error_status @error_status end |
#overall_reward ⇒ Float
Output only. The overall weighted reward. For a
CompositeReinforcementTuningRewardConfig, this is the weighted average of all
rewards. For a SingleReinforcementTuningRewardConfig, this will be the value
of the single reward.
Corresponds to the JSON property overallReward
68581 68582 68583 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68581 def overall_reward @overall_reward end |
#reward_details ⇒ Hash<String,Float>
Output only. Deprecated: Use reward_info_details instead. A map from reward
name to the calculated reward for the reward function. This field will only be
populated when a CompositeReinforcementTuningRewardConfig is provided in the
request. It will not be set for a SingleReinforcementTuningRewardConfig.
Corresponds to the JSON property rewardDetails
68589 68590 68591 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68589 def reward_details @reward_details end |
#reward_info_details ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo>
A map from reward name to reward info.
Corresponds to the JSON property rewardInfoDetails
68594 68595 68596 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68594 def reward_info_details @reward_info_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68601 68602 68603 68604 68605 68606 68607 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68601 def update!(**args) @error = args[:error] if args.key?(:error) @error_status = args[:error_status] if args.key?(:error_status) @overall_reward = args[:overall_reward] if args.key?(:overall_reward) @reward_details = args[:reward_details] if args.key?(:reward_details) @reward_info_details = args[:reward_info_details] if args.key?(:reward_info_details) end |