Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Response message for GenAiTuningService.ValidateReinforcementTuningReward.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse

Returns a new instance of GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse.



66699
66700
66701
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorString

Output only. In case of an error, this field will be populated with a detailed error message to help with debugging. Corresponds to the JSON property error

Returns:

  • (String)


66676
66677
66678
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66676

def error
  @error
end

#overall_rewardFloat

Output only. The overall weighted reward. For a CompositeReinforcementTuningRewardConfig, this is the weighted average of all rewards. For a SingleReinforcementTuningRewardConfig, this will be the value of the single reward. Corresponds to the JSON property overallReward

Returns:

  • (Float)


66684
66685
66686
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66684

def overall_reward
  @overall_reward
end

#reward_detailsHash<String,Float>

Output only. Deprecated: Use reward_info_details instead. A map from reward name to the calculated reward for the reward function. This field will only be populated when a CompositeReinforcementTuningRewardConfig is provided in the request. It will not be set for a SingleReinforcementTuningRewardConfig. Corresponds to the JSON property rewardDetails

Returns:

  • (Hash<String,Float>)


66692
66693
66694
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66692

def reward_details
  @reward_details
end

#reward_info_detailsHash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo>

A map from reward name to reward info. Corresponds to the JSON property rewardInfoDetails



66697
66698
66699
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66697

def reward_info_details
  @reward_info_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66704
66705
66706
66707
66708
66709
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66704

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @overall_reward = args[:overall_reward] if args.key?(:overall_reward)
  @reward_details = args[:reward_details] if args.key?(:reward_details)
  @reward_info_details = args[:reward_info_details] if args.key?(:reward_info_details)
end