Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for GenAiTuningService.ValidateReinforcementTuningReward.
Instance Attribute Summary collapse
-
#error ⇒ String
Output only.
-
#overall_reward ⇒ Float
Output only.
-
#reward_details ⇒ Hash<String,Float>
Output only.
-
#reward_info_details ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo>
A map from reward name to reward info.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse.
66066 66067 66068 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66066 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ String
Output only. In case of an error, this field will be populated with a detailed
error message to help with debugging.
Corresponds to the JSON property error
66043 66044 66045 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66043 def error @error end |
#overall_reward ⇒ Float
Output only. The overall weighted reward. For a
CompositeReinforcementTuningRewardConfig, this is the weighted average of all
rewards. For a SingleReinforcementTuningRewardConfig, this will be the value
of the single reward.
Corresponds to the JSON property overallReward
66051 66052 66053 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66051 def overall_reward @overall_reward end |
#reward_details ⇒ Hash<String,Float>
Output only. Deprecated: Use reward_info_details instead. A map from reward
name to the calculated reward for the reward function. This field will only be
populated when a CompositeReinforcementTuningRewardConfig is provided in the
request. It will not be set for a SingleReinforcementTuningRewardConfig.
Corresponds to the JSON property rewardDetails
66059 66060 66061 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66059 def reward_details @reward_details end |
#reward_info_details ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo>
A map from reward name to reward info.
Corresponds to the JSON property rewardInfoDetails
66064 66065 66066 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66064 def reward_info_details @reward_info_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66071 66072 66073 66074 66075 66076 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66071 def update!(**args) @error = args[:error] if args.key?(:error) @overall_reward = args[:overall_reward] if args.key?(:overall_reward) @reward_details = args[:reward_details] if args.key?(:reward_details) @reward_info_details = args[:reward_info_details] if args.key?(:reward_info_details) end |