Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Response message for GenAiTuningService.ValidateReinforcementTuningReward.
Instance Attribute Summary collapse
-
#error ⇒ String
Output only.
-
#overall_reward ⇒ Float
Output only.
-
#reward_details ⇒ Hash<String,Float>
Output only.
-
#reward_info_details ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo>
A map from reward name to reward info.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse
Returns a new instance of GoogleCloudAiplatformV1beta1ValidateReinforcementTuningRewardResponse.
64434 64435 64436 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64434 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ String
Output only. In case of an error, this field will be populated with a detailed
error message to help with debugging.
Corresponds to the JSON property error
64411 64412 64413 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64411 def error @error end |
#overall_reward ⇒ Float
Output only. The overall weighted reward. For a
CompositeReinforcementTuningRewardConfig, this is the weighted average of all
rewards. For a SingleReinforcementTuningRewardConfig, this will be the value
of the single reward.
Corresponds to the JSON property overallReward
64419 64420 64421 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64419 def overall_reward @overall_reward end |
#reward_details ⇒ Hash<String,Float>
Output only. Deprecated: Use reward_info_details instead. A map from reward
name to the calculated reward for the reward function. This field will only be
populated when a CompositeReinforcementTuningRewardConfig is provided in the
request. It will not be set for a SingleReinforcementTuningRewardConfig.
Corresponds to the JSON property rewardDetails
64427 64428 64429 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64427 def reward_details @reward_details end |
#reward_info_details ⇒ Hash<String,Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ReinforcementTuningRewardInfo>
A map from reward name to reward info.
Corresponds to the JSON property rewardInfoDetails
64432 64433 64434 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64432 def reward_info_details @reward_info_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64439 64440 64441 64442 64443 64444 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64439 def update!(**args) @error = args[:error] if args.key?(:error) @overall_reward = args[:overall_reward] if args.key?(:overall_reward) @reward_details = args[:reward_details] if args.key?(:reward_details) @reward_info_details = args[:reward_info_details] if args.key?(:reward_info_details) end |