Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoHyperParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Hyperparameters for Veo.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VeoHyperParameters

Returns a new instance of GoogleCloudAiplatformV1beta1VeoHyperParameters.



65970
65971
65972
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adapter_sizeString

Optional. The adapter size for LoRA tuning. Corresponds to the JSON property adapterSize

Returns:

  • (String)


65939
65940
65941
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65939

def adapter_size
  @adapter_size
end

#epoch_countFixnum

Optional. Number of complete passes the model makes over the entire training dataset during training. Corresponds to the JSON property epochCount

Returns:

  • (Fixnum)


65945
65946
65947
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65945

def epoch_count
  @epoch_count
end

#learning_rate_multiplierFloat

Optional. Multiplier for adjusting the default learning rate. Corresponds to the JSON property learningRateMultiplier

Returns:

  • (Float)


65950
65951
65952
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65950

def learning_rate_multiplier
  @learning_rate_multiplier
end

#tuning_speedString

The speed of the tuning job. Only supported for Veo 3.0 models. Corresponds to the JSON property tuningSpeed

Returns:

  • (String)


65955
65956
65957
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65955

def tuning_speed
  @tuning_speed
end

#tuning_taskString

The tuning task for Veo. Corresponds to the JSON property tuningTask

Returns:

  • (String)


65960
65961
65962
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65960

def tuning_task
  @tuning_task
end

#veo_data_mixture_ratioFloat

Optional. The ratio of Google internal dataset to use in the training mixture, in range of [0, 1). If 0.2, it means 20% of Google internal dataset and 80% of user dataset will be used for training. If not set, the default value is 0. 1. Corresponds to the JSON property veoDataMixtureRatio

Returns:

  • (Float)


65968
65969
65970
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65968

def veo_data_mixture_ratio
  @veo_data_mixture_ratio
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65975
65976
65977
65978
65979
65980
65981
65982
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 65975

def update!(**args)
  @adapter_size = args[:adapter_size] if args.key?(:adapter_size)
  @epoch_count = args[:epoch_count] if args.key?(:epoch_count)
  @learning_rate_multiplier = args[:learning_rate_multiplier] if args.key?(:learning_rate_multiplier)
  @tuning_speed = args[:tuning_speed] if args.key?(:tuning_speed)
  @tuning_task = args[:tuning_task] if args.key?(:tuning_task)
  @veo_data_mixture_ratio = args[:veo_data_mixture_ratio] if args.key?(:veo_data_mixture_ratio)
end