Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoHyperParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Hyperparameters for Veo.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VeoHyperParameters

Returns a new instance of GoogleCloudAiplatformV1beta1VeoHyperParameters.



62925
62926
62927
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62925

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adapter_sizeString

Optional. The adapter size for LoRA tuning. Corresponds to the JSON property adapterSize

Returns:

  • (String)


62894
62895
62896
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62894

def adapter_size
  @adapter_size
end

#epoch_countFixnum

Optional. Number of complete passes the model makes over the entire training dataset during training. Corresponds to the JSON property epochCount

Returns:

  • (Fixnum)


62900
62901
62902
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62900

def epoch_count
  @epoch_count
end

#learning_rate_multiplierFloat

Optional. Multiplier for adjusting the default learning rate. Corresponds to the JSON property learningRateMultiplier

Returns:

  • (Float)


62905
62906
62907
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62905

def learning_rate_multiplier
  @learning_rate_multiplier
end

#tuning_speedString

The speed of the tuning job. Only supported for Veo 3.0 models. Corresponds to the JSON property tuningSpeed

Returns:

  • (String)


62910
62911
62912
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62910

def tuning_speed
  @tuning_speed
end

#tuning_taskString

The tuning task for Veo. Corresponds to the JSON property tuningTask

Returns:

  • (String)


62915
62916
62917
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62915

def tuning_task
  @tuning_task
end

#veo_data_mixture_ratioFloat

Optional. The ratio of Google internal dataset to use in the training mixture, in range of [0, 1). If 0.2, it means 20% of Google internal dataset and 80% of user dataset will be used for training. If not set, the default value is 0. 1. Corresponds to the JSON property veoDataMixtureRatio

Returns:

  • (Float)


62923
62924
62925
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62923

def veo_data_mixture_ratio
  @veo_data_mixture_ratio
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62930
62931
62932
62933
62934
62935
62936
62937
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62930

def update!(**args)
  @adapter_size = args[:adapter_size] if args.key?(:adapter_size)
  @epoch_count = args[:epoch_count] if args.key?(:epoch_count)
  @learning_rate_multiplier = args[:learning_rate_multiplier] if args.key?(:learning_rate_multiplier)
  @tuning_speed = args[:tuning_speed] if args.key?(:tuning_speed)
  @tuning_task = args[:tuning_task] if args.key?(:tuning_task)
  @veo_data_mixture_ratio = args[:veo_data_mixture_ratio] if args.key?(:veo_data_mixture_ratio)
end