Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoHyperParameters
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoHyperParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Hyperparameters for Veo.
Instance Attribute Summary collapse
-
#adapter_size ⇒ String
Optional.
-
#epoch_count ⇒ Fixnum
Optional.
-
#learning_rate_multiplier ⇒ Float
Optional.
-
#tuning_speed ⇒ String
The speed of the tuning job.
-
#tuning_task ⇒ String
The tuning task for Veo.
-
#veo_data_mixture_ratio ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VeoHyperParameters
constructor
A new instance of GoogleCloudAiplatformV1beta1VeoHyperParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VeoHyperParameters
Returns a new instance of GoogleCloudAiplatformV1beta1VeoHyperParameters.
57710 57711 57712 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57710 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adapter_size ⇒ String
Optional. The adapter size for LoRA tuning.
Corresponds to the JSON property adapterSize
57679 57680 57681 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57679 def adapter_size @adapter_size end |
#epoch_count ⇒ Fixnum
Optional. Number of complete passes the model makes over the entire training
dataset during training.
Corresponds to the JSON property epochCount
57685 57686 57687 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57685 def epoch_count @epoch_count end |
#learning_rate_multiplier ⇒ Float
Optional. Multiplier for adjusting the default learning rate.
Corresponds to the JSON property learningRateMultiplier
57690 57691 57692 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57690 def learning_rate_multiplier @learning_rate_multiplier end |
#tuning_speed ⇒ String
The speed of the tuning job. Only supported for Veo 3.0 models.
Corresponds to the JSON property tuningSpeed
57695 57696 57697 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57695 def tuning_speed @tuning_speed end |
#tuning_task ⇒ String
The tuning task for Veo.
Corresponds to the JSON property tuningTask
57700 57701 57702 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57700 def tuning_task @tuning_task end |
#veo_data_mixture_ratio ⇒ Float
Optional. The ratio of Google internal dataset to use in the training mixture,
in range of [0, 1). If 0.2, it means 20% of Google internal dataset and 80%
of user dataset will be used for training. If not set, the default value is 0.
1.
Corresponds to the JSON property veoDataMixtureRatio
57708 57709 57710 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57708 def veo_data_mixture_ratio @veo_data_mixture_ratio end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57715 57716 57717 57718 57719 57720 57721 57722 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57715 def update!(**args) @adapter_size = args[:adapter_size] if args.key?(:adapter_size) @epoch_count = args[:epoch_count] if args.key?(:epoch_count) @learning_rate_multiplier = args[:learning_rate_multiplier] if args.key?(:learning_rate_multiplier) @tuning_speed = args[:tuning_speed] if args.key?(:tuning_speed) @tuning_task = args[:tuning_task] if args.key?(:tuning_task) @veo_data_mixture_ratio = args[:veo_data_mixture_ratio] if args.key?(:veo_data_mixture_ratio) end |