Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Tuning Spec for Veo LoRA Model Tuning.
Instance Attribute Summary collapse
-
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoHyperParameters
Hyperparameters for Veo.
-
#training_dataset_uri ⇒ String
Required.
-
#validation_dataset_uri ⇒ String
Optional.
-
#video_orientation ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1VeoLoraTuningSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
Returns a new instance of GoogleCloudAiplatformV1beta1VeoLoraTuningSpec.
64559 64560 64561 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64559 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoHyperParameters
Hyperparameters for Veo.
Corresponds to the JSON property hyperParameters
64538 64539 64540 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64538 def hyper_parameters @hyper_parameters end |
#training_dataset_uri ⇒ String
Required. Training dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property trainingDatasetUri
64545 64546 64547 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64545 def training_dataset_uri @training_dataset_uri end |
#validation_dataset_uri ⇒ String
Optional. Validation dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property validationDatasetUri
64552 64553 64554 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64552 def validation_dataset_uri @validation_dataset_uri end |
#video_orientation ⇒ String
Optional. The orientation of the video. Defaults to LANDSCAPE.
Corresponds to the JSON property videoOrientation
64557 64558 64559 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64557 def video_orientation @video_orientation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64564 64565 64566 64567 64568 64569 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64564 def update!(**args) @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters) @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri) @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri) @video_orientation = args[:video_orientation] if args.key?(:video_orientation) end |