Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Tuning Spec for Veo LoRA Model Tuning.
Instance Attribute Summary collapse
-
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoHyperParameters
Hyperparameters for Veo.
-
#training_dataset_uri ⇒ String
Required.
-
#validation_dataset_uri ⇒ String
Optional.
-
#video_orientation ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1VeoLoraTuningSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
Returns a new instance of GoogleCloudAiplatformV1beta1VeoLoraTuningSpec.
62968 62969 62970 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62968 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoHyperParameters
Hyperparameters for Veo.
Corresponds to the JSON property hyperParameters
62947 62948 62949 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62947 def hyper_parameters @hyper_parameters end |
#training_dataset_uri ⇒ String
Required. Training dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property trainingDatasetUri
62954 62955 62956 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62954 def training_dataset_uri @training_dataset_uri end |
#validation_dataset_uri ⇒ String
Optional. Validation dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property validationDatasetUri
62961 62962 62963 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62961 def validation_dataset_uri @validation_dataset_uri end |
#video_orientation ⇒ String
Optional. The orientation of the video. Defaults to LANDSCAPE.
Corresponds to the JSON property videoOrientation
62966 62967 62968 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62966 def video_orientation @video_orientation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62973 62974 62975 62976 62977 62978 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 62973 def update!(**args) @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters) @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri) @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri) @video_orientation = args[:video_orientation] if args.key?(:video_orientation) end |