Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Tuning Spec for Veo LoRA Model Tuning.
Instance Attribute Summary collapse
-
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoHyperParameters
Hyperparameters for Veo.
-
#training_dataset_uri ⇒ String
Required.
-
#validation_dataset_uri ⇒ String
Optional.
-
#video_orientation ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1VeoLoraTuningSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VeoLoraTuningSpec
Returns a new instance of GoogleCloudAiplatformV1beta1VeoLoraTuningSpec.
57923 57924 57925 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57923 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hyper_parameters ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VeoHyperParameters
Hyperparameters for Veo.
Corresponds to the JSON property hyperParameters
57902 57903 57904 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57902 def hyper_parameters @hyper_parameters end |
#training_dataset_uri ⇒ String
Required. Training dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property trainingDatasetUri
57909 57910 57911 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57909 def training_dataset_uri @training_dataset_uri end |
#validation_dataset_uri ⇒ String
Optional. Validation dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property validationDatasetUri
57916 57917 57918 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57916 def validation_dataset_uri @validation_dataset_uri end |
#video_orientation ⇒ String
Optional. The orientation of the video. Defaults to LANDSCAPE.
Corresponds to the JSON property videoOrientation
57921 57922 57923 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57921 def video_orientation @video_orientation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57928 57929 57930 57931 57932 57933 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57928 def update!(**args) @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters) @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri) @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri) @video_orientation = args[:video_orientation] if args.key?(:video_orientation) end |