Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexAiSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Retrieve from Vertex AI Search datastore or engine for grounding. datastore and engine are mutually exclusive. See https://cloud.google.com/products/agent- builder

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VertexAiSearch

Returns a new instance of GoogleCloudAiplatformV1beta1VertexAiSearch.



58009
58010
58011
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_store_specsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexAiSearchDataStoreSpec>

Specifications that define the specific DataStores to be searched, along with configurations for those data stores. This is only considered for Engines with multiple data stores. It should only be set if engine is used. Corresponds to the JSON property dataStoreSpecs



57982
57983
57984
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57982

def data_store_specs
  @data_store_specs
end

#datastoreString

Optional. Fully-qualified Vertex AI Search data store resource ID. Format: projects/project/locations/location/collections/collection/dataStores/ dataStore` Corresponds to the JSON propertydatastore`

Returns:

  • (String)


57989
57990
57991
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57989

def datastore
  @datastore
end

#engineString

Optional. Fully-qualified Vertex AI Search engine resource ID. Format: projects/project/locations/location/collections/collection/engines/ engine` Corresponds to the JSON propertyengine`

Returns:

  • (String)


57996
57997
57998
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 57996

def engine
  @engine
end

#filterString

Optional. Filter strings to be passed to the search API. Corresponds to the JSON property filter

Returns:

  • (String)


58001
58002
58003
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58001

def filter
  @filter
end

#max_resultsFixnum

Optional. Number of search results to return per query. The default value is

  1. The maximumm allowed value is 10. Corresponds to the JSON property maxResults

Returns:

  • (Fixnum)


58007
58008
58009
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58007

def max_results
  @max_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58014
58015
58016
58017
58018
58019
58020
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58014

def update!(**args)
  @data_store_specs = args[:data_store_specs] if args.key?(:data_store_specs)
  @datastore = args[:datastore] if args.key?(:datastore)
  @engine = args[:engine] if args.key?(:engine)
  @filter = args[:filter] if args.key?(:filter)
  @max_results = args[:max_results] if args.key?(:max_results)
end