Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexRagStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Retrieve from Vertex RAG Store for grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VertexRagStore

Returns a new instance of GoogleCloudAiplatformV1beta1VertexRagStore.



67064
67065
67066
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rag_corporaArray<String>

Optional. Deprecated. Please use rag_resources instead. Corresponds to the JSON property ragCorpora

Returns:

  • (Array<String>)


67030
67031
67032
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67030

def rag_corpora
  @rag_corpora
end

#rag_resourcesArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexRagStoreRagResource>

Optional. The representation of the rag source. It can be used to specify corpus only or ragfiles. Currently only support one corpus or multiple files from one corpus. In the future we may open up multiple corpora support. Corresponds to the JSON property ragResources



67037
67038
67039
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67037

def rag_resources
  @rag_resources
end

#rag_retrieval_configGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagRetrievalConfig

Specifies the context retrieval config. Corresponds to the JSON property ragRetrievalConfig



67042
67043
67044
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67042

def rag_retrieval_config
  @rag_retrieval_config
end

#similarity_top_kFixnum

Optional. Number of top k results to return from the selected corpora. Corresponds to the JSON property similarityTopK

Returns:

  • (Fixnum)


67047
67048
67049
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67047

def similarity_top_k
  @similarity_top_k
end

#store_contextBoolean Also known as: store_context?

Optional. Currently only supported for Gemini Multimodal Live API. In Gemini Multimodal Live API, if store_context bool is specified, Gemini will leverage it to automatically memorize the interactions between the client and Gemini, and retrieve context when needed to augment the response generation for users' ongoing and future interactions. Corresponds to the JSON property storeContext

Returns:

  • (Boolean)


67056
67057
67058
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67056

def store_context
  @store_context
end

#vector_distance_thresholdFloat

Optional. Only return results with vector distance smaller than the threshold. Corresponds to the JSON property vectorDistanceThreshold

Returns:

  • (Float)


67062
67063
67064
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67062

def vector_distance_threshold
  @vector_distance_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67069
67070
67071
67072
67073
67074
67075
67076
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 67069

def update!(**args)
  @rag_corpora = args[:rag_corpora] if args.key?(:rag_corpora)
  @rag_resources = args[:rag_resources] if args.key?(:rag_resources)
  @rag_retrieval_config = args[:rag_retrieval_config] if args.key?(:rag_retrieval_config)
  @similarity_top_k = args[:similarity_top_k] if args.key?(:similarity_top_k)
  @store_context = args[:store_context] if args.key?(:store_context)
  @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold)
end