Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexRagStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexRagStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Retrieve from Vertex RAG Store for grounding.
Instance Attribute Summary collapse
-
#rag_corpora ⇒ Array<String>
Optional.
-
#rag_resources ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexRagStoreRagResource>
Optional.
-
#rag_retrieval_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagRetrievalConfig
Specifies the context retrieval config.
-
#similarity_top_k ⇒ Fixnum
Optional.
-
#store_context ⇒ Boolean
(also: #store_context?)
Optional.
-
#vector_distance_threshold ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VertexRagStore
constructor
A new instance of GoogleCloudAiplatformV1beta1VertexRagStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VertexRagStore
Returns a new instance of GoogleCloudAiplatformV1beta1VertexRagStore.
58163 58164 58165 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58163 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rag_corpora ⇒ Array<String>
Optional. Deprecated. Please use rag_resources instead.
Corresponds to the JSON property ragCorpora
58129 58130 58131 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58129 def rag_corpora @rag_corpora end |
#rag_resources ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VertexRagStoreRagResource>
Optional. The representation of the rag source. It can be used to specify
corpus only or ragfiles. Currently only support one corpus or multiple files
from one corpus. In the future we may open up multiple corpora support.
Corresponds to the JSON property ragResources
58136 58137 58138 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58136 def rag_resources @rag_resources end |
#rag_retrieval_config ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1RagRetrievalConfig
Specifies the context retrieval config.
Corresponds to the JSON property ragRetrievalConfig
58141 58142 58143 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58141 def rag_retrieval_config @rag_retrieval_config end |
#similarity_top_k ⇒ Fixnum
Optional. Number of top k results to return from the selected corpora.
Corresponds to the JSON property similarityTopK
58146 58147 58148 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58146 def similarity_top_k @similarity_top_k end |
#store_context ⇒ Boolean Also known as: store_context?
Optional. Currently only supported for Gemini Multimodal Live API. In Gemini
Multimodal Live API, if store_context bool is specified, Gemini will
leverage it to automatically memorize the interactions between the client and
Gemini, and retrieve context when needed to augment the response generation
for users' ongoing and future interactions.
Corresponds to the JSON property storeContext
58155 58156 58157 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58155 def store_context @store_context end |
#vector_distance_threshold ⇒ Float
Optional. Only return results with vector distance smaller than the threshold.
Corresponds to the JSON property vectorDistanceThreshold
58161 58162 58163 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58161 def vector_distance_threshold @vector_distance_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58168 58169 58170 58171 58172 58173 58174 58175 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58168 def update!(**args) @rag_corpora = args[:rag_corpora] if args.key?(:rag_corpora) @rag_resources = args[:rag_resources] if args.key?(:rag_resources) @rag_retrieval_config = args[:rag_retrieval_config] if args.key?(:rag_retrieval_config) @similarity_top_k = args[:similarity_top_k] if args.key?(:similarity_top_k) @store_context = args[:store_context] if args.key?(:store_context) @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold) end |