Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VideoMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Provides metadata for a video, including the start and end offsets for clipping and the frame rate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VideoMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1VideoMetadata.



66494
66495
66496
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_offsetString

Optional. The end offset of the video. Corresponds to the JSON property endOffset

Returns:

  • (String)


66481
66482
66483
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66481

def end_offset
  @end_offset
end

#fpsFloat

Optional. The frame rate of the video sent to the model. If not specified, the default value is 1.0. The valid range is (0.0, 24.0]. Corresponds to the JSON property fps

Returns:

  • (Float)


66487
66488
66489
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66487

def fps
  @fps
end

#start_offsetString

Optional. The start offset of the video. Corresponds to the JSON property startOffset

Returns:

  • (String)


66492
66493
66494
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66492

def start_offset
  @start_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66499
66500
66501
66502
66503
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66499

def update!(**args)
  @end_offset = args[:end_offset] if args.key?(:end_offset)
  @fps = args[:fps] if args.key?(:fps)
  @start_offset = args[:start_offset] if args.key?(:start_offset)
end