Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VideoMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VideoMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Provides metadata for a video, including the start and end offsets for clipping and the frame rate.
Instance Attribute Summary collapse
-
#end_offset ⇒ String
Optional.
-
#fps ⇒ Float
Optional.
-
#start_offset ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VideoMetadata
constructor
A new instance of GoogleCloudAiplatformV1beta1VideoMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VideoMetadata
Returns a new instance of GoogleCloudAiplatformV1beta1VideoMetadata.
63271 63272 63273 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_offset ⇒ String
Optional. The end offset of the video.
Corresponds to the JSON property endOffset
63258 63259 63260 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63258 def end_offset @end_offset end |
#fps ⇒ Float
Optional. The frame rate of the video sent to the model. If not specified, the
default value is 1.0. The valid range is (0.0, 24.0].
Corresponds to the JSON property fps
63264 63265 63266 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63264 def fps @fps end |
#start_offset ⇒ String
Optional. The start offset of the video.
Corresponds to the JSON property startOffset
63269 63270 63271 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63269 def start_offset @start_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63276 63277 63278 63279 63280 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 63276 def update!(**args) @end_offset = args[:end_offset] if args.key?(:end_offset) @fps = args[:fps] if args.key?(:fps) @start_offset = args[:start_offset] if args.key?(:start_offset) end |