Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VideoMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1VideoMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Provides metadata for a video, including the start and end offsets for clipping and the frame rate.
Instance Attribute Summary collapse
-
#end_offset ⇒ String
Optional.
-
#fps ⇒ Float
Optional.
-
#start_offset ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VideoMetadata
constructor
A new instance of GoogleCloudAiplatformV1beta1VideoMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VideoMetadata
Returns a new instance of GoogleCloudAiplatformV1beta1VideoMetadata.
58226 58227 58228 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58226 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_offset ⇒ String
Optional. The end offset of the video.
Corresponds to the JSON property endOffset
58213 58214 58215 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58213 def end_offset @end_offset end |
#fps ⇒ Float
Optional. The frame rate of the video sent to the model. If not specified, the
default value is 1.0. The valid range is (0.0, 24.0].
Corresponds to the JSON property fps
58219 58220 58221 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58219 def fps @fps end |
#start_offset ⇒ String
Optional. The start offset of the video.
Corresponds to the JSON property startOffset
58224 58225 58226 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58224 def start_offset @start_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58231 58232 58233 58234 58235 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 58231 def update!(**args) @end_offset = args[:end_offset] if args.key?(:end_offset) @fps = args[:fps] if args.key?(:fps) @start_offset = args[:start_offset] if args.key?(:start_offset) end |