Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1WorkerPoolSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1WorkerPoolSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
Represents the spec of a worker pool in a job.
Instance Attribute Summary collapse
-
#container_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContainerSpec
The spec of a Container.
-
#disk_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DiskSpec
Represents the spec of disk options.
-
#lustre_mounts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LustreMount>
Optional.
-
#machine_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec
Specification of a single machine.
-
#nfs_mounts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NfsMount>
Optional.
-
#python_package_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PythonPackageSpec
The spec of a Python packaged code.
-
#replica_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1WorkerPoolSpec
constructor
A new instance of GoogleCloudAiplatformV1beta1WorkerPoolSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1WorkerPoolSpec
Returns a new instance of GoogleCloudAiplatformV1beta1WorkerPoolSpec.
69402 69403 69404 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69402 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContainerSpec
The spec of a Container.
Corresponds to the JSON property containerSpec
69370 69371 69372 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69370 def container_spec @container_spec end |
#disk_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DiskSpec
Represents the spec of disk options.
Corresponds to the JSON property diskSpec
69375 69376 69377 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69375 def disk_spec @disk_spec end |
#lustre_mounts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LustreMount>
Optional. List of Lustre mounts.
Corresponds to the JSON property lustreMounts
69380 69381 69382 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69380 def lustre_mounts @lustre_mounts end |
#machine_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
69385 69386 69387 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69385 def machine_spec @machine_spec end |
#nfs_mounts ⇒ Array<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NfsMount>
Optional. List of NFS mount spec.
Corresponds to the JSON property nfsMounts
69390 69391 69392 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69390 def nfs_mounts @nfs_mounts end |
#python_package_spec ⇒ Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PythonPackageSpec
The spec of a Python packaged code.
Corresponds to the JSON property pythonPackageSpec
69395 69396 69397 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69395 def python_package_spec @python_package_spec end |
#replica_count ⇒ Fixnum
Optional. The number of worker replicas to use for this worker pool.
Corresponds to the JSON property replicaCount
69400 69401 69402 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69400 def replica_count @replica_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69407 69408 69409 69410 69411 69412 69413 69414 69415 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69407 def update!(**args) @container_spec = args[:container_spec] if args.key?(:container_spec) @disk_spec = args[:disk_spec] if args.key?(:disk_spec) @lustre_mounts = args[:lustre_mounts] if args.key?(:lustre_mounts) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @nfs_mounts = args[:nfs_mounts] if args.key?(:nfs_mounts) @python_package_spec = args[:python_package_spec] if args.key?(:python_package_spec) @replica_count = args[:replica_count] if args.key?(:replica_count) end |