Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1WorkerPoolSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents the spec of a worker pool in a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1WorkerPoolSpec

Returns a new instance of GoogleCloudAiplatformV1beta1WorkerPoolSpec.



66430
66431
66432
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66430

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContainerSpec

The spec of a Container. Corresponds to the JSON property containerSpec



66398
66399
66400
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66398

def container_spec
  @container_spec
end

#disk_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DiskSpec

Represents the spec of disk options. Corresponds to the JSON property diskSpec



66403
66404
66405
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66403

def disk_spec
  @disk_spec
end

#lustre_mountsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LustreMount>

Optional. List of Lustre mounts. Corresponds to the JSON property lustreMounts



66408
66409
66410
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66408

def lustre_mounts
  @lustre_mounts
end

#machine_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



66413
66414
66415
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66413

def machine_spec
  @machine_spec
end

#nfs_mountsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NfsMount>

Optional. List of NFS mount spec. Corresponds to the JSON property nfsMounts



66418
66419
66420
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66418

def nfs_mounts
  @nfs_mounts
end

#python_package_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PythonPackageSpec

The spec of a Python packaged code. Corresponds to the JSON property pythonPackageSpec



66423
66424
66425
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66423

def python_package_spec
  @python_package_spec
end

#replica_countFixnum

Optional. The number of worker replicas to use for this worker pool. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


66428
66429
66430
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66428

def replica_count
  @replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66435
66436
66437
66438
66439
66440
66441
66442
66443
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66435

def update!(**args)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @disk_spec = args[:disk_spec] if args.key?(:disk_spec)
  @lustre_mounts = args[:lustre_mounts] if args.key?(:lustre_mounts)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @nfs_mounts = args[:nfs_mounts] if args.key?(:nfs_mounts)
  @python_package_spec = args[:python_package_spec] if args.key?(:python_package_spec)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
end