Class: Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1WorkerPoolSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

Represents the spec of a worker pool in a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1WorkerPoolSpec

Returns a new instance of GoogleCloudAiplatformV1beta1WorkerPoolSpec.



64938
64939
64940
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64938

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1ContainerSpec

The spec of a Container. Corresponds to the JSON property containerSpec



64906
64907
64908
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64906

def container_spec
  @container_spec
end

#disk_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1DiskSpec

Represents the spec of disk options. Corresponds to the JSON property diskSpec



64911
64912
64913
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64911

def disk_spec
  @disk_spec
end

#lustre_mountsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1LustreMount>

Optional. List of Lustre mounts. Corresponds to the JSON property lustreMounts



64916
64917
64918
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64916

def lustre_mounts
  @lustre_mounts
end

#machine_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



64921
64922
64923
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64921

def machine_spec
  @machine_spec
end

#nfs_mountsArray<Google::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1NfsMount>

Optional. List of NFS mount spec. Corresponds to the JSON property nfsMounts



64926
64927
64928
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64926

def nfs_mounts
  @nfs_mounts
end

#python_package_specGoogle::Apis::AiplatformV1beta1::GoogleCloudAiplatformV1beta1PythonPackageSpec

The spec of a Python packaged code. Corresponds to the JSON property pythonPackageSpec



64931
64932
64933
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64931

def python_package_spec
  @python_package_spec
end

#replica_countFixnum

Optional. The number of worker replicas to use for this worker pool. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


64936
64937
64938
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64936

def replica_count
  @replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64943
64944
64945
64946
64947
64948
64949
64950
64951
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 64943

def update!(**args)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @disk_spec = args[:disk_spec] if args.key?(:disk_spec)
  @lustre_mounts = args[:lustre_mounts] if args.key?(:lustre_mounts)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @nfs_mounts = args[:nfs_mounts] if args.key?(:nfs_mounts)
  @python_package_spec = args[:python_package_spec] if args.key?(:python_package_spec)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
end