Class: Google::Apis::AiplatformV1beta1::GoogleCloudLocationLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb

Overview

A resource that represents a Google Cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudLocationLocation

Returns a new instance of GoogleCloudLocationLocation.



68809
68810
68811
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68809

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The friendly name for this location, typically a nearby city name. For example, "Tokyo". Corresponds to the JSON property displayName

Returns:

  • (String)


68784
68785
68786
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68784

def display_name
  @display_name
end

#labelsHash<String,String>

Cross-service attributes for the location. For example "cloud.googleapis.com/ region": "us-east1" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


68790
68791
68792
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68790

def labels
  @labels
end

#location_idString

The canonical id for this location. For example: "us-east1". Corresponds to the JSON property locationId

Returns:

  • (String)


68795
68796
68797
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68795

def location_id
  @location_id
end

#metadataHash<String,Object>

Service-specific metadata. For example the available capacity at the given location. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


68801
68802
68803
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68801

def 
  @metadata
end

#nameString

Resource name for the location, which may vary between implementations. For example: "projects/example-project/locations/us-east1" Corresponds to the JSON property name

Returns:

  • (String)


68807
68808
68809
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68807

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68814
68815
68816
68817
68818
68819
68820
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 68814

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location_id = args[:location_id] if args.key?(:location_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end