Class: Google::Apis::AiplatformV1beta1::GoogleCloudLocationLocation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleCloudLocationLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
A resource that represents a Google Cloud location.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The friendly name for this location, typically a nearby city name.
-
#labels ⇒ Hash<String,String>
Cross-service attributes for the location.
-
#location_id ⇒ String
The canonical id for this location.
-
#metadata ⇒ Hash<String,Object>
Service-specific metadata.
-
#name ⇒ String
Resource name for the location, which may vary between implementations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudLocationLocation
constructor
A new instance of GoogleCloudLocationLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudLocationLocation
Returns a new instance of GoogleCloudLocationLocation.
66861 66862 66863 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66861 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The friendly name for this location, typically a nearby city name. For example,
"Tokyo".
Corresponds to the JSON property displayName
66836 66837 66838 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66836 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Cross-service attributes for the location. For example "cloud.googleapis.com/
region": "us-east1"
Corresponds to the JSON property labels
66842 66843 66844 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66842 def labels @labels end |
#location_id ⇒ String
The canonical id for this location. For example: "us-east1".
Corresponds to the JSON property locationId
66847 66848 66849 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66847 def location_id @location_id end |
#metadata ⇒ Hash<String,Object>
Service-specific metadata. For example the available capacity at the given
location.
Corresponds to the JSON property metadata
66853 66854 66855 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66853 def @metadata end |
#name ⇒ String
Resource name for the location, which may vary between implementations. For
example: "projects/example-project/locations/us-east1"
Corresponds to the JSON property name
66859 66860 66861 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66859 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66866 66867 66868 66869 66870 66871 66872 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 66866 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @location_id = args[:location_id] if args.key?(:location_id) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) end |