Class: Google::Apis::AiplatformV1beta1::GoogleRpcStatus
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1beta1::GoogleRpcStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1beta1/classes.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb,
lib/google/apis/aiplatform_v1beta1/representations.rb
Overview
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Instance Attribute Summary collapse
-
#code ⇒ Fixnum
The status code, which should be an enum value of google.rpc.Code.
-
#details ⇒ Array<Hash<String,Object>>
A list of messages that carry the error details.
-
#message ⇒ String
A developer-facing error message, which should be in English.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleRpcStatus
constructor
A new instance of GoogleRpcStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleRpcStatus
Returns a new instance of GoogleRpcStatus.
69284 69285 69286 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69284 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ Fixnum
The status code, which should be an enum value of google.rpc.Code.
Corresponds to the JSON property code
69269 69270 69271 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69269 def code @code end |
#details ⇒ Array<Hash<String,Object>>
A list of messages that carry the error details. There is a common set of
message types for APIs to use.
Corresponds to the JSON property details
69275 69276 69277 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69275 def details @details end |
#message ⇒ String
A developer-facing error message, which should be in English. Any user-facing
error message should be localized and sent in the google.rpc.Status.details
field, or localized by the client.
Corresponds to the JSON property message
69282 69283 69284 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69282 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69289 69290 69291 69292 69293 |
# File 'lib/google/apis/aiplatform_v1beta1/classes.rb', line 69289 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @message = args[:message] if args.key?(:message) end |